@@ -13,9 +13,9 @@ import pkgconfig
 
 # CBLAS can be one of multiple implementations
 cblas_pc = pkgconfig.parse('cblas')
-cblas_libs = list(cblas_pc['libraries'])
-cblas_library_dirs = list(cblas_pc['library_dirs'])
-cblas_include_dirs = list(cblas_pc['include_dirs'])
+cblas_libs = cblas_pc['libraries']
+cblas_library_dirs = cblas_pc['library_dirs']
+cblas_include_dirs = cblas_pc['include_dirs']
 
 # TODO: Remove Cygwin hack by installing a suitable cblas.pc
 if os.path.exists('/usr/lib/libblas.dll.a'):
@@ -23,52 +23,59 @@ if os.path.exists('/usr/lib/libblas.dll.a'):
 
 # LAPACK can be one of multiple implementations
 lapack_pc = pkgconfig.parse('lapack')
-lapack_libs = list(lapack_pc['libraries'])
-lapack_library_dirs = list(lapack_pc['library_dirs'])
-lapack_include_dirs = list(lapack_pc['include_dirs'])
+lapack_libs = lapack_pc['libraries']
+lapack_library_dirs = lapack_pc['library_dirs']
+lapack_include_dirs = lapack_pc['include_dirs']
 
 # FFLAS-FFPACK
 fflas_ffpack_pc = pkgconfig.parse('fflas-ffpack')
-fflas_ffpack_libs = list(fflas_ffpack_pc['libraries'])
-fflas_ffpack_library_dirs = list(fflas_ffpack_pc['library_dirs'])
+fflas_ffpack_libs = fflas_ffpack_pc['libraries']
+fflas_ffpack_library_dirs = fflas_ffpack_pc['library_dirs']
 fflas_ffpack_cflags = pkgconfig.cflags('fflas-ffpack').split()
 
 # Givaro
 givaro_pc = pkgconfig.parse('givaro')
-givaro_libs = list(givaro_pc['libraries'])
-givaro_library_dirs = list(givaro_pc['library_dirs'])
+givaro_libs = givaro_pc['libraries']
+givaro_library_dirs = givaro_pc['library_dirs']
 givaro_cflags = pkgconfig.cflags('givaro').split()
 
 # GNU Scientific Library
-# Note we replace the built-in gslcblas with the above cblas
+# The default gslcblas is removed in the gsl spkg - not need to remove it.
+# The above cblas should already be in the list thanks to #20646
 gsl_pc = pkgconfig.parse('gsl')
-gsl_libs = list(gsl_pc['libraries'].difference(['gslcblas']).union(cblas_libs))
-gsl_library_dirs = list(gsl_pc['library_dirs'])
-gsl_include_dirs = list(gsl_pc['include_dirs'])
+gsl_libs = gsl_pc['libraries']
+gsl_library_dirs = gsl_pc['library_dirs']
+gsl_include_dirs = gsl_pc['include_dirs']
 
 # GD image library
 gd_pc = pkgconfig.parse('gdlib')
-gd_libs = list(gd_pc['libraries'])
-gd_library_dirs = list(gd_pc['library_dirs'])
-gd_include_dirs = list(gd_pc['include_dirs'])
+gd_libs = gd_pc['libraries']
+gd_library_dirs = gd_pc['library_dirs']
+gd_include_dirs = gd_pc['include_dirs']
 
 # LinBox
 linbox_pc = pkgconfig.parse('linbox')
-linbox_libs = list(linbox_pc['libraries'])
-linbox_library_dirs = list(linbox_pc['library_dirs'])
+linbox_libs = linbox_pc['libraries']
+linbox_library_dirs = linbox_pc['library_dirs']
 linbox_cflags = pkgconfig.cflags('linbox').split()
 
+# Singular
+singular_pc = pkgconfig.parse('Singular')
+singular_libs = singular_pc['libraries']
+singular_library_dirs = singular_pc['library_dirs']
+singular_cflags = pkgconfig.cflags('Singular').split()
+
 # PNG image library
 png_pc = pkgconfig.parse('libpng')
-png_libs = list(png_pc['libraries'])
-png_library_dirs = list(png_pc['library_dirs'])
-png_include_dirs = list(png_pc['include_dirs'])
+png_libs = png_pc['libraries']
+png_library_dirs = png_pc['library_dirs']
+png_include_dirs = png_pc['include_dirs']
 
 # zlib
 zlib_pc = pkgconfig.parse('zlib')
-zlib_libs = list(zlib_pc['libraries'])
-zlib_library_dirs = list(zlib_pc['library_dirs'])
-zlib_include_dirs = list(zlib_pc['include_dirs'])
+zlib_libs = zlib_pc['libraries']
+zlib_library_dirs = zlib_pc['library_dirs']
+zlib_include_dirs = zlib_pc['include_dirs']
 
 
 #########################################################
@@ -88,22 +95,19 @@ aliases = dict(
     LINBOX_CFLAGS=linbox_cflags,
     LINBOX_LIBRARIES=linbox_libs,
     LINBOX_LIBDIR=linbox_library_dirs,
+    SINGULAR_CFLAGS=singular_cflags,
+    SINGULAR_LIBRARIES=singular_libs,
+    SINGULAR_LIBDIR=singular_library_dirs
 )
 
-#########################################################
-### C++11 workaround https://trac.sagemath.org/ticket/20926
-#########################################################
-
-nocxx11_args = ['-std=c++98']
-
 #########################################################
 ### M4RI flags
 #########################################################
 
 m4ri_pc = pkgconfig.parse('m4ri')
-m4ri_libs = list(m4ri_pc['libraries'])
-m4ri_library_dirs = list(m4ri_pc['library_dirs'])
-m4ri_include_dirs = list(m4ri_pc['include_dirs'])
+m4ri_libs = m4ri_pc['libraries']
+m4ri_library_dirs = m4ri_pc['library_dirs']
+m4ri_include_dirs = m4ri_pc['include_dirs']
 
 m4ri_extra_compile_args = pkgconfig.cflags('m4ri').split()
 try:
@@ -111,12 +115,6 @@ try:
 except ValueError:
     pass
 
-#########################################################
-### Singular
-#########################################################
-
-singular_libs = ['singular', 'flint', 'ntl', 'gmpxx', 'gmp', 'readline', 'm']
-
 #########################################################
 ### Library order
 #########################################################
@@ -130,9 +128,9 @@ singular_libs = ['singular', 'flint', 'ntl', 'gmpxx', 'gmp', 'readline', 'm']
 # listed here will be added at the end of the list (without changing
 # their relative order). There is one exception: stdc++ is always put
 # at the very end of the list.
-library_order_list = [
-    "singular", "ec", "ecm",
-] + linbox_libs  + gsl_libs + [
+library_order_list = singular_libs + [
+    "ec", "ecm",
+] + linbox_libs + fflas_ffpack_libs + gsl_libs + [
     "pari", "flint", "ratpoints", "ecl", "glpk", "ppl",
     "arb", "mpfi", "mpfr", "mpc", "gmp", "gmpxx",
     "brial",
@@ -188,27 +186,14 @@ ext_modules = [
     Extension('sage.algebras.quatalg.quaternion_algebra_element',
                sources = ['sage/algebras/quatalg/quaternion_algebra_element.pyx'],
                language='c++',
-               libraries = ["flint", "gmp", "gmpxx", "m", "ntl"]),
+               libraries = ["gmp", "m", "ntl"]),
 
-    Extension('sage.algebras.letterplace.free_algebra_letterplace',
-              sources = ['sage/algebras/letterplace/free_algebra_letterplace.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.algebras.letterplace.free_algebra_element_letterplace',
-              sources = ['sage/algebras/letterplace/free_algebra_element_letterplace.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.algebras.letterplace.letterplace_ideal',
-              sources = ['sage/algebras/letterplace/letterplace_ideal.pyx'],
-              libraries = singular_libs,
-              language="c++"),
+    Extension('*', sources = ['sage/algebras/letterplace/*.pyx']),
 
     Extension('sage.algebras.quatalg.quaternion_algebra_cython',
                sources = ['sage/algebras/quatalg/quaternion_algebra_cython.pyx'],
                language='c++',
-               libraries = ["flint", "gmp", "gmpxx", "m", "ntl"]),
+               libraries = ["gmp", "m", "ntl"]),
 
     ################################
     ##
@@ -224,7 +209,7 @@ ext_modules = [
     ##
     ################################
 
-    Extension('*', ['sage/calculus/*.pyx']),
+    Extension('*', ['sage/calculus/**/*.pyx']),
 
     ################################
     ##
@@ -241,8 +226,7 @@ ext_modules = [
     ################################
 
     Extension('sage.coding.codecan.codecan',
-              sources = ['sage/coding/codecan/codecan.pyx'],
-              libraries = ['flint']),
+              sources = ['sage/coding/codecan/codecan.pyx']),
 
     Extension('*', ['sage/coding/**/*.pyx']),
 
@@ -395,7 +379,6 @@ ext_modules = [
 
     Extension('sage.graphs.matchpoly',
               sources = ['sage/graphs/matchpoly.pyx'],
-              libraries = ['flint'],
               extra_compile_args = ['-std=c99']),
 
     OptionalExtension("sage.graphs.mcqd",
@@ -458,8 +441,7 @@ ext_modules = [
               sources = ['sage/graphs/base/dense_graph.pyx']),
 
     Extension('sage.graphs.base.boost_graph',
-              sources = ['sage/graphs/base/boost_graph.pyx'],
-              language = 'c++'),
+              sources = ['sage/graphs/base/boost_graph.pyx']),
 
     ################################
     ##
@@ -483,54 +465,12 @@ ext_modules = [
     Extension('sage.groups.perm_gps.permgroup_element',
               sources = ['sage/groups/perm_gps/permgroup_element.pyx']),
 
-    Extension('sage.groups.perm_gps.partn_ref.automorphism_group_canonical_label',
-              sources = ['sage/groups/perm_gps/partn_ref/automorphism_group_canonical_label.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.canonical_augmentation',
-              sources = ['sage/groups/perm_gps/partn_ref/canonical_augmentation.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.double_coset',
-              sources = ['sage/groups/perm_gps/partn_ref/double_coset.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.refinement_binary',
-              sources = ['sage/groups/perm_gps/partn_ref/refinement_binary.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.refinement_graphs',
-              sources = ['sage/groups/perm_gps/partn_ref/refinement_graphs.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.refinement_lists',
-              sources = ['sage/groups/perm_gps/partn_ref/refinement_lists.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.refinement_matrices',
-              sources = ['sage/groups/perm_gps/partn_ref/refinement_matrices.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.refinement_python',
-              sources = ['sage/groups/perm_gps/partn_ref/refinement_python.pyx'],
-              libraries = ['flint'],
-              extra_compile_args = ['-std=c99']),
-
-    Extension('sage.groups.perm_gps.partn_ref.refinement_sets',
-              sources = ['sage/groups/perm_gps/partn_ref/refinement_sets.pyx'],
-              libraries = ['flint'],
+    Extension('*',
+              sources = ['sage/groups/perm_gps/partn_ref/*.pyx'],
               extra_compile_args = ['-std=c99']),
 
     Extension('sage.groups.perm_gps.partn_ref2.refinement_generic',
               sources = ['sage/groups/perm_gps/partn_ref2/refinement_generic.pyx'],
-              libraries = ["flint", "gmp", "gmpxx", "stdc++"],
               extra_compile_args=["-std=c99"]),
 
     ################################
@@ -564,8 +504,7 @@ ext_modules = [
     ################################
 
     Extension('sage.lfunctions.zero_sums',
-              sources = ['sage/lfunctions/zero_sums.pyx'],
-              libraries = ["m","flint"]),
+              sources = ['sage/lfunctions/zero_sums.pyx']),
 
     ################################
     ##
@@ -592,17 +531,14 @@ ext_modules = [
 
     Extension('sage.libs.flint.flint',
               sources = ["sage/libs/flint/flint.pyx"],
-              libraries = ["flint", "gmp", "gmpxx", "m", "stdc++"],
               extra_compile_args = ["-std=c99", "-D_XPG6"]),
 
     Extension('sage.libs.flint.fmpz_poly',
               sources = ["sage/libs/flint/fmpz_poly.pyx"],
-              libraries = ["flint", "gmp", "gmpxx", "m", "stdc++"],
               extra_compile_args = ["-std=c99", "-D_XPG6"]),
 
     Extension('sage.libs.flint.arith',
               sources = ["sage/libs/flint/arith.pyx"],
-              libraries = ["flint", "gmp", "gmpxx", "m", "stdc++"],
               extra_compile_args = ["-std=c99", "-D_XPG6"]),
 
     Extension("sage.libs.glpk.error",
@@ -611,9 +547,6 @@ ext_modules = [
     Extension('sage.libs.gmp.pylong',
               sources = ['sage/libs/gmp/pylong.pyx']),
 
-    Extension('sage.libs.gmp.rational_reconstruction',
-              sources = ['sage/libs/gmp/rational_reconstruction.pyx']),
-
     OptionalExtension('sage.libs.braiding',
                       sources = ["sage/libs/braiding.pyx"],
                       libraries = ["braiding"],
@@ -626,14 +559,11 @@ ext_modules = [
                       libraries = ["homfly", "gc"],
                       package="libhomfly"),
 
- #    Extension('sage.libs.linbox.linbox',
- #             sources = ['sage/libs/linbox/linbox.pyx']),
-
-    Extension('*',['sage/libs/linbox/*.pyx']),
+    Extension('*', ['sage/libs/linbox/*.pyx']),
 
     Extension('sage.libs.lcalc.lcalc_Lfunction',
               sources = ['sage/libs/lcalc/lcalc_Lfunction.pyx'],
-              libraries = ['m', 'ntl', 'mpfr', 'gmp', 'gmpxx',
+              libraries = ['m', 'ntl', 'mpfr', 'gmp',
                            'Lfunction'],
               extra_compile_args=["-O3", "-ffast-math"],
               language = 'c++'),
@@ -647,26 +577,14 @@ ext_modules = [
     Extension('sage.libs.lrcalc.lrcalc',
               sources = ["sage/libs/lrcalc/lrcalc.pyx"]),
 
-    Extension('sage.libs.pari.closure',
-              sources = ["sage/libs/pari/closure.pyx"]),
-
-    Extension('sage.libs.pari.convert',
-              sources = ["sage/libs/pari/convert.pyx"]),
-
-    Extension('sage.libs.pari.gen',
-              sources = ["sage/libs/pari/gen.pyx"]),
-
-    Extension('sage.libs.pari.handle_error',
-              sources = ["sage/libs/pari/handle_error.pyx"]),
-
-    Extension('sage.libs.pari.pari_instance',
-              sources = ["sage/libs/pari/pari_instance.pyx"],
-              extra_compile_args = ["-std=c99", "-D_XPG6"],
-              libraries = ['flint']),
+    Extension('*', ['sage/libs/cypari2/*.pyx']),
+    Extension('*', ['sage/libs/pari/*.pyx']),
 
     Extension('sage.libs.ppl',
               sources = ['sage/libs/ppl.pyx', 'sage/libs/ppl_shim.cc']),
 
+    Extension('*', ['sage/libs/pynac/*.pyx']),
+
     Extension('sage.libs.ratpoints',
               sources = ["sage/libs/ratpoints.pyx"],
               libraries = ["ratpoints"]),
@@ -675,35 +593,7 @@ ext_modules = [
               sources = ['sage/libs/readline.pyx'],
               libraries = ['readline']),
 
-    Extension('sage.libs.singular.singular',
-              sources = ['sage/libs/singular/singular.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.libs.singular.polynomial',
-              sources = ['sage/libs/singular/polynomial.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.libs.singular.ring',
-              sources = ['sage/libs/singular/ring.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.libs.singular.groebner_strategy',
-              sources = ['sage/libs/singular/groebner_strategy.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.libs.singular.function',
-              sources = ['sage/libs/singular/function.pyx'],
-              libraries = singular_libs,
-              language="c++"),
-
-    Extension('sage.libs.singular.option',
-              sources = ['sage/libs/singular/option.pyx'],
-              libraries = singular_libs,
-              language="c++"),
+    Extension('*', sources = ['sage/libs/singular/*.pyx']),
 
     Extension('sage.libs.symmetrica.symmetrica',
               sources = ["sage/libs/symmetrica/symmetrica.pyx"],
@@ -758,6 +648,14 @@ ext_modules = [
               sources = ["sage/libs/gap/libgap.pyx"],
               libraries = ['gmp', 'gap', 'm']),
 
+    ###################################
+    ##
+    ## sage.libs.gsl
+    ##
+    ###################################
+
+    Extension('*', ["sage/libs/gsl/*.pyx"]),
+
     ###################################
     ##
     ## sage.libs.ntl
@@ -766,107 +664,107 @@ ext_modules = [
 
     Extension('sage.libs.ntl.convert',
               sources = ["sage/libs/ntl/convert.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx"],
+              libraries = ["ntl", "gmp"],
               language='c++'),
 
     Extension('sage.libs.ntl.error',
               sources = ["sage/libs/ntl/error.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx"],
+              libraries = ["ntl", "gmp"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_GF2',
               sources = ["sage/libs/ntl/ntl_GF2.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx"],
+              libraries = ["ntl", "gmp"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_GF2E',
               sources = ["sage/libs/ntl/ntl_GF2E.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_GF2EContext',
               sources = ["sage/libs/ntl/ntl_GF2EContext.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_GF2EX',
               sources = ["sage/libs/ntl/ntl_GF2EX.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_GF2X',
               sources = ["sage/libs/ntl/ntl_GF2X.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_lzz_p',
               sources = ["sage/libs/ntl/ntl_lzz_p.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_lzz_pContext',
               sources = ["sage/libs/ntl/ntl_lzz_pContext.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_lzz_pX',
               sources = ["sage/libs/ntl/ntl_lzz_pX.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_mat_GF2',
               sources = ["sage/libs/ntl/ntl_mat_GF2.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_mat_GF2E',
               sources = ["sage/libs/ntl/ntl_mat_GF2E.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_mat_ZZ',
               sources = ["sage/libs/ntl/ntl_mat_ZZ.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ',
               sources = ["sage/libs/ntl/ntl_ZZ.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZX',
               sources = ["sage/libs/ntl/ntl_ZZX.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ_p',
               sources = ["sage/libs/ntl/ntl_ZZ_p.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ_pContext',
               sources = ["sage/libs/ntl/ntl_ZZ_pContext.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ_pE',
               sources = ["sage/libs/ntl/ntl_ZZ_pE.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ_pEContext',
               sources = ["sage/libs/ntl/ntl_ZZ_pEContext.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ_pEX',
               sources = ["sage/libs/ntl/ntl_ZZ_pEX.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.libs.ntl.ntl_ZZ_pX',
               sources = ["sage/libs/ntl/ntl_ZZ_pX.pyx"],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     ################################
@@ -902,7 +800,6 @@ ext_modules = [
     Extension("sage.matrix.matrix_complex_ball_dense",
               ["sage/matrix/matrix_complex_ball_dense.pyx"],
               libraries=['arb', 'mpfi', 'mpfr'],
-              include_dirs=[SAGE_INC + '/flint'],
               language = "c++"),
 
     Extension('sage.matrix.matrix_complex_double_dense',
@@ -927,8 +824,8 @@ ext_modules = [
 
     Extension('sage.matrix.matrix_integer_dense',
               sources = ['sage/matrix/matrix_integer_dense.pyx'],
-              extra_compile_args = ['-std=c99'] + m4ri_extra_compile_args,
-              libraries = ['iml', 'ntl', 'gmp', 'm', 'flint'] + cblas_libs,
+              extra_compile_args = m4ri_extra_compile_args,
+              libraries = ['iml', 'ntl', 'gmp', 'm'] + cblas_libs,
               library_dirs = cblas_library_dirs,
               include_dirs = cblas_include_dirs),
 
@@ -970,14 +867,15 @@ ext_modules = [
               sources = ['sage/matrix/matrix_modn_sparse.pyx']),
 
     Extension('sage.matrix.matrix_mpolynomial_dense',
-              sources = ['sage/matrix/matrix_mpolynomial_dense.pyx'],
-              libraries = singular_libs,
-              language="c++"),
+              sources = ['sage/matrix/matrix_mpolynomial_dense.pyx']),
+
+    Extension('sage.matrix.matrix_polynomial_dense',
+              sources = ['sage/matrix/matrix_polynomial_dense.pyx']),
 
     Extension('sage.matrix.matrix_rational_dense',
               sources = ['sage/matrix/matrix_rational_dense.pyx'],
               extra_compile_args = ["-std=c99", "-D_XPG6"] + m4ri_extra_compile_args,
-              libraries = ['iml', 'ntl', 'm', 'flint'] + cblas_libs,
+              libraries = ['iml', 'ntl', 'm'] + cblas_libs,
               library_dirs = cblas_library_dirs,
               include_dirs = cblas_include_dirs,
               depends = [SAGE_INC + '/m4ri/m4ri.h']),
@@ -1033,12 +931,6 @@ ext_modules = [
 
     Extension('*', ['sage/misc/*.pyx']),
 
-    # Only include darwin_utilities on OS_X >= 10.5
-    OptionalExtension('sage.misc.darwin_utilities',
-        sources = ['sage/misc/darwin_memory_usage.c',
-                   'sage/misc/darwin_utilities.pyx'],
-        condition = (UNAME[0] == "Darwin" and not UNAME[2].startswith('8.'))),
-
     ################################
     ##
     ## sage.modular
@@ -1049,16 +941,13 @@ ext_modules = [
               sources = ['sage/modular/arithgroup/congroup.pyx']),
 
     Extension('sage.modular.arithgroup.farey_symbol',
-              sources = ['sage/modular/arithgroup/farey_symbol.pyx',
-                         'sage/modular/arithgroup/farey.cpp',
-                         'sage/modular/arithgroup/sl2z.cpp']),
+              sources = ['sage/modular/arithgroup/farey_symbol.pyx']),
 
     Extension('sage.modular.arithgroup.arithgroup_element',
               sources = ['sage/modular/arithgroup/arithgroup_element.pyx']),
 
     Extension('sage.modular.modform.eis_series_cython',
               sources = ['sage/modular/modform/eis_series_cython.pyx'],
-              libraries = ["flint"],
               extra_compile_args = ['-std=c99']),
 
     Extension('sage.modular.modform.l_series_gross_zagier_coeffs',
@@ -1066,7 +955,6 @@ ext_modules = [
 
     Extension('sage.modular.modsym.apply',
               sources = ['sage/modular/modsym/apply.pyx'],
-              libraries = ["flint", "gmp", "gmpxx", "m", "stdc++"],
               extra_compile_args=["-std=c99", "-D_XPG6"]),
 
     Extension('sage.modular.modsym.manin_symbol',
@@ -1077,7 +965,6 @@ ext_modules = [
 
     Extension('sage.modular.modsym.heilbronn',
               sources = ['sage/modular/modsym/heilbronn.pyx'],
-              libraries = ["flint", "gmp", "gmpxx", "m", "stdc++"],
               extra_compile_args=["-std=c99", "-D_XPG6"]),
 
     Extension('sage.modular.modsym.p1list',
@@ -1085,7 +972,7 @@ ext_modules = [
 
     Extension('sage.modular.pollack_stevens.dist',
               sources = ['sage/modular/pollack_stevens/dist.pyx'],
-              libraries = ['flint','gmp','zn_poly'],
+              libraries = ["gmp", "zn_poly"],
               extra_compile_args=['-std=c99', '-D_XPG6']),
 
     ################################
@@ -1248,6 +1135,14 @@ ext_modules = [
     Extension('sage.plot.plot3d.transform',
               sources = ['sage/plot/plot3d/transform.pyx']),
 
+    ################################
+    ##
+    ## sage.probability
+    ##
+    ################################
+
+    Extension('*', ['sage/probability/*.pyx']),
+
     ################################
     ##
     ## sage.quadratic_forms
@@ -1289,7 +1184,7 @@ ext_modules = [
 
     Extension('sage.rings.bernoulli_mod_p',
               sources = ['sage/rings/bernoulli_mod_p.pyx'],
-              libraries=['ntl'],
+              libraries=['ntl', 'gmp'],
               language = 'c++'),
 
     Extension("sage.rings.complex_arb",
@@ -1312,7 +1207,7 @@ ext_modules = [
 
     Extension('sage.rings.integer',
               sources = ['sage/rings/integer.pyx'],
-              libraries=['ntl', 'flint']),
+              libraries=['ntl']),
 
     Extension('sage.rings.integer_ring',
               sources = ['sage/rings/integer_ring.pyx'],
@@ -1329,7 +1224,7 @@ ext_modules = [
 
     Extension('sage.rings.fraction_field_FpT',
               sources = ['sage/rings/fraction_field_FpT.pyx'],
-              libraries = ["flint", "gmp", "gmpxx", "ntl", "zn_poly"],
+              libraries = ["gmp", "ntl", "zn_poly"],
               language = 'c++'),
 
     Extension('sage.rings.laurent_series_ring_element',
@@ -1351,6 +1246,9 @@ ext_modules = [
     Extension('sage.rings.power_series_poly',
               sources = ['sage/rings/power_series_poly.pyx']),
 
+    Extension('sage.rings.power_series_pari',
+              sources = ['sage/rings/power_series_pari.pyx']),
+
     Extension('sage.rings.power_series_ring_element',
               sources = ['sage/rings/power_series_ring_element.pyx']),
 
@@ -1403,7 +1301,7 @@ ext_modules = [
 
     Extension('sage.rings.finite_rings.element_givaro',
               sources = ["sage/rings/finite_rings/element_givaro.pyx"],
-              libraries = ['givaro', 'ntl', 'gmpxx', 'gmp', 'm'],
+              libraries = ['givaro', 'ntl', 'gmp', 'm'],
               language='c++'),
 
     Extension('sage.rings.finite_rings.element_ntl_gf2e',
@@ -1422,8 +1320,7 @@ ext_modules = [
 
     Extension('sage.rings.finite_rings.hom_finite_field_givaro',
               sources = ["sage/rings/finite_rings/hom_finite_field_givaro.pyx"],
-              # this order is needed to compile under windows.
-              libraries = ['givaro', 'ntl', 'gmpxx', 'gmp', 'm'],
+              libraries = ['givaro', 'ntl', 'gmp', 'm'],
               language='c++'),
 
     ################################
@@ -1451,7 +1348,7 @@ ext_modules = [
 
     Extension('sage.rings.number_field.number_field_element_quadratic',
               sources = ['sage/rings/number_field/number_field_element_quadratic.pyx'],
-              libraries=['ntl'],
+              libraries=['ntl', 'mpfr', 'mpfi'],
               language = 'c++'),
 
     Extension('sage.rings.number_field.number_field_morphisms',
@@ -1487,7 +1384,7 @@ ext_modules = [
 
     Extension('sage.rings.padics.padic_ext_element',
               sources = ['sage/rings/padics/padic_ext_element.pyx'],
-              libraries=['ntl', 'gmp', 'gmpxx', 'm'],
+              libraries=['ntl', 'gmp', 'm'],
               language='c++'),
 
     Extension('sage.rings.padics.padic_fixed_mod_element',
@@ -1498,55 +1395,52 @@ ext_modules = [
 
     Extension('sage.rings.padics.padic_printing',
               sources = ['sage/rings/padics/padic_printing.pyx'],
-              libraries=['gmp', 'ntl', 'gmpxx', 'm'],
+              libraries=['gmp', 'ntl', 'm'],
               language='c++'),
 
     Extension('sage.rings.padics.padic_ZZ_pX_CA_element',
               sources = ['sage/rings/padics/padic_ZZ_pX_CA_element.pyx'],
-              libraries = ['ntl', 'gmp', 'gmpxx','m'],
+              libraries = ['ntl', 'gmp', 'm'],
               language='c++'),
 
     Extension('sage.rings.padics.padic_ZZ_pX_CR_element',
               sources = ['sage/rings/padics/padic_ZZ_pX_CR_element.pyx'],
-              libraries=['ntl', 'gmp', 'gmpxx','m'],
+              libraries=['ntl', 'gmp', 'm'],
               language='c++'),
 
     Extension('sage.rings.padics.padic_ZZ_pX_element',
               sources = ['sage/rings/padics/padic_ZZ_pX_element.pyx'],
-              libraries=['ntl', 'gmp', 'gmpxx', 'm'],
+              libraries=['ntl', 'gmp', 'm'],
               language='c++'),
 
     Extension('sage.rings.padics.padic_ZZ_pX_FM_element',
               sources = ['sage/rings/padics/padic_ZZ_pX_FM_element.pyx'],
-              libraries=['ntl', 'gmp', 'gmpxx', 'm'],
+              libraries=['ntl', 'gmp', 'm'],
               language='c++'),
 
     Extension('sage.rings.padics.pow_computer',
               sources = ['sage/rings/padics/pow_computer.pyx'],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.rings.padics.pow_computer_ext',
               sources = ['sage/rings/padics/pow_computer_ext.pyx'],
-              libraries = ["ntl", "gmp", "gmpxx", "m"],
+              libraries = ["ntl", "gmp", "m"],
               language='c++'),
 
     Extension('sage.rings.padics.pow_computer_flint',
               sources = ['sage/rings/padics/pow_computer_flint.pyx'],
-              libraries = ["flint", "gmpxx", "gmp", "ntl"],
+              libraries = ["gmp", "ntl"],
               language='c++'),
 
     Extension('sage.rings.padics.qadic_flint_CR',
-              sources = ['sage/rings/padics/qadic_flint_CR.pyx'],
-              libraries = ["flint"]),
+              sources = ['sage/rings/padics/qadic_flint_CR.pyx']),
 
     Extension('sage.rings.padics.qadic_flint_CA',
-              sources = ['sage/rings/padics/qadic_flint_CA.pyx'],
-              libraries = ["flint"]),
+              sources = ['sage/rings/padics/qadic_flint_CA.pyx']),
 
     Extension('sage.rings.padics.qadic_flint_FM',
-              sources = ['sage/rings/padics/qadic_flint_FM.pyx'],
-              libraries = ["flint"]),
+              sources = ['sage/rings/padics/qadic_flint_FM.pyx']),
 
     ################################
     ##
@@ -1558,7 +1452,7 @@ ext_modules = [
               sources = ['sage/rings/polynomial/cyclotomic.pyx']),
 
     Extension('sage.rings.polynomial.evaluation',
-              libraries = ["flint", "gmp", "ntl", "mpfr", "mpfi"],
+              libraries = ["gmp", "ntl", "mpfr", "mpfi"],
               sources = ['sage/rings/polynomial/evaluation.pyx'],
               language = 'c++'),
 
@@ -1569,19 +1463,13 @@ ext_modules = [
               sources = ['sage/rings/polynomial/multi_polynomial.pyx']),
 
     Extension('sage.rings.polynomial.multi_polynomial_ideal_libsingular',
-              sources = ['sage/rings/polynomial/multi_polynomial_ideal_libsingular.pyx'],
-              libraries = singular_libs,
-              language="c++"),
+              sources = ['sage/rings/polynomial/multi_polynomial_ideal_libsingular.pyx']),
 
     Extension('sage.rings.polynomial.plural',
-              sources = ['sage/rings/polynomial/plural.pyx'],
-              libraries = ['m', 'readline', 'singular', 'givaro', 'gmpxx', 'gmp'],
-              language="c++"),
+              sources = ['sage/rings/polynomial/plural.pyx']),
 
     Extension('sage.rings.polynomial.multi_polynomial_libsingular',
-              sources = ['sage/rings/polynomial/multi_polynomial_libsingular.pyx'],
-              libraries = singular_libs,
-              language="c++"),
+              sources = ['sage/rings/polynomial/multi_polynomial_libsingular.pyx']),
 
     Extension('sage.rings.polynomial.multi_polynomial_ring_generic',
               sources = ['sage/rings/polynomial/multi_polynomial_ring_generic.pyx']),
@@ -1592,6 +1480,10 @@ ext_modules = [
     Extension('sage.rings.polynomial.polydict',
               sources = ['sage/rings/polynomial/polydict.pyx']),
 
+    Extension('sage.rings.polynomial.polynomial_complex_arb',
+               sources = ['sage/rings/polynomial/polynomial_complex_arb.pyx'],
+               language="c++"),
+
     Extension('sage.rings.polynomial.polynomial_compiled',
                sources = ['sage/rings/polynomial/polynomial_compiled.pyx']),
 
@@ -1606,32 +1498,32 @@ ext_modules = [
 
     Extension('sage.rings.polynomial.polynomial_zz_pex',
               sources = ['sage/rings/polynomial/polynomial_zz_pex.pyx'],
-              libraries = ['ntl'],
+              libraries = ['ntl', 'gmp'],
               language = 'c++'),
 
     Extension('sage.rings.polynomial.polynomial_zmod_flint',
               sources = ['sage/rings/polynomial/polynomial_zmod_flint.pyx'],
-              libraries = ["flint", "gmp", "gmpxx", "ntl", "zn_poly"],
+              libraries = ["gmp", "ntl", "zn_poly"],
               language = 'c++'),
 
     Extension('sage.rings.polynomial.polynomial_integer_dense_flint',
               sources = ['sage/rings/polynomial/polynomial_integer_dense_flint.pyx'],
               language = 'c++',
-              libraries = ["flint", "ntl", "gmpxx", "gmp"]),
+              libraries = ["ntl", "gmp"]),
 
     Extension('sage.rings.polynomial.polynomial_integer_dense_ntl',
               sources = ['sage/rings/polynomial/polynomial_integer_dense_ntl.pyx'],
-              libraries = ['ntl'],
+              libraries = ['ntl', 'gmp'],
               language = 'c++'),
 
     Extension('sage.rings.polynomial.polynomial_rational_flint',
               sources = ['sage/rings/polynomial/polynomial_rational_flint.pyx'],
-              libraries = ["flint", "ntl", "gmpxx", "gmp"],
+              libraries = ["ntl", "gmp"],
               language = 'c++'),
 
     Extension('sage.rings.polynomial.polynomial_modn_dense_ntl',
               sources = ['sage/rings/polynomial/polynomial_modn_dense_ntl.pyx'],
-              libraries = ['ntl'],
+              libraries = ['ntl', 'gmp'],
               language = 'c++'),
 
     Extension('sage.rings.polynomial.polynomial_ring_homomorphism',
@@ -1644,8 +1536,7 @@ ext_modules = [
               include_dirs = m4ri_include_dirs + png_include_dirs,
               depends = [SAGE_INC + "/polybori/" + hd + ".h" for hd in ["polybori", "config"] ] +
                         [SAGE_INC + '/m4ri/m4ri.h'],
-              extra_compile_args = m4ri_extra_compile_args,
-              language = 'c++'),
+              extra_compile_args = m4ri_extra_compile_args),
 
     Extension('sage.rings.polynomial.polynomial_real_mpfr_dense',
               sources = ['sage/rings/polynomial/polynomial_real_mpfr_dense.pyx'],
@@ -1710,7 +1601,7 @@ ext_modules = [
     Extension('sage.schemes.elliptic_curves.descent_two_isogeny',
               sources = ['sage/schemes/elliptic_curves/descent_two_isogeny.pyx'],
               extra_compile_args=["-std=c99"],
-              libraries = ['flint', 'ratpoints']),
+              libraries = ['ratpoints']),
 
     Extension('sage.schemes.elliptic_curves.period_lattice_region',
               sources = ['sage/schemes/elliptic_curves/period_lattice_region.pyx']),
@@ -1742,7 +1633,6 @@ ext_modules = [
 
     Extension('sage.sets.disjoint_set',
               sources = ['sage/sets/disjoint_set.pyx'],
-              libraries = ['flint'],
               extra_compile_args = ['-std=c99']),
 
     Extension('sage.sets.finite_set_map_cy',
