@@ -50,5 +50,10 @@ from .weyl_algebra import DifferentialWeylAlgebra
 
 lazy_import('sage.algebras.commutative_dga', 'GradedCommutativeAlgebra')
 
+lazy_import('sage.algebras.rational_cherednik_algebra', 'RationalCherednikAlgebra')
+
 lazy_import('sage.algebras.tensor_algebra', 'TensorAlgebra')
 
+lazy_import('sage.algebras.q_system', 'QSystem')
+
+lazy_import('sage.algebras.cluster_algebra', 'ClusterAlgebra')
