@@ -32,6 +32,9 @@ from sage.quadratic_forms.quadratic_form import QuadraticForm
 from sage.algebras.weyl_algebra import repr_from_monomials
 from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
 
+import six
+
+
 class CliffordAlgebraElement(CombinatorialFreeModule.Element):
     """
     An element in a Clifford algebra.
@@ -114,7 +117,7 @@ class CliffordAlgebraElement(CombinatorialFreeModule.Element):
                 # the dictionary describing the element
                 # ``e[i]`` * (the element described by the dictionary ``cur``)
                 # (where ``e[i]`` is the ``i``-th standard basis vector).
-                for mr,cr in cur.iteritems():
+                for mr,cr in six.iteritems(cur):
                     # Commute the factor as necessary until we are in order
                     pos = 0
                     for j in mr:
@@ -150,7 +153,7 @@ class CliffordAlgebraElement(CombinatorialFreeModule.Element):
                 cur = next
 
             # Add the distributed terms to the total
-            for index,coeff in cur.iteritems():
+            for index,coeff in six.iteritems(cur):
                 d[index] = d.get(index, zero) + cl * coeff
                 if d[index] == zero:
                     del d[index]
@@ -724,8 +727,8 @@ class CliffordAlgebra(CombinatorialFreeModule):
         if x in self.free_module():
             R = self.base_ring()
             if x.parent().base_ring() is R:
-                return self.element_class(self, {(i,): c for i,c in x.iteritems()})
-            return self.element_class(self, {(i,): R(c) for i,c in x.iteritems() if R(c) != R.zero()})
+                return self.element_class(self, {(i,): c for i,c in six.iteritems(x)})
+            return self.element_class(self, {(i,): R(c) for i,c in six.iteritems(x) if R(c) != R.zero()})
 
         if isinstance(x, CliffordAlgebraElement):
             if x.parent() is self:
@@ -1201,7 +1204,7 @@ class CliffordAlgebra(CombinatorialFreeModule):
                 for m,c in (Bi*Bj - Bj*Bi):
                     d[(a, K.index(m)+k*b)] = c
         m = Matrix(R, d, nrows=k, ncols=k*k, sparse=True)
-        from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in x.iteritems()),
+        from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in six.iteritems(x)),
                                                   distinct=True)
         return tuple(map( from_vector, m.kernel().basis() ))
 
@@ -1215,7 +1218,7 @@ class CliffordAlgebra(CombinatorialFreeModule):
         #         v = B[i]*B[j] - B[j]*B[i]
         #         eqns[a].extend([v[k] for k in K])
         # m = Matrix(R, eqns)
-        # from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in x.iteritems()),
+        # from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in six.iteritems(x)),
         #                                           distinct=True)
         # return tuple(map( from_vector, m.kernel().basis() ))
 
@@ -1298,7 +1301,7 @@ class CliffordAlgebra(CombinatorialFreeModule):
                 for m,c in supercommutator:
                     d[(a, K.index(m)+k*b)] = c
         m = Matrix(R, d, nrows=k, ncols=k*k, sparse=True)
-        from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in x.iteritems()),
+        from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in six.iteritems(x)),
                                                   distinct=True)
         return tuple(map( from_vector, m.kernel().basis() ))
 
@@ -1312,7 +1315,7 @@ class CliffordAlgebra(CombinatorialFreeModule):
         #         v = B[i].supercommutator(B[j])   # or better an if-loop as above
         #         eqns[a].extend([v[k] for k in K])
         # m = Matrix(R, eqns)
-        # from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in x.iteritems()),
+        # from_vector = lambda x: self.sum_of_terms(((K[i], c) for i,c in six.iteritems(x)),
         #                                           distinct=True)
         # return tuple(map( from_vector, m.kernel().basis() ))
 
@@ -2196,13 +2199,13 @@ class ExteriorAlgebraDifferential(ModuleMorphismByLinearity, UniqueRepresentatio
         """
         d = {}
 
-        for k,v in dict(s_coeff).iteritems():
+        for k,v in six.iteritems(dict(s_coeff)):
             if not v: # Strip terms with 0
                 continue
 
             if isinstance(v, dict):
                 R = E.base_ring()
-                v = E._from_dict({(i,): R(c) for i,c in v.iteritems()})
+                v = E._from_dict({(i,): R(c) for i,c in six.iteritems(v)})
             else:
                 # Make sure v is in ``E``
                 v = E(v)
@@ -2621,7 +2624,7 @@ class ExteriorAlgebraCoboundary(ExteriorAlgebraDifferential):
         self._cos_coeff = {}
         zero = E.zero()
         B = E.basis()
-        for k,v in dict(s_coeff).iteritems():
+        for k,v in six.iteritems(dict(s_coeff)):
             k = B[k]
             for m,c in v:
                 self._cos_coeff[m] = self._cos_coeff.get(m, zero) + c * k
