@@ -121,6 +121,9 @@ from sage.categories.all import Rings, GroupAlgebras, Hom
 from sage.categories.morphism import SetMorphism
 
 
+import six
+
+
 class GroupAlgebraFunctor(ConstructionFunctor):
     r"""
     For a fixed group, a functor sending a commutative ring to the
@@ -209,7 +212,7 @@ class GroupAlgebraFunctor(ConstructionFunctor):
             (1,2,3)
         """
         codomain = self(f.codomain())
-        return SetMorphism(Hom(self(f.domain()), codomain, Rings()), lambda x: sum(codomain(g) * f(c) for (g, c) in dict(x).iteritems()))
+        return SetMorphism(Hom(self(f.domain()), codomain, Rings()), lambda x: sum(codomain(g) * f(c) for (g, c) in six.iteritems(dict(x))))
 
 class GroupAlgebra(CombinatorialFreeModule):
     r"""
@@ -548,13 +551,13 @@ class GroupAlgebra(CombinatorialFreeModule):
         multiplying a random element of the base ring by a random
         element of the group.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: GroupAlgebra(DihedralGroup(6), QQ).random_element()
-            -1/95*(2,6)(3,5) - 1/2*(1,3)(4,6)
+            -1/95*() - 1/2*(1,4)(2,5)(3,6)
             sage: GroupAlgebra(SU(2, 13), QQ).random_element(1)
-            1/2*[      11    a + 6]
-            [2*a + 12       11]
+            1/2*[       0 4*a + 11]
+            [2*a + 12        4]
         """
         a = self(0)
         for i in range(n):
