@@ -16,10 +16,6 @@ AUTHORS:
 
 - Hugh Thomas (2011-05-08): implement action of Schur algebra and characters
   of irreducible modules
-
-REFERENCES:
-
-.. [GreenPoly] \J. Green, Polynomial representations of `GL_n`, Springer Verlag.
 """
 
 #*****************************************************************************
@@ -211,7 +207,7 @@ class SchurAlgebra(CombinatorialFreeModule):
 
     REFERENCES:
 
-    - [GreenPoly]_
+    - [Gr2007]_
     - :wikipedia:`Schur_algebra`
     """
     def __init__(self, R, n, r):
@@ -493,7 +489,7 @@ class SchurTensorModule(CombinatorialFreeModule_Tensor):
                 sage: x * y
                 Traceback (most recent call last):
                 ...
-                TypeError: unsupported operand parent(s) for '*': ...
+                TypeError: unsupported operand parent(s) for *: ...
 
             ::
 
@@ -506,7 +502,7 @@ class SchurTensorModule(CombinatorialFreeModule_Tensor):
                 sage: y * x
                 Traceback (most recent call last):
                 ...
-                TypeError: unsupported operand parent(s) for '*': ...
+                TypeError: unsupported operand parent(s) for *: ...
 
             ::
 
@@ -568,7 +564,7 @@ def GL_irreducible_character(n, mu, KK):
     in general be smaller.
 
     In characteristic `p`, for a one-part partition `(r)`, where
-    `r = a_0 + p a_1 + p^2 a_2 + \dots`, the result is (see [GreenPoly]_,
+    `r = a_0 + p a_1 + p^2 a_2 + \dots`, the result is (see [Gr2007]_,
     after 5.5d) the product of `h[a_0], h[a_1]( pbasis[p]), h[a_2]
     ( pbasis[p^2]), \dots,` which is consistent with the following ::
 
@@ -591,7 +587,7 @@ def GL_irreducible_character(n, mu, KK):
 
     e = M.basis()[tuple(ell)]  # the element e_l
 
-    # This is the notation `\{X\}` from just before (5.3a) of [GreenPoly]_.
+    # This is the notation `\{X\}` from just before (5.3a) of [Gr2007]_.
     S = SGA._indices
     BracC = SGA._from_dict({S(x.tuple()): x.sign() for x in ST.column_stabilizer()},
                            remove_zeros=False)
