@@ -11,7 +11,7 @@ AUTHORS:
 
 .. rubric:: Milnor multiplication, `p=2`
 
-See Milnor's paper [Mil]_ for proofs, etc.
+See Milnor's paper [Mil1958]_ for proofs, etc.
 
 To multiply Milnor basis elements $\text{Sq}(r_1, r_2, ...)$ and
 $\text{Sq}(s_1, s_2,...)$ at the prime 2, form all possible matrices
@@ -22,7 +22,7 @@ weights are as follows: elements from column $i$ are multiplied by
 $2^i$.  For example, to multiply $\text{Sq}(2)$ and $\text{Sq}(1,1)$,
 form the matrices
 
-.. math::
+.. MATH::
 
   \begin{Vmatrix}
   * & 1 & 1 \\
@@ -48,7 +48,7 @@ both have a summand of 2.)
 Now, for each matrix with multinomial coefficient 1, let $t_n$ be
 the sum of the nth diagonal in the matrix; then
 
-.. math::
+.. MATH::
 
   \text{Sq}(r_1, r_2, ...) \text{Sq}(s_1, s_2, ...) = \sum \text{Sq}(t_1, t_2, ...)
 
@@ -59,18 +59,18 @@ $\text{Sq}(s)=\text{Sq}(s_1, s_2, ...)$; it returns as output a
 dictionary whose keys are tuples $t=(t_1, t_2, ...)$ of non-negative
 integers, and for each tuple the associated value is the coefficient
 of $\text{Sq}(t)$ in the product formula.  (Since we are working mod 2,
-this coefficient is 1 -- if it is zero, the the element is omitted from
+this coefficient is 1 -- if it is zero, the element is omitted from
 the dictionary altogether).
 
 .. rubric:: Milnor multiplication, odd primes
 
-As for the `p=2` case, see Milnor's paper [Mil]_ for proofs.
+As for the `p=2` case, see Milnor's paper [Mil1958]_ for proofs.
 
 Fix an odd prime $p$.  There are three steps to multiply Milnor basis
 elements $Q_{f_1} Q_{f_2} ... \mathcal{P}(q_1, q_2, ...)$ and
 $Q_{g_1} Q_{g_2} ... \mathcal{P}(s_1, s_2,...)$: first, use the formula
 
-.. math::
+.. MATH::
 
     \mathcal{P}(q_1, q_2, ...) Q_k = Q_k \mathcal{P}(q_1, q_2, ...)
     + Q_{k+1} \mathcal{P}(q_1 - p^k, q_2, ...)
@@ -82,7 +82,7 @@ Second, use the fact that the $Q_k$'s form an exterior algebra: $Q_k^2 =
 $Q_i Q_j = -Q_j Q_i$.  After these two steps, the product is a linear
 combination of terms of the form
 
-.. math::
+.. MATH::
 
     Q_{e_1} Q_{e_2} ... \mathcal{P}(r_1, r_2, ...) \mathcal{P}(s_1, s_2, ...).
 
@@ -95,7 +95,7 @@ row $j$: elements from column $i$ are multiplied by $p^i$.  For
 example when $p=5$, to multiply $\mathcal{P}(5)$ and
 $\mathcal{P}(1,1)$, form the matrices
 
-.. math::
+.. MATH::
 
     \begin{Vmatrix}
     * & 1 & 1 \\
@@ -115,14 +115,14 @@ all $n$.
 Now, for each matrix with nonzero multinomial coefficient $b_M$, let
 $t_n$ be the sum of the $n$-th diagonal in the matrix; then
 
-.. math::
+.. MATH::
 
     \mathcal{P}(r_1, r_2, ...) \mathcal{P}(s_1, s_2, ...)
     = \sum b_M \mathcal{P}(t_1, t_2, ...)
 
 For example when $p=5$, we have
 
-.. math::
+.. MATH::
 
     \mathcal{P}(5) \mathcal{P}(1,1) = \mathcal{P}(6,1) + 2 \mathcal{P}(0,2).
 
@@ -140,7 +140,7 @@ If `p=2`, then the mod 2 Steenrod algebra is generated by Steenrod
 squares `\text{Sq}^a` for `a \geq 0` (equal to the Milnor basis element
 `\text{Sq}(a)`).  The *Adem relations* are as follows: if `a < 2b`,
 
-.. math::
+.. MATH::
 
     \text{Sq}^a \text{Sq}^b = \sum_{j=0}^{a/2} \binom{b-j-1}{a-2j} \text{Sq}^{a+b-j} \text{Sq}^j
 
@@ -163,14 +163,14 @@ Milnor basis) and the Bockstein operation `\beta` (= `Q_0` in the
 Milnor basis).  The odd primary *Adem relations* are as follows: if `a
 < pb`,
 
-.. math::
+.. MATH::
 
     \mathcal{P}^a \mathcal{P}^b = \sum_{j=0}^{a/p} (-1)^{a+j}
     \binom{(b-j)(p-1)-1}{a-pj} \mathcal{P}^{a+b-j} \mathcal{P}^j
 
 Also, if `a \leq pb`,
 
-.. math::
+.. MATH::
 
     \mathcal{P}^a \beta \mathcal{P}^b = \sum_{j=0}^{a/p} (-1)^{a+j}
     \binom{(b-j)(p-1)}{a-pj} \beta \mathcal{P}^{a+b-j} \mathcal{P}^j +
@@ -179,7 +179,7 @@ Also, if `a \leq pb`,
 
 The *admissible* monomials at an odd prime are products of the form
 
-.. math::
+.. MATH::
 
     \beta^{\epsilon_0} \mathcal{P}^{s_1} \beta^{\epsilon_1}
     \mathcal{P}^{s_2} ...  \mathcal{P}^{s_n} \beta^{\epsilon_n}
@@ -198,6 +198,7 @@ representing a sum of admissible monomials.
 #  Copyright (C) 2008-2010 John H. Palmieri <palmieri@math.washington.edu>
 #  Distributed under the terms of the GNU General Public License (GPL)
 #*****************************************************************************
+from six.moves import range
 
 from sage.misc.cachefunc import cached_function
 
@@ -235,7 +236,7 @@ def milnor_multiplication(r,s):
 
     These examples correspond to the following product computations:
 
-    .. math::
+    .. MATH::
 
         \text{Sq}(2) \text{Sq}(1) = \text{Sq}(0,1) + \text{Sq}(3)
 
@@ -251,7 +252,7 @@ def milnor_multiplication(r,s):
     cols = len(s) + 1
     diags = len(r) + len(s)
     # initialize matrix
-    M = range(rows)
+    M = list(range(rows))
     for i in range(rows):
         M[i] = [0]*cols
     for j in range(1,cols):
@@ -405,7 +406,7 @@ def milnor_multiplication_odd(m1,m2,p):
 
     These examples correspond to the following product computations:
 
-    .. math::
+    .. MATH::
 
         p=5: \quad Q_0 Q_2 \mathcal{P}(5) Q_1 \mathcal{P}(1) = 4 Q_0 Q_1 Q_2 \mathcal{P}(0,1) + 4 Q_0 Q_1 Q_2 \mathcal{P}(6)
 
@@ -491,7 +492,7 @@ def milnor_multiplication_odd(m1,m2,p):
     # Now for the Milnor matrices.  For each entry '(e,r): coeff' in answer,
     # multiply r with s.  Record coefficient for matrix and multiply by coeff.
     # Store in 'result'.
-    if len(s) == 0:
+    if not s:
         result = answer
     else:
         result = {}
@@ -502,7 +503,7 @@ def milnor_multiplication_odd(m1,m2,p):
             cols = len(s) + 1
             diags = len(r) + len(s)
             # initialize matrix
-            M = range(rows)
+            M = list(range(rows))
             for i in range(rows):
                 M[i] = [0]*cols
             for j in range(1,cols):
@@ -590,7 +591,7 @@ def multinomial_odd(list,p):
     Furthermore, any multinomial coefficient $m! / (n_1! n_2! ...)$
     can be computed as a product of binomial coefficients: it equals
 
-    .. math::
+    .. MATH::
 
        \binom{n_1}{n_1} \binom{n_1 + n_2}{n_2} \binom{n_1 + n_2 + n_3}{n_3} ...
 
@@ -715,19 +716,19 @@ def adem(a, b, c=0, p=2, generic=None):
     The mod `p` Adem relations for the mod `p` Steenrod algebra are as
     follows: if `p=2`, then if `a < 2b`,
 
-    .. math::
+    .. MATH::
 
        \text{Sq}^a \text{Sq}^b = \sum_{j=0}^{a/2} \binom{b-j-1}{a-2j} \text{Sq}^{a+b-j} \text{Sq}^j
 
     If `p` is odd, then if `a < pb`,
 
-    .. math::
+    .. MATH::
 
        P^a P^b = \sum_{j=0}^{a/p} (-1)^{a+j} \binom{(b-j)(p-1)-1}{a-pj} P^{a+b-j} P^j
 
     Also for `p` odd, if `a \leq pb`,
 
-    .. math::
+    .. MATH::
 
        P^a \beta P^b = \sum_{j=0}^{a/p} (-1)^{a+j} \binom{(b-j)(p-1)}{a-pj} \beta P^{a+b-j} P^j
            + \sum_{j=0}^{a/p} (-1)^{a+j-1} \binom{(b-j)(p-1)-1}{a-pj-1} P^{a+b-j} \beta P^j
@@ -754,7 +755,7 @@ def adem(a, b, c=0, p=2, generic=None):
     In either case, the keys in the output are all tuples of odd length,
     with ``(i_1, i_2, ..., i_m)`` representing
 
-    .. math::
+    .. MATH::
 
         \beta^{i_1} P^{i_2} \beta^{i_3} P^{i_4} ... \beta^{i_m}
 
@@ -862,7 +863,7 @@ def make_mono_admissible(mono, p=2, generic=None):
     i_2, ..., e_k)` where each `e_j` is either 0 or 1 and each `i_j`
     is a positive integer: this corresponds to the admissible monomial
 
-    .. math::
+    .. MATH::
 
        \beta^{e_1} \mathcal{P}^{i_2} \beta^{e_2} \mathcal{P}^{i_2} ...
        \mathcal{P}^{i_k} \beta^{e_k}
