@@ -1,5 +1,5 @@
 from .misc import (algdep, bernoulli, is_prime, is_prime_power,
-    is_pseudoprime, is_pseudoprime_power, is_pseudoprime_small_power,
+    is_pseudoprime, is_pseudoprime_power,
     prime_powers, primes_first_n, eratosthenes, primes,
     next_prime_power, next_probable_prime, next_prime,
     previous_prime, previous_prime_power, random_prime,
