@@ -419,14 +419,14 @@ from sage.symbolic.function import Function
 from sage.symbolic.function_factory import function_factory
 from sage.symbolic.integration.integral import (indefinite_integral,
         definite_integral)
-import sage.symbolic.pynac
+from sage.libs.pynac.pynac import symbol_table
 
 from sage.misc.lazy_import import lazy_import
 lazy_import('sage.interfaces.maxima_lib','maxima')
 
 
 ########################################################
-def symbolic_sum(expression, v, a, b, algorithm='maxima'):
+def symbolic_sum(expression, v, a, b, algorithm='maxima', hold=False):
     r"""
     Returns the symbolic sum `\sum_{v = a}^b expression` with respect
     to the variable `v` with endpoints `a` and `b`.
@@ -451,6 +451,10 @@ def symbolic_sum(expression, v, a, b, algorithm='maxima'):
 
       - ``'giac'`` - (optional) use Giac
 
+      - ``'sympy'`` - use SymPy
+
+    - ``hold`` - (default: ``False``) if ``True`` don't evaluate
+
     EXAMPLES::
 
         sage: k, n = var('k,n')
@@ -549,14 +553,43 @@ def symbolic_sum(expression, v, a, b, algorithm='maxima'):
 
     An example of this summation with Giac::
 
-        sage: symbolic_sum(1/(1+k^2), k, -oo, oo, algorithm = 'giac')           # optional - giac
+        sage: symbolic_sum(1/(1+k^2), k, -oo, oo, algorithm = 'giac')
         (pi*e^(2*pi) - pi*e^(-2*pi))/(e^(2*pi) + e^(-2*pi) - 2)
 
+    SymPy can't solve that summation::
+
+        sage: symbolic_sum(1/(1+k^2), k, -oo, oo, algorithm = 'sympy')
+        Traceback (most recent call last):
+        ...
+        AttributeError: Unable to convert SymPy result (=Sum(1/(k**2 + 1),
+        (k, -oo, oo))) into Sage
+
+    SymPy and Maxima 5.39.0 can do the following (see
+    :trac:`22005`)::
+
+        sage: sum(1/((2*n+1)^2-4)^2, n, 0, Infinity, algorithm='sympy')
+        1/64*pi^2
+        sage: sum(1/((2*n+1)^2-4)^2, n, 0, Infinity)
+        1/64*pi^2
+
     Use Maple as a backend for summation::
 
         sage: symbolic_sum(binomial(n,k)*x^k, k, 0, n, algorithm = 'maple')      # optional - maple
         (x + 1)^n
 
+    If you don't want to evaluate immediately give the ``hold`` keyword::
+
+        sage: s = sum(n, n, 1, k, hold=True); s
+        sum(n, n, 1, k)
+        sage: s.unhold()
+        1/2*k^2 + 1/2*k
+        sage: s.subs(k == 10)
+        sum(n, n, 1, 10)
+        sage: s.subs(k == 10).unhold()
+        55
+        sage: s.subs(k == 10).n()
+        55.0000000000000
+
     TESTS:
 
     :trac:`10564` is fixed::
@@ -580,6 +613,10 @@ def symbolic_sum(expression, v, a, b, algorithm='maxima'):
     if v in SR(a).variables() or v in SR(b).variables():
         raise ValueError("summation limits must not depend on the summation variable")
 
+    if hold == True:
+        from sage.functions.other import symbolic_sum as ssum
+        return ssum(expression, v, a, b)
+
     if algorithm == 'maxima':
         return maxima.sr_sum(expression,v,a,b)
 
@@ -613,6 +650,16 @@ def symbolic_sum(expression, v, a, b, algorithm='maxima'):
             raise ValueError("Giac cannot make sense of: %s" % sum)
         return result.sage()
 
+    elif algorithm == 'sympy':
+        expression,v,a,b = [expr._sympy_() for expr in (expression, v, a, b)]
+        from sympy import summation
+        result = summation(expression, (v, a, b))
+        try:
+            return result._sage_()
+        except AttributeError:
+            raise AttributeError("Unable to convert SymPy result (={}) into"
+                    " Sage".format(result))
+
     else:
         raise ValueError("unknown algorithm: %s" % algorithm)
 
@@ -1152,20 +1199,6 @@ def limit(ex, dir=None, taylor=False, algorithm='maxima', **argv):
         sage: limit(f(x), x = pi/4)
         Infinity
 
-    Check that we give deprecation warnings for 'above' and 'below',
-    :trac:`9200`::
-
-        sage: limit(1/x, x=0, dir='above')
-        doctest:...: DeprecationWarning: the keyword
-        'above' is deprecated. Please use 'right' or '+' instead.
-        See http://trac.sagemath.org/9200 for details.
-        +Infinity
-        sage: limit(1/x, x=0, dir='below')
-        doctest:...: DeprecationWarning: the keyword
-        'below' is deprecated. Please use 'left' or '-' instead.
-        See http://trac.sagemath.org/9200 for details.
-        -Infinity
-
     Check that :trac:`12708` is fixed::
 
         sage: limit(tanh(x),x=0)
@@ -1199,15 +1232,9 @@ def limit(ex, dir=None, taylor=False, algorithm='maxima', **argv):
     if algorithm == 'maxima':
         if dir is None:
             l = maxima.sr_limit(ex, v, a)
-        elif dir in ['plus', '+', 'right', 'above']:
-            if dir == 'above':
-                from sage.misc.superseded import deprecation
-                deprecation(9200, "the keyword 'above' is deprecated. Please use 'right' or '+' instead.")
+        elif dir in ['plus', '+', 'right']:
             l = maxima.sr_limit(ex, v, a, 'plus')
-        elif dir in ['minus', '-', 'left', 'below']:
-            if dir == 'below':
-                from sage.misc.superseded import deprecation
-                deprecation(9200, "the keyword 'below' is deprecated. Please use 'left' or '-' instead.")
+        elif dir in ['minus', '-', 'left']:
             l = maxima.sr_limit(ex, v, a, 'minus')
     elif algorithm == 'maxima_taylor':
         if dir is None:
@@ -1248,7 +1275,7 @@ def laplace(ex, t, s):
     defined for all real numbers `t \geq 0`, is the function
     `F(s)` defined by
 
-    .. math::
+    .. MATH::
 
                       F(s) = \int_{0}^{\infty} e^{-st} f(t) dt.
 
@@ -1278,7 +1305,7 @@ def laplace(ex, t, s):
     A BATTLE BETWEEN the X-women and the Y-men (by David
     Joyner): Solve
 
-    .. math::
+    .. MATH::
 
                    x' = -16y, x(0)=270,  y' = -x + 1, y(0) = 90.
 
@@ -1349,7 +1376,7 @@ def inverse_laplace(ex, t, s):
     DEFINITION: The inverse Laplace transform of a function
     `F(s)`, is the function `f(t)` defined by
 
-    .. math::
+    .. MATH::
 
                       F(s) = \frac{1}{2\pi i} \int_{\gamma-i\infty}^{\gamma + i\infty} e^{st} F(s) dt,
 
@@ -1454,7 +1481,7 @@ def at(ex, *args, **kwds):
     """
     if not isinstance(ex, (Expression, Function)):
         ex = SR(ex)
-    kwds={ (k[10:] if k[:10] == "_SAGE_VAR_" else k):v for k,v in kwds.iteritems()}
+    kwds={ (k[10:] if k[:10] == "_SAGE_VAR_" else k):v for k,v in six.iteritems(kwds)}
     if len(args) == 1 and isinstance(args[0],list):
         for c in args[0]:
             kwds[str(c.lhs())]=c.rhs()
@@ -1465,30 +1492,6 @@ def at(ex, *args, **kwds):
     return ex.subs(**kwds)
 
 
-#############################################3333
-def var_cmp(x,y):
-    """
-    Return comparison of the two variables x and y, which is just the
-    comparison of the underlying string representations of the
-    variables. This is used internally by the Calculus package.
-
-    INPUT:
-
-    - ``x, y`` - symbolic variables
-
-    OUTPUT: Python integer; either -1, 0, or 1.
-
-    EXAMPLES::
-
-        sage: sage.calculus.calculus.var_cmp(x,x)
-        0
-        sage: sage.calculus.calculus.var_cmp(x,var('z'))
-        -1
-        sage: sage.calculus.calculus.var_cmp(x,var('a'))
-        1
-    """
-    return cmp(repr(x), repr(y))
-
 def dummy_limit(*args):
     """
     This function is called to create formal wrappers of limits that
@@ -1693,6 +1696,9 @@ symtable = {'%pi':'pi', '%e': 'e', '%i':'I', '%gamma':'euler_gamma',\
 
 import re
 
+import six
+
+
 maxima_tick = re.compile("'[a-z|A-Z|0-9|_]*")
 
 maxima_qp = re.compile("\?\%[a-z|A-Z|0-9|_]*")  # e.g., ?%jacobi_cd
@@ -1740,7 +1746,7 @@ def symbolic_expression_from_maxima_string(x, equals_sub=False, maxima=maxima):
     :trac:`8459` fixed::
 
         sage: maxima('3*li[2](u)+8*li[33](exp(u))').sage()
-        8*polylog(33, e^u) + 3*polylog(2, u)
+        3*dilog(u) + 8*polylog(33, e^u)
 
     Check if :trac:`8345` is fixed::
 
@@ -1793,7 +1799,7 @@ def symbolic_expression_from_maxima_string(x, equals_sub=False, maxima=maxima):
         sage: sefms('%inf')
         +Infinity
     """
-    syms = sage.symbolic.pynac.symbol_table.get('maxima', {}).copy()
+    syms = symbol_table.get('maxima', {}).copy()
 
     if len(x) == 0:
         raise RuntimeError("invalid symbolic expression -- ''")
@@ -1886,7 +1892,7 @@ def symbolic_expression_from_maxima_string(x, equals_sub=False, maxima=maxima):
         # evaluation of maxima code are assumed pre-simplified
         is_simplified = True
         global _syms
-        _syms = sage.symbolic.pynac.symbol_table['functions'].copy()
+        _syms = symbol_table['functions'].copy()
         try:
             global _augmented_syms
             _augmented_syms = syms
@@ -1935,7 +1941,7 @@ def maxima_options(**kwds):
         sage: sage.calculus.calculus.maxima_options(an_option=True, another=False, foo='bar')
         'an_option=true,foo=bar,another=false'
     """
-    return ','.join(['%s=%s'%(key,mapped_opts(val)) for key, val in kwds.iteritems()])
+    return ','.join(['%s=%s'%(key,mapped_opts(val)) for key, val in six.iteritems(kwds)])
 
 
 # Parser for symbolic ring elements
@@ -1947,7 +1953,6 @@ def maxima_options(**kwds):
 # The dictionary _syms is used as a lookup table for the system function
 # registry by _find_func() below. It gets updated by
 # symbolic_expression_from_string() before calling the parser.
-from sage.symbolic.pynac import symbol_table
 _syms = syms_cur = symbol_table.get('functions', {})
 syms_default = dict(syms_cur)
 
@@ -1987,6 +1992,7 @@ def _find_var(name):
 
     # try to find the name in the global namespace
     # needed for identifiers like 'e', etc.
+    import sage.all
     try:
         return SR(sage.all.__dict__[name])
     except (KeyError, TypeError):
@@ -2019,6 +2025,7 @@ def _find_func(name, create_when_missing = True):
             return func
     except KeyError:
         pass
+    import sage.all
     try:
         func = SR(sage.all.__dict__[name])
         if not isinstance(func, Expression):
@@ -2058,7 +2065,7 @@ def symbolic_expression_from_string(s, syms=None, accept_sequence=False):
         [0, 3*y + e^pi]
     """
     global _syms
-    _syms = sage.symbolic.pynac.symbol_table['functions'].copy()
+    _syms = symbol_table['functions'].copy()
     parse_func = SR_parser.parse_sequence if accept_sequence else SR_parser.parse_expression
     if syms is None:
         return parse_func(s)
@@ -2091,6 +2098,7 @@ def _find_Mvar(name):
 
     # try to find the name in the global namespace
     # needed for identifiers like 'e', etc.
+    import sage.all
     try:
         return SR(sage.all.__dict__[name])
     except (KeyError, TypeError):
