@@ -281,7 +281,7 @@ def desolve(de, dvar, ics=None, ivar=None, show_method=False, contrib_ode=False)
     Some more types of ODE's::
 
         sage: desolve(x*diff(y,x)^2-(1+x*y)*diff(y,x)+y==0,y,contrib_ode=True,show_method=True)
-        [[y(x) == _C*e^x, y(x) == _C + log(x)], 'factor']
+        [[y(x) == _C + log(x), y(x) == _C*e^x], 'factor']
 
     ::
 
@@ -524,7 +524,7 @@ def desolve(de, dvar, ics=None, ivar=None, show_method=False, contrib_ode=False)
     soln=soln.sage()
     if is_SymbolicEquation(soln) and soln.lhs() == dvar:
         # Remark: Here we do not check that the right hand side does not depend on dvar.
-        # This probably will not hapen for soutions obtained via ode2, anyway.
+        # This probably will not happen for solutions obtained via ode2, anyway.
         soln = soln.rhs()
     if show_method:
         return [soln,maxima_method.str()]
@@ -1551,7 +1551,7 @@ def desolve_mintides(f, ics, initial, final, delta,  tolrel=1e-16, tolabs=1e-16)
     INPUT:
 
     - ``f`` -- symbolic function. Its first argument will be the independent
-      variable. Its output should be de derivatives of the deppendent variables.
+      variable. Its output should be de derivatives of the dependent variables.
 
     - ``ics`` -- a list or tuple with the initial conditions.
 
@@ -1620,9 +1620,9 @@ def desolve_mintides(f, ics, initial, final, delta,  tolrel=1e-16, tolabs=1e-16)
     genfiles_mintides(intfile, drfile, f, [N(_) for _ in ics], N(initial), N(final), N(delta), N(tolrel),
                      N(tolabs), fileoutput)
     subprocess.check_call('gcc -o ' + runmefile + ' ' + os.path.join(tempdir, '*.c ') +
-                          os.path.join('$SAGE_ROOT','local','lib','libTIDES.a') + ' $LDFLAGS '
-                          + os.path.join('-L$SAGE_ROOT','local','lib ') +' -lm  -O2 ' +
-                          os.path.join('-I$SAGE_ROOT','local','include '),
+                          os.path.join('$SAGE_LOCAL','lib','libTIDES.a') + ' $LDFLAGS '
+                          + os.path.join('-L$SAGE_LOCAL','lib ') +' -lm  -O2 ' +
+                          os.path.join('-I$SAGE_LOCAL','include '),
                           shell=True,  stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     subprocess.check_call(os.path.join(tempdir, 'runme'), shell=True,  stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     outfile = open(fileoutput)
@@ -1642,7 +1642,7 @@ def desolve_tides_mpfr(f, ics, initial, final, delta,  tolrel=1e-16, tolabs=1e-1
     INPUT:
 
     - ``f`` -- symbolic function. Its first argument will be the independent
-      variable. Its output should be de derivatives of the deppendent variables.
+      variable. Its output should be de derivatives of the dependent variables.
 
     - ``ics`` -- a list or tuple with the initial conditions.
 
@@ -1726,9 +1726,9 @@ def desolve_tides_mpfr(f, ics, initial, final, delta,  tolrel=1e-16, tolabs=1e-1
     genfiles_mpfr(intfile, drfile, f, ics, initial, final, delta, [], [],
                       digits, tolrel, tolabs, fileoutput)
     subprocess.check_call('gcc -o ' + runmefile + ' ' + os.path.join(tempdir, '*.c ') +
-                          os.path.join('$SAGE_ROOT','local','lib','libTIDES.a') + ' $LDFLAGS '
-                          + os.path.join('-L$SAGE_ROOT','local','lib ') + '-lmpfr -lgmp -lm  -O2 -w ' +
-                          os.path.join('-I$SAGE_ROOT','local','include ') ,
+                          os.path.join('$SAGE_LOCAL','lib','libTIDES.a') + ' $LDFLAGS '
+                          + os.path.join('-L$SAGE_LOCAL','lib ') + '-lmpfr -lgmp -lm  -O2 -w ' +
+                          os.path.join('-I$SAGE_LOCAL','include ') ,
                           shell=True,  stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     subprocess.check_call(os.path.join(tempdir, 'runme'), shell=True,  stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     outfile = open(fileoutput)
