@@ -508,7 +508,11 @@ explicit calls to Maxima or other systems.
     sage: # (OK-ish) D(x)Abs(x)
     sage: #    Verify(D(x) Abs(x), Sign(x));
     sage: diff(abs(x))
+    1/2*(x + conjugate(x))/abs(x)
+    sage: _ = var('x', domain='real')
+    sage: diff(abs(x))
     x/abs(x)
+    sage: forget()
 
 ::
 
