@@ -201,7 +201,7 @@ class CoxeterGroups(Category_singleton):
             unless this finiteness is explicitly specified::
 
                 sage: I = W.weak_order_ideal(predicate = lambda w: w.length() <= 2,
-                ...                          category = FiniteEnumeratedSets())
+                ....:                        category = FiniteEnumeratedSets())
                 sage: I.cardinality()
                 5
                 sage: list(I)
@@ -551,7 +551,7 @@ class CoxeterGroups(Category_singleton):
 
                 sage: W = WeylGroup("A3")
                 sage: W.canonical_representation()
-                Finite Coxeter group over Universal Cyclotomic Field with Coxeter matrix:
+                Finite Coxeter group over Integer Ring with Coxeter matrix:
                 [1 3 2]
                 [3 1 3]
                 [2 3 1]
@@ -1318,7 +1318,7 @@ class CoxeterGroups(Category_singleton):
             See :meth:`CoxeterGroups.ParentMethods.simple_projections`
             for the definition of the simple projections.
 
-            EXAMPLE::
+            EXAMPLES::
 
                 sage: W=CoxeterGroups().example()
                 sage: w=W.an_element()
@@ -1632,8 +1632,8 @@ class CoxeterGroups(Category_singleton):
                 sage: P4 = Permutations(4)
                 sage: def P4toW(w): return W.from_reduced_word(w.reduced_word())
                 sage: for u in P4:
-                ...       for v in P4:
-                ...           assert u.bruhat_lequal(v) == P4toW(u).bruhat_le(P4toW(v))
+                ....:     for v in P4:
+                ....:         assert u.bruhat_lequal(v) == P4toW(u).bruhat_le(P4toW(v))
 
                 sage: W = WeylGroup(["B",3])
                 sage: P = W.bruhat_poset() # This is built from bruhat_lower_covers
@@ -1998,8 +1998,7 @@ class CoxeterGroups(Category_singleton):
 
             REFERENCES:
 
-                .. [Deodhar] \V. Deodhar,  A splitting criterion for the Bruhat orderings on Coxeter groups. Comm. Algebra, 15:1889-1894, 1987.
-
+                - [Deo1987a]_
             """
 
             if self != self.coset_representative(index_set):
