@@ -8,6 +8,7 @@ Crystals
 #                  http://www.gnu.org/licenses/
 #******************************************************************************
 from __future__ import print_function
+from builtins import zip
 
 from sage.misc.cachefunc import cached_method
 from sage.misc.abstract_method import abstract_method
@@ -76,6 +77,7 @@ class Crystals(Category_singleton):
           Running the test suite of self.an_element()
           running ._test_category() . . . pass
           running ._test_eq() . . . pass
+          running ._test_new() . . . pass
           running ._test_not_implemented_methods() . . . pass
           running ._test_pickling() . . . pass
           running ._test_stembridge_local_axioms() . . . pass
@@ -89,6 +91,7 @@ class Crystals(Category_singleton):
         running ._test_enumerated_set_iter_list() . . . pass
         running ._test_eq() . . . pass
         running ._test_fast_iter() . . . pass
+        running ._test_new() . . . pass
         running ._test_not_implemented_methods() . . . pass
         running ._test_pickling() . . . pass
         running ._test_some_elements() . . . pass
@@ -755,21 +758,21 @@ class Crystals(Category_singleton):
 
                 sage: C = Crystals().example(3)
                 sage: G = C.digraph()
-                sage: view(G, tightpage=True)  # optional - dot2tex graphviz, not tested (opens external window)
+                sage: view(G)  # optional - dot2tex graphviz, not tested (opens external window)
 
             One may also overwrite the colors::
 
                 sage: C = Crystals().example(3)
                 sage: G = C.digraph()
                 sage: G.set_latex_options(color_by_label = {1:"red", 2:"purple", 3:"blue"})
-                sage: view(G, tightpage=True)  # optional - dot2tex graphviz, not tested (opens external window)
+                sage: view(G)  # optional - dot2tex graphviz, not tested (opens external window)
 
             Or one may add colors to yet unspecified edges::
 
                 sage: C = Crystals().example(4)
                 sage: G = C.digraph()
                 sage: C.cartan_type()._index_set_coloring[4]="purple"
-                sage: view(G, tightpage=True)  # optional - dot2tex graphviz, not tested (opens external window)
+                sage: view(G)  # optional - dot2tex graphviz, not tested (opens external window)
 
             Here is an example of how to take the top part up to a
             given depth of an infinite dimensional crystal::
@@ -796,7 +799,7 @@ class Crystals(Category_singleton):
                 sage: list(D)
                 [[[1, 1], [2]], [[1, 1], [3]], [[1, 2], [2]],
                  [[1, 3], [2]], [[1, 3], [3]]]
-                sage: view(D, tightpage=True)  # optional - dot2tex graphviz, not tested (opens external window)
+                sage: view(D)  # optional - dot2tex graphviz, not tested (opens external window)
 
             We can also choose to display particular arrows using the
             ``index_set`` option::
@@ -805,7 +808,20 @@ class Crystals(Category_singleton):
                 sage: G = C.digraph(index_set=[1,3])
                 sage: len(G.edges())
                 20
-                sage: view(G, tightpage=True)  # optional - dot2tex graphviz, not tested (opens external window)
+                sage: view(G)  # optional - dot2tex graphviz, not tested (opens external window)
+
+            TESTS:
+
+            We check that infinite crystals raise an error (:trac:`21986`)::
+
+                sage: B = crystals.infinity.Tableaux(['A',2])
+                sage: B.digraph()
+                Traceback (most recent call last):
+                ...
+                NotImplementedError: crystals not known to be finite
+                 must specify either the subset or depth
+                sage: B.digraph(depth=10)
+                Digraph on 161 vertices
 
             .. TODO:: Add more tests.
             """
@@ -819,6 +835,9 @@ class Crystals(Category_singleton):
 
             # Parse optional arguments
             if subset is None:
+                if self not in Crystals().Finite():
+                    raise NotImplementedError("crystals not known to be finite"
+                                              " must specify the subset")
                 subset = self
             if index_set is None:
                 index_set = self.index_set()
@@ -879,7 +898,7 @@ class Crystals(Category_singleton):
                 sage: T = crystals.Tableaux(['A',2],shape=[1])
                 sage: T._latex_()  # optional - dot2tex graphviz
                 '...tikzpicture...'
-                sage: view(T, tightpage = True) # optional - dot2tex graphviz, not tested (opens external window)
+                sage: view(T) # optional - dot2tex graphviz, not tested (opens external window)
 
             One can for example also color the edges using the following options::
 
@@ -1946,7 +1965,7 @@ class CrystalMorphismByGenerators(CrystalMorphism):
         elif isinstance(on_gens, (list, tuple)):
             if len(self._gens) != len(on_gens):
                 raise ValueError("invalid generator images")
-            d = {x: y for x,y in zip(self._gens, on_gens)}
+            d = {x: y for x, y in zip(self._gens, on_gens)}
             f = lambda x: d[x]
         else:
             f = on_gens
@@ -1976,7 +1995,7 @@ class CrystalMorphismByGenerators(CrystalMorphism):
             [[[3]], [[2]], [[1]]] |--> None
         """
         return '\n'.join(['{} |--> {}'.format(mg, im)
-                          for mg,im in zip(self._gens, self.im_gens())])
+                          for mg, im in zip(self._gens, self.im_gens())])
 
     def _check(self):
         """
@@ -2045,7 +2064,7 @@ class CrystalMorphismByGenerators(CrystalMorphism):
         """
         mg, ef, indices = self.to_module_generator(x)
         cur = self._on_gens(mg)
-        for op,i in reversed(zip(ef, indices)):
+        for op, i in reversed(list(zip(ef, indices))):
             if cur is None:
                 return None
 
