@@ -313,7 +313,7 @@ class Fields(CategoryWithAxiom):
             - ``f`` -- a univariate non-zero polynomial over this field
 
             ALGORITHM: For rings of characteristic zero, we use the algorithm
-            descriped in [Yun]_. Other fields may provide their own
+            descriped in [Yun1976]_. Other fields may provide their own
             implementation by overriding this method.
 
             EXAMPLES::
@@ -331,13 +331,6 @@ class Fields(CategoryWithAxiom):
                 sage: f = QQbar['x'](1)
                 sage: f.squarefree_decomposition()
                 1
-
-            REFERENCES:
-
-            .. [Yun] Yun, David YY. On square-free decomposition algorithms.
-               In Proceedings of the third ACM symposium on Symbolic and algebraic
-               computation, pp. 26-35. ACM, 1976.
-
             """
             from sage.structure.factorization import Factorization
             if f.degree() == 0:
@@ -694,3 +687,24 @@ class Fields(CategoryWithAxiom):
                 return (P.one(), P.zero(), ~other)
             # else both are 0
             return (P.zero(), P.zero(), P.zero())
+
+        def factor(self):
+            """
+            Return a factorization of ``self``.
+
+            Since ``self`` is either a unit or zero, this function is trivial.
+
+            EXAMPLES::
+
+                sage: x = GF(7)(5)
+                sage: x.factor()
+                5
+                sage: RR(0).factor()
+                Traceback (most recent call last):
+                ...
+                ArithmeticError: factorization of 0.000000000000000 is not defined
+            """
+            if not self:
+                raise ArithmeticError("factorization of {!r} is not defined".format(self))
+            from sage.structure.factorization import Factorization
+            return Factorization([], self)  # No factor; "self" as unit
