@@ -10,9 +10,10 @@ Highest Weight Crystals
 
 from sage.misc.cachefunc import cached_method
 from sage.categories.category_singleton import Category_singleton
-from sage.categories.crystals import Crystals, CrystalHomset, \
-    CrystalMorphismByGenerators
+from sage.categories.crystals import (Crystals, CrystalHomset,
+                                      CrystalMorphismByGenerators)
 from sage.categories.tensor import TensorProductsCategory
+from sage.graphs.dot2tex_utils import have_dot2tex
 
 class HighestWeightCrystals(Category_singleton):
     """
@@ -44,6 +45,7 @@ class HighestWeightCrystals(Category_singleton):
           Running the test suite of self.an_element()
           running ._test_category() . . . pass
           running ._test_eq() . . . pass
+          running ._test_new() . . . pass
           running ._test_not_implemented_methods() . . . pass
           running ._test_pickling() . . . pass
           running ._test_stembridge_local_axioms() . . . pass
@@ -57,6 +59,7 @@ class HighestWeightCrystals(Category_singleton):
         running ._test_enumerated_set_iter_list() . . . pass
         running ._test_eq() . . . pass
         running ._test_fast_iter() . . . pass
+        running ._test_new() . . . pass
         running ._test_not_implemented_methods() . . . pass
         running ._test_pickling() . . . pass
         running ._test_some_elements() . . . pass
@@ -240,7 +243,7 @@ class HighestWeightCrystals(Category_singleton):
 
             where `\Delta_+^{\vee}` denotes the set of positive coroots.
             Taking the limit as `q \to 1` gives the dimension of `B(\lambda)`.
-            For more information, see [Kac]_ Section 10.10.
+            For more information, see [Ka1990]_ Section 10.10.
 
             INPUT:
 
@@ -327,10 +330,6 @@ class HighestWeightCrystals(Category_singleton):
                  + 9*q^7 + 13*q^8 + 16*q^9 + 22*q^10 + 27*q^11
                  + 36*q^12 + 44*q^13 + 57*q^14 + 70*q^15 + O(x^16)
 
-            REFERENCES:
-
-            .. [Kac] Victor G. Kac. *Infinite-dimensional Lie Algebras*.
-               Third edition. Cambridge University Press, Cambridge, 1990.
             """
             from sage.rings.all import ZZ
             WLR = self.weight_lattice_realization()
@@ -448,8 +447,210 @@ class HighestWeightCrystals(Category_singleton):
                 raise TypeError("{} is not a crystal".format(Y))
             return HighestWeightCrystalHomset(self, Y, category=category, **options)
 
+        def digraph(self, subset=None, index_set=None, depth=None):
+            """
+            Return the DiGraph associated to ``self``.
+
+            INPUT:
+
+            - ``subset`` -- (optional) a subset of vertices for
+              which the digraph should be constructed
+
+            - ``index_set`` -- (optional) the index set to draw arrows
+
+            - ``depth`` -- the depth to draw; optional only for finite crystals
+
+            EXAMPLES::
+
+                sage: T = crystals.Tableaux(['A',2], shape=[2,1])
+                sage: T.digraph()
+                Digraph on 8 vertices
+                sage: S = T.subcrystal(max_depth=2)
+                sage: len(S)
+                5
+                sage: G = T.digraph(subset=list(S))
+                sage: G.is_isomorphic(T.digraph(depth=2), edge_labels=True)
+                True
+
+            TESTS:
+
+            The following example demonstrates the speed improvement.
+            The speedup in non-affine types is small however::
+
+                sage: depth = 5
+                sage: C = crystals.AlcovePaths(['A',2,1], [1,1,0])
+                sage: general_digraph = Crystals().parent_class.digraph
+                sage: S = C.subcrystal(max_depth=depth, direction='lower')
+                sage: %timeit C.digraph(depth=depth) # not tested
+                10 loops, best of 3: 48.9 ms per loop
+                sage: %timeit general_digraph(C, subset=S) # not tested
+                10 loops, best of 3: 96.5 ms per loop
+                sage: G1 = C.digraph(depth=depth)
+                sage: G2 = general_digraph(C, subset=S)
+                sage: G1.is_isomorphic(G2, edge_labels=True)
+                True
+            """
+            if subset is not None:
+                return Crystals().parent_class.digraph(self, subset, index_set)
+
+            if self not in Crystals().Finite() and depth is None:
+                raise NotImplementedError("crystals not known to be finite must"
+                                          " specify either the subset or depth")
+
+            from sage.graphs.all import DiGraph
+            if index_set is None:
+                index_set = self.index_set()
+
+            rank = 0
+            d = {g: {} for g in self.module_generators}
+            visited = set(d.keys())
+
+            while depth is None or rank < depth:
+                recently_visited = set()
+                for x in visited:
+                    d.setdefault(x, {}) # does nothing if there's a default
+                    for i in index_set:
+                        xfi = x.f(i)
+                        if xfi is not None:
+                            d[x][xfi] = i
+                            recently_visited.add(xfi)
+                if not recently_visited: # No new nodes, nothing more to do
+                    break
+                rank += 1
+                visited = recently_visited
+
+            G = DiGraph(d)
+            if have_dot2tex():
+                G.set_latex_options(format="dot2tex",
+                                    edge_labels=True,
+                                    color_by_label=self.cartan_type()._index_set_coloring)
+            return G
+
     class ElementMethods:
-        pass
+        def string_parameters(self, word=None):
+            r"""
+            Return the string parameters of ``self`` corresponding to the
+            reduced word ``word``.
+
+            Given a reduced expression `w = s_{i_1} \cdots s_{i_k}`,
+            the string parameters of `b \in B` corresponding to `w`
+            are `(a_1, \ldots, a_k)` such that
+
+            .. MATH::
+
+                \begin{aligned}
+                e_{i_m}^{a_m} \cdots e_{i_1}^{a_1} b & \neq 0 \\
+                e_{i_m}^{a_m+1} \cdots e_{i_1}^{a_1} b & = 0
+                \end{aligned}
+
+            for all `1 \leq m \leq k`.
+
+            For connected components isomorphic to `B(\lambda)` or
+            `B(\infty)`, if `w = w_0` is the longest element of the
+            Weyl group, then the path determined by the string
+            parametrization terminates at the highest weight vector.
+
+            INPUT:
+
+            - ``word`` -- a word in the alphabet of the index set; if not
+              specified and we are in finite type, then this will be some
+              reduced expression for the long element determined by the
+              Weyl group
+
+            EXAMPLES::
+
+                sage: B = crystals.infinity.NakajimaMonomials(['A',3])
+                sage: mg = B.highest_weight_vector()
+                sage: w0 = [1,2,1,3,2,1]
+                sage: mg.string_parameters(w0)
+                [0, 0, 0, 0, 0, 0]
+                sage: mg.f_string([1]).string_parameters(w0)
+                [1, 0, 0, 0, 0, 0]
+                sage: mg.f_string([1,1,1]).string_parameters(w0)
+                [3, 0, 0, 0, 0, 0]
+                sage: mg.f_string([1,1,1,2,2]).string_parameters(w0)
+                [1, 2, 2, 0, 0, 0]
+                sage: mg.f_string([1,1,1,2,2]) == mg.f_string([1,1,2,2,1])
+                True
+                sage: x = mg.f_string([1,1,1,2,2,1,3,3,2,1,1,1])
+                sage: x.string_parameters(w0)
+                [4, 1, 1, 2, 2, 2]
+                sage: x.string_parameters([3,2,1,3,2,3])
+                [2, 3, 7, 0, 0, 0]
+                sage: x == mg.f_string([1]*7 + [2]*3 + [3]*2)
+                True
+
+            ::
+
+                sage: B = crystals.infinity.Tableaux("A5")
+                sage: b = B(rows=[[1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,3,6,6,6,6,6,6],
+                ....:             [2,2,2,2,2,2,2,2,2,4,5,5,5,6],
+                ....:             [3,3,3,3,3,3,3,5],
+                ....:             [4,4,4,6,6,6],
+                ....:             [5,6]])
+                sage: b.string_parameters([1,2,1,3,2,1,4,3,2,1,5,4,3,2,1])
+                [0, 1, 1, 1, 1, 0, 4, 4, 3, 0, 11, 10, 7, 7, 6]
+
+                sage: B = crystals.infinity.Tableaux("G2")
+                sage: b = B(rows=[[1,1,1,1,1,3,3,0,-3,-3,-2,-2,-1,-1,-1,-1],[2,3,3,3]])
+                sage: b.string_parameters([2,1,2,1,2,1])
+                [5, 13, 11, 15, 4, 4]
+                sage: b.string_parameters([1,2,1,2,1,2])
+                [7, 12, 15, 8, 10, 0]
+
+            ::
+
+                sage: C = crystals.Tableaux(['C',2], shape=[2,1])
+                sage: mg = C.highest_weight_vector()
+                sage: lw = C.lowest_weight_vectors()[0]
+                sage: lw.string_parameters([1,2,1,2])
+                [1, 2, 3, 1]
+                sage: lw.string_parameters([2,1,2,1])
+                [1, 3, 2, 1]
+                sage: lw.e_string([2,1,1,1,2,2,1]) == mg
+                True
+                sage: lw.e_string([1,2,2,1,1,1,2]) == mg
+                True
+
+            TESTS::
+
+                sage: B = crystals.infinity.NakajimaMonomials(['B',3])
+                sage: mg = B.highest_weight_vector()
+                sage: mg.string_parameters()
+                [0, 0, 0, 0, 0, 0, 0, 0, 0]
+                sage: w0 = WeylGroup(['B',3]).long_element().reduced_word()
+                sage: def f_word(params):
+                ....:     return reversed([index for i, index in enumerate(w0)
+                ....:                      for _ in range(params[i])])
+                sage: all(mg.f_string( f_word(x.value.string_parameters(w0)) ) == x.value
+                ....:     for x in B.subcrystal(max_depth=4))
+                True
+
+                sage: B = crystals.infinity.NakajimaMonomials(['A',2,1])
+                sage: mg = B.highest_weight_vector()
+                sage: mg.string_parameters()
+                Traceback (most recent call last):
+                ...
+                ValueError: the word must be specified because the
+                 Weyl group is not finite
+            """
+            if word is None:
+                if not self.cartan_type().is_finite():
+                    raise ValueError("the word must be specified because"
+                                     " the Weyl group is not finite")
+                from sage.combinat.root_system.weyl_group import WeylGroup
+                word = WeylGroup(self.cartan_type()).long_element().reduced_word()
+            x = self
+            params = []
+            for i in word:
+                count = 0
+                y = x.e(i)
+                while y is not None:
+                    x = y
+                    y = x.e(i)
+                    count += 1
+                params.append(count)
+            return params
 
     class TensorProducts(TensorProductsCategory):
         """
