@@ -32,6 +32,10 @@ from sage.categories.modules import Modules
 from sage.categories.poor_man_map import PoorManMap
 from sage.rings.infinity import Infinity
 from sage.structure.element import Element, parent
+
+import six
+
+
 lazy_import('sage.modules.with_basis.morphism',
             ['ModuleMorphismByLinearity',
              'ModuleMorphismFromMatrix',
@@ -342,7 +346,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: phi.category_for() # todo: not implemented (ZZ is currently not in Modules(ZZ))
                 Category of modules over Integer Ring
 
-            Or more generaly any ring admitting a coercion map from
+            Or more generally any ring admitting a coercion map from
             the base ring::
 
                 sage: phi = X.module_morphism(on_basis=lambda i: i, codomain=RR )
@@ -453,7 +457,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
             invertible elements on its diagonal. This is used to compute
             preimages and to invert the morphism::
 
-                sage: I = range(1,200)
+                sage: I = list(range(1, 200))
                 sage: X = CombinatorialFreeModule(QQ, I); X.rename("X"); x = X.basis()
                 sage: Y = CombinatorialFreeModule(QQ, I); Y.rename("Y"); y = Y.basis()
                 sage: f = Y.sum_of_monomials * divisors
@@ -1077,11 +1081,11 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
             if hasattr( codomain, 'linear_combination' ):
                 mc = x.monomial_coefficients(copy=False)
                 return codomain.linear_combination( (on_basis(key), coeff)
-                                                    for key, coeff in mc.iteritems() )
+                                                    for key, coeff in six.iteritems(mc) )
             else:
                 return_sum = codomain.zero()
                 mc = x.monomial_coefficients(copy=False)
-                for key, coeff in mc.iteritems():
+                for key, coeff in six.iteritems(mc):
                     return_sum += coeff * on_basis(key)
                 return return_sum
 
@@ -1099,7 +1103,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
             """
             mc = x.monomial_coefficients(copy=False)
             return self.linear_combination( (on_basis(key), coeff)
-                                            for key, coeff in mc.iteritems() )
+                                            for key, coeff in six.iteritems(mc) )
 
     class ElementMethods:
         # TODO: Define the appropriate element methods here (instead of in
@@ -1281,7 +1285,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 4
             """
             zero = self.parent().base_ring().zero()
-            return len([key for key, coeff in self.monomial_coefficients(copy=False).iteritems()
+            return len([key for key, coeff in six.iteritems(self.monomial_coefficients(copy=False))
                         if coeff != zero])
 
         def length(self):
@@ -1330,7 +1334,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 [[1], [1, 1, 1], [2, 1], [4]]
             """
             zero = self.parent().base_ring().zero()
-            return [key for key, coeff in self.monomial_coefficients(copy=False).iteritems()
+            return [key for key, coeff in six.iteritems(self.monomial_coefficients(copy=False))
                     if coeff != zero]
 
         def monomials(self):
@@ -1374,7 +1378,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
             P = self.parent()
             zero = P.base_ring().zero()
             return [P.term(key, value)
-                    for key, value in self.monomial_coefficients(copy=False).iteritems()
+                    for key, value in six.iteritems(self.monomial_coefficients(copy=False))
                     if value != zero]
 
         def coefficients(self, sort=True):
@@ -1412,9 +1416,9 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
             zero = self.parent().base_ring().zero()
             mc = self.monomial_coefficients(copy=False)
             if not sort:
-                return [value for key, value in mc.iteritems() if value != zero]
+                return [value for key, value in six.iteritems(mc) if value != zero]
 
-            v = sorted([(key, value) for key, value in mc.iteritems()
+            v = sorted([(key, value) for key, value in six.iteritems(mc)
                         if value != zero])
             return [value for key, value in v]
 
@@ -2189,7 +2193,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                     sage: def f(a,b):
                     ....:     return sum(a.coefficients()) * sum(b.coefficients())
                     sage: type(f(A.zero(), B.zero()))
-                    <type 'int'>
+                    <... 'int'>
 
                 Which would be wrong and break this method::
 
