@@ -4,7 +4,7 @@ Reed-Muller code
 Given integers `m, r` and a finite field `F`,
 the corresponding Reed-Muller Code is the set:
 
-.. math::
+.. MATH::
 
     \{ (f(\alpha_i)\mid \alpha_i \in F^m)  \mid  f \in F[x_1,x_2,\ldots,x_m], \deg f \leq r \}
 
@@ -139,7 +139,7 @@ def ReedMullerCode(base_field, order, num_of_var):
 
     A Reed-Muller Code of order `r` and number of variables `m` over a finite field `F` is the set:
 
-    .. math::
+    .. MATH::
 
         \{ (f(\alpha_i)\mid \alpha_i \in F^m)  \mid  f \in F[x_1,x_2,\ldots,x_m], \deg f \leq r \}
 
@@ -661,7 +661,9 @@ class ReedMullerVectorEncoder(Encoder):
                                 degree, submultiset=True)
             matrix_list += [[reduce(mul, [x[i] for i in exponent], 1)
                              for x in points] for exponent in exponents]
-        return matrix(base_field, matrix_list)
+        M = matrix(base_field, matrix_list)
+        M.set_immutable()
+        return M
 
     def points(self):
         r"""
