@@ -112,6 +112,9 @@ from sage.rings.integer_ring import ZZ
 from sage.matrix.matrix import is_Matrix
 from sage.matrix.matrix_space import MatrixSpace
 
+import six
+
+
 class NakajimaMonomial(Element):
     r"""
     An element of the monomial crystal.
@@ -187,7 +190,7 @@ class NakajimaMonomial(Element):
         if not self._Y:
             return "1"
 
-        L = sorted(self._Y.iteritems(), key=lambda x: (x[0][0], x[0][1]))
+        L = sorted(six.iteritems(self._Y), key=lambda x: (x[0][0], x[0][1]))
         exp = lambda e: "^{}".format(e) if e != 1 else ""
         return ' '.join("Y({},{})".format(mon[0][0], mon[0][1]) + exp(mon[1])
                         for mon in L)
@@ -205,13 +208,13 @@ class NakajimaMonomial(Element):
         """
         try:
             Y = {(i,0): c for i,c in self.parent().hw}
-        except:
+        except Exception:
             Y = {}
 
         if not Y and not self._A:
             return "1"
 
-        L = sorted(Y.iteritems(), key=lambda x: (x[0][0], x[0][1]))
+        L = sorted(six.iteritems(Y), key=lambda x: (x[0][0], x[0][1]))
         exp = lambda e: "^{}".format(e) if e != 1 else ""
         ret = ' '.join("Y({},{})".format(mon[0][0], mon[0][1]) + exp(mon[1])
                         for mon in L)
@@ -219,7 +222,7 @@ class NakajimaMonomial(Element):
             return ret
         if Y:
             ret += ' '
-        L = sorted(self._A.iteritems(), key=lambda x: (x[0][0], x[0][1]))
+        L = sorted(six.iteritems(self._A), key=lambda x: (x[0][0], x[0][1]))
         return ret + ' '.join("A({},{})".format(mon[0][0], mon[0][1]) + exp(mon[1])
                               for mon in L)
 
@@ -233,7 +236,7 @@ class NakajimaMonomial(Element):
             4715601665014767730  # 64-bit
             -512614286           # 32-bit
         """
-        return hash(frozenset(tuple(self._Y.iteritems())))
+        return hash(frozenset(tuple(six.iteritems(self._Y))))
 
     def __eq__(self, other):
         r"""
@@ -310,7 +313,7 @@ class NakajimaMonomial(Element):
         if not self._Y:
             return "\\boldsymbol{1}"
 
-        L = sorted(self._Y.iteritems(), key=lambda x:(x[0][0],x[0][1]))
+        L = sorted(six.iteritems(self._Y), key=lambda x:(x[0][0],x[0][1]))
         return_str = ''
         for x in L:
             if x[1] != 1:
@@ -332,20 +335,20 @@ class NakajimaMonomial(Element):
         """
         try:
             Y = {(i,0): c for i,c in self.parent().hw}
-        except:
+        except Exception:
             Y = {}
 
         if not Y and not self._A:
             return "\\boldsymbol{1}"
 
-        L = sorted(Y.iteritems(), key=lambda x:(x[0][0],x[0][1]))
+        L = sorted(six.iteritems(Y), key=lambda x:(x[0][0],x[0][1]))
         return_str = ''
         for x in L:
             if x[1] != 1:
                 return_str += "Y_{%s,%s}"%(x[0][0],x[0][1]) + "^{%s} "%x[1]
             else:
                 return_str += "Y_{%s,%s} "%(x[0][0],x[0][1])
-        L = sorted(self._A.iteritems(), key=lambda x:(x[0][0],x[0][1]))
+        L = sorted(six.iteritems(self._A), key=lambda x:(x[0][0],x[0][1]))
         for x in L:
             if x[1] != 1:
                 return_str += "A_{%s,%s}"%(x[0][0],x[0][1]) + "^{%s} "%x[1]
@@ -372,7 +375,7 @@ class NakajimaMonomial(Element):
         """
         P = self.parent().weight_lattice_realization()
         La = P.fundamental_weights()
-        return P(sum(v*La[k[0]] for k,v in self._Y.iteritems()))
+        return P(sum(v*La[k[0]] for k,v in six.iteritems(self._Y)))
 
     def weight_in_root_lattice(self):
         r"""
@@ -398,7 +401,7 @@ class NakajimaMonomial(Element):
         """
         Q = RootSystem(self.parent().cartan_type()).root_lattice()
         al = Q.simple_roots()
-        return Q.sum(e*al[k[0]] for k,e in self._A.iteritems())
+        return Q.sum(e*al[k[0]] for k,e in six.iteritems(self._A))
 
     def weight(self):
         r"""
@@ -476,7 +479,7 @@ class NakajimaMonomial(Element):
                 continue
             else:
                 d[(i,a)] = 0
-        S = sorted((x for x in d.iteritems() if x[0][0] == i), key=lambda x: x[0][1])
+        S = sorted((x for x in six.iteritems(d) if x[0][0] == i), key=lambda x: x[0][1])
         return max(sum(S[k][1] for k in range(s)) for s in range(1,len(S)+1))
 
     def _ke(self, i):
@@ -508,7 +511,7 @@ class NakajimaMonomial(Element):
                 d[(i,a)] = 0
         total = ZZ.zero()
         L = []
-        S = sorted((x for x in d.iteritems() if x[0][0] == i), key=lambda x: x[0][1])
+        S = sorted((x for x in six.iteritems(d) if x[0][0] == i), key=lambda x: x[0][1])
         for var,exp in S:
             total += exp
             if total == phi:
@@ -541,7 +544,7 @@ class NakajimaMonomial(Element):
                 continue
             else:
                 d[(i,a)] = 0
-        S = sorted((x for x in d.iteritems() if x[0][0] == i), key=lambda x: x[0][1])
+        S = sorted((x for x in six.iteritems(d) if x[0][0] == i), key=lambda x: x[0][1])
         sum = 0
         phi = self.phi(i)
         for var,exp in S:
@@ -611,7 +614,7 @@ class NakajimaMonomial(Element):
             if cm[j_index,i-shift] != 0:
                 Aik[(j, ke+c)] = cm[j_index,i-shift]
         # Multiply by Aik
-        for key,value in Aik.iteritems():
+        for key,value in six.iteritems(Aik):
             if key in newdict:
                 if newdict[key] == -value: # The result would be a 0 exponent
                     del newdict[key]
@@ -660,7 +663,7 @@ class NakajimaMonomial(Element):
             if cm[j_index,i-shift] != 0:
                 Aik[(j, kf+c)] = -cm[j_index,i-shift]
         # Multiply by Aik
-        for key,value in Aik.iteritems():
+        for key,value in six.iteritems(Aik):
             if key in newdict:
                 if newdict[key] == -value: # The result would be a 0 exponent
                     del newdict[key]
@@ -921,7 +924,7 @@ class InfinityCrystalOfNakajimaMonomials(UniqueRepresentation, Parent):
             if ct.is_finite():
                 shift = 1
             Y = {}
-            for k,v in A.iteritems():
+            for k,v in six.iteritems(A):
                 Y[k] = Y.get(k, 0) + v
                 Y[(k[0],k[1]+1)] = Y.get((k[0],k[1]+1), 0) + v
                 for j_index,j in enumerate(I):
