@@ -958,7 +958,7 @@ class TensorProductOfCrystalsElement(ImmutableListWithParent):
         Comparison of two elements of this crystal:
 
         - different length: incomparable
-        - otherwise lexicographicaly, considering ``self[i]`` and ``other[i]``
+        - otherwise lexicographically, considering ``self[i]`` and ``other[i]``
           as incomparable if ``self[i] < other[i]`` returns NotImplemented
         """
         if parent(self) is not parent(other):
@@ -1928,7 +1928,7 @@ class CrystalOfTableaux(CrystalOfWords):
         crystal of given shape. The module generator is the unique tableau with equal
         shape and content.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = crystals.Tableaux(['D',3], shape = [1,1])
             sage: T.module_generator([1,1])
@@ -2131,7 +2131,7 @@ class CrystalOfTableauxElement(TensorProductOfRegularCrystalsElement):
             }
         """
         from sage.combinat.output import tex_from_array
-        # Modified version of to_tableau() to have the entrys be letters
+        # Modified version of to_tableau() to have the entries be letters
         #   rather than their values
         if self._list == []:
             return "{\\emptyset}"
@@ -2161,7 +2161,7 @@ class CrystalOfTableauxElement(TensorProductOfRegularCrystalsElement):
             sage: type(t)
             <class 'sage.combinat.tableau.Tableaux_all_with_category.element_class'>
             sage: type(t[0][0])
-            <type 'int'>
+            <... 'int'>
             sage: T = crystals.Tableaux(['D',3], shape = [1,1])
             sage: t=T(rows=[[-3],[3]]).to_tableau(); t
             [[-3], [3]]
