@@ -11,6 +11,7 @@ Free modules
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from __future__ import print_function
+from six.moves import range
 
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.structure.element import Element, have_same_parent
@@ -26,10 +27,13 @@ from sage.sets.disjoint_union_enumerated_sets import DisjointUnionEnumeratedSets
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_attribute import lazy_attribute
 from sage.categories.all import Category, Sets, ModulesWithBasis
-from sage.combinat.dict_addition import dict_addition, dict_linear_combination
+import sage.data_structures.blas_dict as blas
 from sage.typeset.ascii_art import AsciiArt, empty_ascii_art
 from sage.typeset.unicode_art import UnicodeArt, empty_unicode_art
 
+import six
+
+
 # TODO: move the content of this class to CombinatorialFreeModule.Element and ModulesWithBasis.Element
 class CombinatorialFreeModuleElement(Element):
     def __init__(self, M, x):
@@ -67,7 +71,7 @@ class CombinatorialFreeModuleElement(Element):
             sage: [i for i in sorted(a)]
             [([2, 1], 1), ([3], 1)]
         """
-        return self._monomial_coefficients.iteritems()
+        return six.iteritems(self._monomial_coefficients)
 
     def __contains__(self, x):
         """
@@ -168,7 +172,7 @@ class CombinatorialFreeModuleElement(Element):
             sage: a = s([2,1])+2*s([3,2])
             sage: d = a.monomial_coefficients()
             sage: type(d)
-            <type 'dict'>
+            <... 'dict'>
             sage: d[ Partition([2,1]) ]
             1
             sage: d[ Partition([3,2]) ]
@@ -194,7 +198,7 @@ class CombinatorialFreeModuleElement(Element):
             [('c', 2), ('b', 3), ('a', 1)]
             sage: F.print_options(sorting_reverse=False) #reset to original state
 
-        .. seealso:: :meth:`_repr_`, :meth:`_latex_`, :meth:`print_options`
+        .. SEEALSO:: :meth:`_repr_`, :meth:`_latex_`, :meth:`print_options`
         """
         print_options = self.parent().print_options()
         v = self._monomial_coefficients.items()
@@ -254,6 +258,8 @@ class CombinatorialFreeModuleElement(Element):
                ***        *             *        ****         ***      **
                *          *           ***        *           **
                *                      *
+            sage: ascii_art(M.zero())
+            0
         """
         from sage.misc.misc import coeff_repr
         terms = self._sorted_items_for_printing()
@@ -296,7 +302,7 @@ class CombinatorialFreeModuleElement(Element):
                 s += AsciiArt([coeff], break_points) + b
                 first = False
         if first:
-            return "0"
+            return AsciiArt(["0"])
         elif s == empty_ascii_art:
             return AsciiArt(["1"])
         else:
@@ -540,10 +546,10 @@ class CombinatorialFreeModuleElement(Element):
             sage: len(a.monomial_coefficients())
             1
         """
-        assert have_same_parent(self, other)
-
         F = self.parent()
-        return F._from_dict( dict_addition( [ self._monomial_coefficients, other._monomial_coefficients ] ), remove_zeros=False )
+        return F._from_dict(blas.add(self._monomial_coefficients,
+                                     other._monomial_coefficients),
+                            remove_zeros=False)
 
     def _neg_(self):
         """
@@ -562,7 +568,8 @@ class CombinatorialFreeModuleElement(Element):
             -s[2, 1]
         """
         F = self.parent()
-        return F._from_dict( dict_linear_combination( [ ( self._monomial_coefficients, -1 ) ] ), remove_zeros=False )
+        return F._from_dict(blas.negate(self._monomial_coefficients),
+                            remove_zeros=False)
 
     def _sub_(self, other):
         """
@@ -579,9 +586,11 @@ class CombinatorialFreeModuleElement(Element):
             sage: s([2,1]) - s([5,4]) # indirect doctest
             s[2, 1] - s[5, 4]
         """
-        assert have_same_parent(self, other)
         F = self.parent()
-        return F._from_dict( dict_linear_combination( [ ( self._monomial_coefficients, 1 ), (other._monomial_coefficients, -1 ) ] ), remove_zeros=False )
+        return F._from_dict(blas.axpy(-1,
+                                      other._monomial_coefficients,
+                                      self._monomial_coefficients),
+                            remove_zeros=False)
 
     def _coefficient_fast(self, m):
         """
@@ -761,12 +770,8 @@ class CombinatorialFreeModuleElement(Element):
 
         F = self.parent()
         D = self._monomial_coefficients
-        if self_on_left:
-            D = dict_linear_combination( [ ( D, scalar ) ], factor_on_left = False )
-        else:
-            D = dict_linear_combination( [ ( D, scalar ) ] )
-
-        return F._from_dict( D, remove_zeros=False )
+        return F._from_dict(blas.scal(scalar, D, factor_on_left=not self_on_left),
+                            remove_zeros=False)
 
     # For backward compatibility
     _lmul_ = _acted_upon_
@@ -798,9 +803,8 @@ class CombinatorialFreeModuleElement(Element):
         x = self.base_ring()( x )
         x_inv = x**-1
         D = self._monomial_coefficients
-        D = dict_linear_combination( [ ( D, x_inv ) ] )
-
-        return F._from_dict( D, remove_zeros=False )
+        return F._from_dict(blas.scal(x_inv, D),
+                            remove_zeros=False)
 
     __div__ = __truediv__
 
@@ -1065,6 +1069,8 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
             sage: F is G
             False
         """
+        if isinstance(basis_keys, range):
+            basis_keys = tuple(basis_keys)
         if isinstance(basis_keys, (list, tuple)):
             basis_keys = FiniteEnumeratedSet(basis_keys)
         category = ModulesWithBasis(base_ring).or_subcategory(category)
@@ -1121,10 +1127,10 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
         turn triggers ``self._repr_()``::
 
             sage: class MyAlgebra(CombinatorialFreeModule):
-            ...       def _repr_(self):
-            ...           return "MyAlgebra on %s"%(self.basis().keys())
-            ...       def product_on_basis(self,i,j):
-            ...           pass
+            ....:     def _repr_(self):
+            ....:         return "MyAlgebra on %s"%(self.basis().keys())
+            ....:     def product_on_basis(self,i,j):
+            ....:         pass
             sage: MyAlgebra(ZZ, ZZ, category = AlgebrasWithBasis(QQ))
             MyAlgebra on Integer Ring
 
@@ -1558,7 +1564,7 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
             sage: A._order_cmp('a', 'y')
             1
         """
-        return cmp( self._rank_basis(x), self._rank_basis(y) )
+        return cmp(self._rank_basis(x), self._rank_basis(y))
 
     def get_order_key(self):
         """
@@ -1604,7 +1610,7 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
     @cached_method
     def _dense_free_module(self, base_ring=None):
         """
-        Returns a dense free module of the same dimension
+        Return a dense free module of the same dimension.
 
         INPUT:
 
@@ -1647,7 +1653,7 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
             True
         """
         cc = self.get_order()
-        return self._from_dict(dict( (cc[index], coeff) for (index,coeff) in vector.iteritems()))
+        return self._from_dict(dict( (cc[index], coeff) for (index,coeff) in six.iteritems(vector)))
 
     def __cmp__(self, other):
         """
@@ -1663,7 +1669,8 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
         if not isinstance(other, self.__class__):
             return -1
         c = cmp(self.base_ring(), other.base_ring())
-        if c: return c
+        if c:
+            return c
         return 0
 
     def sum(self, iter_of_elements):
@@ -1685,8 +1692,8 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
             sage: F.sum( f for _ in range(5) )
             10*B[1] + 10*B[2]
         """
-        D = dict_addition( element._monomial_coefficients for element in iter_of_elements )
-        return self._from_dict( D, remove_zeros=False )
+        D = blas.sum(element._monomial_coefficients for element in iter_of_elements)
+        return self._from_dict(D, remove_zeros=False)
 
     def linear_combination(self, iter_of_elements_coeff, factor_on_left=True):
         """
@@ -1712,7 +1719,10 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
             sage: F.linear_combination( (f,i) for i in range(5) )
             20*B[1] + 20*B[2]
         """
-        return self._from_dict( dict_linear_combination( ( ( element._monomial_coefficients, coeff ) for element, coeff in iter_of_elements_coeff ), factor_on_left=factor_on_left ), remove_zeros=False )
+        return self._from_dict(blas.linear_combination( ((element._monomial_coefficients, coeff)
+                                                        for element, coeff in iter_of_elements_coeff),
+                                                        factor_on_left=factor_on_left ),
+                               remove_zeros=False)
 
     def term(self, index, coeff=None):
         """
@@ -1735,7 +1745,7 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
         """
         if coeff is None:
             coeff = self.base_ring().one()
-        return self._from_dict( {index: coeff} )
+        return self._from_dict({index: coeff})
 
     def _monomial(self, index):
         """
@@ -1745,7 +1755,7 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
             sage: F._monomial('a')
             B['a']
         """
-        return self._from_dict( {index: self.base_ring().one()}, remove_zeros = False )
+        return self._from_dict({index: self.base_ring().one()}, remove_zeros=False)
 
     @lazy_attribute
     def monomial(self):
@@ -1873,9 +1883,9 @@ class CombinatorialFreeModule(UniqueRepresentation, Module, IndexedGenerators):
         assert isinstance(d, dict)
         if coerce:
             R = self.base_ring()
-            d = {key: R(coeff) for key,coeff in d.iteritems()}
+            d = {key: R(coeff) for key,coeff in six.iteritems(d)}
         if remove_zeros:
-            d = {key: coeff for key, coeff in d.iteritems() if coeff}
+            d = {key: coeff for key, coeff in six.iteritems(d) if coeff}
         return self.element_class( self, d )
 
 class CombinatorialFreeModule_Tensor(CombinatorialFreeModule):
@@ -1905,7 +1915,7 @@ class CombinatorialFreeModule_Tensor(CombinatorialFreeModule):
         The basis of T is indexed by tuples of basis indices of F and G::
 
             sage: T.basis().keys()
-            Image of Cartesian product of {1, 2}, {3, 4} by <type 'tuple'>
+            Image of Cartesian product of {1, 2}, {3, 4} by <... 'tuple'>
             sage: T.basis().keys().list()
             [(1, 3), (1, 4), (2, 3), (2, 4)]
 
@@ -2396,7 +2406,7 @@ class CombinatorialFreeModule_CartesianProduct(CombinatorialFreeModule):
             sage: CP._sets_keys()
             [0, 1]
         """
-        return range(len(self._sets))
+        return list(range(len(self._sets)))
 
     def _repr_(self):
         """
@@ -2456,7 +2466,7 @@ class CombinatorialFreeModule_CartesianProduct(CombinatorialFreeModule):
 
          - ``i`` -- an integer
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: F = CombinatorialFreeModule(ZZ, [4,5]); F.__custom_name = "F"
             sage: G = CombinatorialFreeModule(ZZ, [4,6]); G.__custom_name = "G"
