@@ -38,6 +38,7 @@ REFERENCES:
 #*****************************************************************************
 from __future__ import print_function
 from six.moves import range
+from six import add_metaclass
 
 from sage.structure.parent import Parent
 from sage.structure.list_clone import ClonableArray
@@ -54,6 +55,7 @@ from sage.combinat.combinatorial_map import combinatorial_map
 from sage.misc.all import prod
 
 
+@add_metaclass(InheritComparisonClasscallMetaclass)
 class GelfandTsetlinPattern(ClonableArray):
     r"""
     A Gelfand-Tsetlin (sometimes written as Gelfand-Zetlin or Gelfand-Cetlin)
@@ -137,8 +139,6 @@ class GelfandTsetlinPattern(ClonableArray):
     """
     # Note that the width == height, so len(gt) == len(gt[0]) except
     #   we don't have to check if it is the emtry GT pattern
-    __metaclass__ = InheritComparisonClasscallMetaclass
-
     @staticmethod
     def __classcall_private__(self, gt):
         """
@@ -536,8 +536,8 @@ class GelfandTsetlinPatterns(UniqueRepresentation, Parent):
         sage: c = 0
         sage: from sage.combinat.crystals.kirillov_reshetikhin import partitions_in_box
         sage: for p in partitions_in_box(3,3):
-        ...      S = SemistandardTableaux(p, max_entry=3)
-        ...      c += S.cardinality()
+        ....:    S = SemistandardTableaux(p, max_entry=3)
+        ....:    c += S.cardinality()
         sage: c == G.cardinality()
         True
 
@@ -718,8 +718,8 @@ class GelfandTsetlinPatterns(UniqueRepresentation, Parent):
             sage: c = 0
             sage: from sage.combinat.crystals.kirillov_reshetikhin import partitions_in_box
             sage: for p in partitions_in_box(3,3):
-            ...      S = SemistandardTableaux(p, max_entry=3)
-            ...      c += S.cardinality()
+            ....:    S = SemistandardTableaux(p, max_entry=3)
+            ....:    c += S.cardinality()
             sage: c == len(L)
             True
             sage: G = GelfandTsetlinPatterns(3, 3, strict=True)
@@ -823,7 +823,7 @@ class GelfandTsetlinPatterns(UniqueRepresentation, Parent):
             sage: len(L) == G.cardinality()
             True
             sage: type(L[0])
-            <type 'list'>
+            <... 'list'>
         """
         # Setup the first row
         iters = [None]*n
@@ -1141,7 +1141,7 @@ class GelfandTsetlinPatternsTopRow(GelfandTsetlinPatterns):
             sage: [[4,3,1], [4,2], [3]] in G
             False
         """
-        # Check if the the top row matches (if applicable)
+        # Check if the top row matches (if applicable)
         if tuple(gt[0]) != self._row:
             return False
         return GelfandTsetlinPatterns.__contains__(self, gt)
