@@ -441,7 +441,7 @@ class LatinSquare:
            right of self, and that the used symbols are in the range
            {0, 1, ..., m} (no holes in that list).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.combinat.matrices.latin import *
             sage: B = back_circulant(3)
@@ -503,7 +503,7 @@ class LatinSquare:
         Returns the number of distinct symbols in the partial latin square
         self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.combinat.matrices.latin import *
             sage: back_circulant(5).nr_distinct_symbols()
@@ -1710,7 +1710,7 @@ def tau1(T1, T2, cells_map):
     r"""
     The definition of `\tau_1` is
 
-    .. math::
+    .. MATH::
 
        \tau_1 : T1 \rightarrow T1 \\
        \tau_1 = \beta_2^{-1} \beta_3
@@ -1761,7 +1761,7 @@ def tau2(T1, T2, cells_map):
     r"""
     The definition of `\tau_2` is
 
-    .. math::
+    .. MATH::
 
        \tau_2 : T1 \rightarrow T1 \\
        \tau_2 = \beta_3^{-1} \beta_1
@@ -1812,7 +1812,7 @@ def tau3(T1, T2, cells_map):
     r"""
     The definition of `\tau_3` is
 
-    .. math::
+    .. MATH::
 
        \tau_3 : T1 \rightarrow T1 \\
        \tau_3 = \beta_1^{-1} \beta_2
@@ -2533,7 +2533,7 @@ def tau_to_bitrade(t1, t2, t3):
     convert them to an explicit latin bitrade (T1, T2). The result is
     unique up to isotopism.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.combinat.matrices.latin import *
         sage: T1 = back_circulant(5)
