@@ -53,6 +53,7 @@ REFERENCES:
 # python3
 from __future__ import division, print_function
 from six.moves import range
+from six import add_metaclass
 
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.structure.parent import Parent
@@ -70,6 +71,7 @@ from sage.matrix.constructor import Matrix
 from sage.combinat.combinatorial_map import combinatorial_map
 
 
+@add_metaclass(InheritComparisonClasscallMetaclass)
 class PerfectMatching(ElementWrapper):
     r"""
     Class of perfect matching.
@@ -108,7 +110,6 @@ class PerfectMatching(ElementWrapper):
     __lt__ = ElementWrapper._lt_by_value
     #During the creation of the instance of the class, the function
     #__classcall_private__ will be called instead of __init__ directly.
-    __metaclass__ = InheritComparisonClasscallMetaclass
 
     @staticmethod
     def __classcall_private__(cls, p):
@@ -343,7 +344,7 @@ class PerfectMatching(ElementWrapper):
         Returns the conjugate of the perfect matching ``self`` by the
         permutation ``p`` of the ground set.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: m = PerfectMatching([(1,4),(2,6),(3,5)])
             sage: m.conjugate_by_permutation(Permutation([4,1,5,6,3,2]))
@@ -996,7 +997,7 @@ class PerfectMatchings(UniqueRepresentation, Parent):
             sage: [(1, 3, 6), (2, 4), (5,)] in PerfectMatchings(6)
             False
             sage: [('a', 'b'), ('a', 'c')] in PerfectMatchings(
-            ...        ('a', 'b', 'c', 'd'))
+            ....:      ('a', 'b', 'c', 'd'))
             False
         """
         if not isinstance(x, PerfectMatching):
