@@ -122,7 +122,7 @@ class HasseDiagram(DiGraph):
         """
         return self.topological_sort_generator()
 
-    def is_linear_extension(self,lin_ext=None):
+    def is_linear_extension(self, lin_ext=None):
         r"""
         Test if an ordering is a linear extension.
 
@@ -130,18 +130,18 @@ class HasseDiagram(DiGraph):
 
             sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
             sage: H = HasseDiagram({0:[1,2],1:[3],2:[3],3:[]})
-            sage: H.is_linear_extension(range(4))
+            sage: H.is_linear_extension(list(range(4)))
             True
             sage: H.is_linear_extension([3,2,1,0])
             False
         """
         if lin_ext is None or lin_ext == list(range(len(self))):
-            for x,y in self.cover_relations_iterator():
+            for x, y in self.cover_relations_iterator():
                 if not x < y:
                     return False
             return True
         else:
-            for x,y in self.cover_relations_iterator():
+            for x, y in self.cover_relations_iterator():
                 if not lin_ext.index(x) < lin_ext.index(y):
                     return False
             return True
@@ -416,6 +416,27 @@ class HasseDiagram(DiGraph):
                 all(d<=1 for d in self.out_degree())   and # max outdegree is <= 1
                 all(d<=1 for d in self.in_degree()))       # max  indegree is <= 1
 
+    def is_antichain_of_poset(self, elms):
+        """
+        Return ``True`` if ``elms`` is an antichain of the Hasse
+        diagram and ``False`` otherwise.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2, 3], 1: [4], 2: [4], 3: [4]})
+            sage: H.is_antichain_of_poset([1, 2, 3])
+            True
+            sage: H.is_antichain_of_poset([0, 2, 3])
+            False
+        """
+        from itertools import combinations
+        from sage.misc.misc import uniq
+
+        elms_sorted = uniq(elms)
+        return not any(self.is_lequal(a, b) for a, b in
+                       combinations(elms_sorted, 2))
+
     def dual(self):
         """
         Returns a poset that is dual to the given poset.
@@ -655,18 +676,6 @@ class HasseDiagram(DiGraph):
         """
         return bool(self.rank_function())
 
-    def is_graded(self):
-        r"""
-        Deprecated, has conflicting definition of "graded" vs. "ranked"
-        with posets.
-
-        Return ``True`` if the Hasse diagram is ranked. For definition
-        of ranked see :meth:`~rank_function`.
-        """
-        from sage.misc.superseded import deprecation
-        deprecation(16998, "Use is_ranked(). Definition conflict with posets.")
-        return self.is_ranked()
-
     def covers(self,x,y):
         """
         Returns True if y covers x and False otherwise.
@@ -1017,6 +1026,60 @@ class HasseDiagram(DiGraph):
         """
         return bool(self._leq_matrix[i,j])
 
+    def prime_elements(self):
+        r"""
+        Return the join-prime and meet-prime elements of the bounded poset.
+
+        An element `x` of a poset `P` is join-prime if the subposet
+        induced by `\{y \in P \mid y \not\ge x\}` has a top element.
+        Meet-prime is defined dually.
+
+        .. NOTE::
+
+            The poset is expected to be bounded, and this is *not* checked.
+
+        OUTPUT:
+
+        A pair `(j, m)` where `j` is a list of join-prime elements
+        and `m` is a list of meet-prime elements.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2], 1: [3], 2: [4], 3: [4]})
+            sage: H.prime_elements()
+            ([1, 2], [2, 3])
+        """
+        n = self.order()
+        join_primes = []
+        meet_primes = []
+
+        def add_elements(e):
+            upset = frozenset(self.depth_first_search(e))
+            # The complement of the upper set of a join-prime must have
+            # a top element. Maximal elements of the complement are those
+            # covered by only elements in the upper set. If there is only
+            # one maximal element, it is a meet-prime and 'e' is a
+            # join-prime.
+            meet_prime = None
+            for u in upset:
+                for m in self.neighbor_in_iterator(u):
+                    if (m not in upset and
+                        all(u_ in upset for u_ in
+                            self.neighbor_out_iterator(m))):
+                        if meet_prime is not None:
+                            return
+                        meet_prime = m
+            join_primes.append(e)
+            meet_primes.append(meet_prime)
+
+        for e in range(n):
+            # Join-primes are join-irreducibles, only check those.
+            if self.in_degree(e) == 1:
+                add_elements(e)
+
+        return join_primes, meet_primes
+
     @lazy_attribute
     def _meet(self):
         r"""
@@ -1204,26 +1267,22 @@ class HasseDiagram(DiGraph):
             return matrix(0)
         if not self.has_top():
             raise ValueError("not a join-semilattice: no top element")
-        join = [[0 for x in range(n)] for x in range(n)]
-        le = self.lequal_matrix()
-        uc = [sorted([n-1-y for y in self.neighbors_out(x)]) for
-                x in reversed(range(n))]
+        join = [[n for x in range(n)] for x in range(n)]
+        uc = [self.neighbors_out(x) for x in range(n)]  # uc = upper covers
 
-        for x in range(n): # x=x_k
+        for x in range(n-1, -1, -1):
             join[x][x] = x
-
-            for y in range(x):
+            for y in range(n-1, x, -1):
                 T = [join[y][z] for z in uc[x]]
 
-                q = max(T)
+                q = min(T)
                 for z in T:
-                    if not le[n-1-q, n-1-z]:
-                        raise LatticeError('join', n-1-x, n-1-y)
+                    if join[z][q] != z:
+                        raise LatticeError('join', x, y)
                 join[x][y] = q
                 join[y][x] = q
 
-        return matrix(ZZ, [[n-1-join[n-1-x][n-1-y] for y in range(n)]
-                           for x in range(n)])
+        return matrix(ZZ, join)
 
     def join_matrix(self):
         r"""
@@ -1383,22 +1442,24 @@ class HasseDiagram(DiGraph):
         functions of lattices.
 
         The property of being vertically decomposable is defined for lattices.
-        This is not checked, and the function works with any bounded poset.
+        This is *not* checked, and the function works with any bounded poset.
 
         INPUT:
 
         - ``return_list``, a boolean. If ``False`` (the default), return
-          ``True`` if the lattice is vertically decomposable and ``False``
-          otherwise. If ``True``, return list of decomposition elements.
+          an element that is not the top neither the bottom element of the
+          lattice, but is comparable to all elements of the lattice, if
+          the lattice is vertically decomposable and ``None`` otherwise.
+          If ``True``, return list of decomposition elements.
 
         EXAMPLES::
 
             sage: H = Posets.BooleanLattice(4)._hasse_diagram
-            sage: H.vertical_decomposition()
-            False
+            sage: H.vertical_decomposition() is None
+            True
             sage: P = Poset( ([1,2,3,6,12,18,36], attrcall("divides")) )
             sage: P._hasse_diagram.vertical_decomposition()
-            True
+            3
             sage: P._hasse_diagram.vertical_decomposition(return_list=True)
             [3]
         """
@@ -1407,7 +1468,7 @@ class HasseDiagram(DiGraph):
             if return_list:
                 return []
             else:
-                return False
+                return None
         result = [] # Never take the bottom element to list.
         e = 0
         m = 0
@@ -1416,7 +1477,10 @@ class HasseDiagram(DiGraph):
                 m = max(m, j[1])
             if m == i+1:
                 if not return_list:
-                    return m < n-1
+                    if m < n-1:
+                        return m
+                    else:
+                        return None
                 result.append(m)
         result.pop() # Remove the top element.
         return result
@@ -1456,23 +1520,6 @@ class HasseDiagram(DiGraph):
 
         return None
 
-    def complements(self):
-        r"""
-        Deprecated.
-        """
-        from sage.misc.superseded import deprecation
-        deprecation(17138, "This function is broken. Do not use.")
-        jn = self.join_matrix()
-        mt = self.meet_matrix()
-        n = self.cardinality()
-        c = [None for x in range(n)]
-        for x in range(n):
-            for y in range(x,n):
-                if jn[x][y]==n-1 and mt[x][y]==0:
-                    c[x]=y
-                    c[y]=x
-        return c
-
     def pseudocomplement(self, element):
         """
         Return the pseudocomplement of ``element``, if it exists.
@@ -1700,7 +1747,7 @@ class HasseDiagram(DiGraph):
         semimodularity otherwise.
 
         EXAMPLES::
-    
+
             sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
             sage: H = HasseDiagram({0:[1, 2], 1:[3, 4], 2:[4, 5], 3:[6], 4:[6], 5:[6]})
             sage: H.find_nonsemimodular_pair(upper=True) is None
@@ -1922,7 +1969,7 @@ class HasseDiagram(DiGraph):
             sage: list(P._hasse_diagram.chains(element_class=tuple, exclude=[0]))
             [(), (1,), (1, 2), (2,), (3,)]
 
-        .. seealso:: :meth:`antichains`
+        .. SEEALSO:: :meth:`antichains`
         """
         from sage.combinat.subsets_pairwise import PairwiseCompatibleSubsets
         if not(exclude is None):
@@ -2100,6 +2147,106 @@ class HasseDiagram(DiGraph):
         return [e for e in range(self.cardinality()) if
                 all(e in ms for ms in max_sublats)]
 
+    def kappa_dual(self, a):
+        r"""
+        Return the minimum element smaller than the element covering
+        ``a`` but not smaller than ``a``.
+
+        Define `\kappa^*(a)` as the minimum element of
+        `(\downarrow a_*) \setminus (\downarrow a)`, where `a_*` is the element
+        covering `a`. It is always a join-irreducible element, if it exists.
+
+        .. NOTE::
+
+            Element ``a`` is expected to be meet-irreducible, and
+            this is *not* checked.
+
+        INPUT:
+
+        - ``a`` -- a join-irreducible element of the lattice
+
+        OUTPUT:
+
+        The element `\kappa^*(a)` or ``None`` if there
+        is not a unique smallest element with given constraints.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2], 1: [3, 4], 2: [4, 5], 3: [6], 4: [6], 5: [6]})
+            sage: H.kappa_dual(3)
+            2
+            sage: H.kappa_dual(4) is None
+            True
+
+        TESTS::
+
+            sage: H = HasseDiagram({0: [1]})
+            sage: H.kappa_dual(0)
+            1
+        """
+        uc = next(self.neighbor_out_iterator(a))
+        if self.in_degree(uc) == 1:
+            return uc
+        lt_a = set(self.depth_first_search(a, neighbors=self.neighbors_in))
+        tmp = list(self.depth_first_search(uc, neighbors=lambda v: [v_ for v_ in self.neighbors_in(v) if v_ not in lt_a]))
+        result = None
+        for e in tmp:
+            if all(x not in tmp for x in self.neighbors_in(e)):
+                if result:
+                    return None
+                result = e
+        return result
+
+    def skeleton(self):
+        """
+        Return the skeleton of the lattice.
+
+        The lattice is expected to be pseudocomplemented and non-empty.
+
+        The skeleton of the lattice is the subposet induced by
+        those elements that are the pseudocomplement to at least one
+        element.
+
+        OUTPUT:
+
+        List of elements such that the subposet induced by them is
+        the skeleton of the lattice.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2], 1: [3, 4], 2: [4],
+            ....:                   3: [5], 4: [5]})
+            sage: H.skeleton()
+            [5, 2, 0, 3]
+        """
+        p_atoms = []
+        for atom in self.neighbor_out_iterator(0):
+            p_atom = self.pseudocomplement(atom)
+            if p_atom is None:
+                raise ValueError("lattice is not pseudocomplemented")
+            p_atoms.append(p_atom)
+        n = len(p_atoms)
+        mt = self._meet
+        pos = [0] * n
+        meets = [self.order()-1] * n
+        result = [self.order()-1]
+        i = 0
+
+        while i >= 0:
+            new_meet = mt[meets[i-1], p_atoms[pos[i]]]
+            result.append(new_meet)
+            if pos[i] == n-1:
+                i -= 1
+                pos[i] = pos[i]+1
+            else:
+                meets[i] = new_meet
+                pos[i+1] = pos[i]+1
+                i += 1
+
+        return result
+
     def is_convex_subset(self, S):
         r"""
         Return ``True`` if `S` is a convex subset of the poset,
@@ -2149,5 +2296,512 @@ class HasseDiagram(DiGraph):
 
         return True
 
+    def neutral_elements(self):
+        """
+        Return the list of neutral elements of the lattice.
+
+        An element `a` in a lattice is neutral if the sublattice
+        generated by `a`, `x` and `y` is distributive for every
+        `x`, `y` in the lattice.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H= HasseDiagram({0: [1, 2], 1: [4], 2: [3], 3: [4, 5],
+            ....:                  4: [6], 5:[6]})
+            sage: sorted(H.neutral_elements())
+            [0, 4, 6]
+
+        ALGORITHM:
+
+        Basically we just check the distributivity against all element
+        pairs `x, y` to see if element `a` is neutral or not.
+
+        If we found that `a, x, y` is not a distributive triple, we add
+        all three to list of non-neutral elements. If we found `a` to
+        be neutral, we add it to list of neutral elements. When testing
+        we skip already found neutral elements, as they can't be our `x`
+        or `y`.
+
+        We skip `a, x, y` as trivial if it is a chain. We do that by
+        letting `x` to be a non-comparable to `a`; `y` can be any element.
+
+        We first try to found `x` and `y` from elements not yet tested,
+        so that we could get three birds with one stone.
+
+        And last, the top and bottom elements are always neutral and
+        need not be tested.
+        """
+        n = self.order()
+        if n < 5:
+            return set(range(n))
+
+        todo = set(range(1, n-1))
+        neutrals = set([0, n-1])
+        notneutrals = set()
+        all_elements = set(range(n))
+
+        mt = self._meet
+        jn = self._join
+
+        def is_neutral(a):
+            noncomp = all_elements.difference(self.depth_first_search(a))
+            noncomp.difference_update(self.depth_first_search(a, neighbors=self.neighbors_in))
+
+            for x in noncomp.intersection(todo):
+                meet_ax = mt[a, x]
+                join_ax = jn[a, x]
+                for y in todo:
+                    if (mt[mt[join_ax, jn[a, y]], jn[x, y]] !=
+                        jn[jn[meet_ax, mt[a, y]], mt[x, y]]):
+                        notneutrals.add(x)
+                        notneutrals.add(y)
+                        return False
+                for y in notneutrals:
+                    if (mt[mt[join_ax, jn[a, y]], jn[x, y]] !=
+                        jn[jn[meet_ax, mt[a, y]], mt[x, y]]):
+                        notneutrals.add(x)
+                        return False
+            for x in noncomp.difference(todo):
+                meet_ax = mt[a, x]
+                join_ax = jn[a, x]
+                for y in todo:
+                    if (mt[mt[join_ax, jn[a, y]], jn[x, y]] !=
+                        jn[jn[meet_ax, mt[a, y]], mt[x, y]]):
+                        notneutrals.add(y)
+                        return False
+                for y in notneutrals:
+                    if (mt[mt[join_ax, jn[a, y]], jn[x, y]] !=
+                        jn[jn[meet_ax, mt[a, y]], mt[x, y]]):
+                        return False
+            return True
+
+        while todo:
+            e = todo.pop()
+            if is_neutral(e):
+                neutrals.add(e)
+            else:
+                notneutrals.add(e)
+
+        return neutrals
+
+    def kappa(self, a):
+        r"""
+        Return the maximum element greater than the element covered
+        by ``a`` but not greater than ``a``.
+
+        Define `\kappa(a)` as the maximum element of
+        `(\uparrow a_*) \setminus (\uparrow a)`, where `a_*` is the element
+        covered by `a`. It is always a meet-irreducible element, if it exists.
+
+        .. NOTE::
+
+            Element ``a`` is expected to be join-irreducible, and
+            this is *not* checked.
+
+        INPUT:
+
+        - ``a`` -- a join-irreducible element of the lattice
+
+        OUTPUT:
+
+        The element `\kappa(a)` or ``None`` if there
+        is not a unique greatest element with given constraints.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2, 3], 1: [4], 2: [4, 5], 3: [5], 4: [6], 5: [6]})
+            sage: H.kappa(1)
+            5
+            sage: H.kappa(2) is None
+            True
+
+        TESTS::
+
+            sage: H = HasseDiagram({0: [1]})
+            sage: H.kappa(1)
+            0
+        """
+        lc = next(self.neighbor_in_iterator(a))
+        if self.out_degree(lc) == 1:
+            return lc
+        gt_a = set(self.depth_first_search(a))
+        tmp = list(self.depth_first_search(lc, neighbors=lambda v: [v_ for v_ in self.neighbors_out(v) if v_ not in gt_a]))
+        result = None
+        for e in tmp:
+            if all(x not in tmp for x in self.neighbors_out(e)):
+                if result:
+                    return None
+                result = e
+        return result
+
+    def atoms_of_congruence_lattice(self):
+        r"""
+        Return atoms of the congruence lattice.
+
+        In other words, return "minimal non-trivial" congruences:
+        A congruence is minimal if the only finer (as a partition
+        of set of elements) congruence is the trivial congruence
+        where every block contains only one element.
+
+        .. SEEALSO:: :meth:`congruence`
+
+        OUTPUT:
+
+        List of congruences, every congruence as
+        :class:`sage.combinat.set_partition.SetPartition`
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: N5 = HasseDiagram({0: [1, 2], 1: [4], 2: [3], 3:[4]})
+            sage: N5.atoms_of_congruence_lattice()
+            [{{0}, {1}, {2, 3}, {4}}]
+            sage: Hex = HasseDiagram({0: [1, 2], 1: [3], 2: [4], 3: [5], 4: [5]})
+            sage: Hex.atoms_of_congruence_lattice()
+            [{{0}, {1}, {2, 4}, {3}, {5}}, {{0}, {1, 3}, {2}, {4}, {5}}]
+
+        ALGORITHM:
+
+        Every atom is a join-irreducible. Every join-irreducible of
+        `\mathrm{Con}(L)` is a principal congruence generated by a
+        meet-irreducible element and the only element covering it (and also
+        by a join-irreducible element and the only element covered by it).
+        Hence we check those principal congruences to find the minimal ones.
+        """
+        # Note: A lattice L if subdirectly reducible (i.e. is a sublattice
+        # of a Cartesian product of two smaller lattices) iff Con(L) has
+        # at least two atoms. That's were this is used for.
+
+        from sage.combinat.set_partition import SetPartitions
+
+        # Get smaller set, meet- or join-irreducibles
+        join_irreducibles = [v for v in self if self.in_degree(v) == 1]
+        meet_irreducibles = [v for v in self if self.out_degree(v) == 1]
+        if len(join_irreducibles) < len(meet_irreducibles):
+            irr = [(v, next(self.neighbor_in_iterator(v))) for v in join_irreducibles]
+        else:
+            irr = [(next(self.neighbor_out_iterator(v)), v) for v in meet_irreducibles]
+
+        S = SetPartitions(range(self.order()))
+        min_congruences = []
+        already_tried = []
+
+        while irr:
+            next_pair = irr.pop()
+            cong = self.congruence([next_pair], stop_pairs=already_tried)
+            already_tried.append(next_pair)
+            if cong is not None:
+                cong = S(cong)
+                min_congruences = [c for c in min_congruences if c != cong and not S.is_less_than(cong, c)]
+                if not any(S.is_less_than(c, cong) for c in min_congruences):
+                    min_congruences.append(cong)
+
+        return min_congruences
+
+    def congruence(self, parts, start=None, stop_pairs=[]):
+        """
+        Return the congruence ``start`` "extended" by ``parts``.
+
+        ``start`` is assumed to be a valid congruence of the lattice,
+        and this is *not* checked.
+
+        INPUT:
+
+        - ``parts`` -- a list of lists; congruences to add
+        - ``start`` -- a disjoint set; already computed congruence (or ``None``)
+        - ``stop_pairs`` -- a list of pairs; list of pairs for stopping computation
+
+        OUTPUT:
+
+        ``None``, if the congruence generated by ``start`` and ``parts``
+        together contains a block that has elements `a, b` so that ``(a, b)``
+        is in the list ``stop_pairs``. Otherwise the least congruence that
+        contains a block whose subset is `p` for every `p` in ``parts`` or
+        ``start``, given as :class:`sage.sets.disjoint_set.DisjointSet_class`.
+
+        ALGORITHM:
+
+        Use the quadrilateral argument from page 120 of [Dav1997]_.
+
+        Basically we take one block from todo-list, search quadrilateral
+        blocks up and down against the block, and then complete them to
+        closed intervals and add to todo-list.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2], 1: [3], 2: [4], 3: [4]})
+            sage: cong = H.congruence([[0, 1]]); cong
+            {{0, 1, 3}, {2, 4}}
+            sage: H.congruence([[0, 2]], start=cong)
+            {{0, 1, 2, 3, 4}}
+
+            sage: H.congruence([[0, 1]], stop_pairs=[(1, 3)]) is None
+            True
+
+        TESTS::
+
+            sage: H = HasseDiagram('HT@O?GO?OE?G@??')
+            sage: H.congruence([[0, 1]]).number_of_subsets()
+            1
+            sage: H = HasseDiagram('HW_oC?@@O@?O@??')
+            sage: H.congruence([[0, 1]]).number_of_subsets()
+            1
+
+        Check :trac:`21861`::
+
+            sage: H = HasseDiagram({0: [1, 2], 1: [3], 2: [4], 3: [4]})
+            sage: tmp = H.congruence([[1, 3]])
+            sage: tmp.number_of_subsets()
+            4
+            sage: H.congruence([[0, 1]], start=tmp).number_of_subsets()
+            2
+            sage: tmp.number_of_subsets()
+            4
+        """
+        from sage.sets.disjoint_set import DisjointSet
+        from copy import copy
+
+        n = self.order()
+        mt = self._meet
+        jn = self._join
+
+        def fill_to_interval(S):
+            """
+            Return the smallest interval containing elements in the set S.
+            """
+            m = n-1
+            for e in S:
+                m = mt[m, e]
+            j = 0
+            for e in S:
+                j = jn[j, e]
+            return self.interval(m, j)
+
+        cong = copy(start) if start else DisjointSet(n)
+        t = -1
+
+        while t != cong.number_of_subsets():
+            for part in parts:
+                if part:  # Skip empty parts
+                    c = part[0]
+                    for e in fill_to_interval(part):
+                        cong.union(e, c)
+            t = cong.number_of_subsets()
+
+            # Following is needed for cases like
+            # Posets.BooleanLattice(3).congruence([(0,1), (0,2), (0,4)])
+            for c in list(cong):
+                r = c[0]
+                for v in fill_to_interval(c):
+                    cong.union(r, v)
+
+        todo = set(cong.find(e) for part in parts for e in part)
+
+        while todo:
+
+            # First check if we should stop now.
+            for a, b in stop_pairs:
+                if cong.find(a) == cong.find(b):
+                    return None
+
+            # We take one block and try to find as big interval
+            # as possible to unify as a new block by the quadrilateral
+            # argument.
+            block = sorted(cong.root_to_elements_dict()[cong.find(todo.pop())])
+
+            b = block[-1]
+            for a in block:  # Quadrilateral up
+                for c in self.neighbor_out_iterator(a):
+                    if c not in block:
+                        d = self._join[c, b]
+                        if cong.find(d) != cong.find(c):
+                            break
+                else:
+                    continue
+                break
+
+            else:  # Not found, so...
+                a = block[0]
+                for b in reversed(block):  # ...quadrilateral down
+                    for d in self.neighbor_in_iterator(b):
+                        if d not in block:
+                            c = self._meet[d, a]
+                            if cong.find(c) != cong.find(d):
+                                break
+                    else:
+                        continue
+                    break
+                else:  # Nothing found
+                    continue
+
+            # Something was found, so we put this block back to todo
+            # together with just found new block.
+            todo.add(a)
+            todo.add(c)
+
+            # Now the interval [c, d] will be of the same block.
+            # It may "crab" other blocks within, and that can be
+            # recursive process. In particular it may also combine to
+            # [a, b] block we just used.
+            while c is not None:
+                newblock = cong.find(c)
+                I = self.interval(c, d)
+                for i in I:
+                    cong.union(newblock, i)
+                C = cong.root_to_elements_dict()[cong.find(newblock)]
+                mins = [i for i in C if all(i_ not in C for i_ in self.neighbor_in_iterator(i))]
+                maxs = [i for i in C if all(i_ not in C for i_ in self.neighbor_out_iterator(i))]
+                c = None  # To stop loop, if this is not changed below.
+                if len(mins) > 1 or len(maxs) > 1:
+                    c = n-1
+                    for m in mins:
+                        c = self._meet[c, m]
+                    d = 0
+                    for m in maxs:
+                        d = self._join[d, m]
+
+            # This removes duplicates from todo.
+            todo = set(cong.find(x) for x in todo)
+
+        return cong
+
+    def find_nontrivial_congruence(self):
+        """
+        Return a pair that generates non-trivial congruence or
+        ``None`` if there is not any.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram({0: [1, 2], 1: [5], 2: [3, 4], 3: [5], 4: [5]})
+            sage: H.find_nontrivial_congruence()
+            {{0, 1}, {2, 3, 4, 5}}
+
+            sage: H = HasseDiagram({0: [1, 2, 3], 1: [4], 2: [4], 3: [4]})
+            sage: H.find_nontrivial_congruence() is None
+            True
+
+        ALGORITHM:
+
+        See http://www.math.hawaii.edu/~ralph/Preprints/conlat.pdf:
+
+        If `\Theta` is a join irreducible element of a `\mathrm{Con}(L)`,
+        then there is at least one join-irreducible `j` and one
+        meet-irreducible `m` such that `\Theta` is both the principal
+        congruence generated by `(j^*, j)`, where `j^*` is the unique
+        lower cover of `j`, and the principal congruence generated by
+        `(m, m^*)`, where `m^*` is the unique upper cover of `m`.
+
+        So, we only check join irreducibles or meet irreducibles,
+        whichever is a smaller set. To optimize more we stop computation
+        whenever it founds a pair that we know to generate one-element
+        congruence.
+        """
+        join_irreducibles = [v for v in self if self.in_degree(v) == 1]
+        meet_irreducibles = [v for v in self if self.out_degree(v) == 1]
+        if len(join_irreducibles) < len(meet_irreducibles):
+            irr = [(v, self.neighbors_in(v)[0]) for v in join_irreducibles]
+        else:
+            irr = [(self.neighbors_out(v)[0], v) for v in meet_irreducibles]
+        tried = []
+        for pair in irr:
+            cong = self.congruence([pair], stop_pairs=tried)
+            if cong is not None and cong.number_of_subsets() > 1:
+                return cong
+            tried.append(pair)
+        return None
+
+    def principal_congruences_poset(self):
+        r"""
+        Return the poset of join-irreducibles of the congruence lattice.
+
+        OUTPUT:
+
+        A pair `(P, D)` where `P` is a poset and `D` is a dictionary.
+
+        Elements of `P` are pairs `(x, y)` such that `x` is an element
+        of the lattice and `y` is an element covering it. In the poset
+        `(a, b)` is less than `(c, d)` iff the principal congruence
+        generated by `(a, b)` is refinement of the principal congruence
+        generated by `(c, d)`.
+
+        `D` is a dictionary from pairs `(x, y)` to the congruence
+        (given as DisjointSet) generated by the pair.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: N5 = HasseDiagram({0: [1, 2], 1: [4], 2: [3], 3: [4]})
+            sage: P, D = N5.principal_congruences_poset()
+            sage: P
+            Finite poset containing 3 elements
+            sage: P.bottom()
+            (2, 3)
+            sage: D[(2, 3)]
+            {{0}, {1}, {2, 3}, {4}}
+        """
+        from sage.combinat.set_partition import SetPartition, SetPartitions
+        from sage.combinat.posets.posets import Poset
+
+        n = self.order()
+
+        # Select smaller set, meet- or join-irreducibles
+        if self.in_degree_sequence().count(1) > self.out_degree_sequence().count(1):
+            irr = [(e, next(self.neighbor_out_iterator(e))) for e in range(n) if self.out_degree(e) == 1]
+        else:
+            irr = [(next(self.neighbor_in_iterator(e)), e) for e in range(n) if self.in_degree(e) == 1]
+
+        D = {}
+        P = {}
+        uniq_congs = set()
+        for ab in irr:
+            cong = self.congruence([ab])
+            cong_ = SetPartition(cong)
+            if cong_ not in uniq_congs:
+                uniq_congs.add(cong_)
+                D[ab] = cong
+                P[ab] = cong_
+
+        # Todo: Make a function that creates the poset from a set
+        # by comparison function with minimal number of comparisons.
+
+        T = SetPartitions(n)
+        P = DiGraph([D, lambda a, b: T.is_less_than(P[a], P[b])])
+        return (Poset(P), D)
+
+    def congruences_iterator(self):
+        """
+        Return an iterator over all congruences of the lattice.
+
+        EXAMPLES::
+
+            sage: from sage.combinat.posets.hasse_diagram import HasseDiagram
+            sage: H = HasseDiagram('GY@OQ?OW@?O?')
+            sage: it = H.congruences_iterator(); it
+            <generator object ...>
+            sage: sorted([cong.number_of_subsets() for cong in it])
+            [1, 2, 2, 2, 4, 4, 4, 8]
+        """
+        from sage.sets.disjoint_set import DisjointSet
+
+        P, congs = self.principal_congruences_poset()
+        for a in P.antichains_iterator():
+            achain = tuple(a)
+            n = len(achain)
+            if n == 0:
+                yield DisjointSet(self.order())
+            if n == 1:
+                # We have congs[(x,y)], but we want congs[((x,y))].
+                congs[achain] = congs[a[0]]
+                yield congs[achain[0]]
+            if n > 1:
+                c = congs[achain[:-1]]
+                c = self.congruence([achain[-1]], start=c)
+                yield c
+                congs[achain] = c
+
 from sage.misc.rest_index_of_methods import gen_rest_table_index
 __doc__ = __doc__.format(INDEX_OF_FUNCTIONS=gen_rest_table_index(HasseDiagram))
