@@ -26,6 +26,7 @@ Classes and methods
 #****************************************************************************
 from __future__ import print_function
 from six.moves import range
+from six import add_metaclass
 
 from sage.rings.rational_field import QQ
 from sage.categories.posets import Posets
@@ -42,6 +43,8 @@ from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
 from sage.graphs.dot2tex_utils import have_dot2tex
 from sage.structure.list_clone import ClonableArray
 
+
+@add_metaclass(InheritComparisonClasscallMetaclass)
 class LinearExtensionOfPoset(ClonableArray):
     r"""
     A linear extension of a finite poset `P` of size `n` is a total
@@ -89,8 +92,6 @@ class LinearExtensionOfPoset(ClonableArray):
         sage: Q.cover_relations()
         [[1, 2], [1, 4], [3, 4]]
     """
-    __metaclass__ = InheritComparisonClasscallMetaclass
-
     @staticmethod
     def __classcall_private__(cls, linear_extension, poset):
         r"""
@@ -288,7 +289,7 @@ class LinearExtensionOfPoset(ClonableArray):
 
         For more details see [Stan2009]_.
 
-        .. seealso:: :meth:`tau`, :meth:`evacuation`
+        .. SEEALSO:: :meth:`tau`, :meth:`evacuation`
 
         EXAMPLES::
 
@@ -313,7 +314,7 @@ class LinearExtensionOfPoset(ClonableArray):
         `\pi (\tau_1 \cdots \tau_{n-1}) (\tau_1 \cdots \tau_{n-2}) \cdots (\tau_1)`.
         For more details see [Stan2009]_.
 
-        .. seealso:: :meth:`tau`, :meth:`promotion`
+        .. SEEALSO:: :meth:`tau`, :meth:`promotion`
 
         EXAMPLES::
 
@@ -338,7 +339,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
     - ``poset`` -- a poset `P` of size `n`
     - ``facade`` -- a boolean (default: ``False``)
 
-    .. seealso::
+    .. SEEALSO::
 
         - :meth:`sage.combinat.posets.posets.FinitePoset.linear_extensions`
         - :class:`sage.graphs.linearextensions.LinearExtensions`
@@ -579,7 +580,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             ([2, 1, 4, 3], [1, 2, 4, 3], 1), ([2, 1, 4, 3], [2, 1, 3, 4], 3), ([2, 1, 4, 3], [2, 1, 4, 3], 2)]
             sage: view(G) # optional - dot2tex graphviz, not tested (opens external window)
 
-        .. seealso:: :meth:`markov_chain_transition_matrix`, :meth:`promotion`, :meth:`tau`
+        .. SEEALSO:: :meth:`markov_chain_transition_matrix`, :meth:`promotion`, :meth:`tau`
 
         TESTS::
 
@@ -655,7 +656,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             [           x0             0             0      -x1 - x2            x3]
             [            0            x0             0            x2      -x1 - x3]
 
-        .. seealso:: :meth:`markov_chain_digraph`, :meth:`promotion`, :meth:`tau`
+        .. SEEALSO:: :meth:`markov_chain_digraph`, :meth:`promotion`, :meth:`tau`
 
         """
         from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
