@@ -21,6 +21,9 @@ lazy_import('sage.rings.integer_ring', 'ZZ')
 from sage.modules.free_module_element import vector
 from sage.combinat.root_system.hecke_algebra_representation import HeckeAlgebraRepresentation
 
+import six
+
+
 class Algebras(AlgebrasCategory):
     """
     The category of group algebras of root lattice realizations.
@@ -116,7 +119,7 @@ class Algebras(AlgebrasCategory):
             .. TODO:: make this work for Laurent polynomials too
             """
             L = self.basis().keys()
-            return self.sum_of_terms((L.from_vector(vector(t)), c) for (t,c) in p.dict().iteritems())
+            return self.sum_of_terms((L.from_vector(vector(t)), c) for (t,c) in six.iteritems(p.dict()))
 
         @cached_method
         def divided_difference_on_basis(self, weight, i):
