@@ -25,7 +25,7 @@ class AmbientSpace(CombinatorialFreeModule):
     ambient space, and by endowing it with the canonical scalar product.
 
     The coefficient of an element in `\delta^\vee`, thus its scalar
-    product with `\delta^\vee` gives its level, and dualy for the
+    product with `\delta^\vee` gives its level, and dually for the
     colevel. The canonical projection onto the classical ambient space
     (by killing `\delta` and `\delta^\vee`) maps the simple roots
     (except `\alpha_0`) onto the corresponding classical simple roots,
