@@ -17,11 +17,14 @@ from __future__ import absolute_import
 #
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
+from six.moves import zip
+
 from . import classical
 import sage.libs.symmetrica.all as symmetrica
 import sage.libs.lrcalc.lrcalc as lrcalc
 from sage.rings.all import ZZ, QQ, Integer
 
+
 class SymmetricFunctionAlgebra_schur(classical.SymmetricFunctionAlgebra_classical):
     def __init__(self, Sym):
         """
@@ -468,15 +471,16 @@ class SymmetricFunctionAlgebra_schur(classical.SymmetricFunctionAlgebra_classica
             for (lam, coeff) in s_coords_of_self:
                 if len(lam.core(n)) == 0:
                     quotient = lam.quotient(n)
-                    quotient_prod = parent.prod([parent(part) for part in quotient])
+                    quotient_prod = parent.prod(parent(part)
+                                                for part in quotient)
                     # Now, compute the sign of quotient_prod in the
                     # n-th Verschiebung of lam.
                     len_lam = len(lam)
                     ns = len_lam + ((- len_lam) % n)
                     s = ns // n   # This is actually ns / n, as we have n | ns.
                     beta_list = lam.beta_numbers(ns)
-                    zipped_beta_list = zip(beta_list, range(1, ns + 1))
-                    zipped_beta_list.sort(key = lambda a: (- 1 - a[0]) % n)
+                    zipped_beta_list = sorted(zip(beta_list, range(1, ns + 1)),
+                                              key=lambda a: (-1 - a[0]) % n)
                     # We are using the fact that sort is a stable sort.
                     perm_list = [a[1] for a in zipped_beta_list]
                     if Permutation(perm_list).sign() == 1:
