@@ -53,7 +53,7 @@ spades, or clubs) and a value (2, 3, ..., 10, jack, queen, king, ace). The
 game is played with a full deck, which consists of the Cartesian product
 of the set of suits and the set of values:
 
-.. math:: \operatorname{Cards} = \operatorname{Suits} \times
+.. MATH:: \operatorname{Cards} = \operatorname{Suits} \times
           \operatorname{Values} = \{ (s, v)  \mathrel| s\in
           \operatorname{Suits} \text{ et } v \in \operatorname{Values} \}\,.
 
@@ -239,12 +239,12 @@ Our next goal is to recover this result using ``Sage``. Let
 `C_0=\emptyset` and `c_0=0`. The set of all trees is
 then the disjoint union of the sets `C_n`:
 
-.. math:: C=\biguplus_{n\in \mathbb N} C_n\,.
+.. MATH:: C=\biguplus_{n\in \mathbb N} C_n\,.
 
 Having named the set `C` of all trees, we can translate the
 recursive definition of trees into a set-theoretic equation:
 
-.. math:: C \quad \approx \quad  \{ \mathrm{L} \} \quad \uplus\quad C \times C\,.
+.. MATH:: C \quad \approx \quad  \{ \mathrm{L} \} \quad \uplus\quad C \times C\,.
 
 In words: a tree `t` (which is by definition in `C`) is either a
 leaf (so in `\{\mathrm{L}\}`) or a node to which two trees
@@ -258,7 +258,7 @@ manipulate all the numbers `c_n` simultaneously, by encoding them
 as coefficients in a formal power series, called the *generating
 function* of the `c_n`’s:
 
-.. math:: C(z) = \sum_{n\in \mathbb N} c_n z^n\,,
+.. MATH:: C(z) = \sum_{n\in \mathbb N} c_n z^n\,,
 
 where `z` is a formal variable (which means that we do not
 have to worry about questions of convergence). The beauty of this idea
@@ -269,7 +269,7 @@ the corresponding series (`A(z)+B(z)`,
 satisfied by `C` can be translated directly into an algebraic
 equation satisfied by `C(z)`:
 
-.. math:: C(z) = z + C(z) \cdot C(z)\,.
+.. MATH:: C(z) = z + C(z) \cdot C(z)\,.
 
 Now we can solve this equation with ``Sage``. In order to do so, we
 introduce two variables, `C` and `z`, and we define the
@@ -370,7 +370,7 @@ satisfies the recurrence relation
 `c_{n+1}=\frac{(4n-2)}{n+1}c_n`. Simplifying, we find that
 `c_n` is the `(n-1)`-th Catalan number:
 
-.. math:: c_n = \operatorname{Catalan}(n-1) = \frac {1}{n} \binom{2(n-1)}{n-1}\,.
+.. MATH:: c_n = \operatorname{Catalan}(n-1) = \frac {1}{n} \binom{2(n-1)}{n-1}\,.
 
 We check this::
 
@@ -427,11 +427,11 @@ equation with respect to `z`::
 
 or, in a more readable format,
 
-.. math:: \frac{d C(z)}{d z} \frac{\partial P}{\partial y} (z, C(z)) + \frac{\partial P}{\partial x}(z,C(z)) = 0
+.. MATH:: \frac{d C(z)}{d z} \frac{\partial P}{\partial y} (z, C(z)) + \frac{\partial P}{\partial x}(z,C(z)) = 0
 
 From this we deduce:
 
-.. math:: \frac{d C(z)}{d z} = - \frac{\frac{\partial P}{\partial x}}{\frac{\partial P}{\partial y}}(z, C(z))\,.
+.. MATH:: \frac{d C(z)}{d z} = - \frac{\frac{\partial P}{\partial x}}{\frac{\partial P}{\partial y}}(z, C(z))\,.
 
 In the case of complete binary trees, this gives::
 
@@ -482,7 +482,7 @@ We lift the result to `\QQ(x)[y]` and then substitute
 
 or, more legibly,
 
-.. math:: \frac{\partial C(z)}{\partial z} = \frac{1}{1-4z} -\frac{2}{1-4z}C(z)\,.
+.. MATH:: \frac{\partial C(z)}{\partial z} = \frac{1}{1-4z} -\frac{2}{1-4z}C(z)\,.
 
 In this simple case, we can directly deduce from this expression a
 linear differential equation with coefficients in `\QQ[z]`::
@@ -498,7 +498,7 @@ linear differential equation with coefficients in `\QQ[z]`::
 
 or, more legibly,
 
-.. math:: (1-4z) \frac{\partial C(z)}{\partial z} + 2 C(z) - 1 = 0\,.
+.. MATH:: (1-4z) \frac{\partial C(z)}{\partial z} + 2 C(z) - 1 = 0\,.
 
 It is trivial to verify this equation on the closed form::
 
@@ -528,7 +528,7 @@ the differential equation, we obtain the desired recurrence relation on
 the coefficients; in this case we recover the relation we had already
 found, based on the closed form:
 
-.. math:: c_{n+1}=\frac{(4n-2)}{n+1}c_n
+.. MATH:: c_{n+1}=\frac{(4n-2)}{n+1}c_n
 
 After fixing the correct initial conditions, it becomes possible to
 calculate the coefficients of `C(z)` recursively::
