@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 r"""
 Common words
 
@@ -725,7 +725,7 @@ class WordGenerator(object):
         satisfying `s_{\alpha,0} = ac_\alpha` and `s'_{\alpha,0} = bc_\alpha`,
         where `s_{\alpha,0}` and `s'_{\alpha,0}` are respectively the lower
         and upper mechanical words with slope `\alpha` and intercept `0`.
-        Equivalently, for irrationnal `\alpha`,
+        Equivalently, for irrational `\alpha`,
         `c_\alpha = s_{\alpha,\alpha} = s'_{\alpha,\alpha}`.
 
         Let `\alpha = [0, d_1 + 1, d_2, d_3, \ldots]` be the continued
@@ -779,9 +779,9 @@ class WordGenerator(object):
         From an iterator of the continued fraction expansion of a real::
 
             sage: def cf():
-            ...     yield 0
-            ...     yield 2
-            ...     while True: yield 1
+            ....:   yield 0
+            ....:   yield 2
+            ....:   while True: yield 1
             sage: F = words.CharacteristicSturmianWord(cf()); F
             word: 0100101001001010010100100101001001010010...
             sage: Fib = words.FibonacciWord(); Fib
@@ -1011,10 +1011,10 @@ class WordGenerator(object):
         TESTS::
 
             sage: for i in range(1,10):
-            ...       for j in range(1,10):
-            ...           if i != j:
-            ...               w = words.KolakoskiWord(alphabet=(i,j))
-            ...               assert w[:50] == w.delta()[:50]
+            ....:     for j in range(1,10):
+            ....:         if i != j:
+            ....:             w = words.KolakoskiWord(alphabet=(i,j))
+            ....:             assert w[:50] == w.delta()[:50]
 
         ::
 
@@ -1776,7 +1776,7 @@ class WordGenerator(object):
 
             sage: from sage.misc.prandom import randint
             sage: def it():
-            ...     while True: yield randint(0,1)
+            ....:   while True: yield randint(0,1)
             sage: words.s_adic(it(), repeat('a'), [tm,fib])
             word: abbaabababbaababbaabbaababbaabababbaabba...
             sage: words.s_adic(it(), repeat('a'), [tm,fib])
@@ -1834,7 +1834,7 @@ class WordGenerator(object):
             sage: s = words.s_adic(w, repeat(3), x); s
             word: 3232232232322322322323223223232232232232...
             sage: prefixe = s[:10000]
-            sage: map(prefixe.number_of_factors, range(15))
+            sage: list(map(prefixe.number_of_factors, range(15)))
             [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15]
             sage: [_[i+1] - _[i] for i in range(len(_)-1)]
             [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]
@@ -1978,4 +1978,68 @@ class WordGenerator(object):
         w = a + b*k + a + b*kk + a + a + b*kk + a + b*k + a
         return FiniteWords(alphabet)(w)
 
+    def BaumSweetWord(self):
+        r"""
+        Returns the Baum-Sweet Word.
+
+        The Baum-Sweet Sequence is an infinite word over the alphabet `\{0,1\}`
+        defined by the following string substitution rules:
+
+        `00 \rightarrow 0000`
+
+        `01 \rightarrow 1001`
+
+        `10 \rightarrow 0100`
+
+        `11 \rightarrow 1101`
+
+        The substitution rule above can be considered as a morphism on the
+        submonoid of `\{0,1\}` generated by `\{00,01,10,11\}` (which is a free
+        monoid on these generators).
+
+        It is also defined as the concatenation of the terms from the Baum-Sweet
+        Sequence:
+
+        .. MATH::
+
+            b_n = \begin{cases}
+            0,      & \text{if } n = 0 \\
+            1,      & \text{if } m \text{ is even} \\
+            b_{\frac{m-1}{2}}, & \text{if } m \text{ is odd}
+            \end{cases}
+
+        where `n=m4^k` and `m` is not divisible by 4 if `m \neq 0`.
+
+        The individual terms of the Baum-Sweet Sequence are also given by:
+
+        .. MATH::
+
+            b_n = \begin{cases}
+            1,      & \text{if the binary representation of} n \text{ contains no block of consecutive 0's of odd length}\\
+            0,      & \text{otherwise}\\
+            \end{cases}\\
+
+        for `n > 0` with `b_0 = 1`.
+
+        For more information see:
+        :wikipedia:`Baum-Sweet_sequence`.
+
+        EXAMPLES:
+
+        Baum-Sweet Word::
+
+            sage: w = words.BaumSweetWord(); w
+            word: 1101100101001001100100000100100101001001...
+
+        Block Definition::
+
+            sage: w = words.BaumSweetWord()
+            sage: f = lambda n: '1' if all(len(x)%2==0 for x in bin(n)[2:].split('1')) else '0'
+            sage: all(f(i) == w[i] for i in range(1,100))
+            True
+        """
+        outer = WordMorphism('a->00,b->01,c->10,d->11')
+        inner = WordMorphism('a->aa,b->cb,c->ba,d->db')
+        return outer(inner.fixed_point('d'))
+
 words = WordGenerator()
