@@ -1326,7 +1326,7 @@ class SageDocTestRunner(doctest.DocTestRunner):
             sage: D = DictAsObject({'cputime':[],'walltime':[],'err':None})
             sage: DTR.update_results(D)
             0
-            sage: sorted(list(D.iteritems()))
+            sage: sorted(list(D.items()))
             [('cputime', [...]), ('err', None), ('failures', 0), ('walltime', [...])]
         """
         for key in ["cputime","walltime"]:
@@ -1486,7 +1486,7 @@ class DocTestDispatcher(SageObject):
         # Logger
         log = self.controller.log
 
-        from sage.ext.pselect import PSelecter
+        from cysignals.pselect import PSelecter
         try:
             # Block SIGCHLD and SIGINT except during the pselect() call
             with PSelecter([signal.SIGCHLD, signal.SIGINT]) as sel:
@@ -1970,7 +1970,7 @@ class DocTestWorker(multiprocessing.Process):
         We set up the worker to start by blocking ``SIGHUP``, such that
         killing will fail initially::
 
-            sage: from sage.ext.pselect import PSelecter
+            sage: from cysignals.pselect import PSelecter
             sage: import signal
             sage: def block_hup():
             ....:     # We never __exit__()
@@ -2068,7 +2068,7 @@ class DocTestTask(object):
         OUTPUT:
 
         - ``(doctests, result_dict)`` where ``doctests`` is the number of
-          doctests and and ``result_dict`` is a dictionary annotated with
+          doctests and ``result_dict`` is a dictionary annotated with
           timings and error information.
 
         - Also put ``(doctests, result_dict)`` onto the ``result_queue``
