@@ -5,7 +5,7 @@ A labelled (generalized) permutation is better suited to study the
 dynamic of a translation surface than a reduced one (see the module
 :mod:`sage.dynamics.interval_exchanges.reduced`). The latter is more
 adapted to the study of strata. This kind of permutation was
-introduced by Yoccoz [Yoc05]_ (see also [MMY03]_).
+introduced by Yoccoz [Yoc2005]_ (see also [MMY2003]_).
 
 In fact, there is a geometric counterpart of labelled
 permutations. They correspond to translation surfaces with marked
@@ -81,14 +81,6 @@ TESTS::
     WordMorphism: a->abcd, b->bab, c->cdc, d->dcbababcd
     sage: s1.incidence_matrix() == s2.incidence_matrix().transpose()
     True
-
-REFERENCES:
-
-.. [Yoc05] Jean-Christophe Yoccoz "Echange d'Intervalles", Cours au college de
-   France
-
-.. [MMY03] Jean-Christophe Yoccoz, Stefano Marmi and Pierre Moussa "On the
-   cohomological equation for interval exchange maps", :arxiv:`math/0304469v1`
 """
 #*****************************************************************************
 #       Copyright (C) 2008 Vincent Delecroix <20100.delecroix@gmail.com>
@@ -96,8 +88,8 @@ REFERENCES:
 #  Distributed under the terms of the GNU General Public License (GPL)
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
+from six.moves import zip
 
 from sage.structure.sage_object import SageObject
 from sage.misc.lazy_attribute import lazy_attribute
@@ -116,6 +108,7 @@ from .template import twin_list_iet, twin_list_li
 from .template import RauzyDiagram, FlippedRauzyDiagram
 from .template import interval_conversion, side_conversion
 
+
 class LabelledPermutation(SageObject):
     r"""
     General template for labelled objects.
@@ -1567,13 +1560,15 @@ class FlippedLabelledPermutation(LabelledPermutation):
             True
         """
         if flips:
-            a0 = zip([self._alphabet.unrank(_) for _ in self._intervals[0]], self._flips[0])
-            a1 = zip([self._alphabet.unrank(_) for _ in self._intervals[1]], self._flips[1])
+            a0 = list(zip([self._alphabet.unrank(_)
+                           for _ in self._intervals[0]], self._flips[0]))
+            a1 = list(zip([self._alphabet.unrank(_)
+                           for _ in self._intervals[1]], self._flips[1]))
         else:
             a0 = [self._alphabet.unrank(_) for _ in self._intervals[0]]
             a1 = [self._alphabet.unrank(_) for _ in self._intervals[1]]
 
-        return [a0,a1]
+        return [a0, a1]
 
     def __getitem__(self,i):
         r"""
@@ -1600,7 +1595,7 @@ class FlippedLabelledPermutation(LabelledPermutation):
         letters = [self._alphabet.unrank(_) for _ in self._intervals[i]]
         flips = self._flips[i]
 
-        return zip(letters,flips)
+        return list(zip(letters, flips))
 
     def __eq__(self,other):
         r"""
@@ -1822,8 +1817,8 @@ class FlippedLabelledPermutationIET(
             f = self._flips
             i = self._intervals
             l = []
-            l.extend([str(j*(1+k)) for j,k in zip(f[0],i[0])])
-            l.extend([str(-j*(1+k)) for j,k in zip(f[1],i[1])])
+            l.extend([str(j*(1+k)) for j, k in zip(f[0],i[0])])
+            l.extend([str(-j*(1+k)) for j, k in zip(f[1],i[1])])
             self._hash = hash(''.join(l))
 
         return self._hash
@@ -1950,7 +1945,7 @@ class FlippedLabelledPermutationLI(FlippedLabelledPermutation,
 
         permutation -- the associated reduced permutation
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: p = iet.GeneralizedPermutation('a a','b b c c',flips='a')
             sage: q = iet.GeneralizedPermutation('a a','b b c c',flips='a',reduced=True)
@@ -2218,7 +2213,7 @@ class LabelledRauzyDiagram(RauzyDiagram):
 
             boolean -- ``True`` if the path is full and ``False`` else
 
-            EXAMPLE::
+            EXAMPLES::
 
                 sage: p = iet.Permutation('a b c','c b a')
                 sage: r = p.rauzy_diagram()
@@ -2243,7 +2238,7 @@ class LabelledRauzyDiagram(RauzyDiagram):
 
         WordMorphism -- the WordMorphism corresponding to the edge
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: p = iet.Permutation('a b c','c b a')
             sage: r = p.rauzy_diagram()
@@ -2273,7 +2268,7 @@ class LabelledRauzyDiagram(RauzyDiagram):
 
         WordMorphism -- the word morphism corresponding to the edge
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: p = iet.Permutation('a b c','c b a')
             sage: r = p.rauzy_diagram()
@@ -2309,7 +2304,7 @@ class LabelledRauzyDiagram(RauzyDiagram):
 
         iterator -- iterator over full loops
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: p = iet.Permutation('a b','b a')
             sage: r = p.rauzy_diagram()
@@ -2348,7 +2343,7 @@ class LabelledRauzyDiagram(RauzyDiagram):
 
         iterator -- an iterator over the full loops of given length
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: p = iet.Permutation('a b','b a')
             sage: d = p.rauzy_diagram()
