@@ -165,7 +165,8 @@ class FunctionAiryAiSimple(BuiltinFunction):
                                  latex_name=r'\operatorname{Ai}',
                                  conversions=dict(mathematica='AiryAi',
                                                   maxima='airy_ai',
-                                                  sympy='airyai'))
+                                                  sympy='airyai',
+                                                  fricas='airyAi'))
 
     def _derivative_(self, x, diff_param=None):
         """
@@ -270,7 +271,8 @@ class FunctionAiryAiPrime(BuiltinFunction):
                                  latex_name=r"\operatorname{Ai}'",
                                  conversions=dict(mathematica='AiryAiPrime',
                                                   maxima='airy_dai',
-                                                  sympy='airyaiprime'))
+                                                  sympy='airyaiprime',
+                                                  fricas='airyAiPrime'))
 
     def _derivative_(self, x, diff_param=None):
         """
@@ -360,7 +362,7 @@ def airy_ai(alpha, x=None, hold_derivative=True, **kwds):
     solutions to the Airy differential equation `f''(x) - x f(x) = 0`. It is
     defined by the initial conditions:
 
-    .. math::
+    .. MATH::
 
         \operatorname{Ai}(0)=\frac{1}{2^{2/3} \Gamma\left(\frac{2}{3}\right)},
 
@@ -368,7 +370,7 @@ def airy_ai(alpha, x=None, hold_derivative=True, **kwds):
 
     Another way to define the Airy Ai function is:
 
-    .. math::
+    .. MATH::
 
         \operatorname{Ai}(x)=\frac{1}{\pi}\int_0^\infty
         \cos\left(\frac{1}{3}t^3+xt\right) dt.
@@ -381,7 +383,7 @@ def airy_ai(alpha, x=None, hold_derivative=True, **kwds):
       `\operatorname{Ai}^{(n)}(z)`, and for `\alpha = -n = -1,-2,-3,\ldots`
       this gives the `n`-fold iterated integral.
 
-    .. math::
+    .. MATH::
 
         f_0(z) = \operatorname{Ai}(z)
 
@@ -497,7 +499,7 @@ class FunctionAiryBiGeneral(BuiltinFunction):
           `\operatorname{Bi}^{(n)}(z)`, and for `\alpha = -n = -1,-2,-3,\ldots`
           this gives the `n`-fold iterated integral.
 
-        .. math::
+        .. MATH::
 
             f_0(z) = \operatorname{Bi}(z)
 
@@ -592,7 +594,8 @@ class FunctionAiryBiSimple(BuiltinFunction):
                                  latex_name=r'\operatorname{Bi}',
                                  conversions=dict(mathematica='AiryBi',
                                                   maxima='airy_bi',
-                                                  sympy='airybi'))
+                                                  sympy='airybi',
+                                                  fricas='airyBi'))
 
     def _derivative_(self, x, diff_param=None):
         """
@@ -699,7 +702,8 @@ class FunctionAiryBiPrime(BuiltinFunction):
                                  latex_name=r"\operatorname{Bi}'",
                                  conversions=dict(mathematica='AiryBiPrime',
                                                   maxima='airy_dbi',
-                                                  sympy='airybiprime'))
+                                                  sympy='airybiprime',
+                                                  fricas='airyBiPrime'))
 
     def _derivative_(self, x, diff_param=None):
         """
@@ -789,7 +793,7 @@ def airy_bi(alpha, x=None, hold_derivative=True, **kwds):
     solutions to the Airy differential equation `f''(x) - x f(x) = 0`. It is
     defined by the initial conditions:
 
-    .. math::
+    .. MATH::
 
         \operatorname{Bi}(0)=\frac{1}{3^{1/6} \Gamma\left(\frac{2}{3}\right)},
 
@@ -797,7 +801,7 @@ def airy_bi(alpha, x=None, hold_derivative=True, **kwds):
 
     Another way to define the Airy Bi function is:
 
-    .. math::
+    .. MATH::
 
         \operatorname{Bi}(x)=\frac{1}{\pi}\int_0^\infty
         \left[ \exp\left( xt -\frac{t^3}{3} \right)
