@@ -101,7 +101,7 @@ The main objects which are exported from this module are:
 -  When solving for separable solutions of Laplace's equation in
    spherical coordinates, the radial equation has the form:
 
-   .. math::
+   .. MATH::
 
          x^2 \frac{d^2 y}{dx^2} + 2x \frac{dy}{dx} + [x^2 - n(n+1)]y = 0.
 
@@ -110,11 +110,11 @@ The main objects which are exported from this module are:
    related to the ordinary Bessel functions `J_n` and
    `Y_n` by:
 
-   .. math::
+   .. MATH::
 
          j_n(x) = \sqrt{\frac{\pi}{2x}} J_{n+1/2}(x),
 
-   .. math::
+   .. MATH::
 
          y_n(x) = \sqrt{\frac{\pi}{2x}} Y_{n+1/2}(x) = (-1)^{n+1} \sqrt{\frac{\pi}{2x}} J_{-n-1/2}(x).
 
@@ -179,19 +179,21 @@ AUTHORS:
 
 REFERENCES:
 
-.. [AS-Bessel] \F. W. J. Olver: 9. Bessel Functions of Integer Order, in Abramowitz and Stegun: Handbook of Mathematical Functions
-    http://people.math.sfu.ca/~cbm/aands/page_355.htm
-.. [AS-Spherical] \H. A. Antosiewicz: 10. Bessel Functions of Fractional Order, in Abramowitz and Stegun: Handbook of Mathematical Functions
-    http://people.math.sfu.ca/~cbm/aands/page_435.htm
-.. [AS-Struve] \M. Abramowitz: 12. Struve Functions and Related Functions, in Abramowitz and Stegun: Handbook of Mathematical Functions
-   http://people.math.sfu.ca/~cbm/aands/page_495.htm
-.. [DLMF-Bessel] \F. W. J. Olver and L. C. Maximon: 10. Bessel Functions, in NIST Digital Library of Mathematical Functions
-    http://dlmf.nist.gov/10
-.. [DLMF-Struve] \R. B. Paris: 11. Struve and Related Functions, in NIST Digital Library of Mathematical Functions
-    http://dlmf.nist.gov/11
-.. _`mpmath Library`: https://github.com/fredrik-johansson/mpmath
-.. [WP-Bessel] :wikipedia:`Bessel_function`
-.. [WP-Struve] :wikipedia:`Struve_function`
+- [AS-Bessel]_
+
+- [AS-Spherical]_
+
+- [AS-Struve]_
+
+- [DLMF-Bessel]_
+
+- [DLMF-Struve]_
+
+.. _`mpmath library`: http://mpmath.org
+
+- [WP-Bessel]_
+
+- [WP-Struve]_
 """
 
 #*****************************************************************************
@@ -301,7 +303,7 @@ class Function_Bessel_J(BuiltinFunction):
         1/24*x^3*hypergeometric((3/2,), (5/2, 3), -1/4*x^2)
         sage: m = maxima(bessel_J(2, x))
         sage: m.integrate(x)
-        hypergeometric([3/2],[5/2,3],-_SAGE_VAR_x^2/4)*_SAGE_VAR_x^3/24
+        (hypergeometric([3/2],[5/2,3],-_SAGE_VAR_x^2/4)*_SAGE_VAR_x^3)/24
 
     Visualization (set plot_points to a higher value to get more detail)::
 
@@ -342,7 +344,8 @@ class Function_Bessel_J(BuiltinFunction):
         BuiltinFunction.__init__(self, "bessel_J", nargs=2,
                                  conversions=dict(mathematica='BesselJ',
                                                   maxima='bessel_j',
-                                                  sympy='besselj'))
+                                                  sympy='besselj',
+                                                  fricas='besselJ'))
 
     def _eval_(self, n, x):
         """
@@ -557,7 +560,8 @@ class Function_Bessel_Y(BuiltinFunction):
         BuiltinFunction.__init__(self, "bessel_Y", nargs=2,
                                  conversions=dict(mathematica='BesselY',
                                                   maxima='bessel_y',
-                                                  sympy='bessely'))
+                                                  sympy='bessely',
+                                                  fricas='besselY'))
 
     def _eval_(self, n, x):
         """
@@ -571,6 +575,11 @@ class Function_Bessel_Y(BuiltinFunction):
             -sqrt(2)*sqrt(1/(pi*x))*cos(x)
             sage: bessel_Y(-1/2, x)
             sqrt(2)*sqrt(1/(pi*x))*sin(x)
+
+        TESTS::
+
+            sage: bessel_Y(0, 0)
+            -Infinity
         """
         from sage.rings.infinity import infinity, unsigned_infinity
         if not isinstance(x, Expression) and x == 0:
@@ -756,7 +765,8 @@ class Function_Bessel_I(BuiltinFunction):
         BuiltinFunction.__init__(self, "bessel_I", nargs=2,
                                  conversions=dict(mathematica='BesselI',
                                                   maxima='bessel_i',
-                                                  sympy='besseli'))
+                                                  sympy='besseli',
+                                                  fricas='besselI'))
 
     def _eval_(self, n, x):
         """
@@ -955,7 +965,8 @@ class Function_Bessel_K(BuiltinFunction):
         BuiltinFunction.__init__(self, "bessel_K", nargs=2,
                                  conversions=dict(mathematica='BesselK',
                                                   maxima='bessel_k',
-                                                  sympy='besselk'))
+                                                  sympy='besselk',
+                                                  fricas='besselK'))
 
     def _eval_(self, n, x):
         """
@@ -968,8 +979,13 @@ class Function_Bessel_K(BuiltinFunction):
             sqrt(1/2)*sqrt(pi)*e^(-x)/sqrt(x)
             sage: bessel_K(n, 0)
             bessel_K(n, 0)
+
+        TESTS::
+
+            sage: bessel_K(0, 0)
+            +Infinity
         """
-        from sage.rings.infinity import unsigned_infinity
+        from sage.rings.infinity import infinity, unsigned_infinity
         if not isinstance(x, Expression) and x == 0:
             if n == 0:
                 return infinity
@@ -1104,7 +1120,7 @@ def Bessel(*args, **kwds):
         sage: x,y = var('x,y')
         sage: f = maxima(Bessel(typ='K')(x,y))
         sage: f.derivative('_SAGE_VAR_x')
-        %pi*csc(%pi*_SAGE_VAR_x)*('diff(bessel_i(-_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1)-'diff(bessel_i(_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1))/2-%pi*bessel_k(_SAGE_VAR_x,_SAGE_VAR_y)*cot(%pi*_SAGE_VAR_x)
+        (%pi*csc(%pi*_SAGE_VAR_x)*('diff(bessel_i(-_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1)-'diff(bessel_i(_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1)))/2-%pi*bessel_k(_SAGE_VAR_x,_SAGE_VAR_y)*cot(%pi*_SAGE_VAR_x)
         sage: f.derivative('_SAGE_VAR_y')
         -(bessel_k(_SAGE_VAR_x+1,_SAGE_VAR_y)+bessel_k(_SAGE_VAR_x-1,_SAGE_VAR_y))/2
 
@@ -1242,7 +1258,8 @@ class Function_Struve_H(BuiltinFunction):
         BuiltinFunction.__init__(self, 'struve_H', nargs=2,
                                  conversions=dict(maple='StruveH',
                                                   mathematica='StruveH',
-                                                  maxima='struve_h'))
+                                                  maxima='struve_h',
+                                                  fricas='struveH'))
 
     def _eval_(self, a, z):
         """
@@ -1355,7 +1372,8 @@ class Function_Struve_L(BuiltinFunction):
         BuiltinFunction.__init__(self, 'struve_L', nargs=2,
                                  conversions=dict(maple='StruveL',
                                                   mathematica='StruveL',
-                                                  maxima='struve_l'))
+                                                  maxima='struve_l',
+                                                  fricas='struveL'))
 
     def _eval_(self, a, z):
         """
@@ -1433,7 +1451,7 @@ class Function_Hankel1(BuiltinFunction):
 
     DEFINITION:
 
-    .. math::
+    .. MATH::
 
         H_\nu^{(1)}(z) = J_{\nu}(z) + iY_{\nu}(z)
 
@@ -1465,7 +1483,8 @@ class Function_Hankel1(BuiltinFunction):
                                  conversions=dict(maple='HankelH1',
                                                   mathematica='HankelH1',
                                                   maxima='hankel1',
-                                                  sympy='hankel1'))
+                                                  sympy='hankel1',
+                                                  fricas='hankelH1'))
 
     def _evalf_(self, nu, z, parent, algorithm=None):
         r"""
@@ -1519,7 +1538,7 @@ class Function_Hankel2(BuiltinFunction):
 
     DEFINITION:
 
-    .. math::
+    .. MATH::
 
         H_\nu^{(2)}(z) = J_{\nu}(z) - iY_{\nu}(z)
 
@@ -1551,7 +1570,8 @@ class Function_Hankel2(BuiltinFunction):
                                  conversions=dict(maple='HankelH2',
                                                   mathematica='HankelH2',
                                                   maxima='hankel2',
-                                                  sympy='hankel2'))
+                                                  sympy='hankel2',
+                                                  fricas='hankelH2'))
 
     def _evalf_(self, nu, z, parent, algorithm=None):
         r"""
@@ -1605,7 +1625,7 @@ class SphericalBesselJ(BuiltinFunction):
 
     DEFINITION:
 
-    .. math::
+    .. MATH::
 
         j_n(z) = \sqrt{\frac{\pi}{2z}} \,J_{n + \frac{1}{2}}(z)
 
@@ -1704,7 +1724,7 @@ class SphericalBesselY(BuiltinFunction):
 
     DEFINITION:
 
-    .. math::
+    .. MATH::
 
         y_n(z) = \sqrt{\frac{\pi}{2z}} \,Y_{n + \frac{1}{2}}(z)
 
@@ -1803,7 +1823,7 @@ class SphericalHankel1(BuiltinFunction):
 
     DEFINITION:
 
-    .. math::
+    .. MATH::
 
         h_n^{(1)}(z) = \sqrt{\frac{\pi}{2z}} \,H_{n + \frac{1}{2}}^{(1)}(z)
 
@@ -1899,7 +1919,7 @@ class SphericalHankel2(BuiltinFunction):
 
     DEFINITION:
 
-    .. math::
+    .. MATH::
 
         h_n^{(2)}(z) = \sqrt{\frac{\pi}{2z}} \,H_{n + \frac{1}{2}}^{(2)}(z)
 
