@@ -6,8 +6,8 @@ from six.moves import range
 
 from sage.symbolic.function import GinacFunction, BuiltinFunction
 from sage.symbolic.expression import Expression
-from sage.symbolic.pynac import register_symbol, symbol_table
-from sage.symbolic.pynac import py_factorial_py
+from sage.libs.pynac.pynac import (register_symbol, symbol_table,
+        py_factorial_py, I)
 from sage.symbolic.all import SR
 from sage.rings.all import Integer, Rational, RealField, RR, ZZ, ComplexField
 from sage.rings.complex_number import is_ComplexNumber
@@ -67,7 +67,7 @@ class Function_erf(BuiltinFunction):
     REFERENCES:
 
     - http://en.wikipedia.org/wiki/Error_function
-    - http://mpmath.googlecode.com/svn/trunk/doc/build/functions/expintegrals.html#error-functions
+    - http://mpmath.org/doc/current/functions/expintegrals.html#error-functions
 
     TESTS:
 
@@ -161,7 +161,8 @@ class Function_erf(BuiltinFunction):
         """
         BuiltinFunction.__init__(self, "erf", latex_name=r"\text{erf}",
                                  conversions=dict(maxima='erf',
-                                                  sympy='erf'))
+                                                  sympy='erf',
+                                                  fricas='erf'))
 
     def _eval_(self, x):
         """
@@ -769,7 +770,7 @@ class Function_gamma(GinacFunction):
         r"""
         The Gamma function.  This is defined by
 
-        .. math::
+        .. MATH::
 
             \Gamma(z) = \int_0^\infty t^{z-1}e^{-t} dt
 
@@ -896,6 +897,13 @@ class Function_gamma(GinacFunction):
             sage: float(gamma(8.5)) == gamma(8.5r) == float(gamma(mpmath.mpf(8.5)))
             True
 
+        Check that ``QQbar`` half integers work with the ``pi`` formula::
+
+            sage: gamma(QQbar(1/2))
+            sqrt(pi)
+            sage: gamma(QQbar(-9/2))
+            -32/945*sqrt(pi)
+
         .. SEEALSO::
 
             :meth:`sage.functions.other.gamma`
@@ -904,7 +912,8 @@ class Function_gamma(GinacFunction):
                 ginac_name='tgamma',
                 conversions={'mathematica':'Gamma',
                              'maple':'GAMMA',
-                             'sympy':'gamma'})
+                             'sympy':'gamma',
+                             'fricas':'Gamma'})
 
 gamma1 = Function_gamma()
 
@@ -1012,7 +1021,8 @@ class Function_log_gamma(GinacFunction):
         GinacFunction.__init__(self, "log_gamma", latex_name=r'\log\Gamma',
                                conversions=dict(mathematica='LogGamma',
                                                 maxima='log_gamma',
-                                                sympy='loggamma'))
+                                                sympy='loggamma',
+                                                fricas='logGamma'))
 
 log_gamma = Function_log_gamma()
 
@@ -1023,7 +1033,7 @@ class Function_gamma_inc(BuiltinFunction):
 
         It is defined by the integral
 
-        .. math::
+        .. MATH::
 
             \Gamma(a,z)=\int_z^\infty t^{a-1}e^{-t}\,\mathrm{d}t
 
@@ -1138,7 +1148,7 @@ class Function_gamma_inc(BuiltinFunction):
             sage: r = gamma_inc(float(0), float(1)); r
             0.21938393439552029
             sage: type(r)
-            <type 'float'>
+            <... 'float'>
         """
         R = parent or s_parent(x)
         # C is the complex version of R
@@ -1176,7 +1186,7 @@ class Function_gamma_inc_lower(BuiltinFunction):
 
         It is defined by the integral
 
-        .. math::
+        .. MATH::
 
             \Gamma(a,z)=\int_0^z t^{a-1}e^{-t}\,\mathrm{d}t
 
@@ -1423,7 +1433,7 @@ class Function_psi1(GinacFunction):
         The digamma function, `\psi(x)`, is the logarithmic derivative of the
         gamma function.
 
-        .. math::
+        .. MATH::
 
             \psi(x) = \frac{d}{dx} \log(\Gamma(x)) = \frac{\Gamma'(x)}{\Gamma(x)}
 
@@ -1547,7 +1557,7 @@ def psi(x, *args, **kwds):
     The digamma function, `\psi(x)`, is the logarithmic derivative of the
     gamma function.
 
-    .. math::
+    .. MATH::
 
         \psi(x) = \frac{d}{dx} \log(\Gamma(x)) = \frac{\Gamma'(x)}{\Gamma(x)}
 
@@ -1715,7 +1725,8 @@ class Function_factorial(GinacFunction):
         GinacFunction.__init__(self, "factorial", latex_name='{\\rm factorial}',
                 conversions=dict(maxima='factorial',
                                  mathematica='Factorial',
-                                 sympy='factorial'))
+                                 sympy='factorial',
+                                 fricas='factorial'))
 
     def _eval_(self, x):
         """
@@ -1755,7 +1766,7 @@ class Function_binomial(GinacFunction):
         r"""
         Return the binomial coefficient
 
-        .. math::
+        .. MATH::
 
             \binom{x}{m} = x (x-1) \cdots (x-m+1) / m!
 
@@ -1764,7 +1775,7 @@ class Function_binomial(GinacFunction):
         `x`. We extend this definition to include cases when
         `x-m` is an integer but `m` is not by
 
-        .. math::
+        .. MATH::
 
             \binom{x}{m}= \binom{x}{x-m}
 
@@ -1846,7 +1857,8 @@ class Function_binomial(GinacFunction):
         GinacFunction.__init__(self, "binomial", nargs=2, preserved_arg=1,
                 conversions=dict(maxima='binomial',
                                  mathematica='Binomial',
-                                 sympy='binomial'))
+                                 sympy='binomial',
+                                 fricas='binomial'))
 
     def _binomial_sym(self, n, k):
         """
@@ -1931,7 +1943,7 @@ class Function_binomial(GinacFunction):
             sage: binomial._evalf_(5.r, 3)
             10.0
             sage: type(binomial._evalf_(5.r, 3))
-            <type 'float'>
+            <... 'float'>
             sage: binomial._evalf_(1/2,1/1)
             1/2
             sage: binomial._evalf_(10^20+1/1,10^20)
@@ -1950,7 +1962,7 @@ class Function_beta(GinacFunction):
         r"""
         Return the beta function.  This is defined by
 
-        .. math::
+        .. MATH::
 
             \operatorname{B}(p,q) = \int_0^1 t^{p-1}(1-t)^{q-1} dt
 
@@ -1966,20 +1978,20 @@ class Function_beta(GinacFunction):
         other.  In other cases, GiNaC uses one of the following
         formulas:
 
-        .. math::
+        .. MATH::
 
             \operatorname{B}(p,q) = \frac{\Gamma(p)\Gamma(q)}{\Gamma(p+q)}
 
         or
 
-        .. math::
+        .. MATH::
 
             \operatorname{B}(p,q) = (-1)^q \operatorname{B}(1-p-q, q).
 
 
         For numerical inputs, GiNaC uses the formula
 
-        .. math::
+        .. MATH::
 
             \operatorname{B}(p,q) =  \exp[\log\Gamma(p)+\log\Gamma(q)-\log\Gamma(p+q)]
 
@@ -2047,7 +2059,8 @@ class Function_beta(GinacFunction):
         GinacFunction.__init__(self, "beta", nargs=2,
                 conversions=dict(maxima='beta',
                                  mathematica='Beta',
-                                 sympy='beta'))
+                                 sympy='beta',
+                                 fricas='Beta'))
 
 beta = Function_beta()
 
@@ -2098,7 +2111,6 @@ def _do_sqrt(x, prec=None, extend=True, all=False):
             else:
                  return ComplexField(prec)(x).sqrt(all=all)
         if x == -1:
-            from sage.symbolic.pynac import I
             z = I
         else:
             z = SR(x) ** one_half
@@ -2408,6 +2420,12 @@ class Function_real_part(GinacFunction):
             sage: f(x) = function('f')(x)
             sage: latex( f(x).real())
             \Re \left( f\left(x\right) \right)
+
+        Check that some real part expansions evaluate correctly
+        (:trac:`21614`)::
+
+            sage: real(sqrt(sin(x))).subs(x==0)
+            0
         """
         GinacFunction.__init__(self, "real_part",
                                conversions=dict(maxima='realpart',
@@ -2419,7 +2437,7 @@ class Function_real_part(GinacFunction):
         TESTS::
 
             sage: type(real(complex(3, 4)))
-            <type 'float'>
+            <... 'float'>
         """
         if isinstance(x, complex):
             return x.real
@@ -2478,7 +2496,7 @@ class Function_imag_part(GinacFunction):
         TESTS::
 
             sage: type(imag(complex(3, 4)))
-            <type 'float'>
+            <... 'float'>
         """
         if isinstance(x, complex):
             return x.imag
@@ -2565,3 +2583,27 @@ class Function_conjugate(GinacFunction):
                                conversions=dict(sympy='conjugate'))
 
 conjugate = Function_conjugate()
+
+
+class Function_sum(BuiltinFunction):
+    """
+    Placeholder symbolic sum function that is only accessible internally.
+
+    EXAMPLES::
+
+        sage: from sage.functions.other import symbolic_sum as ssum
+        sage: ssum(x, x, 1, 10)
+        sum(x, x, 1, 10)
+    """
+    def __init__(self):
+        """
+        EXAMPLES::
+
+            sage: from sage.functions.other import symbolic_sum as ssum
+            sage: maxima(ssum(x, x, 1, 10))
+            55
+        """
+        BuiltinFunction.__init__(self, "sum", nargs=4,
+                               conversions=dict(maxima='sum'))
+
+symbolic_sum = Function_sum()
