@@ -35,7 +35,7 @@ implemented here.
 -  Spherical harmonics: Laplace's equation in spherical coordinates
    is:
 
-   .. math::
+   .. MATH::
 
        \frac{1}{r^2} \frac{\partial}{\partial r}
        \left( r^2 \frac{\partial f}{\partial r} \right) +
@@ -53,14 +53,14 @@ implemented here.
    The general solution which remains finite towards infinity is a
    linear combination of functions of the form
 
-   .. math::
+   .. MATH::
 
          r^{-1-\ell} \cos (m \varphi) P_\ell^m (\cos{\theta} )
 
 
    and
 
-   .. math::
+   .. MATH::
 
          r^{-1-\ell} \sin (m \varphi) P_\ell^m (\cos{\theta} )
 
@@ -72,7 +72,7 @@ implemented here.
    `- \ell\leq m\leq \ell`, can be written as linear
    combinations of:
 
-   .. math::
+   .. MATH::
 
          U_{\ell,m}(r,\theta , \varphi ) =
          r^{-1-\ell} Y_\ell^m( \theta , \varphi )
@@ -82,7 +82,7 @@ implemented here.
    functions with parameters `\ell`, `m`, which can be
    written as:
 
-   .. math::
+   .. MATH::
 
          Y_\ell^m( \theta , \varphi ) = (-1)^m
          \sqrt{ \frac{(2\ell+1)}{4\pi} \frac{(\ell-m)!}{(\ell+m)!} }
@@ -93,7 +93,7 @@ implemented here.
    The spherical harmonics obey the normalisation condition
 
 
-   .. math::
+   .. MATH::
 
      \int_{\theta=0}^\pi\int_{\varphi=0}^{2\pi}
      Y_\ell^mY_{\ell'}^{m'*}\,d\Omega =
@@ -103,7 +103,7 @@ implemented here.
 
    -  The incomplete elliptic integrals (of the first kind, etc.) are:
 
-      .. math::
+      .. MATH::
 
          \begin{array}{c}
          \displaystyle\int_0^\phi \frac{1}{\sqrt{1 - m\sin(x)^2}}\, dx,\\
@@ -184,9 +184,9 @@ class SphericalHarmonic(BuiltinFunction):
 
         sage: x, y = var('x, y')
         sage: spherical_harmonic(3, 2, x, y)
-        15/4*sqrt(7/30)*cos(x)*e^(2*I*y)*sin(x)^2/sqrt(pi)
+        1/8*sqrt(30)*sqrt(7)*cos(x)*e^(2*I*y)*sin(x)^2/sqrt(pi)
         sage: spherical_harmonic(3, 2, 1, 2)
-        15/4*sqrt(7/30)*cos(1)*e^(4*I)*sin(1)^2/sqrt(pi)
+        1/8*sqrt(30)*sqrt(7)*cos(1)*e^(4*I)*sin(1)^2/sqrt(pi)
         sage: spherical_harmonic(3 + I, 2., 1, 2)
         -0.351154337307488 - 0.415562233975369*I
         sage: latex(spherical_harmonic(3, 2, x, y, hold=True))
@@ -221,17 +221,29 @@ class SphericalHarmonic(BuiltinFunction):
             sage: spherical_harmonic(1/2, 2, x, y)
             spherical_harmonic(1/2, 2, x, y)
             sage: spherical_harmonic(3, 2, x, y)
-            15/4*sqrt(7/30)*cos(x)*e^(2*I*y)*sin(x)^2/sqrt(pi)
+            1/8*sqrt(30)*sqrt(7)*cos(x)*e^(2*I*y)*sin(x)^2/sqrt(pi)
             sage: spherical_harmonic(3, 2, 1, 2)
-            15/4*sqrt(7/30)*cos(1)*e^(4*I)*sin(1)^2/sqrt(pi)
+            1/8*sqrt(30)*sqrt(7)*cos(1)*e^(4*I)*sin(1)^2/sqrt(pi)
             sage: spherical_harmonic(3 + I, 2., 1, 2)
             -0.351154337307488 - 0.415562233975369*I
+
+        Check that :trac:`20939` is fixed::
+
+            sage: spherical_harmonic(3,2,1,2*pi/3)
+            -1/240*sqrt(30)*(15*I*sqrt(7)*sqrt(3)
+             + 15*sqrt(7))*cos(1)*sin(1)^2/sqrt(pi)
         """
         if n in ZZ and m in ZZ and n > -1:
             if abs(m) > n:
                 return ZZ(0)
-            return maxima("spherical_harmonic({},{},{},{})".format(
-                ZZ(n), ZZ(m), maxima(theta), maxima(phi))).sage()
+            if m == 0 and theta.is_zero():
+                return sqrt((2*n+1)/4/pi)
+            from sage.arith.misc import factorial
+            from sage.functions.trig import cos
+            from sage.functions.orthogonal_polys import gen_legendre_P
+            return (sqrt(factorial(n-m) * (2*n+1) / (4*pi * factorial(n+m))) *
+                    exp(I*m*phi) * gen_legendre_P(n, m, cos(theta)) *
+                    (-1)**m).simplify_trig()
 
     def _evalf_(self, n, m, theta, phi, parent, **kwds):
         r"""
@@ -347,7 +359,7 @@ class EllipticE(BuiltinFunction):
     Return the incomplete elliptic integral of the
     second kind:
 
-    .. math::
+    .. MATH::
 
         E(\varphi\,|\,m)=\int_0^\varphi \sqrt{1 - m\sin(x)^2}\, dx.
 
@@ -394,7 +406,8 @@ class EllipticE(BuiltinFunction):
                                  # k instead of m as the second argument
                                  conversions=dict(mathematica='EllipticE',
                                                   maxima='elliptic_e',
-                                                  sympy='elliptic_e'))
+                                                  sympy='elliptic_e',
+                                              ))
 
     def _eval_(self, z, m):
         """
@@ -474,7 +487,7 @@ class EllipticEC(BuiltinFunction):
     """
     Return the complete elliptic integral of the second kind:
 
-    .. math::
+    .. MATH::
 
         E(m)=\int_0^{\pi/2} \sqrt{1 - m\sin(x)^2}\, dx.
 
@@ -505,7 +518,8 @@ class EllipticEC(BuiltinFunction):
         BuiltinFunction.__init__(self, 'elliptic_ec', nargs=1, latex_name='E',
                                  conversions=dict(mathematica='EllipticE',
                                                   maxima='elliptic_ec',
-                                                  sympy='elliptic_e'))
+                                                  sympy='elliptic_e',
+                                                  fricas='ellipticE'))
  
     def _eval_(self, x):
         """
@@ -553,7 +567,7 @@ class EllipticEU(BuiltinFunction):
     r"""
     Return Jacobi's form of the incomplete elliptic integral of the second kind:
 
-    .. math::
+    .. MATH::
 
         E(u,m)=
         \int_0^u \mathrm{dn}(x,m)^2\, dx = \int_0^\tau
@@ -677,7 +691,7 @@ class EllipticF(BuiltinFunction):
     r"""
     Return the incomplete elliptic integral of the first kind.
 
-    .. math::
+    .. MATH::
 
         F(\varphi\,|\,m)=\int_0^\varphi \frac{dx}{\sqrt{1 - m\sin(x)^2}},
 
@@ -787,7 +801,7 @@ class EllipticKC(BuiltinFunction):
     r"""
     Return the complete elliptic integral of the first kind:
 
-    .. math::
+    .. MATH::
 
         K(m)=\int_0^{\pi/2} \frac{dx}{\sqrt{1 - m\sin(x)^2}}.
 
@@ -820,7 +834,8 @@ class EllipticKC(BuiltinFunction):
         BuiltinFunction.__init__(self, 'elliptic_kc', nargs=1, latex_name='K',
                                  conversions=dict(mathematica='EllipticK',
                                                   maxima='elliptic_kc',
-                                                  sympy='elliptic_k'))
+                                                  sympy='elliptic_k',
+                                                  fricas='ellipticK'))
  
     def _eval_(self, z):
         """
@@ -879,7 +894,7 @@ class EllipticPi(BuiltinFunction):
     r"""
     Return the incomplete elliptic integral of the third kind:
 
-    .. math::
+    .. MATH::
 
         \Pi(n, t, m) = \int_0^t \frac{dx}{(1 - n \sin(x)^2)\sqrt{1 - m \sin(x)^2}}.
 
