@@ -263,7 +263,25 @@ class Function_cot(GinacFunction):
             sage: diff(cot(x), x)
             -cot(x)^2 - 1
 
-        TESTS:
+        TESTS::
+
+            sage: cot(float(0))
+            Infinity
+            sage: cot(SR(0))
+            Infinity
+            sage: cot(float(0.1))
+            9.966644423259238
+            sage: type(_)
+            <... 'float'>
+
+            sage: cot(float(0))
+            Infinity
+            sage: cot(SR(0))
+            Infinity
+            sage: cot(float(0.1))
+            9.966644423259238
+            sage: type(_)
+            <... 'float'>
 
         Test complex input::
 
@@ -481,7 +499,7 @@ class Function_arcsin(GinacFunction):
             (0.6662394324925152+1.0612750619050357j)
         """
         GinacFunction.__init__(self, 'arcsin', latex_name=r"\arcsin",
-                conversions=dict(maxima='asin', sympy='asin'))
+                conversions=dict(maxima='asin', sympy='asin', fricas="asin"))
 
 arcsin = asin = Function_arcsin()
 
@@ -540,7 +558,7 @@ class Function_arccos(GinacFunction):
             (0.9045568943023814-1.0612750619050357j)
         """
         GinacFunction.__init__(self, 'arccos', latex_name=r"\arccos",
-                conversions=dict(maxima='acos', sympy='acos'))
+                conversions=dict(maxima='acos', sympy='acos', fricas='acos'))
 
 arccos = acos = Function_arccos()
 
@@ -608,7 +626,7 @@ class Function_arctan(GinacFunction):
             1/2*pi
         """
         GinacFunction.__init__(self, 'arctan', latex_name=r"\arctan",
-                conversions=dict(maxima='atan', sympy='atan'))
+                conversions=dict(maxima='atan', sympy='atan', fricas='atan'))
 
 arctan = atan = Function_arctan()
 
@@ -658,7 +676,7 @@ class Function_arccot(GinacFunction):
 
         """
         GinacFunction.__init__(self, 'arccot', latex_name=r"\operatorname{arccot}",
-                conversions=dict(maxima='acot', sympy='acot'))
+                conversions=dict(maxima='acot', sympy='acot', fricas='acot'))
 
     def _eval_numpy_(self, x):
         """
@@ -714,7 +732,7 @@ class Function_arccsc(GinacFunction):
             (0.45227844715119064-0.5306375309525178j)
         """
         GinacFunction.__init__(self, 'arccsc', latex_name=r"\operatorname{arccsc}",
-                                   conversions=dict(maxima='acsc', sympy='acsc'))
+                               conversions=dict(maxima='acsc', sympy='acsc', fricas='acsc'))
 
     def _eval_numpy_(self, x):
         """
@@ -772,7 +790,7 @@ class Function_arcsec(GinacFunction):
             (1.118517879643706+0.5306375309525178j)
         """
         GinacFunction.__init__(self, 'arcsec', latex_name=r"\operatorname{arcsec}",
-                                   conversions=dict(maxima='asec', sympy='asec'))
+                               conversions=dict(maxima='asec', sympy='asec', fricas='asec'))
 
     def _eval_numpy_(self, x):
         """
@@ -819,7 +837,7 @@ class Function_arctan2(GinacFunction):
         This is consistent with Python and Maxima::
 
             sage: maxima.atan2(1,-1)
-            3*%pi/4
+            (3*%pi)/4
             sage: math.atan2(1,-1)
             2.356194490192345
 
@@ -885,20 +903,16 @@ class Function_arctan2(GinacFunction):
             sage: arctan2(0, -log(2)).n()
             3.14159265358979
 
-        Check if atan2(0,0) throws error of :trac:`11423`::
+        Check that atan2(0,0) returns NaN :trac:`21614`::
 
             sage: atan2(0,0)
-            Traceback (most recent call last):
-            ...
-            RuntimeError: arctan2_eval(): arctan2(0,0) encountered
-
+            NaN
+            sage: atan2(0,0).n()
+            NaN
             sage: atan2(0,0,hold=True)
             arctan2(0, 0)
-
             sage: atan2(0,0,hold=True).n()
-            Traceback (most recent call last):
-            ...
-            ValueError: arctan2(0,0) undefined
+            NaN
 
         Check if :trac:`10062` is fixed, this was caused by
         ``(I*I).is_positive()`` returning ``True``::
