@@ -9,8 +9,6 @@ from .fan import Fan, FaceFan, NormalFan, Fan2d
 
 from .fan_morphism import FanMorphism
 
-from .polytope import polymake
-
 from .polyhedron.all import *
 
 from .lattice_polytope import (LatticePolytope, NefPartition, ReflexivePolytope,
@@ -25,5 +23,6 @@ from . import toric_plotter
 
 from .hyperbolic_space.all import *
 
+lazy_import('sage.geometry.ribbon_graph', 'RibbonGraph')
 lazy_import('sage.geometry.hyperplane_arrangement.arrangement', 'HyperplaneArrangements')
 lazy_import('sage.geometry.hyperplane_arrangement.library', 'hyperplane_arrangements')
