@@ -36,8 +36,10 @@ add them and multiply them with scalars::
     sage: m-m
     0*x + 0*y + 0*z + 0
 """
+from six.moves import zip
 
 from sage.structure.parent import Parent
+from sage.structure.sage_object import richcmp
 from sage.structure.element import ModuleElement
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.misc.cachefunc import cached_method
@@ -263,8 +265,8 @@ class LinearExpression(ModuleElement):
             '0'
         """
         atomic_repr = self.parent().base_ring()._repr_option('element_is_atomic')
-        names = [multiplication+n for n in self.parent()._names]
-        terms = zip(self._coeffs, names)
+        names = [multiplication + n for n in self.parent()._names]
+        terms = list(zip(self._coeffs, names))
         if include_constant:
             terms += [(self._const, '')]
         if not include_zero:
@@ -389,7 +391,7 @@ class LinearExpression(ModuleElement):
         """
         return hash(self._coeffs) ^ hash(self._const)
 
-    def __cmp__(self, other):
+    def _richcmp_(self, other, op):
         """
         Compare two linear expressions.
 
@@ -416,8 +418,8 @@ class LinearExpression(ModuleElement):
             sage: x == 'test'
             False
         """
-        assert type(self) is type(other) and self.parent() is other.parent()  # guaranteed by framework
-        return cmp(self._coeffs, other._coeffs) or cmp(self._const, other._const)
+        return richcmp((self._coeffs, self._const),
+                (other._coeffs, other._const), op)
 
     def evaluate(self, point):
         """
