@@ -145,7 +145,7 @@ class Polyhedron_ppl(Polyhedron_base):
         EXAMPLES::
 
             sage: p = Polyhedron(vertices=[(0,1/2),(2,0),(4,5/6)],
-            ...                  backend='ppl')  # indirect doctest
+            ....:                backend='ppl')  # indirect doctest
             sage: p.Hrepresentation()
             (An inequality (1, 4) x - 2 >= 0,
              An inequality (1, -12) x + 6 >= 0,
@@ -182,7 +182,7 @@ class Polyhedron_ppl(Polyhedron_base):
         EXAMPLES::
 
             sage: p = Polyhedron(vertices=[(0,1/2),(2,0),(4,5/6)],
-            ...                  backend='ppl')  # indirect doctest
+            ....:                backend='ppl')  # indirect doctest
             sage: p.Hrepresentation()
             (An inequality (1, 4) x - 2 >= 0,
              An inequality (1, -12) x + 6 >= 0,
@@ -240,7 +240,7 @@ class Polyhedron_QQ_ppl(Polyhedron_ppl, Polyhedron_QQ):
     EXAMPLES::
 
         sage: p = Polyhedron(vertices=[(0,0),(1,0),(0,1)], rays=[(1,1)], lines=[],
-        ...                  backend='ppl', base_ring=QQ)
+        ....:                backend='ppl', base_ring=QQ)
         sage: TestSuite(p).run(skip='_test_pickling')
     """
     pass
@@ -260,7 +260,7 @@ class Polyhedron_ZZ_ppl(Polyhedron_ppl, Polyhedron_ZZ):
     EXAMPLES::
 
         sage: p = Polyhedron(vertices=[(0,0),(1,0),(0,1)], rays=[(1,1)], lines=[])
-        ...                  backend='ppl', base_ring=ZZ)
+        ....:                backend='ppl', base_ring=ZZ)
         sage: TestSuite(p).run(skip='_test_pickling')
     """
     pass
