@@ -57,6 +57,14 @@ representation. For example, `(0,0)` is a superfluous vertex here::
     sage: triangle.vertices()
     (A vertex at (-1, 0), A vertex at (1, 0), A vertex at (0, 2))
 
+.. SEEALSO::
+
+    If one only needs to keep track of a system of linear system of
+    inequalities, one should also consider the class for mixed integer linear
+    programming.
+
+    - :mod:`Mixed Integer Linear Programming <sage.numerical.mip>`
+
 
 Unbounded Polyhedra
 -------------------
@@ -173,11 +181,14 @@ exact way to work with roots in Sage is the :mod:`Algebraic Real Field
 
 Without specifying the ``base_ring``, the ``sqrt(3)`` would be a
 symbolic ring element and, therefore, the polyhedron defined over the
-symbolic ring. This is possible as well, but rather slow::
+symbolic ring. This is currently not supported as SR is not exact::
 
     sage: Polyhedron([(0,0), (1,0), (1/2, sqrt(3)/2)])
-    A 2-dimensional polyhedron in (Symbolic Ring)^2 defined as the convex 
-    hull of 3 vertices
+    Traceback (most recent call last):
+    ...
+    ValueError: no appropriate backend for computations with Symbolic Ring
+    sage: SR.is_exact()
+    False
 
 Even faster than all algebraic real numbers (the field ``AA``) is
 to take the smallest extension field. For the equilateral
@@ -188,6 +199,36 @@ triangle, that would be::
     A 2-dimensional polyhedron in (Number Field in sqrt3 with defining 
     polynomial x^2 - 3)^2 defined as the convex hull of 3 vertices
 
+Base classes
+------------
+
+Depending on the chosen base ring, a specific class is used to represent the polyhedron object.
+
+.. SEEALSO::
+
+    - :mod:`Base class for polyhedra <sage.geometry.polyhedron.base.Polyhedron_base>`
+    - :mod:`Base class for polyhedra over integers <sage.geometry.polyhedron.base_ZZ.Polyhedron_ZZ>`
+    - :mod:`Base class for polyhedra over rationals <sage.geometry.polyhedron.base_QQ.Polyhedron_QQ>`
+    - :mod:`Base class for polyhedra over RDF <sage.geometry.polyhedron.base_RDF.Polyhedron_RDF>`
+
+The most important base class is **Base class for polyhedra** from which other base classes and backends inherit.
+
+Backends
+--------
+
+There are different backends available to deal with polyhedron objects.
+
+.. SEEALSO::
+
+    - :mod:`cdd backend for polyhedra <sage.geometry.polyhedron.backend_cdd.Polyhedron_cdd>`
+    - :mod:`field backend for polyhedra <sage.geometry.polyhedron.backend_field.Polyhedron_field>`
+    - :mod:`normaliz backend for polyhedra <sage.geometry.polyhedron.backend_normaliz.Polyhedron_normaliz>`
+    - :mod:`ppl backend for polyhedra <sage.geometry.polyhedron.backend_ppl.Polyhedron_ppl>`
+
+.. NOTE::
+
+    Depending on the backend used, it may occur that different methods are
+    available or not.
 
 Appendix
 --------
@@ -195,7 +236,7 @@ Appendix
 REFERENCES:
 
     Komei Fukuda's `FAQ in Polyhedral Computation
-    <http://www.ifor.math.ethz.ch/~fukuda/polyfaq/polyfaq.html>`_
+    <https://www.inf.ethz.ch/personal/fukudak/polyfaq/polyfaq.html>`_
 
 AUTHORS:
 
@@ -220,13 +261,11 @@ from __future__ import print_function
 from __future__ import absolute_import
 
 from sage.rings.all import QQ, ZZ, RDF, RR
-from sage.misc.decorators import rename_keyword
 
 from .misc import _make_listlist, _common_length_of
 
 
 #########################################################################
-@rename_keyword(deprecation=11634, field='base_ring')
 def Polyhedron(vertices=None, rays=None, lines=None,
                ieqs=None, eqns=None,
                ambient_dim=None, base_ring=None, minimize=True, verbose=False,
@@ -277,6 +316,10 @@ def Polyhedron(vertices=None, rays=None, lines=None,
         (:mod:`~sage.geometry.polyhedron.backend_cdd`) with `\QQ` or
         `\RDF` coefficients depending on ``base_ring``.
 
+      * ``'normaliz'``: use normaliz
+        (:mod:`~sage.geometry.polyhedron.backend_normaliz`) with `\ZZ` or
+        `\QQ` coefficients depending on ``base_ring``.
+
       * ``'ppl'``: use ppl
         (:mod:`~sage.geometry.polyhedron.backend_ppl`) with `\ZZ` or
         `\QQ` coefficients depending on ``base_ring``.
@@ -341,10 +384,10 @@ def Polyhedron(vertices=None, rays=None, lines=None,
     ::
 
         sage: positive_coords = Polyhedron(ieqs=[
-        ...       [0, 1, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0],
-        ...       [0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 1]])
+        ....:     [0, 1, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0],
+        ....:     [0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 1]])
         sage: P = Polyhedron(ieqs=positive_coords.inequalities() + (
-        ...       [0,0,1,-1,-1,1,0], [0,0,-1,1,-1,1,0]), eqns=[[-31,1,1,1,1,1,1]])
+        ....:     [0,0,1,-1,-1,1,0], [0,0,-1,1,-1,1,0]), eqns=[[-31,1,1,1,1,1,1]])
         sage: P
         A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 7 vertices
         sage: P.dim()
@@ -359,7 +402,7 @@ def Polyhedron(vertices=None, rays=None, lines=None,
 
       * Once constructed, a ``Polyhedron`` object is immutable.
 
-      * Although the option ``field=RDF`` allows numerical data to
+      * Although the option ``base_ring=RDF`` allows numerical data to
         be used, it might not give the right answer for degenerate
         input data - the results can depend upon the tolerance
         setting of cdd.
