@@ -50,13 +50,6 @@ The following constructions are available
     :meth:`~sage.geometry.polyhedron.library.Polytopes.truncated_tetrahedron`
     :meth:`~sage.geometry.polyhedron.library.Polytopes.truncated_octahedron`
     :meth:`~sage.geometry.polyhedron.library.Polytopes.twenty_four_cell`
-
-REFERENCES:
-
-..  [Fetter2012]
-    Hans L. Fetter,
-    "A Polyhedron Full of Surprises",
-    Mathematics Magazine 85 (2012), no. 5, 334-342.
 """
 from __future__ import absolute_import
 
@@ -754,7 +747,7 @@ class Polytopes():
         off all the permutations of `(0, \pm 1, \pm 2)`. For more
         information, see the :wikipedia:`Truncated_octahedron`.
 
-        This is also know as the permutohedron of dimension 3.
+        This is also known as the permutohedron of dimension 3.
 
         EXAMPLES::
 
@@ -892,7 +885,7 @@ class Polytopes():
             sage: sum(1 for f in bb.faces(2) if len(f.vertices()) == 6)
             20
         """
-        return self.icosahedron(exact=exact, base_ring=base_ring).edge_truncation()
+        return self.icosahedron(exact=exact, base_ring=base_ring).truncation()
 
     def icosidodecahedron(self, exact=True):
         """
@@ -1111,7 +1104,7 @@ class Polytopes():
 
         The Kirkman icosahedron is a 3-polytope with integer coordinates: `(\pm
         9, \pm 6, \pm 6)`, `(\pm 12, \pm 4, 0)`, `(0, \pm 12, \pm 8)`, `(\pm 6,
-        0, \pm 12)`. See [Fetter2012]_ for more information.
+        0, \pm 12)`. See [Fe2012]_ for more information.
 
         EXAMPLES::
 
@@ -1382,7 +1375,7 @@ class Polytopes():
             sage: p600 = polytopes.six_hundred_cell()
             sage: p600
             A 4-dimensional polyhedron in RDF^4 defined as the convex hull of 120 vertices
-            sage: p600.f_vector()
+            sage: p600.f_vector()  # long time ~2sec
             (1, 120, 720, 1200, 600, 1)
 
         Computation with exact coordinates is currently too long to be useful::
