@@ -33,11 +33,16 @@ def Polyhedra(base_ring, ambient_dim, backend=None):
 
     - ``ambient_dim`` -- integer. The ambient space dimension.
 
-    - ``backend`` -- string. The name of the backend for computations. Currently there are two backends implemented:
+    - ``backend`` -- string. The name of the backend for computations. There are
+       several backends implemented:
 
-         * ``backend=ppl`` uses the Parma Polyhedra Library
+         * ``backend="ppl"`` uses the Parma Polyhedra Library
 
-         * ``backend=cdd`` uses CDD
+         * ``backend="cdd"`` uses CDD
+
+         * ``backend="normaliz"`` uses normaliz
+
+         * ``backend="field"`` a generic Sage implementation
 
     OUTPUT:
 
@@ -64,6 +69,17 @@ def Polyhedra(base_ring, ambient_dim, backend=None):
 
         sage: Polyhedra(ZZ, 3, backend='cdd')
         Polyhedra in QQ^3
+
+    TESTS::
+
+        sage: Polyhedra(RR, 3, backend='field')
+        Traceback (most recent call last):
+        ...
+        ValueError: the 'field' backend for polyhedron can not be used with non-exact fields
+        sage: Polyhedra(RR, 3)
+        Traceback (most recent call last):
+        ...
+        ValueError: no appropriate backend for computations with Real Field with 53 bits of precision
     """
     if backend is None:
         if base_ring is ZZ:
@@ -72,17 +88,26 @@ def Polyhedra(base_ring, ambient_dim, backend=None):
             backend = 'ppl'
         elif base_ring is RDF:
             backend = 'cdd'
-        else:
+        elif base_ring.is_exact():
             backend = 'field'
+        else:
+            raise ValueError("no appropriate backend for computations with {}".format(base_ring))
+
     if backend == 'ppl' and base_ring is QQ:
         return Polyhedra_QQ_ppl(base_ring, ambient_dim)
     elif backend == 'ppl' and base_ring is ZZ:
         return Polyhedra_ZZ_ppl(base_ring, ambient_dim)
+    elif backend == 'normaliz' and base_ring is QQ:
+        return Polyhedra_QQ_normaliz(base_ring, ambient_dim)
+    elif backend == 'normaliz' and base_ring is ZZ:
+        return Polyhedra_ZZ_normaliz(base_ring, ambient_dim)
     elif backend == 'cdd' and base_ring in (ZZ, QQ):
         return Polyhedra_QQ_cdd(QQ, ambient_dim)
     elif backend == 'cdd' and base_ring is RDF:
         return Polyhedra_RDF_cdd(RDF, ambient_dim)
     elif backend == 'field':
+        if not base_ring.is_exact():
+            raise ValueError("the 'field' backend for polyhedron can not be used with non-exact fields")
         return Polyhedra_field(base_ring.fraction_field(), ambient_dim)
     else:
         raise ValueError('No such backend (='+str(backend)+
@@ -539,7 +564,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         Boolean.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.geometry.polyhedron.parent import Polyhedra
             sage: Polyhedra(QQ,3).has_coerce_map_from( Polyhedra(ZZ,3) )   # indirect doctest
@@ -792,14 +817,21 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
 from sage.geometry.polyhedron.backend_cdd import Polyhedron_QQ_cdd, Polyhedron_RDF_cdd
 from sage.geometry.polyhedron.backend_ppl import Polyhedron_ZZ_ppl, Polyhedron_QQ_ppl
+from sage.geometry.polyhedron.backend_normaliz import Polyhedron_ZZ_normaliz, Polyhedron_QQ_normaliz
 from sage.geometry.polyhedron.backend_field import Polyhedron_field
 
 class Polyhedra_ZZ_ppl(Polyhedra_base):
     Element = Polyhedron_ZZ_ppl
 
+class Polyhedra_ZZ_normaliz(Polyhedra_base):
+    Element = Polyhedron_ZZ_normaliz
+
 class Polyhedra_QQ_ppl(Polyhedra_base):
     Element = Polyhedron_QQ_ppl
 
+class Polyhedra_QQ_normaliz(Polyhedra_base):
+    Element = Polyhedron_QQ_normaliz
+
 class Polyhedra_QQ_cdd(Polyhedra_base):
     Element = Polyhedron_QQ_cdd
 
