@@ -7,7 +7,7 @@ arrangement of pseudolines in several different ways, and to translate one
 description into another, as well as to display *Wiring diagrams* via the
 :meth:`show <sage.geometry.pseudolines.PseudolineArrangement.show>` method.
 
-In the following, we try to stick to the terminology given in [Felsner]_, which
+In the following, we try to stick to the terminology given in [Fe1997]_, which
 can be checked in case of doubt. And please fix this module's documentation
 afterwards :-)
 
@@ -110,7 +110,7 @@ corresponds in the wiring diagram to a line going up while the line immediately
 above it goes down -- those two lines cross. Each time such a pattern is found
 it yields a new transposition, and the matrix can be updated so that this
 pattern disappears. A more detailed description of this algorithm is given in
-[Felsner]_.
+[Fe1997]_.
 
 ::
 
@@ -149,14 +149,6 @@ And finally build the line arrangement::
     Arrangement of pseudolines of size 20
     sage: p.show(figsize=[20,8])
 
-
-References
-^^^^^^^^^^
-
-.. [Felsner] On the Number of Arrangements of Pseudolines,
-  Stefan Felsner,
-  http://page.math.tu-berlin.de/~felsner/Paper/numarr.pdf
-
 Author
 ^^^^^^
 Nathann Cohen
@@ -316,7 +308,7 @@ class PseudolineArrangement:
         See the :mod:`pseudolines module <sage.geometry.pseudolines>`'s
         documentation for more information on this encoding.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.geometry.pseudolines import PseudolineArrangement
             sage: permutations = [[3, 2, 1], [3, 2, 0], [3, 1, 0], [2, 1, 0]]
@@ -373,7 +365,7 @@ class PseudolineArrangement:
         See the :mod:`pseudolines module <sage.geometry.pseudolines>`'s
         documentation for more information on this encoding.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.geometry.pseudolines import PseudolineArrangement
             sage: permutations = [[3, 2, 1], [3, 2, 0], [3, 1, 0], [2, 1, 0]]
@@ -390,7 +382,7 @@ class PseudolineArrangement:
         See the :mod:`pseudolines module <sage.geometry.pseudolines>`'s
         documentation for more information on this encoding.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.geometry.pseudolines import PseudolineArrangement
             sage: permutations = [[3, 2, 1], [3, 2, 0], [3, 1, 0], [2, 1, 0]]
@@ -420,7 +412,7 @@ class PseudolineArrangement:
           particular, to tune the dimensions, use the ``figsize`` argument
           (example below).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.geometry.pseudolines import PseudolineArrangement
             sage: permutations = [[3, 2, 1], [3, 2, 0], [3, 1, 0], [2, 1, 0]]
@@ -478,7 +470,7 @@ class PseudolineArrangement:
         r"""
         A short txt description of the pseudoline arrangement.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.geometry.pseudolines import PseudolineArrangement
             sage: permutations = [[3, 2, 1], [3, 2, 0], [3, 1, 0], [2, 1, 0]]
