@@ -113,7 +113,7 @@ class BipartiteGraph(Graph):
     one bipartite graph from another into this category::
 
         sage: P = graphs.PetersenGraph()
-        sage: partition = [range(5), range(5,10)]
+        sage: partition = [list(range(5)), list(range(5,10))]
         sage: B = BipartiteGraph(P, partition)
         Traceback (most recent call last):
         ...
@@ -131,7 +131,7 @@ class BipartiteGraph(Graph):
         sage: B2 = BipartiteGraph(B)
         sage: B == B2
         True
-        sage: B3 = BipartiteGraph(G, [range(4), range(4,7)])
+        sage: B3 = BipartiteGraph(G, [list(range(4)), list(range(4,7))])
         sage: B3
         Bipartite graph on 7 vertices
         sage: B3 == B2
@@ -140,7 +140,7 @@ class BipartiteGraph(Graph):
       ::
 
         sage: G = Graph({0:[], 1:[], 2:[]})
-        sage: part = (range(2), [2])
+        sage: part = (list(range(2)), [2])
         sage: B = BipartiteGraph(G, part)
         sage: B2 = BipartiteGraph(B)
         sage: B == B2
@@ -149,7 +149,7 @@ class BipartiteGraph(Graph):
     4. From a reduced adjacency matrix::
 
         sage: M = Matrix([(1,1,1,0,0,0,0), (1,0,0,1,1,0,0),
-        ...               (0,1,0,1,0,1,0), (1,1,0,1,0,0,1)])
+        ....:             (0,1,0,1,0,1,0), (1,1,0,1,0,0,1)])
         sage: M
         [1 1 1 0 0 0 0]
         [1 0 0 1 1 0 0]
@@ -256,10 +256,10 @@ class BipartiteGraph(Graph):
         Create a bipartite graph. See documentation ``BipartiteGraph?`` for
         detailed information.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P = graphs.PetersenGraph()
-            sage: partition = [range(5), range(5,10)]
+            sage: partition = [list(range(5)), list(range(5,10))]
             sage: B = BipartiteGraph(P, partition, check=False)
         """
         if data is None:
@@ -411,7 +411,7 @@ class BipartiteGraph(Graph):
         r"""
         Returns a short string representation of self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: B = BipartiteGraph(graphs.CycleGraph(16))
             sage: B
@@ -829,7 +829,7 @@ class BipartiteGraph(Graph):
         r"""
         Returns the underlying bipartition of the bipartite graph.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: B = BipartiteGraph(graphs.CycleGraph(4))
             sage: B.bipartition()
@@ -842,7 +842,7 @@ class BipartiteGraph(Graph):
         Projects ``self`` onto left vertices. Edges are 2-paths in the
         original.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: B = BipartiteGraph(graphs.CycleGraph(20))
             sage: G = B.project_left()
@@ -861,7 +861,7 @@ class BipartiteGraph(Graph):
         Projects ``self`` onto right vertices. Edges are 2-paths in the
         original.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: B = BipartiteGraph(graphs.CycleGraph(20))
             sage: G = B.project_right()
@@ -879,7 +879,7 @@ class BipartiteGraph(Graph):
         r"""
         Overrides Graph's plot function, to illustrate the bipartite nature.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: B = BipartiteGraph(graphs.CycleGraph(20))
             sage: B.plot()
@@ -932,7 +932,7 @@ class BipartiteGraph(Graph):
 
         - ``name`` - optional string for the variable name in the polynomial.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: BipartiteGraph(graphs.CubeGraph(3)).matching_polynomial()
             x^8 - 12*x^6 + 42*x^4 - 44*x^2 + 9
@@ -994,7 +994,7 @@ class BipartiteGraph(Graph):
         http://www.inference.phy.cam.ac.uk/mackay/codes/data.html
         for examples and definition of the format.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: file_name = os.path.join(SAGE_TMP, 'deleteme.alist.txt')
             sage: fi = open(file_name, 'w')
@@ -1082,10 +1082,10 @@ class BipartiteGraph(Graph):
         http://www.inference.phy.cam.ac.uk/mackay/codes/data.html
         for examples and definition of the format.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = Matrix([(1,1,1,0,0,0,0), (1,0,0,1,1,0,0),
-            ...               (0,1,0,1,0,1,0), (1,1,0,1,0,0,1)])
+            ....:             (0,1,0,1,0,1,0), (1,1,0,1,0,0,1)])
             sage: M
             [1 1 1 0 0 0 0]
             [1 0 0 1 1 0 0]
@@ -1104,7 +1104,7 @@ class BipartiteGraph(Graph):
             sage: for order in range(3, 13, 3):
             ....:     num_chks = int(order / 3)
             ....:     num_vars = order - num_chks
-            ....:     partition = (range(num_vars), range(num_vars, num_vars+num_chks))
+            ....:     partition = (list(range(num_vars)), list(range(num_vars, num_vars+num_chks)))
             ....:     for idx in range(100):
             ....:         g = graphs.RandomGNP(order, 0.5)
             ....:         try:
@@ -1165,12 +1165,12 @@ class BipartiteGraph(Graph):
 
         Returns (row index, column index) for the given pair of vertices.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P = graphs.PetersenGraph()
-            sage: partition = [range(5), range(5,10)]
+            sage: partition = [list(range(5)), list(range(5,10))]
             sage: B = BipartiteGraph(P, partition, check=False)
-            sage: B._BipartiteGraph__edge2idx(2,7,range(5),range(5,10))
+            sage: B._BipartiteGraph__edge2idx(2,7,list(range(5)),list(range(5,10)))
             (2, 2)
         """
         try:
@@ -1200,7 +1200,7 @@ class BipartiteGraph(Graph):
         Bipartite graphs that are not weighted will return a matrix over ZZ::
 
             sage: M = Matrix([(1,1,1,0,0,0,0), (1,0,0,1,1,0,0),
-            ...               (0,1,0,1,0,1,0), (1,1,0,1,0,0,1)])
+            ....:             (0,1,0,1,0,1,0), (1,1,0,1,0,0,1)])
             sage: B = BipartiteGraph(M)
             sage: N = B.reduced_adjacency_matrix()
             sage: N
