@@ -19,6 +19,7 @@ Functions
 
 """
 from __future__ import absolute_import
+import six
 from six.moves import range
 
 
@@ -32,7 +33,7 @@ def from_graph6(G, g6_string):
 
     - ``g6_string`` -- a graph6 string
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_graph6
         sage: g = Graph()
@@ -73,7 +74,7 @@ def from_sparse6(G, g6_string):
 
     - ``g6_string`` -- a sparse6 string
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_sparse6
         sage: g = Graph()
@@ -125,7 +126,7 @@ def from_dig6(G, dig6_string):
 
     - ``dig6_string`` -- a dig6 string
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_dig6
         sage: g = DiGraph()
@@ -165,7 +166,7 @@ def from_seidel_adjacency_matrix(G, M):
 
     - ``M`` -- a Seidel adjacency matrix
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_seidel_adjacency_matrix
         sage: g = Graph()
@@ -218,7 +219,7 @@ def from_adjacency_matrix(G, M, loops=False, multiedges=False, weighted=False):
     - ``loops``, ``multiedges``, ``weighted`` (booleans) -- whether to consider
       the graph as having loops, multiple edges, or weights. Set to ``False`` by default.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_adjacency_matrix
         sage: g = Graph()
@@ -299,7 +300,7 @@ def from_incidence_matrix(G, M, loops=False, multiedges=False, weighted=False):
     - ``loops``, ``multiedges``, ``weighted`` (booleans) -- whether to consider
       the graph as having loops, multiple edges, or weights. Set to ``False`` by default.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_incidence_matrix
         sage: g = Graph()
@@ -361,7 +362,7 @@ def from_oriented_incidence_matrix(G, M, loops=False, multiedges=False, weighted
     - ``loops``, ``multiedges``, ``weighted`` (booleans) -- whether to consider
       the graph as having loops, multiple edges, or weights. Set to ``False`` by default.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_oriented_incidence_matrix
         sage: g = DiGraph()
@@ -410,7 +411,7 @@ def from_dict_of_dicts(G, M, loops=False, multiedges=False, weighted=False, conv
     - ``convert_empty_dict_labels_to_None`` (boolean) -- whether to adjust for
       empty dicts instead of None in NetworkX default edge labels.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_dict_of_dicts
         sage: g = Graph()
@@ -421,9 +422,9 @@ def from_dict_of_dicts(G, M, loops=False, multiedges=False, weighted=False, conv
     if not all(isinstance(M[u], dict) for u in M):
         raise ValueError("Input dict must be a consistent format.")
 
-    if not loops and any(u in neighb for u,neighb in M.iteritems()):
+    if not loops and any(u in neighb for u,neighb in six.iteritems(M)):
         if loops is False:
-            u = next(u for u,neighb in M.iteritems() if u in neighb)
+            u = next(u for u,neighb in six.iteritems(M) if u in neighb)
             raise ValueError("The graph was built with loops=False but input M has a loop at {}.".format(u))
         loops = True
     if loops is None:
@@ -479,7 +480,7 @@ def from_dict_of_lists(G, D, loops=False, multiedges=False, weighted=False):
     - ``loops``, ``multiedges``, ``weighted`` (booleans) -- whether to consider
       the graph as having loops, multiple edges, or weights. Set to ``False`` by default.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_input import from_dict_of_lists
         sage: g = Graph()
@@ -494,7 +495,7 @@ def from_dict_of_lists(G, D, loops=False, multiedges=False, weighted=False):
                 if loops is None:
                     loops = True
                 elif loops is False:
-                    u = next(u for u,neighb in D.iteritems() if u in neighb)
+                    u = next(u for u,neighb in six.iteritems(D) if u in neighb)
                     raise ValueError("The graph was built with loops=False but input D has a loop at {}.".format(u))
                 break
         if loops is None:
