@@ -163,8 +163,10 @@ graphplot_options.update(
                         '(larger and white).',
                     'graph_border': 'Whether or not to draw a frame around the graph.'})
 
+from six import iteritems
+
 _PLOT_OPTIONS_TABLE = ""
-for key, value in graphplot_options.iteritems():
+for key, value in iteritems(graphplot_options):
     _PLOT_OPTIONS_TABLE += "    ``"+str(key)+"`` | "+str(value)+"\n"
 __doc__ = __doc__.format(PLOT_OPTIONS_TABLE=_PLOT_OPTIONS_TABLE)
 
@@ -188,6 +190,7 @@ from sage.structure.sage_object import SageObject
 from sage.plot.all import Graphics, scatter_plot, bezier_path, line, arrow, text, circle
 from sage.misc.decorators import options
 from math import sqrt, cos, sin, atan, pi
+import six
 from six import text_type as str
 
 DEFAULT_SHOW_OPTIONS = {
@@ -223,33 +226,33 @@ class GraphPlot(SageObject):
         as some functions to set parameters for vertices and edges.  This constructor
         assumes default options are set.  Defaults are shown in the example below.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.graphs.graph_plot import GraphPlot
             sage: options = {
-            ...     'vertex_size':200,
-            ...     'vertex_labels':True,
-            ...     'layout':None,
-            ...     'edge_style':'solid',
-            ...     'edge_color':'black',
-            ...     'edge_colors':None,
-            ...     'edge_labels':False,
-            ...     'iterations':50,
-            ...     'tree_orientation':'down',
-            ...     'heights':None,
-            ...     'graph_border':False,
-            ...     'talk':False,
-            ...     'color_by_label':False,
-            ...     'partition':None,
-            ...     'dist':.075,
-            ...     'max_dist':1.5,
-            ...     'loop_size':.075}
+            ....:   'vertex_size':200,
+            ....:   'vertex_labels':True,
+            ....:   'layout':None,
+            ....:   'edge_style':'solid',
+            ....:   'edge_color':'black',
+            ....:   'edge_colors':None,
+            ....:   'edge_labels':False,
+            ....:   'iterations':50,
+            ....:   'tree_orientation':'down',
+            ....:   'heights':None,
+            ....:   'graph_border':False,
+            ....:   'talk':False,
+            ....:   'color_by_label':False,
+            ....:   'partition':None,
+            ....:   'dist':.075,
+            ....:   'max_dist':1.5,
+            ....:   'loop_size':.075}
             sage: g = Graph({0:[1,2], 2:[3], 4:[0,1]})
             sage: GP = GraphPlot(g, options)
 
         """
         # Setting the default values if needed
-        for k,value in DEFAULT_PLOT_OPTIONS.iteritems():
+        for k, value in iteritems(DEFAULT_PLOT_OPTIONS):
             if k not in options:
                 options[k] = value
         self._plot_components = {}
@@ -271,7 +274,7 @@ class GraphPlot(SageObject):
         """
         Returns a string representation of a ``GraphPlot`` object.
 
-        EXAMPLE:
+        EXAMPLES:
 
         This function is called implicitly by the code below::
 
@@ -329,11 +332,11 @@ class GraphPlot(SageObject):
             sage: g = graphs.FruchtGraph()
             sage: gp = g.graphplot()
             sage: set(map(type, flatten(gp._pos.values())))
-            {<type 'float'>}
+            {<... 'float'>}
             sage: g = graphs.BullGraph()
             sage: gp = g.graphplot(save_pos=True)
             sage: set(map(type, flatten(gp._pos.values())))
-            {<type 'float'>}
+            {<... 'float'>}
 
         Non-ascii labels are also possible using unicode (:trac:`21008`)::
 
@@ -342,7 +345,8 @@ class GraphPlot(SageObject):
         """
         self._pos = self._graph.layout(**self._options)
         # make sure the positions are floats (trac #10124)
-        self._pos = dict((k,(float(v[0]), float(v[1]))) for k,v in self._pos.iteritems())
+        self._pos = dict((k, (float(v[0]), float(v[1])))
+                         for k, v in iteritems(self._pos))
 
     def set_vertices(self, **vertex_options):
         """
@@ -355,9 +359,9 @@ class GraphPlot(SageObject):
 
             sage: g = Graph({}, loops=True, multiedges=True, sparse=True)
             sage: g.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
-            ...                (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
+            ....:              (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = g.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
-            ...                    edge_style='dashed')
+            ....:                  edge_style='dashed')
             sage: GP.set_vertices(talk=True)
             sage: GP.plot()
             Graphics object consisting of 26 graphics primitives
@@ -497,9 +501,9 @@ class GraphPlot(SageObject):
 
             sage: g = Graph({}, loops=True, multiedges=True, sparse=True)
             sage: g.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
-            ...    (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
+            ....:  (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = g.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
-            ...    edge_style='dashed')
+            ....:  edge_style='dashed')
             sage: GP.set_edges(edge_style='solid')
             sage: GP.plot()
             Graphics object consisting of 26 graphics primitives
@@ -535,9 +539,9 @@ class GraphPlot(SageObject):
 
             sage: d = DiGraph({}, loops=True, multiedges=True, sparse=True)
             sage: d.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
-            ...     (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
+            ....:   (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = d.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
-            ...    edge_style='dashed')
+            ....:  edge_style='dashed')
             sage: GP.set_edges(edge_style='solid')
             sage: GP.plot()
             Graphics object consisting of 28 graphics primitives
@@ -580,18 +584,18 @@ class GraphPlot(SageObject):
             sage: test_graphs = graphs.FruchtGraph(), graphs.BullGraph()
             sage: tol = 0.001
             sage: for G in test_graphs:
-            ...       E=G.edges()
-            ...       for e0, e1, elab in E:
-            ...           G.set_edge_label(e0, e1, '%d %d' % (e0, e1))
-            ...       gp = G.graphplot(save_pos=True,edge_labels=True)
-            ...       vx = gp._plot_components['vertices'][0].xdata
-            ...       vy = gp._plot_components['vertices'][0].ydata
-            ...       for elab in gp._plot_components['edge_labels']:
-            ...           textobj = elab[0]
-            ...           x, y, s = textobj.x, textobj.y, textobj.string
-            ...           v0, v1 = map(int, s.split())
-            ...           vn = vector(((x-(vx[v0]+vx[v1])/2.),y-(vy[v0]+vy[v1])/2.)).norm()
-            ...           assert vn < tol
+            ....:     E=G.edges()
+            ....:     for e0, e1, elab in E:
+            ....:         G.set_edge_label(e0, e1, '%d %d' % (e0, e1))
+            ....:     gp = G.graphplot(save_pos=True,edge_labels=True)
+            ....:     vx = gp._plot_components['vertices'][0].xdata
+            ....:     vy = gp._plot_components['vertices'][0].ydata
+            ....:     for elab in gp._plot_components['edge_labels']:
+            ....:         textobj = elab[0]
+            ....:         x, y, s = textobj.x, textobj.y, textobj.string
+            ....:         v0, v1 = map(int, s.split())
+            ....:         vn = vector(((x-(vx[v0]+vx[v1])/2.),y-(vy[v0]+vy[v1])/2.)).norm()
+            ....:         assert vn < tol
 
         """
         for arg in edge_options:
@@ -800,13 +804,13 @@ class GraphPlot(SageObject):
         segment from A to B (xy tuples) and circles centered at A and B, both with
         radius VR.  Returns a tuple of xy tuples representing the two points.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: d = DiGraph({}, loops=True, multiedges=True, sparse=True)
             sage: d.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
-            ...     (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
+            ....:   (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: GP = d.graphplot(vertex_size=100, edge_labels=True, color_by_label=True,
-            ...    edge_style='dashed')
+            ....:  edge_style='dashed')
             sage: GP._polar_hack_for_multidigraph((0,1),(1,1),.1)
             ([0.10..., 1.00...], [0.90..., 1.00...])
 
@@ -852,7 +856,7 @@ class GraphPlot(SageObject):
             - Any options not used by plot will be passed on to the
               :meth:`~sage.plot.graphics.Graphics.show` method.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: C = graphs.CubeGraph(8)
             sage: P = C.graphplot(vertex_labels=False, vertex_size=0, graph_border=True)
@@ -866,7 +870,7 @@ class GraphPlot(SageObject):
 
         """
         # Setting the default values if needed
-        for k,value in DEFAULT_SHOW_OPTIONS.iteritems():
+        for k, value in iteritems(DEFAULT_SHOW_OPTIONS):
             if k not in kwds:
                 kwds[k] = value
 
@@ -892,17 +896,17 @@ class GraphPlot(SageObject):
             sage: from math import sin, cos, pi
             sage: P = graphs.PetersenGraph()
             sage: d = {'#FF0000':[0,5], '#FF9900':[1,6], '#FFFF00':[2,7], '#00FF00':[3,8],
-            ...    '#0000FF':[4,9]}
+            ....:  '#0000FF':[4,9]}
             sage: pos_dict = {}
             sage: for i in range(5):
-            ...    x = float(cos(pi/2 + ((2*pi)/5)*i))
-            ...    y = float(sin(pi/2 + ((2*pi)/5)*i))
-            ...    pos_dict[i] = [x,y]
+            ....:  x = float(cos(pi/2 + ((2*pi)/5)*i))
+            ....:  y = float(sin(pi/2 + ((2*pi)/5)*i))
+            ....:  pos_dict[i] = [x,y]
             ...
-            sage: for i in range(10)[5:]:
-            ...    x = float(0.5*cos(pi/2 + ((2*pi)/5)*i))
-            ...    y = float(0.5*sin(pi/2 + ((2*pi)/5)*i))
-            ...    pos_dict[i] = [x,y]
+            sage: for i in range(5,10):
+            ....:  x = float(0.5*cos(pi/2 + ((2*pi)/5)*i))
+            ....:  y = float(0.5*sin(pi/2 + ((2*pi)/5)*i))
+            ....:  pos_dict[i] = [x,y]
             ...
             sage: pl = P.graphplot(pos=pos_dict, vertex_colors=d)
             sage: pl.show()
@@ -919,7 +923,7 @@ class GraphPlot(SageObject):
                 y = float(sin(pi/2 + ((2*pi)/5)*i))
                 pos_dict[i] = [x,y]
             
-            for i in range(10)[5:]:
+            for i in range(5,10):
                 x = float(0.5*cos(pi/2 + ((2*pi)/5)*i))
                 y = float(0.5*sin(pi/2 + ((2*pi)/5)*i))
                 pos_dict[i] = [x,y]
@@ -943,7 +947,7 @@ class GraphPlot(SageObject):
 
             sage: G = graphs.HeawoodGraph().copy(sparse=True)
             sage: for u,v,l in G.edges():
-            ...    G.set_edge_label(u,v,'(' + str(u) + ',' + str(v) + ')')
+            ....:  G.set_edge_label(u,v,'(' + str(u) + ',' + str(v) + ')')
             sage: G.graphplot(edge_labels=True).show()
 
         .. PLOT::
@@ -956,11 +960,11 @@ class GraphPlot(SageObject):
         The options for plotting also work with directed graphs::
 
             sage: D = DiGraph( { 0: [1, 10, 19], 1: [8, 2], 2: [3, 6], 3: [19, 4],
-            ...    4: [17, 5], 5: [6, 15], 6: [7], 7: [8, 14], 8: [9], 9: [10, 13],
-            ...    10: [11], 11: [12, 18], 12: [16, 13], 13: [14], 14: [15], 15: [16],
-            ...    16: [17], 17: [18], 18: [19], 19: []})
+            ....:  4: [17, 5], 5: [6, 15], 6: [7], 7: [8, 14], 8: [9], 9: [10, 13],
+            ....:  10: [11], 11: [12, 18], 12: [16, 13], 13: [14], 14: [15], 15: [16],
+            ....:  16: [17], 17: [18], 18: [19], 19: []})
             sage: for u,v,l in D.edges():
-            ...    D.set_edge_label(u,v,'(' + str(u) + ',' + str(v) + ')')
+            ....:  D.set_edge_label(u,v,'(' + str(u) + ',' + str(v) + ')')
             sage: D.graphplot(edge_labels=True, layout='circular').show()
 
         .. PLOT::
@@ -980,11 +984,11 @@ class GraphPlot(SageObject):
             sage: R = rainbow(5)
             sage: edge_colors = {}
             sage: for i in range(5):
-            ...    edge_colors[R[i]] = []
+            ....:  edge_colors[R[i]] = []
             sage: for u,v,l in C.edges():
-            ...    for i in range(5):
-            ...        if u[i] != v[i]:
-            ...            edge_colors[R[i]].append((u,v,l))
+            ....:  for i in range(5):
+            ....:      if u[i] != v[i]:
+            ....:          edge_colors[R[i]].append((u,v,l))
             sage: C.graphplot(vertex_labels=False, vertex_size=0, edge_colors=edge_colors).show()
 
         .. PLOT::
@@ -1044,7 +1048,7 @@ class GraphPlot(SageObject):
         More options::
 
             sage: pos = {0:[0.0, 1.5], 1:[-0.8, 0.3], 2:[-0.6, -0.8],
-            ...    3:[0.6, -0.8], 4:[0.8, 0.3]}
+            ....:  3:[0.6, -0.8], 4:[0.8, 0.3]}
             sage: g = Graph({0:[1], 1:[2], 2:[3], 3:[4], 4:[0]})
             sage: g.graphplot(pos=pos, layout='spring', iterations=0).plot()
             Graphics object consisting of 11 graphics primitives
@@ -1155,8 +1159,8 @@ class GraphPlot(SageObject):
 
             sage: D = DiGraph(multiedges=True, sparse=True)
             sage: for i in range(5):
-            ...     D.add_edge((i,i+1,'a'))
-            ...     D.add_edge((i,i-1,'b'))
+            ....:   D.add_edge((i,i+1,'a'))
+            ....:   D.add_edge((i,i-1,'b'))
             sage: D.graphplot(edge_labels=True,edge_colors=D._color_by_label()).plot()
             Graphics object consisting of 34 graphics primitives
 
@@ -1172,7 +1176,7 @@ class GraphPlot(SageObject):
 
             sage: g = Graph({}, loops=True, multiedges=True, sparse=True)
             sage: g.add_edges([(0,0,'a'),(0,0,'b'),(0,1,'c'),(0,1,'d'),
-            ...     (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
+            ....:   (0,1,'e'),(0,1,'f'),(0,1,'f'),(2,1,'g'),(2,2,'h')])
             sage: g.graphplot(edge_labels=True, color_by_label=True, edge_style='dashed').plot()
             Graphics object consisting of 26 graphics primitives
 
@@ -1365,7 +1369,7 @@ def _circle_embedding(g, vertices, center=(0, 0), radius=1, shift=0):
     circle by an angle of `\alpha 2\pi/n` (where `n` is the number of
     vertices set on the circle).
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_plot import _circle_embedding
         sage: g = graphs.CycleGraph(5)
@@ -1395,7 +1399,7 @@ def _line_embedding(g, vertices, first=(0, 0), last=(0, 1)):
     is the pair ``first`` and the position of ``vertices[-1]`` is
     ``last``. The vertices are evenly spaced.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.graphs.graph_plot import _line_embedding
         sage: g = graphs.PathGraph(5)
