@@ -376,7 +376,8 @@ from six import itervalues
 from sage.structure.sage_object import SageObject
 from sage.structure.unique_representation import CachedRepresentation, UniqueRepresentation
 from sage.misc.unknown import Unknown
-from sage.env import SAGE_SHARE
+from sage.env import GRAPHS_DATA_DIR
+import six
 
 #*****************************************************************************
 #      Copyright (C) 2011 Nathann Cohen <nathann.cohen@gmail.com>
@@ -393,7 +394,7 @@ class GraphClass(SageObject, CachedRepresentation):
     An instance of this class represents a Graph Class, matching some entry in
     the ISGCI database.
 
-    EXAMPLE:
+    EXAMPLES:
 
     Testing the inclusion of two classes::
 
@@ -423,7 +424,7 @@ class GraphClass(SageObject, CachedRepresentation):
           return boolan answers to the question : *does ``g`` belong to the
           class represented by ``gc_id`` ?*
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal  # indirect doctest
             Chordal graphs
@@ -438,7 +439,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         Returns a short description of the class
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal  # indirect doctest
             Chordal graphs
@@ -449,7 +450,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         Returns the class' ID hash
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: hash(graph_classes.Chordal) == hash(graph_classes.Chordal)
             True
@@ -460,7 +461,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         <= operator
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal <= graph_classes.Tree
             Unknown
@@ -471,7 +472,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         >= operator
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal >= graph_classes.Tree
             True
@@ -487,7 +488,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         == operator
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal == graph_classes.Tree
             Unknown
@@ -498,7 +499,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         >, !=, and < operators
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal > graph_classes.Tree
             Traceback (most recent call last):
@@ -605,7 +606,7 @@ class GraphClass(SageObject, CachedRepresentation):
         r"""
         Prints the information of ISGCI about the current class.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.Chordal.description()
             Class of graphs : Chordal
@@ -643,7 +644,7 @@ class GraphClass(SageObject, CachedRepresentation):
         print("Class of graphs : "+self._name)
         print("-" * (len(self._name)+18))
 
-        for key, value in cls.iteritems():
+        for key, value in six.iteritems(cls):
             if value != "" and key != "problem":
                 print("{:30} : {}".format(key, value))
 
@@ -669,7 +670,7 @@ class GraphClasses(UniqueRepresentation):
 
             :meth:`~sage.graphs.isgci.GraphClasses.show_all`
 
-        EXAMPLE:
+        EXAMPLES:
 
         With an existing id::
 
@@ -709,7 +710,7 @@ class GraphClasses(UniqueRepresentation):
 
             sage: t = graph_classes.classes()
             sage: type(t)
-            <type 'dict'>
+            <... 'dict'>
             sage: sorted(t["gc_151"].keys())
             ['id', 'name', 'problem', 'type']
             sage: t["gc_151"]['name']
@@ -736,7 +737,7 @@ class GraphClasses(UniqueRepresentation):
 
             sage: t = graph_classes.inclusions()
             sage: type(t)
-            <type 'list'>
+            <... 'list'>
             sage: t[0]
             {'sub': 'gc_1', 'super': 'gc_2'}
         """
@@ -799,7 +800,7 @@ class GraphClasses(UniqueRepresentation):
         r"""
         Downloads the current version of the ISGCI db
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes._download_db() # Not tested -- requires internet
         """
@@ -818,11 +819,11 @@ class GraphClasses(UniqueRepresentation):
         # Save a systemwide updated copy whenever possible
 
         try:
-            z.extract(_XML_FILE, os.path.join(SAGE_SHARE,'graphs'))
-            z.extract(_SMALLGRAPHS_FILE, os.path.join(SAGE_SHARE,'graphs'))
+            z.extract(_XML_FILE, GRAPHS_DATA_DIR)
+            z.extract(_SMALLGRAPHS_FILE, GRAPHS_DATA_DIR)
         except IOError:
             z.extract(_XML_FILE, SAGE_TMP)
-            z.extract(_SMALLGRAPHS_FILE, os.path.join(SAGE_SHARE,'graphs'))
+            z.extract(_SMALLGRAPHS_FILE, GRAPHS_DATA_DIR)
 
     def _parse_db(self, directory):
         r"""
@@ -833,16 +834,16 @@ class GraphClasses(UniqueRepresentation):
         - ``directory`` -- the name of the directory containing the latest
           version of the database.
 
-        EXAMPLE::
+        EXAMPLES::
 
-            sage: from sage.env import SAGE_SHARE
-            sage: graph_classes._parse_db(os.path.join(SAGE_SHARE,'graphs'))
+            sage: from sage.env import GRAPHS_DATA_DIR
+            sage: graph_classes._parse_db(GRAPHS_DATA_DIR)
         """
         import xml.etree.cElementTree as ET
         import os.path
         from sage.graphs.graph import Graph
 
-        xml_file = os.path.join(SAGE_SHARE,'graphs',_XML_FILE)
+        xml_file = os.path.join(GRAPHS_DATA_DIR,_XML_FILE)
         tree = ET.ElementTree(file=xml_file)
         root = tree.getroot()
         DB = _XML_to_dict(root)
@@ -856,7 +857,7 @@ class GraphClasses(UniqueRepresentation):
         inclusions = DB['Inclusions']['incl']
 
         # Parses the list of ISGCI small graphs
-        smallgraph_file = open(os.path.join(SAGE_SHARE,'graphs',_SMALLGRAPHS_FILE),'r')
+        smallgraph_file = open(os.path.join(GRAPHS_DATA_DIR,_SMALLGRAPHS_FILE),'r')
         smallgraphs = {}
 
         for l in smallgraph_file.readlines():
@@ -883,7 +884,7 @@ class GraphClasses(UniqueRepresentation):
         sufficient, the XML file are saved instead in the user's directory (in
         the SAGE_DB folder).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.update_db() # Not tested -- requires internet
         """
@@ -914,7 +915,7 @@ class GraphClasses(UniqueRepresentation):
             This method returns the data contained in the most recent ISGCI database
             present on the computer. See :meth:`update_db` to update the latter.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes._get_ISGCI()  # long time (4s on sage.math, 2012)
         """
@@ -928,15 +929,15 @@ class GraphClasses(UniqueRepresentation):
 
             # Which copy is the most recent on the disk ?
             if (os.path.getmtime(os.path.join(SAGE_DB,_XML_FILE)) >
-                os.path.getmtime(os.path.join(SAGE_SHARE,'graphs',_XML_FILE))):
+                os.path.getmtime(os.path.join(GRAPHS_DATA_DIR,_XML_FILE))):
 
                 directory = os.path.join(SAGE_DB,_XML_FILE)
 
             else:
-                directory = os.path.join(SAGE_SHARE,'graphs',_XML_FILE)
+                directory = os.path.join(GRAPHS_DATA_DIR,_XML_FILE)
 
         except IOError as e:
-            directory = os.path.join(SAGE_SHARE,'graphs',_XML_FILE)
+            directory = os.path.join(GRAPHS_DATA_DIR,_XML_FILE)
 
         self._parse_db(directory)
 
@@ -944,7 +945,7 @@ class GraphClasses(UniqueRepresentation):
         r"""
         Prints all graph classes stored in ISGCI
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: graph_classes.show_all()
             id        | name                                     | type                 | smallgraph
@@ -982,7 +983,7 @@ class GraphClasses(UniqueRepresentation):
             MAX[key] = len(max((str(x.get(key,"")) for x in classes_list), key = len))
 
         # At most MAX characters per field
-        for key, length in MAX.iteritems():
+        for key, length in six.iteritems(MAX):
             MAX[key] = min(length, MAX_LEN)
 
         # Head of the table
@@ -1009,7 +1010,7 @@ def _XML_to_dict(root):
 
     A dictionary representing the XML data.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: graph_classes.Perfect.description() # indirect doctest
         Class of graphs : Perfect
@@ -1037,7 +1038,9 @@ def _XML_to_dict(root):
 graph_classes = GraphClasses()
 
 # Any object added to this list should also appear in the class' documentation, at the top of the file.
+graph_classes.Apex = GraphClass("Apex", "gc_1181", recognition_function = lambda x:x.is_apex())
 graph_classes.AT_free = GraphClass("AT-free", "gc_61", recognition_function = lambda x:x.is_asteroidal_triple_free())
+graph_classes.Biconnected = GraphClass("Biconnected", "gc_771", recognition_function = lambda x:x.is_biconnected())
 graph_classes.BinaryTrees = GraphClass("BinaryTrees", "gc_847")
 graph_classes.Bipartite = GraphClass("Bipartite", "gc_69", recognition_function = lambda x:x.is_bipartite())
 graph_classes.Block = GraphClass("Block", "gc_93")
