@@ -152,7 +152,7 @@ def contracted_edge(G, unlabeled_edge):
 def removed_loops(G):
     r"""
     A context manager which removes all the loops in the graph `G`.
-    It yields a list of the the loops, and restores the loops upon
+    It yields a list of the loops, and restores the loops upon
     exiting.
 
     EXAMPLES::
@@ -204,14 +204,14 @@ def underlying_graph(G):
 
 def edge_multiplicities(G):
     r"""
-    Returns the a dictionary of multiplicities of the edges in the
+    Return the a dictionary of multiplicities of the edges in the
     graph `G`.
 
     EXAMPLES::
 
         sage: from sage.graphs.tutte_polynomial import edge_multiplicities
         sage: G = Graph({1: [2,2,3], 2: [2], 3: [4,4], 4: [2,2,2]})
-        sage: sorted(edge_multiplicities(G).iteritems())
+        sage: sorted(edge_multiplicities(G).items())
         [((1, 2), 2), ((1, 3), 1), ((2, 2), 1), ((2, 4), 3), ((3, 4), 2)]
     """
     d = {}
