@@ -8,6 +8,7 @@ from sage.libs.all import pari_gen
 from sage.rings.all import Integer
 from sage.structure.parent import Parent
 
+
 class PariGroup(Group):
     def __init__(self, x, degree=None):
         """
@@ -39,27 +40,81 @@ class PariGroup(Group):
                                            "_test_some_elements"])
         """
         if not isinstance(x, pari_gen):
-            raise TypeError("x (=%s) must be a PARI gen"%x)
+            raise TypeError("x (=%s) must be a PARI gen" % x)
         self.__x = x
         self.__degree = degree
         from sage.categories.finite_groups import FiniteGroups
-        Parent.__init__(self, category = FiniteGroups())
+        Parent.__init__(self, category=FiniteGroups())
 
     def __repr__(self):
-        return "PARI group %s of degree %s"%(self.__x, self.__degree)
+        return "PARI group %s of degree %s" % (self.__x, self.__degree)
 
-    def __cmp__(self, other):
-        if not isinstance(other, PariGroup):
-            return cmp(type(self), type(other))
-        return cmp((self.__x, self.__degree), (other.__x, other.__degree))
+    def __eq__(self, other):
+        """
+        Test equality.
+
+        EXAMPLES::
+
+            sage: R.<x> = PolynomialRing(QQ)
+            sage: f1 = x^4 - 17*x^3 - 2*x + 1
+            sage: f2 = x^3 - x - 1
+            sage: G1 = f1.galois_group(pari_group=True)
+            sage: G2 = f2.galois_group(pari_group=True)
+            sage: G1 == G1
+            True
+            sage: G1 == G2
+            False
+        """
+        return (isinstance(other, PariGroup) and
+            (self.__x, self.__degree) == (other.__x, other.__degree))
+
+    def __ne__(self, other):
+        """
+        Test inequality.
+
+        EXAMPLES::
+
+            sage: R.<x> = PolynomialRing(QQ)
+            sage: f1 = x^4 - 17*x^3 - 2*x + 1
+            sage: f2 = x^3 - x - 1
+            sage: G1 = f1.galois_group(pari_group=True)
+            sage: G2 = f2.galois_group(pari_group=True)
+            sage: G1 != G1
+            False
+            sage: G1 != G2
+            True
+        """
+        return not (self == other)
 
     def _pari_(self):
         return self.__x
 
     def degree(self):
+        """
+        Return the degree of ``self``.
+
+        EXAMPLES::
+
+            sage: R.<x> = PolynomialRing(QQ)
+            sage: f1 = x^4 - 17*x^3 - 2*x + 1
+            sage: G1 = f1.galois_group(pari_group=True)
+            sage: G1.degree()
+            4
+        """
         return self.__degree
 
     def order(self):
+        """
+        Return the order of ``self``.
+
+        EXAMPLES::
+
+            sage: R.<x> = PolynomialRing(QQ)
+            sage: f1 = x^4 - 17*x^3 - 2*x + 1
+            sage: G1 = f1.galois_group(pari_group=True)
+            sage: G1.order()
+            24
+        """
         return Integer(self.__x[0])
 
     def permutation_group(self):
