@@ -171,6 +171,9 @@ class GenericCellComplex(SageObject):
         try:
             return max([x.dimension() for x in self._facets])
         except AttributeError:
+            if len(self.cells()) == 0:
+                # The empty cell complex has dimension -1.
+                return -1
             return max(self.cells())
 
     def n_cells(self, n, subcomplex=None):
@@ -768,7 +771,7 @@ class GenericCellComplex(SageObject):
         coefficients in ``base_ring``.
 
         The term "algebraic topological model" is defined by Pilarczyk
-        and Réal [PR]_.
+        and Réal [PR2015]_.
 
         This is not implemented for generic cell complexes. For any
         classes deriving from this one, when this method is
@@ -982,8 +985,8 @@ class GenericCellComplex(SageObject):
         :meth:`~sage.homology.cubical_complex.Cube.alexander_whitney`. Then
         the method for simplicial complexes just calls the method for
         individual simplices, and similarly for cubical complexes. For
-        `\Delta`-complexes, the method is instead defined at the level
-        of the cell complex.
+        `\Delta`-complexes and simplicial sets, the method is instead
+        defined at the level of the cell complex.
 
         EXAMPLES::
 
@@ -1054,6 +1057,37 @@ class GenericCellComplex(SageObject):
         """
         raise NotImplementedError
 
+    def is_connected(self):
+        """
+        True if this cell complex is connected.
+
+        EXAMPLES::
+
+            sage: V = SimplicialComplex([[0,1,2],[3]])
+            sage: V
+            Simplicial complex with vertex set (0, 1, 2, 3) and facets {(0, 1, 2), (3,)}
+            sage: V.is_connected()
+            False
+            sage: X = SimplicialComplex([[0,1,2]])
+            sage: X.is_connected()
+            True
+            sage: U = simplicial_complexes.ChessboardComplex(3,3)
+            sage: U.is_connected()
+            True
+            sage: W = simplicial_complexes.Sphere(3)
+            sage: W.is_connected()
+            True
+            sage: S = SimplicialComplex([[0,1],[2,3]])
+            sage: S.is_connected()
+            False
+
+            sage: cubical_complexes.Sphere(0).is_connected()
+            False
+            sage: cubical_complexes.Sphere(2).is_connected()
+            True
+        """
+        return self.graph().is_connected()
+
     @abstract_method
     def n_skeleton(self, n):
         """
