@@ -7,12 +7,8 @@ for computing cup products and cohomology operations.
 
 REFERENCES:
 
-.. [G-DR03] \R. González-Díaz and P. Réal, *Computation of cohomology
-   operations on finite simplicial complexes* in Homology,
-   Homotopy and Applications 5 (2003), 83-93.
-
-.. [G-DR99] \R. González-Díaz and P. Réal, *A combinatorial method for
-   computing Steenrod squares* in J. Pure Appl. Algebra 139 (1999), 89-108.
+- [GDR2003]_
+- [GDR1999]_
 
 AUTHORS:
 
@@ -37,6 +33,7 @@ from sage.categories.modules import Modules
 from sage.combinat.free_module import CombinatorialFreeModule, CombinatorialFreeModuleElement
 from sage.sets.family import Family
 from .simplicial_complex import SimplicialComplex
+from .simplicial_set import SimplicialSet_arbitrary
 
 class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
     r"""
@@ -107,7 +104,8 @@ class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
         sage: x.cup_product(x)
         0
 
-    This works with simplicial, cubical, and `\Delta`-complexes::
+    This works with simplicial, cubical, and `\Delta`-complexes, and
+    also simplicial sets::
 
         sage: Klein_c = cubical_complexes.KleinBottle()
         sage: H = Klein_c.cohomology_ring(GF(2))
@@ -129,6 +127,29 @@ class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
         sage: v.cup_product(v)
         h^{2,0}
 
+        sage: X = simplicial_sets.RealProjectiveSpace(6)
+        sage: H_X = X.cohomology_ring(GF(2))
+        sage: a = H_X.basis()[1,0]
+        sage: a**6
+        h^{6,0}
+        sage: a**7
+        0
+
+    All products of positive-dimensional elements in a suspension
+    should be zero::
+
+        sage: Y = X.suspension()
+        sage: H_Y = Y.cohomology_ring(GF(2))
+        sage: b = H_Y.basis()[2,0]
+        sage: b**2
+        0
+        sage: B = sorted(H_Y.basis())[1:]
+        sage: B
+        [h^{2,0}, h^{3,0}, h^{4,0}, h^{5,0}, h^{6,0}, h^{7,0}]
+        sage: import itertools
+        sage: [a*b for (a,b) in itertools.combinations(B, 2)]
+        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
+
     The basis elements in the simplicial complex case have been chosen
     differently; apply the change of basis `x \mapsto a + b`, `y \mapsto
     b` to see the same product structure. ::
@@ -415,12 +436,30 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
         sage: x * x
         -h^{4,0}
 
-    There are mod 2 cohomology operations defined, also::
+    There are mod 2 cohomology operations defined, also, for
+    simplicial complexes and simplicial sets::
 
         sage: Hmod2 = CP2.cohomology_ring(GF(2))
         sage: y = Hmod2.basis(2)[2,0]
         sage: y.Sq(2)
         h^{4,0}
+
+        sage: Y = simplicial_sets.RealProjectiveSpace(6).suspension()
+        sage: H_Y = Y.cohomology_ring(GF(2))
+        sage: b = H_Y.basis()[2,0]
+        sage: b.Sq(1)
+        h^{3,0}
+        sage: b.Sq(2)
+        0
+        sage: c = H_Y.basis()[4,0]
+        sage: c.Sq(1)
+        h^{5,0}
+        sage: c.Sq(2)
+        h^{6,0}
+        sage: c.Sq(3)
+        h^{7,0}
+        sage: c.Sq(4)
+        0
     """
     def __init__(self, base_ring, cell_complex):
         """
@@ -513,7 +552,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
             sage: x.cup_product(x)
             0
 
-        and `\Delta`-complexes::
+        `\Delta`-complexes::
 
             sage: T_d = delta_complexes.Torus()
             sage: a,b = T_d.cohomology_ring(QQ).basis(1)
@@ -526,6 +565,14 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
             sage: w.cup_product(w)
             h^{2,0}
 
+        and simplicial sets::
+
+            sage: from sage.homology.simplicial_set_examples import RealProjectiveSpace
+            sage: RP5 = RealProjectiveSpace(5)
+            sage: x = RP5.cohomology_ring(GF(2)).basis()[1,0]
+            sage: x**4
+            h^{4,0}
+
         A non-connected example::
 
             sage: K = cubical_complexes.Torus().disjoint_union(cubical_complexes.Torus())
@@ -566,7 +613,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
             r"""
             Return the cup product of this element and ``other``.
 
-            Algorithm: see González-Díaz and Réal [G-DR03]_, p. 88.
+            Algorithm: see González-Díaz and Réal [GDR2003]_, p. 88.
             Given two cohomology classes, lift them to cocycle
             representatives via the chain contraction for this
             complex, using
@@ -633,7 +680,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
             This cohomology operation is only defined in
             characteristic 2.
 
-            Algorithm: see González-Díaz and Réal [G-DR99]_,
+            Algorithm: see González-Díaz and Réal [GDR1999]_,
             Corollary 3.2.
 
             EXAMPLES::
@@ -659,6 +706,15 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
                 sage: z.Sq(1)  # long time
                 h^{4,0}
 
+            This calculation is much faster with simplicial sets (on
+            one machine, 20 seconds with a simplicial complex, 4 ms
+            with a simplicial set). ::
+
+                sage: RP4_ss = simplicial_sets.RealProjectiveSpace(4)
+                sage: z_ss = RP4_ss.cohomology_ring(GF(2)).basis()[3,0]
+                sage: z_ss.Sq(1)
+                h^{4,0}
+
             TESTS::
 
                 sage: T = cubical_complexes.Torus()
@@ -666,7 +722,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
                 sage: x.Sq(1)
                 Traceback (most recent call last):
                 ...
-                NotImplementedError: Steenrod squares are only implemented for simplicial complexes
+                NotImplementedError: Steenrod squares are only implemented for simplicial complexes and simplicial sets
                 sage: S2 = simplicial_complexes.Sphere(2)
                 sage: x = S2.cohomology_ring(GF(7)).basis()[2,0]
                 sage: x.Sq(1)
@@ -676,12 +732,13 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
             """
             P = self.parent()
             scomplex = P.complex()
-            if not isinstance(scomplex, SimplicialComplex):
-                raise NotImplementedError('Steenrod squares are only implemented for simplicial complexes')
+            if not isinstance(scomplex, (SimplicialComplex, SimplicialSet_arbitrary)):
+                raise NotImplementedError('Steenrod squares are only implemented for '
+                                          'simplicial complexes and simplicial sets')
             base_ring = P.base_ring()
             if base_ring.characteristic() != 2:
                 raise ValueError('Steenrod squares are only defined in characteristic 2')
-            # We keep the same notation as in [G-DR99].
+            # We keep the same notation as in [GDR1999].
             # The trivial cases:
             if i == 0:
                 # Sq^0 is the identity.
@@ -720,7 +777,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
                 # [i_n, i_{n-1}, ..., i_0]. (It is reversed from the
                 # obvious order because this is closer to the order in
                 # which the face maps will be applied.)  Now we sum over
-                # these, according to the formula in [G-DR99], Corollary 3.2.
+                # these, according to the formula in [GDR1999], Corollary 3.2.
                 result = {}
                 cycle = elt.to_cycle()
                 n_chains = scomplex.n_chains(j, base_ring)
@@ -761,9 +818,13 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
                                 for k in range(right_endpoint, -1, -1):
                                     right = scomplex.face(right, k)
 
-                            left = n_chains(left)
-                            right = n_chains(right)
-                            gamma_coeff += coeff * cycle.eval(left) * cycle.eval(right)
+                            if ((hasattr(left, 'is_nondegenerate')
+                                 and left.is_nondegenerate()
+                                 and right.is_nondegenerate())
+                                or not hasattr(left, 'is_nondegenerate')):
+                                left = n_chains(left)
+                                right = n_chains(right)
+                                gamma_coeff += coeff * cycle.eval(left) * cycle.eval(right)
                     if gamma_coeff != base_ring.zero():
                         result[(m, gamma_index)] = gamma_coeff
                 ret += P._from_dict(result, remove_zeros=False)
@@ -772,7 +833,7 @@ class CohomologyRing(HomologyVectorSpaceWithBasis):
 def sum_indices(k, i_k_plus_one, S_k_plus_one):
     r"""
     This is a recursive function for computing the indices for the
-    nested sums in González-Díaz and Réal [G-DR99]_, Corollary 3.2.
+    nested sums in González-Díaz and Réal [GDR1999]_, Corollary 3.2.
 
     In the paper, given indices `i_n`, `i_{n-1}`, ..., `i_{k+1}`,
     given `k`, and given `S(k+1)`, the number `S(k)` is defined to be
