@@ -174,11 +174,12 @@ AUTHORS:
 #
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-from __future__ import print_function
-from __future__ import absolute_import
+
+from __future__ import absolute_import, print_function
 
 from .expect import Expect, ExpectElement, FunctionElement, ExpectFunction
-from sage.env import SAGE_LOCAL, SAGE_EXTCODE, DOT_SAGE
+from .gap_workspace import gap_workspace_file, prepare_workspace_dir
+from sage.env import SAGE_LOCAL, SAGE_EXTCODE
 from sage.misc.misc import is_in_string
 from sage.misc.superseded import deprecation
 from sage.misc.cachefunc import cached_method
@@ -190,9 +191,7 @@ import time
 import platform
 import string
 
-GAP_DIR = os.path.join(DOT_SAGE, 'gap')
-
-WORKSPACE = os.path.join(GAP_DIR, 'workspace-%s'%abs(hash(SAGE_LOCAL)))
+WORKSPACE = gap_workspace_file()
 
 GAP_BINARY = os.path.join(SAGE_LOCAL, 'bin', 'gap')
 
@@ -240,7 +239,7 @@ def set_gap_memory_pool_size(size_in_bytes):
     EXAMPLES::
 
         sage: from sage.interfaces.gap import \
-        ...       get_gap_memory_pool_size, set_gap_memory_pool_size
+        ....:     get_gap_memory_pool_size, set_gap_memory_pool_size
         sage: n = get_gap_memory_pool_size()
         sage: set_gap_memory_pool_size(n)
         sage: n == get_gap_memory_pool_size()
@@ -257,24 +256,28 @@ def get_gap_memory_pool_size():
 
     EXAMPLES::
 
-        sage: from sage.interfaces.gap import \
-        ...       get_gap_memory_pool_size
+        sage: from sage.interfaces.gap import get_gap_memory_pool_size
         sage: get_gap_memory_pool_size()   # random output
         1534059315
     """
     global gap_memory_pool_size
     if gap_memory_pool_size is not None:
         return gap_memory_pool_size
-    from sage.misc.memory_info import MemoryInfo
-    mem = MemoryInfo()
-    suggested_size = max(mem.available_swap() // 10,
-                         mem.available_ram()  // 50)
+
+    import psutil
+    from sage.misc.getusage import virtual_memory_limit
+    mem = psutil.virtual_memory()
+    swap = psutil.swap_memory()
+    vmax = virtual_memory_limit()
+
+    suggested_size = max(swap.free // 10, mem.available // 50)
     # Don't eat all address space if the user set ulimit -v
-    suggested_size = min(suggested_size, mem.virtual_memory_limit()//10)
+    suggested_size = min(suggested_size, vmax // 10)
     # ~220MB is the minimum for long doctests
     suggested_size = max(suggested_size, 250 * 1024**2)
     return suggested_size
 
+
 def _get_gap_memory_pool_size_MB():
     """
     Return the gap memory pool size suitable for usage on the GAP
@@ -290,7 +293,7 @@ def _get_gap_memory_pool_size_MB():
     EXAMPLES:
 
         sage: from sage.interfaces.gap import \
-        ...       _get_gap_memory_pool_size_MB
+        ....:     _get_gap_memory_pool_size_MB
         sage: _get_gap_memory_pool_size_MB()   # random output
         '1467m'
     """
@@ -1297,6 +1300,8 @@ class Gap(Gap_generic):
             5
             sage: sage.interfaces.gap.WORKSPACE = ORIGINAL_WORKSPACE
         """
+        prepare_workspace_dir()
+
         # According to the GAP Reference Manual,
         # [http://www.gap-system.org/Manuals/doc/htm/ref/CHAP003.htm#SSEC011.1]
         # SaveWorkspace can only be used at the main gap> prompt. It cannot
@@ -1490,7 +1495,7 @@ def gap_reset_workspace(max_workspace_size=None, verbose=False):
     default when Sage first starts GAP.
 
     The first time you start GAP from Sage, it saves the startup state
-    of GAP in a file ``$HOME/.sage/gap/workspace-HASH``, where ``HASH``
+    of GAP in a file ``$HOME/.sage/gap/workspace-gap-HASH``, where ``HASH``
     is a hash of the directory where Sage is installed.
 
     This is useful, since then subsequent startup of GAP is at least 10
@@ -1504,21 +1509,6 @@ def gap_reset_workspace(max_workspace_size=None, verbose=False):
 
     TESTS:
 
-    Check that ``gap_reset_workspace`` still works when ``GAP_DIR``
-    doesn't exist, see :trac:`14171`::
-
-        sage: ORIGINAL_GAP_DIR = sage.interfaces.gap.GAP_DIR
-        sage: ORIGINAL_WORKSPACE = sage.interfaces.gap.WORKSPACE
-        sage: sage.interfaces.gap.GAP_DIR = os.path.join(tmp_dir(), "test_gap_dir")
-        sage: sage.interfaces.gap.WORKSPACE = os.path.join(sage.interfaces.gap.GAP_DIR, "test_workspace")
-        sage: os.path.isfile(sage.interfaces.gap.WORKSPACE)  # long time
-        False
-        sage: gap_reset_workspace()                          # long time
-        sage: os.path.isfile(sage.interfaces.gap.WORKSPACE)  # long time
-        True
-        sage: sage.interfaces.gap.GAP_DIR = ORIGINAL_GAP_DIR
-        sage: sage.interfaces.gap.WORKSPACE = ORIGINAL_WORKSPACE
-
     Check that the race condition from :trac:`14242` has been fixed.
     We temporarily need to change the worksheet filename. ::
 
@@ -1536,36 +1526,6 @@ def gap_reset_workspace(max_workspace_size=None, verbose=False):
         sage: os.unlink(sage.interfaces.gap.WORKSPACE)  # long time
         sage: sage.interfaces.gap.WORKSPACE = ORIGINAL_WORKSPACE
     """
-    # Make sure GAP_DIR exists
-    try:
-        os.makedirs(GAP_DIR)
-        msg = "It is OK to delete all these cache files.  They will be recreated as needed.\n"
-        open(os.path.join(GAP_DIR, 'README.txt'), 'w').write(msg)
-    except OSError:
-        if not os.path.isdir(GAP_DIR):
-            raise
-
-    # Delete all gap workspaces that haven't been used in the last
-    # week, to avoid needless cruft.  I had an install on sage.math
-    # with 90 of these, since I run a lot of different versions of
-    # Sage, and it totalled 1.3GB of wasted space!  See trac #4936.
-    # We only do this after creating a new workspace, since this cruft
-    # issue is only a problem if workspaces get created every so
-    # often.  We don't want to have to do this on every startup.
-    now = time.time()
-    for F in os.listdir(GAP_DIR):
-        if F.startswith('workspace-'):
-            W = os.path.join(GAP_DIR, F)
-            try:
-                age = now - os.path.getatime(W)
-                if age >= 604800:    # 1 week in seconds
-                    os.unlink(W)
-            except OSError:
-                # It's not a problem if W doesn't exist, everything
-                # else is an error.
-                if os.path.exists(W):
-                    raise
-
     # Create new workspace with filename WORKSPACE
     g = Gap(use_workspace_cache=False, max_workspace_size=None)
     g.eval('SetUserPreference("HistoryMaxLines", 30)')
