@@ -38,9 +38,10 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from __future__ import print_function
+from six import iteritems
+import six
 
 import operator
-import six
 
 from sage.structure.sage_object import SageObject
 from sage.structure.parent_base import ParentWithBase
@@ -488,7 +489,7 @@ class Interface(ParentWithBase):
         for i, arg in enumerate(args):
             if not isinstance(arg, InterfaceElement) or arg.parent() is not self:
                 args[i] = self(arg)
-        for key, value in kwds.iteritems():
+        for key, value in iteritems(kwds):
             if not isinstance(value, InterfaceElement) or value.parent() is not self:
                 kwds[key] = self(value)
 
@@ -733,6 +734,7 @@ class InterfaceElement(Element):
             PolynomialRing( Rationals, ["x"] )
             sage: S = singular.ring(0, ('x'))
             sage: loads(dumps(S))
+            polynomial ring, over a field, global ordering
             //   characteristic : 0
             //   number of vars : 1
             //        block   1 : ordering lp
@@ -1107,7 +1109,7 @@ class InterfaceElement(Element):
             sage: int(maxima('1'))
             1
             sage: type(_)
-            <type 'int'>
+            <... 'int'>
         """
         return int(repr(self))
 
@@ -1117,7 +1119,7 @@ class InterfaceElement(Element):
         cmd = '%s %s %s'%(self._name, P._equality_symbol(), t)
         return P.eval(cmd) == t
 
-    def __nonzero__(self):
+    def __bool__(self):
         """
         EXAMPLES::
 
@@ -1128,6 +1130,8 @@ class InterfaceElement(Element):
         """
         return self.bool()
 
+    __nonzero__ = __bool__
+
     def __long__(self):
         """
         EXAMPLES::
@@ -1289,9 +1293,9 @@ class InterfaceElement(Element):
         The Maxima variable ``x`` is different from the Sage symbolic variable::
 
             sage: (f+maxima.cos(x))
-            cos(_SAGE_VAR_x)+sin(x)
+            sin(x)+cos(_SAGE_VAR_x)
             sage: (f+maxima.cos(y))
-            cos(_SAGE_VAR_y)+sin(x)
+            sin(x)+cos(_SAGE_VAR_y)
 
         Note that you may get unexpected results when calling symbolic expressions
         and not explicitly giving the variables::
