@@ -681,7 +681,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
             sage: len(l)                  # optional - macaulay2
             3
             sage: type(_)                 # optional - macaulay2
-            <type 'int'>
+            <... 'int'>
         """
         self._check_valid()
         return int(self.parent()("#%s"%self.name()))
@@ -735,7 +735,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         """
         Quotient of division of self by other.  This is denoted //.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: R.<x,y> = GF(7)[]
 
@@ -770,7 +770,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         """
         Remainder of division of self by other.  This is denoted %.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: R.<x,y> = GF(7)[]
 
@@ -803,19 +803,21 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
             x = self.parent(x)
         return self.parent().new('%s %% %s'%(self.name(), x.name()))
 
-    def __nonzero__(self):
+    def __bool__(self):
         """
         EXAMPLES::
 
             sage: a = macaulay2(0)  # optional - macaulay2
             sage: a == 0            # optional - macaulay2
             True
-            sage: a.__nonzero__()   # optional - macaulay2
+            sage: bool(a)           # optional - macaulay2
             False
         """
         P = self.parent()
         return P.eval('%s == 0'%self.name()) == 'false'
 
+    __nonzero__ = __bool__
+
     def sage_polystring(self):
         """
         If this Macaulay2 element is a polynomial, return a string
