@@ -306,8 +306,7 @@ For more details, see the documentation for ``._sage_()``.
 OTHER Examples::
 
     sage: def math_bessel_K(nu,x):
-    ...       return mathematica(nu).BesselK(x).N(20)
-    ...
+    ....:     return mathematica(nu).BesselK(x).N(20)
     sage: math_bessel_K(2,I)                      # optional - mathematica
     -2.5928861754911969782 + 0.1804899720669620266 I
 
@@ -733,7 +732,7 @@ class MathematicaElement(ExpectElement):
           compatibility, while still supporting conversion of symbolic
           expressions.
         """
-        from sage.symbolic.pynac import symbol_table
+        from sage.libs.pynac.pynac import symbol_table
         from sage.symbolic.constants import constants_name_table as constants
         from sage.calculus.calculus import symbolic_expression_from_string
         from sage.calculus.calculus import _find_func as find_func
@@ -747,7 +746,7 @@ class MathematicaElement(ExpectElement):
         # Find all the mathematica functions, constants and symbolic variables
         # present in `res`.  Convert MMA functions and constants to their
         # Sage equivalents (if possible), using `locals` and
-        # `sage.symbolic.pynac.symbol_table['mathematica']` as translation
+        # `sage.libs.pynac.pynac.symbol_table['mathematica']` as translation
         # dictionaries.  If a MMA function or constant is not either
         # dictionary, then we use a variety of tactics listed in `autotrans`.
         # If a MMA variable is not in any dictionary, then create an
