@@ -222,7 +222,7 @@ After execution of this code, the %R and %%R magics are available :
    possible via the -i and -o options. Do "%R?" in a standalone cell
    to get the documentation.
 
-- %%R alows the execution in R of the whole text of a cell, with
+- %%R allows the execution in R of the whole text of a cell, with
     similar options (do "%%R?" in a standalone cell for
     documentation).
 
@@ -263,13 +263,13 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #
 ##########################################################################
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
+from six.moves import range
+import six
 
 from .expect import Expect, ExpectElement, ExpectFunction, FunctionElement
 from sage.env import DOT_SAGE
 import re
-import six
 import sage.rings.integer
 from sage.structure.element import parent
 from sage.misc.cachefunc import cached_method
@@ -707,7 +707,7 @@ class R(ExtraTabCompletion, Expect):
         #The following was more structural, but breaks on my machine.  (stein)
         #p = p._sage_()
         #s = p['_Dim'][0]
-        #l = [[p['DATA'][i],p['DATA'][s+1+i]] for i in xrange(0,s)]
+        #l = [[p['DATA'][i],p['DATA'][s+1+i]] for i in range(0,s)]
         #return l
 
     def _object_class(self):
@@ -787,7 +787,7 @@ class R(ExtraTabCompletion, Expect):
 
             .. note::
 
-            This is similar to typing r.command?.
+                This is similar to typing r.command?.
         """
         s = self.eval('help("%s")'%command).strip()     # ?cmd is only an unsafe shortcut
         import sage.plot.plot
@@ -1250,7 +1250,7 @@ class R(ExtraTabCompletion, Expect):
 
 # patterns for _sage_()
 rel_re_param = re.compile('\s([\w\.]+)\s=')
-rel_re_xrange = re.compile('([\d]+):([\d]+)')
+rel_re_range = re.compile('([\d]+):([\d]+)')
 rel_re_integer = re.compile('([^\d])([\d]+)L')
 rel_re_terms = re.compile('terms\s*=\s*(.*?),')
 rel_re_call = re.compile('call\s*=\s*(.*?)\),')
@@ -1386,14 +1386,14 @@ class RElement(ExtraTabCompletion, ExpectElement):
             return P.new('%s[%s]'%(self._name, n))
         else:
             L = []
-            for i in xrange(len(n)):
+            for i in range(len(n)):
                 if parent(n[i]) is P:
                     L.append(n[i].name())
                 else:
                     L.append(str(n[i]))
             return P.new('%s[%s]'%(self._name, ','.join(L)))
 
-    def __nonzero__(self):
+    def __bool__(self):
         """
         Implements bool(self).
 
@@ -1416,6 +1416,8 @@ class RElement(ExtraTabCompletion, ExpectElement):
         """
         return "FALSE" in repr(self==0)
 
+    __nonzero__ = __bool__
+
     def _comparison(self, other, symbol):
         """
         Used to implement comparison of two objects.
@@ -1640,9 +1642,9 @@ class RElement(ExtraTabCompletion, ExpectElement):
         """
         return x.group().replace('.','_')
 
-    def _subs_xrange(self, x):
+    def _subs_range(self, x):
         """
-        Change endpoints of xranges.  This is used internally in the
+        Change endpoints of ranges.  This is used internally in the
         code for converting R expressions to Sage objects.
 
         INPUT:
@@ -1655,13 +1657,13 @@ class RElement(ExtraTabCompletion, ExpectElement):
 
             sage: import re
             sage: a = r([1,2,3])
-            sage: rel_re_xrange = re.compile('([\d]+):([\d]+)')
-            sage: rel_re_xrange.sub(a._subs_xrange, ' 1:10')
-            ' xrange(1,11)'
+            sage: rel_re_range = re.compile('([\d]+):([\d]+)')
+            sage: rel_re_range.sub(a._subs_range, ' 1:10')
+            ' range(1,11)'
         """
         g = x.groups()
         g1 = int(g[1]) + 1
-        return 'xrange(%s,%s)'%(g[0],g1)
+        return 'range(%s,%s)' % (g[0],  g1)
 
     def _subs_integer(self, x):
         """
@@ -1856,8 +1858,8 @@ class RElement(ExtraTabCompletion, ExpectElement):
         exp = re.sub(' list\(', ' _r_list(', exp)
         exp = re.sub('\(list\(', '(_r_list(', exp)
 
-        # Change 'a:b' to 'xrange(a,b+1)'
-        exp = rel_re_xrange.sub(self._subs_xrange, exp)
+        # Change 'a:b' to 'range(a,b+1)'
+        exp = rel_re_range.sub(self._subs_range, exp)
 
         # Change 'dL' to 'Integer(d)'
         exp = rel_re_integer.sub(self._subs_integer, exp)
@@ -2002,7 +2004,7 @@ class RFunction(ExpectFunction):
         else:
             self._name = parent._sage_to_r_name(name)
 
-    def __cmp__(self, other):
+    def __eq__(self, other):
         """
         EXAMPLES::
 
@@ -2011,9 +2013,19 @@ class RFunction(ExpectFunction):
             sage: r.mean == r.lr
             False
         """
-        if not isinstance(other, RFunction):
-            return cmp(type(self), type(other))
-        return cmp(self._name, other._name)
+        return (isinstance(other, RFunction) and
+            self._name == other._name)
+
+    def __ne__(self, other):
+        """
+        EXAMPLES::
+
+            sage: r.mean != loads(dumps(r.mean))
+            False
+            sage: r.mean != r.lr
+            True
+        """        
+        return not (self == other)
 
     def _sage_doc_(self):
         """
