@@ -64,6 +64,7 @@ factorization::
 
     sage: R1 = singular.ring(0, '(x,y)', 'dp')
     sage: R1
+    polynomial ring, over a field, global ordering
     //   characteristic : 0
     //   number of vars : 2
     //        block   1 : ordering dp
@@ -212,7 +213,7 @@ We compute the projective genus of ideals that define curves over
 ``normal.lib`` library before calling the
 ``genus`` command, or you'll get an error message.
 
-EXAMPLE::
+EXAMPLES::
 
     sage: singular.lib('normal.lib')
     sage: R = singular.ring(0,'(x,y)','dp')
@@ -241,6 +242,7 @@ Groebner basis for some ideal, using Singular through Sage.
 
     sage: singular.lib('poly.lib')
     sage: singular.ring(32003, '(a,b,c,d,e,f)', 'lp')
+            polynomial ring, over a field, global ordering
             //   characteristic : 32003
             //   number of vars : 6
             //        block   1 : ordering lp
@@ -317,6 +319,7 @@ see :trac:`11645`::
 #*****************************************************************************
 from __future__ import print_function
 from __future__ import absolute_import
+from six.moves import range
 
 import os
 import re
@@ -611,6 +614,7 @@ class Singular(ExtraTabCompletion, Expect):
             // dimension (affine) = 0
             // degree (affine)  = 8
             // ** right side is not a datum, assignment ignored
+            ...
 
         rather than ignored
 
@@ -995,6 +999,7 @@ class Singular(ExtraTabCompletion, Expect):
 
             sage: R = singular.ring(0, '(x,y,z)', 'dp')
             sage: R
+            polynomial ring, over a field, global ordering
             //   characteristic : 0
             //   number of vars : 3
             //        block   1 : ordering dp
@@ -1034,7 +1039,7 @@ class Singular(ExtraTabCompletion, Expect):
             sage: R = singular.ring(7, '(a,b)', 'ds')
             sage: S = singular.ring('real', '(a,b)', 'lp')
             sage: singular.new('10*a')
-            1.000e+01*a
+            (1.000e+01)*a
             sage: R.set_ring()
             sage: singular.new('10*a')
             3*a
@@ -1074,6 +1079,7 @@ class Singular(ExtraTabCompletion, Expect):
             sage: R = singular.ring(7, '(a,b)', 'ds')
             sage: S = singular.ring('real', '(a,b)', 'lp')
             sage: singular.current_ring()
+            polynomial ring, over a field, global ordering
             //   characteristic : 0 (real)
             //   number of vars : 2
             //        block   1 : ordering lp
@@ -1081,6 +1087,7 @@ class Singular(ExtraTabCompletion, Expect):
             //        block   2 : ordering C
             sage: singular.set_ring(R)
             sage: singular.current_ring()
+            polynomial ring, over a field, local ordering
             //   characteristic : 7
             //   number of vars : 2
             //        block   1 : ordering ds
@@ -1122,12 +1129,14 @@ class Singular(ExtraTabCompletion, Expect):
 
             sage: r = PolynomialRing(GF(127),3,'xyz', order='invlex')
             sage: r._singular_()
+            polynomial ring, over a field, global ordering
             //   characteristic : 127
             //   number of vars : 3
             //        block   1 : ordering rp
             //                  : names    x y z
             //        block   2 : ordering C
             sage: singular.current_ring()
+            polynomial ring, over a field, global ordering
             //   characteristic : 127
             //   number of vars : 3
             //        block   1 : ordering rp
@@ -1149,7 +1158,7 @@ class Singular(ExtraTabCompletion, Expect):
              sage: singular._tab_completion()
              ['exteriorPower',
               ...
-              'stdfglm']
+              'flintZ']
          """
         p = re.compile("// *([a-z0-9A-Z_]*).*") #compiles regular expression
         proclist = self.eval("listvar(proc)").splitlines()
@@ -1170,7 +1179,12 @@ class Singular(ExtraTabCompletion, Expect):
 
     def version(self):
         """
-        EXAMPLES:
+        Return the version of Singular being used.
+
+        EXAMPLES::
+
+            sage: singular.version()
+            "Singular ... version 4.1.0 ...
         """
         return singular_version()
 
@@ -1277,7 +1291,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         r"""
         Return string representation of ``self``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: r = singular.ring(0,'(x,y)','dp')
             sage: singular(0)
@@ -1345,6 +1359,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             sage: cpQ=copy(Q)
             sage: cpQ.set_ring()
             sage: cpQ
+            polynomial ring, over a field, global ordering
             //   characteristic : 0
             //   number of vars : 2
             //        block   1 : ordering dp
@@ -1427,19 +1442,21 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         else:
             P.eval('%s[%s] = %s'%(self.name(), n, value.name()))
 
-    def __nonzero__(self):
+    def __bool__(self):
         """
-        Returns True if this Singular element is not zero.
+        Returns ``True`` if this Singular element is not zero.
 
         EXAMPLES::
 
-            sage: singular(0).__nonzero__()
+            sage: bool(singular(0))
             False
-            sage: singular(1).__nonzero__()
+            sage: bool(singular(1))
             True
         """
         P = self.parent()
-        return P.eval('%s == 0'%self.name()) == '0'
+        return P.eval('%s == 0' % self.name()) == '0'
+
+    __nonzero__ = __bool__
 
     def sage_polystring(self):
         r"""
@@ -1468,7 +1485,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         """
         Return the current basering in Singular as a polynomial ring or quotient ring.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: singular.eval('ring r1 = (9,x),(a,b,c,d,e,f),(M((1,2,3,0)),wp(2,3),lp)')
             ''
@@ -1550,10 +1567,10 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         charstr = singular.eval('charstr(basering)').split(',',1)
         from sage.all import ZZ
         is_extension = len(charstr)==2
-        if charstr[0]=='integer':
+        if charstr[0] in ['integer', 'ZZ']:
             br = ZZ
             is_extension = False
-        elif charstr[0]=='0':
+        elif charstr[0] in ['0', 'QQ']:
             from sage.all import QQ
             br = QQ
         elif charstr[0]=='real':
@@ -1568,7 +1585,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             is_extension = False
         else:
             # it ought to be a finite field
-            q = ZZ(charstr[0])
+            q = ZZ(charstr[0].lstrip('ZZ/'))
             from sage.all import GF
             if q.is_prime():
                 br = GF(q)
@@ -1600,7 +1617,10 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         # using Singular's term order
         from sage.rings.polynomial.term_order import termorder_from_singular
         from sage.all import PolynomialRing
-        if singular.eval('typeof(basering)')=='ring':
+        # Meanwhile Singulars quotient rings are also of 'ring' type, not 'qring' as it was in the past.
+        # To find out if a singular ring is a quotient ring or not checking for ring type does not help
+        # and instead of that we we check if the quotient ring is zero or not:
+        if (singular.eval('ideal(basering)==0')=='1'):
             return PolynomialRing(BR, names=singular.eval('varstr(basering)'), order=termorder_from_singular(singular))
         P = PolynomialRing(BR, names=singular.eval('varstr(basering)'), order=termorder_from_singular(singular))
         return P.quotient(singular('ringlist(basering)[4]')._sage_(P), names=singular.eval('varstr(basering)'))
@@ -1722,11 +1742,18 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             singular_poly_list = self.parent().eval("string(coef(%s,%s))"%(\
                     self.name(),variable_str)).split(",")
 
-        if singular_poly_list == ['1','0'] :
-            return R(0)
+        # Directly treat constants
+        if singular_poly_list[0] in ['1', '(1.000e+00)']:
+            return R(singular_poly_list[1])
 
         coeff_start = len(singular_poly_list) // 2
 
+        # Singular 4 puts parentheses around floats and sign outside them
+        charstr = self.parent().eval('charstr(basering)').split(',',1)
+        if charstr[0] in ['real', 'complex']:
+              for i in range(coeff_start, 2 * coeff_start):
+                  singular_poly_list[i] = singular_poly_list[i].replace('(','').replace(')','')
+
         if isinstance(R,(MPolynomialRing_polydict,QuotientRing_generic)) and (ring_is_fine or can_convert_to_singular(R)):
             # we need to lookup the index of a given variable represented
             # through a string
@@ -1778,7 +1805,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
                         exp = int(1)
 
                 if kcache is None:
-                    sage_repr[exp]=k(singular_poly_list[coeff_start+i])
+                    sage_repr[exp] = k(singular_poly_list[coeff_start+i])
                 else:
                     elem = singular_poly_list[coeff_start+i]
                     if elem not in kcache:
@@ -1861,7 +1888,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         ::
 
             sage: singular.eval('ring R = integer, (x,y,z),lp')
-            '// ** redefining R **'
+            '// ** redefining R (ring R = integer, (x,y,z),lp;)'
             sage: I = singular.ideal(['x^2','y*z','z+x'])
             sage: I.sage()
             Ideal (x^2, y*z, x + z) of Multivariate Polynomial Ring in x, y, z over Integer Ring
@@ -1883,7 +1910,8 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         Note that the current base ring has not been changed by asking for another ring::
 
             sage: singular('basering')
-            //   coeff. ring is : Integers
+            polynomial ring, over a domain, global ordering
+            //   coeff. ring is : ZZ
             //   number of vars : 3
             //        block   1 : ordering lp
             //                  : names    x y z
@@ -1927,8 +1955,8 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             from sage.matrix.constructor import matrix
             from sage.rings.integer_ring import ZZ
             A =  matrix(ZZ, int(self.nrows()), int(self.ncols()))
-            for i in xrange(A.nrows()):
-                for j in xrange(A.ncols()):
+            for i in range(A.nrows()):
+                for j in range(A.ncols()):
                     A[i,j] = sage.rings.integer.Integer(str(self[i+1,j+1]))
             return A
         elif typ == 'string':
@@ -1967,6 +1995,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             sage: R = singular.ring(7, '(a,b)', 'ds')
             sage: S = singular.ring('real', '(a,b)', 'lp')
             sage: singular.current_ring()
+            polynomial ring, over a field, global ordering
             //   characteristic : 0 (real)
             //   number of vars : 2
             //        block   1 : ordering lp
@@ -1974,6 +2003,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             //        block   2 : ordering C
             sage: R.set_ring()
             sage: singular.current_ring()
+            polynomial ring, over a field, local ordering
             //   characteristic : 7
             //   number of vars : 2
             //        block   1 : ordering ds
@@ -2046,7 +2076,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             sage: R._tab_completion()
             ['exteriorPower',
              ...
-             'stdfglm']
+             'flintZ']
         """
         return self.parent()._tab_completion()
 
@@ -2085,7 +2115,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
             l = self.ncols()
         else:
             l = len(self)
-        for i in range(1, l+1):
+        for i in range(1, l + 1):
             yield self[i]
 
     def _singular_(self):
@@ -2123,7 +2153,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement):
         resolution withDim - value of type int is the dimension (see dim)
         withMult - value of type int is the multiplicity (see mult)
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y,z> = PolynomialRing(QQ)
             sage: I = Ideal([z^2, y*z, y^2, x*z, x*y, x^2])
@@ -2158,7 +2188,7 @@ class SingularFunction(ExpectFunction):
 This function is an automatically generated pexpect wrapper around the Singular
 function '%s'.
 
-EXAMPLE::
+EXAMPLES::
 
     sage: groebner = singular.groebner
     sage: P.<x, y> = PolynomialRing(QQ)
@@ -2229,6 +2259,7 @@ def reduce_load():
     By :trac:`18848`, pickling actually often works::
 
         sage: loads(dumps(singular.ring()))
+        polynomial ring, over a field, global ordering
         //   characteristic : 0
         //   number of vars : 1
         //        block   1 : ordering lp
@@ -2247,18 +2278,20 @@ def generate_docstring_dictionary():
     Generate global dictionaries which hold the docstrings for
     Singular functions.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.interfaces.singular import generate_docstring_dictionary
         sage: generate_docstring_dictionary()
     """
+    from sage.env import SAGE_LOCAL
+
     global nodes
     global node_names
 
     nodes.clear()
     node_names.clear()
 
-    singular_docdir = os.environ["SAGE_LOCAL"]+"/share/singular/"
+    singular_docdir = SAGE_LOCAL+"/share/info/"
 
     new_node = re.compile("File: singular\.hlp,  Node: ([^,]*),.*")
     new_lookup = re.compile("\* ([^:]*):*([^.]*)\..*")
@@ -2294,7 +2327,7 @@ def get_docstring(name):
 
     - ``name`` - a Singular function name
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.interfaces.singular import get_docstring
         sage: 'groebner' in get_docstring('groebner')
@@ -2346,9 +2379,12 @@ def singular_console():
 
 def singular_version():
     """
-    Returns the version of Singular being used.
+    Return the version of Singular being used.
 
-    EXAMPLES:
+    EXAMPLES::
+
+        sage: singular.version()
+        "Singular ... version 4.1.0 ...
     """
     return singular.eval('system("--version");')
 
@@ -2393,7 +2429,7 @@ class SingularGBLogPrettyPrinter:
         - ``verbosity`` - how much information should be printed
           (between 0 and 3)
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.interfaces.singular import SingularGBLogPrettyPrinter
             sage: s0 = SingularGBLogPrettyPrinter(verbosity=0)
@@ -2418,7 +2454,7 @@ class SingularGBLogPrettyPrinter:
 
     def write(self, s):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.interfaces.singular import SingularGBLogPrettyPrinter
             sage: s3 = SingularGBLogPrettyPrinter(verbosity=3)
@@ -2517,7 +2553,7 @@ class SingularGBLogPrettyPrinter:
 
     def flush(self):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.interfaces.singular import SingularGBLogPrettyPrinter
             sage: s3 = SingularGBLogPrettyPrinter(verbosity=3)
@@ -2544,7 +2580,7 @@ class SingularGBDefaultContext:
 
         -  ``singular`` - Singular instance (default: default instance)
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.interfaces.singular import SingularGBDefaultContext
             sage: P.<a,b,c> = PolynomialRing(QQ,3, order='lex')
@@ -2587,7 +2623,7 @@ class SingularGBDefaultContext:
 
     def __enter__(self):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.interfaces.singular import SingularGBDefaultContext
             sage: P.<a,b,c> = PolynomialRing(QQ,3, order='lex')
@@ -2625,7 +2661,7 @@ class SingularGBDefaultContext:
 
     def __exit__(self, typ, value, tb):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.interfaces.singular import SingularGBDefaultContext
             sage: P.<a,b,c> = PolynomialRing(QQ,3, order='lex')
