@@ -1,7 +1,7 @@
 r"""
 Interface to TIDES
 
-This module contains tools to write the .c files needed for TIDES [TI]_ .
+This module contains tools to write the .c files needed for TIDES [TIDES]_ .
 
 Tides is an integration engine based on the Taylor method. It is implemented
 as a c library. The user must translate its initial value problem (IVP) into a
@@ -33,12 +33,9 @@ AUTHORS:
 
 REFERENCES:
 
-.. [ALG924] \A. Abad, R. Barrio, F. Blesa, M. Rodriguez. Algorithm 924. *ACM Transactions on Mathematical Software*, *39* (1), 1-28.
+- [ABBR2012]_
 
-.. [TI]
-   A. Abad, R. Barrio, F. Blesa, M. Rodriguez.
-   TIDES tutorial: Integrating ODEs by using the Taylor Series Method.
-   <http://www.unizar.es/acz/05Publicaciones/Monografias/MonografiasPublicadas/Monografia36/IndMonogr36.htm>
+- [TIDES]_
 """
 
 
@@ -407,7 +404,7 @@ def genfiles_mintides(integrator, driver, f, ics, initial, final, delta,
     -  ``output`` -- the name of the file that the compiled integrator will write to
 
     This function creates two files, integrator and driver, that can be used
-    later with the min_tides library [TI]_.
+    later with the min_tides library [TIDES]_.
 
 
     TESTS::
@@ -678,7 +675,7 @@ def genfiles_mpfr(integrator, driver, f, ics, initial, final, delta,
     -  ``output`` -- the name of the file that the compiled integrator will write to
 
     This function creates two files, integrator and driver, that can be used
-    later with the tides library ([TI]_).
+    later with the tides library ([TIDES]_).
 
 
     TESTS::
