@@ -7,6 +7,7 @@ Coxeter Groups implemented with Coxeter3
 #  Distributed under the terms of the GNU General Public License (GPL)
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
+from six import iteritems
 
 from sage.libs.coxeter3.coxeter import get_CoxGroup, CoxGroupElement
 from sage.misc.cachefunc import cached_method
@@ -19,6 +20,7 @@ from sage.structure.parent import Parent
 from sage.rings.integer_ring import ZZ
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 
+
 class CoxeterGroup(UniqueRepresentation, Parent):
     @staticmethod
     def __classcall__(cls, cartan_type, *args, **options):
@@ -103,7 +105,6 @@ class CoxeterGroup(UniqueRepresentation, Parent):
             (0, 1, 2, 3)
         """
         return self.cartan_type().index_set()
-        #return range(1, self.rank()+1)
 
     def bruhat_interval(self, u, v):
         """
@@ -303,7 +304,7 @@ class CoxeterGroup(UniqueRepresentation, Parent):
                 sage: all(W.kazhdan_lusztig_polynomial(u,u) == 1 for u in W) # optional - coxeter3
                 True
 
-            This convention differs from Theorem 2.7 in [LeclercThibon1998]_ by:
+            This convention differs from Theorem 2.7 in [LT1998]_ by:
 
             .. MATH::
 
@@ -347,22 +348,16 @@ class CoxeterGroup(UniqueRepresentation, Parent):
         - ``J`` -- a subset of the index set of ``self`` specifying the parabolic subgroup
 
         This method implements the parabolic Kazhdan-Lusztig polynomials
-        `P^{-,J}_{u,v}` of [Deodhar1987]_, which are defined as
+        `P^{-,J}_{u,v}` of [Deo1987b]_, which are defined as
         `P^{-,J}_{u,v} = \sum_{z\in W_J} (-1)^{\ell(z)} P_{yz,w}(q)`
         with the conventions in Sage.
         As for :meth:`kazhdan_lusztig_polynomial` the convention
-        differs from Theorem 2.7 in [LeclercThibon1998]_ by:
+        differs from Theorem 2.7 in [LT1998]_ by:
 
         .. MATH::
 
             {}^{LT} P_{y,w}^{-,J}(q) = q^{\ell(w)-\ell(y)} P_{y,w}^{-,J}(q^{-2})
 
-        REFERENCES:
-
-            .. [Deodhar1987] \V.V. Deodhar, On some geometric aspects of Bruhat orderings II. The parabolic analogue of Kazhdan-Lusztig polynomials, J. Alg. 111 (1987) 483-506.
-
-            .. [LeclercThibon1998] \B. Leclerc, J.-Y. Thibon, Littlewood-Richardson coefficients and Kazhdan-Lusztig polynomials, http://front.math.ucdavis.edu/9809.5122
-
         EXAMPLES::
 
             sage: W = CoxeterGroup(['A',3], implementation='coxeter3')                      # optional - coxeter3
@@ -622,7 +617,7 @@ class CoxeterGroup(UniqueRepresentation, Parent):
 
         def action(self, v):
             """
-            Return the action of of this Coxeter group element on the root space.
+            Return the action of this Coxeter group element on the root space.
 
             INPUT:
 
@@ -691,7 +686,7 @@ class CoxeterGroup(UniqueRepresentation, Parent):
                     exponent = self.action(exponent)
 
                     monomial = 1
-                    for s, c in exponent.monomial_coefficients().iteritems():
+                    for s, c in iteritems(exponent.monomial_coefficients()):
                         monomial *= Q_gens[basis_to_order[s]]**int(c)
 
                     result += monomial
@@ -700,4 +695,3 @@ class CoxeterGroup(UniqueRepresentation, Parent):
 
             numerator, denominator = results
             return numerator / denominator
-
