@@ -20,12 +20,9 @@ AUTHORS:
 
 REFERENCES:
 
-.. [1] \S. Kobayashi & K. Nomizu : *Foundations of Differential Geometry*,
-   vol. 1, Interscience Publishers (New York) (1963)
-.. [2] \J.M. Lee : *Introduction to Smooth Manifolds*, 2nd ed., Springer
-   (New York) (2013)
-.. [3] \B. O'Neill : *Semi-Riemannian Geometry*, Academic Press (San Diego)
-   (1983)
+- [KN1963]_
+- [Lee2013]_
+- [ONe1983]_
 
 """
 
@@ -632,6 +629,7 @@ class DiffScalarField(ScalarField):
         """
         ScalarField.__init__(self, parent, coord_expression=coord_expression,
                              chart=chart, name=name, latex_name=latex_name)
+        self._tensor_type = (0,0)
 
     ####### Required methods for an algebra element (beside arithmetic) #######
 
@@ -647,8 +645,9 @@ class DiffScalarField(ScalarField):
             sage: f._init_derived()
 
         """
-        ScalarField._init_derived(self) # derived quantities of the mother class
-        # More to come in ticket #18843
+        ScalarField._init_derived(self) # derived quantities of the parent class
+        self._differential = None  # differential 1-form of the scalar field
+        self._lie_derivatives = {} # dict. of Lie derivatives of self, (keys: id(vector))
 
     def _del_derived(self):
         r"""
@@ -673,5 +672,260 @@ class DiffScalarField(ScalarField):
 
         """
         ScalarField._del_derived(self) # derived quantities of the mother class
-        # More to come in ticket #18843
+        self._differential = None  # reset of the differential
+        # First deletes any reference to self in the vectors' dictionaries:
+        for vid, val in self._lie_derivatives.items():
+            del val[0]._lie_der_along_self[id(self)]
+        # Then clears the dictionary of Lie derivatives
+        self._lie_derivatives.clear()
 
+    def tensor_type(self):
+        r"""
+        Return the tensor type of ``self``, when the latter is considered
+        as a tensor field on the manifold. This is always `(0, 0)`.
+
+        OUTPUT:
+
+        - always `(0, 0)`
+
+        EXAMPLES::
+
+            sage: M = Manifold(2, 'M')
+            sage: c_xy.<x,y> = M.chart()
+            sage: f = M.scalar_field(x+2*y)
+            sage: f.tensor_type()
+            (0, 0)
+
+        """
+        return self._tensor_type
+
+    def differential(self):
+        r"""
+        Return the differential of ``self``.
+
+        OUTPUT:
+
+        - a :class:`~sage.manifolds.differentiable.diff_form.DiffForm` (or of
+          :class:`~sage.manifolds.differentiable.diff_form.DiffFormParal` if
+          the scalar field's domain is parallelizable) representing the 1-form
+          that is the differential of the scalar field
+
+        EXAMPLES:
+
+        Differential of a scalar field on a 3-dimensional differentiable
+        manifold::
+
+            sage: M = Manifold(3, 'M')
+            sage: c_xyz.<x,y,z> = M.chart()
+            sage: f = M.scalar_field(cos(x)*z^3 + exp(y)*z^2, name='f')
+            sage: df = f.differential() ; df
+            1-form df on the 3-dimensional differentiable manifold M
+            sage: df.display()
+            df = -z^3*sin(x) dx + z^2*e^y dy + (3*z^2*cos(x) + 2*z*e^y) dz
+            sage: latex(df)
+            \mathrm{d}f
+            sage: df.parent()
+            Free module /\^1(M) of 1-forms on the 3-dimensional differentiable
+             manifold M
+
+        The result is cached, i.e. is not recomputed unless ``f`` is changed::
+
+            sage: f.differential() is df
+            True
+
+        Since the exterior derivative of a scalar field (considered a 0-form)
+        is nothing but its differential, ``exterior_derivative()`` is an
+        alias of ``differential()``::
+
+            sage: df = f.exterior_derivative() ; df
+            1-form df on the 3-dimensional differentiable manifold M
+            sage: df.display()
+            df = -z^3*sin(x) dx + z^2*e^y dy + (3*z^2*cos(x) + 2*z*e^y) dz
+            sage: latex(df)
+            \mathrm{d}f
+
+        One may also use the global function
+        :func:`~sage.manifolds.utilities.exterior_derivative`
+        or its alias :func:`~sage.manifolds.utilities.xder` instead
+        of the method ``exterior_derivative()``::
+
+            sage: from sage.manifolds.utilities import xder
+            sage: xder(f) is f.exterior_derivative()
+            True
+
+        Differential computed on a chart that is not the default one::
+
+            sage: c_uvw.<u,v,w> = M.chart()
+            sage: g = M.scalar_field(u*v^2*w^3, c_uvw, name='g')
+            sage: dg = g.differential() ; dg
+            1-form dg on the 3-dimensional differentiable manifold M
+            sage: dg._components
+            {Coordinate frame (M, (d/du,d/dv,d/dw)): 1-index components w.r.t.
+             Coordinate frame (M, (d/du,d/dv,d/dw))}
+            sage: dg.comp(c_uvw.frame())[:, c_uvw]
+            [v^2*w^3, 2*u*v*w^3, 3*u*v^2*w^2]
+            sage: dg.display(c_uvw.frame(), c_uvw)
+            dg = v^2*w^3 du + 2*u*v*w^3 dv + 3*u*v^2*w^2 dw
+
+        The exterior derivative is nilpotent::
+
+            sage: ddf = df.exterior_derivative() ; ddf
+            2-form ddf on the 3-dimensional differentiable manifold M
+            sage: ddf == 0
+            True
+            sage: ddf[:] # for the incredule
+            [0 0 0]
+            [0 0 0]
+            [0 0 0]
+            sage: ddg = dg.exterior_derivative() ; ddg
+            2-form ddg on the 3-dimensional differentiable manifold M
+            sage: ddg == 0
+            True
+
+        """
+        from sage.tensor.modules.format_utilities import (format_unop_txt,
+                                                          format_unop_latex)
+        if self._differential is None:
+            # A new computation is necessary:
+            rname = format_unop_txt('d', self._name)
+            rlname = format_unop_latex(r'\mathrm{d}', self._latex_name)
+            self._differential = self._domain.one_form(name=rname,
+                                                       latex_name=rlname)
+            if self._is_zero:
+                for chart in self._domain._atlas:
+                    self._differential.add_comp(chart._frame) # since a newly
+                                            # created set of components is zero
+            else:
+                for chart, func in self._express.items():
+                    diff_func = self._differential.add_comp(chart._frame)
+                    for i in self._manifold.irange():
+                        diff_func[i, chart] = func.diff(i)
+        return self._differential
+
+    exterior_derivative = differential
+
+    def lie_derivative(self, vector):
+        r"""
+        Compute the Lie derivative with respect to a vector field.
+
+        In the present case (scalar field), the Lie derivative is equal to
+        the scalar field resulting from the action of the vector field on
+        the scalar field.
+
+        INPUT:
+
+        - ``vector`` -- vector field with respect to which the Lie derivative
+          is to be taken
+
+        OUTPUT:
+
+        - the scalar field that is the Lie derivative of the scalar field with
+          respect to ``vector``
+
+        EXAMPLES:
+
+        Lie derivative on a 2-dimensional manifold::
+
+            sage: M = Manifold(2, 'M')
+            sage: c_xy.<x,y> = M.chart()
+            sage: f = M.scalar_field(x^2*cos(y))
+            sage: v = M.vector_field(name='v')
+            sage: v[:] = (-y, x)
+            sage: f.lie_derivative(v)
+            Scalar field on the 2-dimensional differentiable manifold M
+            sage: f.lie_derivative(v).expr()
+            -x^3*sin(y) - 2*x*y*cos(y)
+
+        The result is cached::
+
+            sage: f.lie_derivative(v) is f.lie_derivative(v)
+            True
+
+        An alias is ``lie_der``::
+
+            sage: f.lie_der(v) is f.lie_derivative(v)
+            True
+
+        Alternative expressions of the Lie derivative of a scalar field::
+
+            sage: f.lie_der(v) == v(f)  # the vector acting on f
+            True
+            sage: f.lie_der(v) == f.differential()(v)  # the differential of f acting on the vector
+            True
+
+        A vanishing Lie derivative::
+
+            sage: f.set_expr(x^2 + y^2)
+            sage: f.lie_der(v).display()
+            M --> R
+            (x, y) |--> 0
+
+        """
+        # The Lie derivative is cached in _lie_derivatives if neither
+        #   the scalar field nor ``vector`` have been modified.
+        if id(vector) not in self._lie_derivatives:
+            # A new computation must be performed
+            res = vector(self)
+            self._lie_derivatives[id(vector)] = (vector, res)
+            vector._lie_der_along_self[id(self)] = self
+        return self._lie_derivatives[id(vector)][1]
+
+    lie_der = lie_derivative
+
+    def hodge_dual(self, metric):
+        r"""
+        Compute the Hodge dual of the scalar field with respect to some
+        metric.
+
+        If `M` is the domain of the scalar field (denoted by `f`), `n` is the
+        dimension of `M` and `g` is a pseudo-Riemannian metric on `M`, the
+        *Hodge dual* of `f` w.r.t. `g` is the `n`-form `*f` defined by
+
+        .. MATH::
+
+            *f = f \epsilon,
+
+        where `\epsilon` is the volume `n`-form associated with `g` (see
+        :meth:`~sage.manifolds.differentiable.metric.PseudoRiemannianMetric.volume_form`).
+
+        INPUT:
+
+        - ``metric``: a pseudo-Riemannian metric defined on the same manifold
+          as the current scalar field; must be an instance of
+          :class:`~sage.manifolds.differentiable.metric.PseudoRiemannianMetric`
+
+        OUTPUT:
+
+        - the `n`-form `*f`
+
+        EXAMPLES:
+
+        Hodge dual of a scalar field in the Euclidean space `R^3`::
+
+            sage: M = Manifold(3, 'M', start_index=1)
+            sage: X.<x,y,z> = M.chart()
+            sage: g = M.metric('g')
+            sage: g[1,1], g[2,2], g[3,3] = 1, 1, 1
+            sage: f = M.scalar_field(function('F')(x,y,z), name='f')
+            sage: sf = f.hodge_dual(g) ; sf
+            3-form *f on the 3-dimensional differentiable manifold M
+            sage: sf.display()
+            *f = F(x, y, z) dx/\dy/\dz
+            sage: ssf = sf.hodge_dual(g) ; ssf
+            Scalar field **f on the 3-dimensional differentiable manifold M
+            sage: ssf.display()
+            **f: M --> R
+               (x, y, z) |--> F(x, y, z)
+            sage: ssf == f # must hold for a Riemannian metric
+            True
+
+        Instead of calling the method :meth:`hodge_dual` on the scalar field,
+        one can invoke the method
+        :meth:`~sage.manifolds.differentiable.metric.PseudoRiemannianMetric.hodge_star`
+        of the metric::
+
+            sage: f.hodge_dual(g) == g.hodge_star(f)
+            True
+
+        """
+        return metric.hodge_star(self)
