@@ -307,14 +307,11 @@ AUTHORS:
 
 REFERENCES:
 
-.. [Lee11] \J.M. Lee : *Introduction to Topological Manifolds*,
-   2nd ed., Springer (New York) (2011).
-.. [Lee13] \J.M. Lee : *Introduction to Smooth Manifolds*,
-   2nd ed., Springer (New York) (2013)
-.. [KN63] \S. Kobayashi & K. Nomizu : *Foundations of Differential Geometry*,
-   vol. 1, Interscience Publishers (New York) (1963).
-.. [Huybrechts05] \D. Huybrechts : *Complex Geometry*,
-   Springer (Berlin) (2005).
+- [Lee2011]_
+- [Lee2013]_
+- [KN1963]_
+- [Huy2005]_
+
 """
 
 #*****************************************************************************
@@ -876,7 +873,7 @@ class TopologicalManifold(ManifoldSubset):
             sd._subsets.add(resu)
         self._top_subsets.add(resu)
         # Charts on the result from the coordinate definition:
-        for chart, restrictions in coord_def.iteritems():
+        for chart, restrictions in coord_def.items():
             if chart not in self._atlas:
                 raise ValueError("the {} does not belong to ".format(chart) +
                                  "the atlas of {}".format(self))
@@ -2246,7 +2243,7 @@ def Manifold(dim, name, latex_name=None, field='real', structure='smooth',
         +Infinity
 
     Actually, since ``'smooth'`` is the default value of the parameter
-    ``structure``, the creation of a real smooth manifold can be shorten to::
+    ``structure``, the creation of a real smooth manifold can be shortened to::
 
         sage: M = Manifold(3, 'M'); M
         3-dimensional differentiable manifold M
