@@ -462,7 +462,7 @@ class OperationTable(SageObject):
           strings and the actual elements.  So the keys are the strings and
           the values are the elements of the structure.
 
-        EXAMPLE:
+        EXAMPLES:
         This routine is tested extensively in the :class:`OperationTable`
         and :meth:`change_names` methods.  So we just just demonstrate
         the nature of the output here. ::
@@ -559,7 +559,7 @@ class OperationTable(SageObject):
         This uses the table as a look-up device.  If you want to use
         the operation, then use the operation.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.matrix.operation_table import OperationTable
             sage: G=DiCyclicGroup(3)
@@ -648,7 +648,7 @@ class OperationTable(SageObject):
         r"""
         Returns a printable version of the operation table.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.matrix.operation_table import OperationTable
             sage: R=Integers(5)
@@ -674,7 +674,7 @@ class OperationTable(SageObject):
         - ``latex`` - a string to represent an operation in LaTeX math mode.
           Note the need for double-backslashes to escape properly.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.matrix.operation_table import OperationTable
             sage: G=AlternatingGroup(3)
@@ -776,7 +776,7 @@ class OperationTable(SageObject):
         to the order of the elements in the headings of the table
         and the order of the output of the :meth:`list` method.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.matrix.operation_table import OperationTable
             sage: C=CyclicPermutationGroup(3)
@@ -916,7 +916,7 @@ class OperationTable(SageObject):
         r"""
         Returns a string that is an ASCII version of the table.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.matrix.operation_table import OperationTable
             sage: R=Integers(5)
@@ -1008,7 +1008,7 @@ class OperationTable(SageObject):
         Returns a `LaTeX` version of the operation table as a string,
         using a `LaTeX` ``array`` environment.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.matrix.operation_table import OperationTable
             sage: R=Integers(2)
