@@ -14,16 +14,16 @@ AUTHORS:
 #
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
+from six.moves import builtins
+from six import iteritems
 
 import os
 import sys
 import platform
-from six.moves import builtins
 
-from sage.env import SAGE_LOCAL, SAGE_SRC, SAGE_LIB, UNAME
+
+from sage.env import SAGE_LOCAL, SAGE_SRC
 from .misc import SPYX_TMP
 from .temporary_file import tmp_filename
 import pkgconfig
@@ -309,8 +309,7 @@ def cython(filename, verbose=False, compile_message=False,
 
         sage: code = [
         ....: "#clang C++",
-        ....: "#cinclude %s/include/singular %s/include/factory"%(SAGE_LOCAL, SAGE_LOCAL),
-        ....: "#clib m readline singular givaro ntl gmpxx gmp",
+        ....: "#clib m readline Singular givaro ntl gmpxx gmp",
         ....: "from sage.rings.polynomial.multi_polynomial_libsingular cimport MPolynomial_libsingular",
         ....: "from sage.libs.singular.polynomial cimport singular_polynomial_pow",
         ....: "def test(MPolynomial_libsingular p):",
@@ -709,7 +708,7 @@ def cython_import_all(filename, globals, verbose=False, compile_message=False,
     m = cython_import(filename, verbose=verbose, compile_message=compile_message,
                      use_cache=use_cache,
                      create_local_c_file=create_local_c_file)
-    for k, x in m.__dict__.iteritems():
+    for k, x in iteritems(m.__dict__):
         if k[0] != '_':
             globals[k] = x
 
@@ -767,7 +766,6 @@ def compile_and_load(code):
 TESTS = {
 'trac11680':"""
 #cargs -O3 -ggdb
-#cinclude $SAGE_SRC/sage/libs/flint $SAGE_LOCAL/include/flint
 #clib flint
 
 from sage.rings.rational cimport Rational
