@@ -303,7 +303,7 @@ def eta(x):
 
     The `\eta` function is
 
-    .. math::
+    .. MATH::
 
                     \eta(z) = e^{\pi i z / 12} \prod_{n=1}^{\infty}(1-e^{2\pi inz})
 
@@ -420,6 +420,8 @@ def symbolic_sum(expression, *args, **kwds):
 
       - ``'giac'`` - (optional) use Giac
 
+      - ``'sympy'`` - use SymPy
+
     EXAMPLES::
 
         sage: k, n = var('k,n')
