@@ -71,10 +71,8 @@ from warnings import warn
 import os
 import stat
 import sys
-import signal
 import time
 import resource
-import math
 import sage.misc.prandom as random
 from .lazy_string import lazy_string
 
@@ -199,6 +197,8 @@ except KeyError:
 # uses the GMP library
 #################################################################
 def to_gmp_hex(n):
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "to_gmp_hex() is deprecated")
     return hex(n).replace("L","").replace("0x","")
 
 #################################################################
@@ -304,7 +304,7 @@ class GlobalCputime:
 
     - Martin Albrecht - (2008-12): initial version
 
-    EXAMPLE:
+    EXAMPLES:
 
     Objects of this type are returned if ``subprocesses=True`` is
     passed to :func:`cputime`::
@@ -329,7 +329,7 @@ class GlobalCputime:
         sage: float(t) #output somewhat random
         2.1088339999999999
 
-    .. seealso::
+    .. SEEALSO::
 
       :func:`cputime`
     """
@@ -338,7 +338,7 @@ class GlobalCputime:
         Create a new CPU time object which also keeps track of
         subprocesses.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.misc.misc import GlobalCputime
             sage: ct = GlobalCputime(0.0); ct
@@ -350,7 +350,7 @@ class GlobalCputime:
 
     def __repr__(self):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: cputime(subprocesses=True) # indirect doctest, output random
             0.2347431
@@ -359,7 +359,7 @@ class GlobalCputime:
 
     def __add__(self, other):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = cputime(subprocesses=True)
             sage: P = PolynomialRing(QQ,7,'x')
@@ -375,7 +375,7 @@ class GlobalCputime:
 
     def __sub__(self, other):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = cputime(subprocesses=True)
             sage: P = PolynomialRing(QQ,7,'x')
@@ -391,7 +391,7 @@ class GlobalCputime:
 
     def __float__(self):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = cputime(subprocesses=True)
             sage: float(t) #output somewhat random
@@ -424,10 +424,6 @@ def walltime(t=0):
     """
     return time.time() - t
 
-#def clock(cmd):
-#    t=cputime()
-#    eval(compile(cmd,"clock",'single'))
-#    return cputime(t)
 
 #################################################################
 # simple verbosity system
@@ -460,7 +456,7 @@ def verbose(mesg="", t=0, level=1, caller_name=None):
     OUTPUT: possibly prints a message to stdout; also returns
     cputime()
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: set_verbose(1)
         sage: t = cputime()
@@ -503,10 +499,11 @@ def verbose(mesg="", t=0, level=1, caller_name=None):
         s = s + " (time = %s)"%cputime(t)
     print(s)
     sys.stdout.flush()
-    #open(LOGFILE,"a").write(s+"\n")
     return cputime()
 
 def todo(mesg=""):
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "todo() is deprecated")
     caller_name = sys._getframe(1).f_code.co_name
     raise NotImplementedError("{}: todo -- {}".format(caller_name, mesg))
 
@@ -597,6 +594,8 @@ def generic_cmp(x,y):
     This is similar to x.__cmp__(y), but works even in some cases
     when a .__cmp__ method isn't defined.
     """
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "generic_cmp() is deprecated")
     if x<y:
         return -1
     elif x==y:
@@ -891,6 +890,8 @@ def assert_attribute(x, attr, init=None):
     If the object x has the attribute attr, do nothing. If not, set
     x.attr to init.
     """
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "assert_attribute() is deprecated")
     if attr in x.__dict__: return
     if attr[:2] == "__":
         z = str(x.__class__).split("'")
@@ -906,7 +907,7 @@ def compose(f, g):
     """
     Return the composition of one-variable functions: `f \circ g`
 
-    See also :func:`self_compose()` and :func:`nest()`
+    See also :func:`nest()`
 
     INPUT:
         - `f` -- a function of one variable
@@ -957,6 +958,8 @@ def self_compose(f, n):
 
         sage: def f(x): return x^2 + 1
         sage: g = self_compose(f, 3)
+        doctest:... DeprecationWarning: self_compose() is deprecated, use nest() instead
+        See http://trac.sagemath.org/21926 for details.
         sage: x = var('x')
         sage: g(x)
         ((x^2 + 1)^2 + 1)^2 + 1
@@ -975,9 +978,11 @@ def self_compose(f, n):
         x
 
     """
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "self_compose() is deprecated, use nest() instead")
     from sage.rings.all import Integer
+    n = Integer(n)
 
-    typecheck(n, (int, long, Integer), 'n')
     if n < 0:
         raise ValueError("n must be a nonnegative integer, not {}.".format(n))
 
@@ -1021,8 +1026,8 @@ def nest(f, n, x):
 
     """
     from sage.rings.all import Integer
+    n = Integer(n)
 
-    typecheck(n, (int, long, Integer), 'n')
     if n < 0:
         raise ValueError("n must be a nonnegative integer, not {}.".format(n))
 
@@ -1112,11 +1117,11 @@ def is_iterator(it):
         True
 
         sage: class wrong():
-        ...      def __init__(self): self.n = 5
-        ...      def next(self):
-        ...          self.n -= 1
-        ...          if self.n == 0: raise StopIteration
-        ...          return self.n
+        ....:    def __init__(self): self.n = 5
+        ....:    def next(self):
+        ....:        self.n -= 1
+        ....:        if self.n == 0: raise StopIteration
+        ....:        return self.n
         sage: x = wrong()
         sage: is_iterator(x)
         False
@@ -1126,7 +1131,7 @@ def is_iterator(it):
         TypeError: iteration over non-sequence
 
         sage: class good(wrong):
-        ...      def __iter__(self): return self
+        ....:    def __iter__(self): return self
         sage: x = good()
         sage: is_iterator(x)
         True
@@ -1274,6 +1279,8 @@ def typecheck(x, C, var="x"):
     Check that x is of instance C. If not raise a TypeError with an
     error message.
     """
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "typecheck is deprecated, use isinstance instead")
     if not isinstance(x, C):
         raise TypeError("{} (={}) must be of type {}.".format(var, x, C))
 
@@ -1287,6 +1294,8 @@ class cached_attribute(object):
     Computes attribute value and caches it in the instance.
     """
     def __init__(self, method, name=None):
+        from sage.misc.superseded import deprecation
+        deprecation(21926, "cached_attribute is deprecated")
         # record the unbound-method and the name
         self.method = method
         self.name = name or method.__name__
@@ -1301,6 +1310,8 @@ class cached_attribute(object):
 
 class lazy_prop(object):
     def __init__(self, calculate_function):
+        from sage.misc.superseded import deprecation
+        deprecation(21926, "lazy_prop is deprecated")
         self._calculate = calculate_function
         self.__doc__ = calculate_function.__doc__
 
@@ -1312,6 +1323,8 @@ class lazy_prop(object):
         return value
 
 def prop(f):
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "prop() is deprecated")
     return property(f, None, None, f.__doc__)
 
 
@@ -1434,6 +1447,8 @@ def sourcefile(object):
     """
     Work out which source or compiled file an object was defined in.
     """
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "sourcefile(x) is deprecated, use inspect.getfile(x) instead")
     return inspect.getfile(object)
 
 
@@ -1500,8 +1515,12 @@ def getitem(v, n):
     ::
 
         sage: getitem(v, ZZ(1))
+        doctest:... DeprecationWarning: getitem(v, n) is deprecated, use v[n] instead
+        See http://trac.sagemath.org/21926 for details.
         2
     """
+    from sage.misc.superseded import deprecation
+    deprecation(21926, "getitem(v, n) is deprecated, use v[n] instead")
     try:
         return v[n]
     except TypeError:
@@ -1643,7 +1662,7 @@ class AttrCallObject(object):
             sage: hash(x)       # random # indirect doctest
             210434060
             sage: type(hash(x))
-            <type 'int'>
+            <... 'int'>
             sage: y = attrcall('core', 3, blah = 1, flatten = True)
             sage: hash(y) == hash(x)
             True
