@@ -343,7 +343,7 @@ class Gamma0_class(GammaH_class):
         based on Todd-Coxeter enumeration will be used. This tends to return
         far larger sets of generators.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: Gamma0(3).generators()
             [
@@ -494,7 +494,7 @@ class Gamma0_class(GammaH_class):
         0 if `N` is divisible by 4 or any prime congruent to -1 mod 4, and
         otherwise `2^d` where d is the number of odd primes dividing `N`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: Gamma0(2).nu2()
             1
@@ -519,7 +519,7 @@ class Gamma0_class(GammaH_class):
         0 if `N` is divisible by 9 or any prime congruent to -1 mod 3, and
         otherwise `2^d` where d is the number of primes other than 3 dividing `N`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: Gamma0(2).nu3()
             0
@@ -545,7 +545,7 @@ class Gamma0_class(GammaH_class):
 
         This is given by
 
-        .. math::
+        .. MATH::
 
             N \prod_{\substack{p \mid N \\ \text{$p$ prime}}}\left(1 + \frac{1}{p}\right).
 
