@@ -85,6 +85,8 @@ List representatives for Gamma_0(N) - equivalence classes of cusps:
 
 from sage.structure.parent_base import ParentWithBase
 from sage.structure.element import Element, is_InfinityElement
+from sage.structure.sage_object import richcmp, rich_to_bool
+
 from sage.misc.cachefunc import cached_method
 from sage.misc.superseded import deprecated_function_alias
 
@@ -92,6 +94,7 @@ _nfcusps_cache = {}
 
 _list_reprs_cache = {}
 
+
 def NFCusps_clear_list_reprs_cache():
     """
     Clear the global cache of lists of representatives for ideal classes.
@@ -142,19 +145,17 @@ def list_of_representatives(N):
         sage: N = k.ideal(713, a + 208)
         sage: L = list_of_representatives(N); L
         (Fractional ideal (1),
-        Fractional ideal (37, a + 12),
-        Fractional ideal (47, a - 9))
+         Fractional ideal (47, a - 9),
+         Fractional ideal (53, a - 16))
 
-    The output of ``list_of_representatives`` has been cached:
-
-    ::
+    The output of ``list_of_representatives`` has been cached::
 
         sage: sage.modular.cusps_nf._list_reprs_cache.keys()
         [Fractional ideal (713, a + 208)]
         sage: sage.modular.cusps_nf._list_reprs_cache[N]
         (Fractional ideal (1),
-        Fractional ideal (37, a + 12),
-        Fractional ideal (47, a - 9))
+         Fractional ideal (47, a - 9),
+         Fractional ideal (53, a - 16))
     """
     if N in _list_reprs_cache:
         lreps = _list_reprs_cache[N]
@@ -314,7 +315,7 @@ class NFCuspsSpace(ParentWithBase):
             Set of all cusps of Number Field in a with defining polynomial x^2 + 2
 
         """
-        return "Set of all cusps of %s" %(self.number_field())
+        return "Set of all cusps of %s" % self.number_field()
 
     def _latex_(self):
         """
@@ -327,7 +328,7 @@ class NFCuspsSpace(ParentWithBase):
             sage: latex(kCusps) # indirect doctest
             \mathbf{P}^1(\Bold{Q}[a]/(a^{2} + 5))
         """
-        return "\\mathbf{P}^1(%s)" %(self.number_field()._latex_())
+        return "\\mathbf{P}^1(%s)" % self.number_field()._latex_()
 
     def __call__(self, x):
         """
@@ -364,7 +365,7 @@ class NFCuspsSpace(ParentWithBase):
         It is not intended that the returned cusp is an additive
         neutral element.
 
-        EXAMPLE::
+        EXAMPLES::
 
              sage: k.<a> = NumberField(x^2 + 5)
              sage: kCusps = NFCusps(k)
@@ -516,8 +517,8 @@ class NFCusp(Element):
         R = number_field.maximal_order()
         if b is None:
             if not a:#that is cusp "0"
-                self.__a = R(0)
-                self.__b = R(1)
+                self.__a = R.zero()
+                self.__b = R.one()
                 return
             if isinstance(a, NFCusp):
                 if a.parent() == parent:
@@ -527,23 +528,23 @@ class NFCusp(Element):
                     raise ValueError("Cannot coerce cusps from one field to another")
             elif a in R:
                 self.__a = R(a)
-                self.__b = R(1)
+                self.__b = R.one()
             elif a in number_field:
                 self.__b = R(a.denominator())
                 self.__a = R(a * self.__b)
             elif is_InfinityElement(a):
-                self.__a = R(1)
-                self.__b = R(0)
+                self.__a = R.one()
+                self.__b = R.zero()
             elif isinstance(a, (int, long)):
                 self.__a = R(a)
-                self.__b = R(1)
+                self.__b = R.one()
             elif isinstance(a, (tuple, list)):
                 if len(a) != 2:
                     raise TypeError("unable to convert %r to a cusp \
                                       of the number field"%a)
                 if a[1].is_zero():
-                    self.__a = R(1)
-                    self.__b = R(0)
+                    self.__a = R.one()
+                    self.__b = R.zero()
                 elif a[0] in R and a[1] in R:
                     self.__a = R(a[0])
                     self.__b = R(a[1])
@@ -575,20 +576,20 @@ class NFCusp(Element):
             if is_InfinityElement(b):
                 if is_InfinityElement(a) or (isinstance(a, NFCusp) and a.is_infinity()):
                     raise TypeError("unable to convert (%r, %r) \
-                                      to a cusp of the number field"%(a, b))
-                self.__a = R(0)
-                self.__b = R(1)
+                                      to a cusp of the number field" % (a, b))
+                self.__a = R.zero()
+                self.__b = R.one()
                 return
             elif not b:
                 if not a:
                      raise TypeError("unable to convert (%r, %r) \
-                                       to a cusp of the number field"%(a, b))
-                self.__a = R(1)
-                self.__b = R(0)
+                                       to a cusp of the number field" % (a, b))
+                self.__a = R.one()
+                self.__b = R.zero()
                 return
             if not a:
-                self.__a = R(0)
-                self.__b = R(1)
+                self.__a = R.zero()
+                self.__b = R.one()
                 return
             if (b in R or isinstance(b, (int, long))) and (a in R or isinstance(a, (int, long))):
                 self.__a = R(a)
@@ -597,13 +598,13 @@ class NFCusp(Element):
                 if a in R or a in number_field:
                     r = a / b
                 elif is_InfinityElement(a):
-                    self.__a = R(1)
-                    self.__b = R(0)
+                    self.__a = R.one()
+                    self.__b = R.zero()
                     return
                 elif isinstance(a, NFCusp):
                     if a.is_infinity():
-                        self.__a = R(1)
-                        self.__b = R(0)
+                        self.__a = R.one()
+                        self.__b = R.zero()
                         return
                     r = a.__a / (a.__b * b)
                 elif isinstance(a, (int, long)):
@@ -611,14 +612,14 @@ class NFCusp(Element):
                 elif isinstance(a, (tuple, list)):
                     if len(a) != 2:
                         raise TypeError("unable to convert (%r, %r) \
-                                          to a cusp of the number field"%(a, b))
+                                          to a cusp of the number field" % (a, b))
                     r = R(a[0]) / (R(a[1]) * b)
                 else:
                     try:
                         r = number_field(a) / b
                     except (ValueError, TypeError):
                         raise TypeError("unable to convert (%r, %r) \
-                                          to a cusp of the number field"%(a, b))
+                                          to a cusp of the number field" % (a, b))
                 self.__b = R(r.denominator())
                 self.__a = R(r * self.__b)
         if not lreps is None:
@@ -650,10 +651,10 @@ class NFCusp(Element):
             Cusp [a: 2] of Number Field in a with defining polynomial x^2 + 1
         """
         if self.__b.is_zero():
-            return "Cusp Infinity of %s"%self.parent().number_field()
+            return "Cusp Infinity of %s" % self.parent().number_field()
         else:
-            return "Cusp [%s: %s] of %s"%(self.__a, self.__b, \
-                                          self.parent().number_field())
+            return "Cusp [%s: %s] of %s" % (self.__a, self.__b,
+                                            self.parent().number_field())
 
 
     def number_field(self):
@@ -736,8 +737,8 @@ class NFCusp(Element):
             -1/3*a + 1/3
         """
         if self.__b.is_zero():
-            raise TypeError("%s is not an element of %s"%(self, \
-                                                          self.number_field()))
+            raise TypeError("%s is not an element of %s" % (self,
+                                                            self.number_field()))
         k = self.number_field()
         return k(self.__a / self.__b)
 
@@ -759,7 +760,7 @@ class NFCusp(Element):
         if self.__b.is_one():
             return self.__a
         if self.__b.is_zero():
-            raise TypeError("%s is not an element of %s"%(self, \
+            raise TypeError("%s is not an element of %s" % (self,
                                          self.number_field.ring_of_integers()))
         R = self.number_field().ring_of_integers()
         try:
@@ -784,14 +785,15 @@ class NFCusp(Element):
         if self.__b.is_zero():
             return "\\infty"
         else:
-            return "\\[%s: %s\\]"%(self.__a._latex_(), \
-                                   self.__b._latex_())
+            return "\\[%s: %s\\]" % (self.__a._latex_(),
+                                     self.__b._latex_())
 
-    def __cmp__(self, right):
+    def _richcmp_(self, right, op):
         """
-        Compare the cusps self and right.  Comparison is as for elements in
-        the number field, except with the cusp oo which is greater than
-        everything but itself.
+        Compare the cusps ``self`` and ``right``.
+
+        Comparison is as for elements in the number field, except with
+        the cusp oo which is greater than everything but itself.
 
         The ordering in comparison is only really meaningful for infinity.
 
@@ -817,17 +819,16 @@ class NFCusp(Element):
             False
         """
         if self.__b.is_zero():
-            # self is oo, which is bigger than everything but oo.
             if right.__b.is_zero():
-                return 0
+                return rich_to_bool(op, 0)
             else:
-                return 1
-        elif right.__b.is_zero():
-            if self.__b.is_zero():
-                return 0
+                return rich_to_bool(op, 1)
+        else:
+            if right.__b.is_zero():
+                return rich_to_bool(op, -1)
             else:
-                return -1
-        return cmp(self._number_field_element_(), right._number_field_element_())
+                return richcmp(self._number_field_element_(),
+                               right._number_field_element_(), op)
 
     def __neg__(self):
         """
@@ -1255,9 +1256,9 @@ def NFCusps_ideal_reps_for_levelN(N, nlists=1):
         sage: from sage.modular.cusps_nf import NFCusps_ideal_reps_for_levelN
         sage: NFCusps_ideal_reps_for_levelN(N)
         [(Fractional ideal (1),
-          Fractional ideal (13, a - 2),
-          Fractional ideal (43, a - 1),
-          Fractional ideal (67, a + 17))]
+          Fractional ideal (67, a + 17),
+          Fractional ideal (127, a + 48),
+          Fractional ideal (157, a - 19))]
         sage: L = NFCusps_ideal_reps_for_levelN(N, 5)
         sage: all([len(L[i])==k.class_number() for i in range(len(L))])
         True
@@ -1337,4 +1338,4 @@ def units_mod_ideal(I):
     from sage.misc.mrange import xmrange
     from sage.misc.all import prod
 
-    return [prod([u**e for u,e in zip(ulist,ei)],k(1)) for ei in xmrange(elist)]
+    return [k.prod(u**e for u, e in zip(ulist, ei)) for ei in xmrange(elist)]
