@@ -4,7 +4,7 @@ Dirichlet characters
 
 A :class:`DirichletCharacter` is the extension of a homomorphism
 
-.. math::
+.. MATH::
 
     (\ZZ/N\ZZ)^* \to R^*,
 
@@ -80,15 +80,17 @@ from sage.structure.gens_py                 import multiplicative_iterator
 from sage.structure.parent                  import Parent
 from sage.structure.sequence                import Sequence
 from sage.structure.factory                 import UniqueFactory
+from sage.structure.sage_object import richcmp
 from sage.arith.all import (binomial, bernoulli, kronecker, factor, gcd,
         lcm, fundamental_discriminant, euler_phi, factorial, valuation)
 
+
 def trivial_character(N, base_ring=rings.RationalField()):
     r"""
     Return the trivial character of the given modulus, with values in the given
     base ring.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: t = trivial_character(7)
         sage: [t(x) for x in [0..20]]
@@ -104,7 +106,7 @@ TrivialCharacter = trivial_character
 
 def kronecker_character(d):
     """
-    Returns the quadratic Dirichlet character (d/.) of minimal
+    Return the quadratic Dirichlet character (d/.) of minimal
     conductor.
 
     EXAMPLES::
@@ -134,7 +136,7 @@ def kronecker_character(d):
 
 def kronecker_character_upside_down(d):
     """
-    Returns the quadratic Dirichlet character (./d) of conductor d, for
+    Return the quadratic Dirichlet character (./d) of conductor d, for
     d0.
 
     EXAMPLES::
@@ -347,7 +349,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
           base ring of ``self``, or a ring homomorphism with the base
           ring of ``self`` as its domain
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: e = DirichletGroup(7, QQ).0
             sage: f = e.change_ring(QuadraticField(3, 'a'))
@@ -379,7 +381,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
         G = self.parent().change_ring(R)
         return G.element_class(G, [R(x) for x in self.values_on_gens()])
 
-    def _cmp_(self, other):
+    def _richcmp_(self, other, op):
         """
         Compare ``self`` to ``other``.
 
@@ -403,9 +405,8 @@ class DirichletCharacter(MultiplicativeGroupElement):
             sage: k = DirichletGroup(7)([-1])
             sage: k == e
             False
-
         """
-        return cmp(self.values_on_gens(), other.values_on_gens())
+        return richcmp(self.values_on_gens(), other.values_on_gens(), op)
 
     def __hash__(self):
         """
@@ -470,7 +471,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
         """
         Return a (shallow) copy of this Dirichlet character.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: G.<a> = DirichletGroup(11)
             sage: b = copy(a)
@@ -629,9 +630,9 @@ class DirichletCharacter(MultiplicativeGroupElement):
         of modulus `N`.  This function returns the generalized
         Bernoulli number `B_{k,\varepsilon}`, as defined by the
         following identity of power series (see for example
-        [Diamond-Im]_, Section 2.2):
+        [DI1995]_, Section 2.2):
 
-        .. math::
+        .. MATH::
 
             \sum_{a=1}^N \frac{\varepsilon(a) t e^{at}}{e^{Nt}-1}
             = sum_{k=0}^{\infty} \frac{B_{k,\varepsilon}}{k!} t^k.
@@ -640,7 +641,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
 
         The ``'recurrence'`` algorithm computes generalized Bernoulli
         numbers via classical Bernoulli numbers using the formula in
-        [Cohen-II]_, Proposition 9.4.5; this is usually optimal.  The
+        [Coh2007]_, Proposition 9.4.5; this is usually optimal.  The
         ``definition`` algorithm uses the definition directly.
 
         .. WARNING::
@@ -651,19 +652,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
             the value `B_1 = -1/2` for the classical Bernoulli number.
             Some authors use an alternative definition giving
             `B_{1,\varepsilon} = -1/2`; see the discussion in
-            [Cohen-II]_, Section 9.4.1.
-
-        REFERENCES:
-
-        .. [Cohen-II] \H. Cohen, Number Theory and Diophantine
-           Equations, Volume II.  Graduate Texts in Mathematics 240.
-           Springer, 2007.
-
-        .. [Diamond-Im] \F. Diamond and J. Im, Modular forms and
-           modular curves.  In: V. Kumar Murty (ed.), Seminar on
-           Fermat's Last Theorem (Toronto, 1993-1994), 39-133.  CMS
-           Conference Proceedings 17.  American Mathematical Society,
-           1995.
+            [Coh2007]_, Section 9.4.1.
 
         EXAMPLES::
 
@@ -794,7 +783,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
             sage: d[0]*d[1] == c
             Traceback (most recent call last):
             ...
-            TypeError: unsupported operand parent(s) for '*': 'Group of Dirichlet characters modulo 4 with values in Cyclotomic Field of order 4 and degree 2' and 'Group of Dirichlet characters modulo 5 with values in Cyclotomic Field of order 4 and degree 2'
+            TypeError: unsupported operand parent(s) for *: 'Group of Dirichlet characters modulo 4 with values in Cyclotomic Field of order 4 and degree 2' and 'Group of Dirichlet characters modulo 5 with values in Cyclotomic Field of order 4 and degree 2'
 
         We can multiply if we're explicit about where we want the
         multiplication to take place.
@@ -907,7 +896,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
 
         The Gauss sum associated to `\chi` is
 
-        .. math::
+        .. MATH::
 
             g_a(\chi) = \sum_{r \in \ZZ/m\ZZ} \chi(r)\,\zeta^{ar},
 
@@ -992,7 +981,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
 
         The Gauss sum associated to `\chi` is
 
-        .. math::
+        .. MATH::
 
             g_a(\chi) = \sum_{r \in \ZZ/m\ZZ} \chi(r)\,\zeta^{ar},
 
@@ -1061,7 +1050,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
         Return the Jacobi sum associated to these Dirichlet characters
         (i.e., J(self,char)). This is defined as
 
-        .. math::
+        .. MATH::
 
             J(\chi, \psi) = \sum_{a \in \ZZ / N\ZZ} \chi(a) \psi(1-a)
 
@@ -1168,7 +1157,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
 
         The Kloosterman sum associated to `\chi` and the integers a,b is
 
-        .. math::
+        .. MATH::
 
             K(a,b,\chi) = \sum_{r \in (\ZZ/m\ZZ)^\times} \chi(r)\,\zeta^{ar+br^{-1}},
 
@@ -1409,14 +1398,14 @@ class DirichletCharacter(MultiplicativeGroupElement):
         r"""
         Let
 
-        .. math::
+        .. MATH::
 
            \varepsilon : (\ZZ/N\ZZ)^* \to \QQ(\zeta_n)
 
         be a Dirichlet character. This function returns an equal Dirichlet
         character
 
-        .. math::
+        .. MATH::
 
            \chi : (\ZZ/N\ZZ)^* \to \QQ(\zeta_m)
 
@@ -1478,7 +1467,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
             sage: eps = f.character()
             sage: eps.minimize_base_ring() == eps
             True
-        
+
         A related bug (see :trac:`18086`)::
 
             sage: K.<a,b>=NumberField([x^2 + 1, x^2 - 3])
@@ -1524,7 +1513,7 @@ class DirichletCharacter(MultiplicativeGroupElement):
         """
         Synonym for modulus.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: e = DirichletGroup(100, QQ).0
             sage: e.level()
@@ -2682,7 +2671,7 @@ class DirichletGroup_class(WithEqualityById, Parent):
              Dirichlet character modulo 5 of conductor 5 mapping 2 |--> -1,
              Dirichlet character modulo 5 of conductor 5 mapping 2 |--> -zeta4]
         """
-        return self._list_from_iterator_cached()
+        return self._list_from_iterator()
 
     def modulus(self):
         """
