@@ -68,7 +68,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         Create a Hecke module. Not intended to be called directly.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: CuspForms(Gamma0(17),2) # indirect doctest
             Cuspidal subspace of dimension 1 of Modular Forms space of dimension 2 for Congruence Subgroup Gamma0(17) of weight 2 over Rational Field
@@ -98,7 +98,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         Ensure that the category is initialized correctly on unpickling.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: loads(dumps(ModularSymbols(11))).category() # indirect doctest
             Category of Hecke modules over Rational Field
@@ -112,7 +112,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         The hash is determined by the base ring and the level.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: MS = sage.modular.hecke.module.HeckeModule_generic(QQ,1)
             sage: hash(MS) == hash((MS.base_ring(), MS.level()))
@@ -125,7 +125,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         Compare self to other. This must be overridden in all subclasses.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularForms(Gamma0(3))
             sage: sage.modular.hecke.module.HeckeModule_generic.__cmp__(M, M)
@@ -142,7 +142,7 @@ class HeckeModule_generic(sage.modules.module.Module):
 
         All derived classes must override either this function or ``self.character()``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularForms(SL2Z, 24)
             sage: M._compute_hecke_matrix_prime_power(3, 3)
@@ -177,7 +177,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         factorising n into prime powers and multiplying together the Hecke
         operators for each of these.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(Gamma0(3), 4)
             sage: M._compute_hecke_matrix_general_product(factor(10))
@@ -199,7 +199,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         Compute the matrix of the Hecke operator `T_n` acting on the dual of self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(Gamma0(3), 4)
             sage: M._compute_dual_hecke_matrix(10)
@@ -212,7 +212,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         Compute the matrix of the Hecke operator `T_n` acting on self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = EisensteinForms(DirichletGroup(3).0, 3)
             sage: M._compute_hecke_matrix(16)
@@ -242,7 +242,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         Derived classes should overload this function, and they will inherit
         the machinery for calculating general Hecke operators.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = EisensteinForms(DirichletGroup(3).0, 3)
             sage: sage.modular.hecke.module.HeckeModule_generic._compute_hecke_matrix_prime(M, 3)
@@ -258,7 +258,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         in cases where this isn't self-evident (i.e. when this is not a space
         with fixed character).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = EisensteinForms(Gamma1(5), 3)
             sage: sage.modular.hecke.module.HeckeModule_generic._compute_diamond_matrix(M, 2)
@@ -321,7 +321,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         The character of this space. As this is an abstract base class, return None.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: sage.modular.hecke.module.HeckeModule_generic(QQ, 10).character() is None
             True
@@ -332,7 +332,7 @@ class HeckeModule_generic(sage.modules.module.Module):
         r"""
         Synonym for rank.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = sage.modular.hecke.module.HeckeModule_generic(QQ, 10).dimension()
             Traceback (most recent call last):
@@ -670,7 +670,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         Return `T_n(e_i)`, where `e_i` is the
         `i`th basis vector of the ambient space.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(Gamma0(3))._hecke_image_of_ith_basis_vector(4, 0)
             7*(1,0)
@@ -684,7 +684,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         r"""
         Return the dot product of self with the eigenvector returned by dual_eigenvector.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(11)[0]
             sage: M._element_eigenvalue(M.0)
@@ -736,7 +736,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         For internal use. If this Hecke module was computed via a decomposition of another
         Hecke module, this method stores the index of this space in that decomposition.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(Gamma0(3))[0].factor_number() # indirect doctest
             0
@@ -747,7 +747,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         r"""
         Synonym for ambient_hecke_module. Return the ambient module associated to this module.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: CuspForms(1, 12).ambient()
             Modular Forms space of dimension 2 for Modular Group SL(2,Z) of weight 12 over Rational Field
@@ -758,7 +758,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         r"""
         Synonym for ambient_hecke_module. Return the ambient module associated to this module.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: CuspForms(1, 12).ambient_module()
             Modular Forms space of dimension 2 for Modular Group SL(2,Z) of weight 12 over Rational Field
@@ -774,7 +774,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         Return the ambient module associated to this module. As this is an
         abstract base class, return NotImplementedError.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: sage.modular.hecke.module.HeckeModule_free_module(QQ, 10, 3).ambient_hecke_module()
             Traceback (most recent call last):
@@ -889,7 +889,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         Return the matrix of the basis vectors of self (as vectors in some
         ambient module)
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: CuspForms(1, 12).basis_matrix()
             [1 0]
@@ -1068,7 +1068,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         The degree of this Hecke module (i.e. the rank of the ambient free
         module)
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: CuspForms(1, 12).degree()
             2
@@ -1120,7 +1120,7 @@ class HeckeModule_free_module(HeckeModule_generic):
               eigenvector for the dual action of Hecke operators on
               functionals.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: SF = ModularSymbols(14).cuspidal_subspace().simple_factors()
             sage: sorted([u.dual_eigenvector() for u in SF])
@@ -1213,7 +1213,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         The matrix of the `n^{th}` Hecke operator acting on the dual
         embedded representation of self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: CuspForms(1, 24).dual_hecke_matrix(5)
             [     79345647584250/2796203 50530996976060416/763363419]
@@ -1367,7 +1367,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         """
         Return a tuple of basis elements of ``self``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(23).gens()
             ((1,0), (1,17), (1,19), (1,20), (1,21))
@@ -1378,7 +1378,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         r"""
         Return the nth basis vector of the space.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(23).gen(1)
             (1,17)
@@ -1390,7 +1390,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         The matrix of the `n^{th}` Hecke operator acting on given
         basis.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: C = CuspForms(1, 16)
             sage: C.hecke_matrix(3)
@@ -1483,7 +1483,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         Returns the `n^{th}` Hecke operator `T_n`. This
         function is a synonym for :meth:`.hecke_operator`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(11,2)
             sage: M.T(3)
@@ -1504,7 +1504,7 @@ class HeckeModule_free_module(HeckeModule_generic):
 
         OUTPUT: a polynomial
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(11,2).hecke_polynomial(3)
             x^3 - 2*x^2 - 7*x - 4
@@ -1517,7 +1517,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         Hecke algebra. Raises NotImplementedError, as this is an abstract base
         class.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: sage.modular.hecke.module.HeckeModule_free_module(QQ, 10, 3).is_simple()
             Traceback (most recent call last):
@@ -1534,7 +1534,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         of several copies of the same simple module is not splittable in this
         sense.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(Gamma0(64)).cuspidal_subspace()
             sage: M.is_splittable()
@@ -1573,7 +1573,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         of several copies of the same simple module is not splittable in this
         sense.
 
-           EXAMPLE::
+           EXAMPLES::
 
             sage: M = ModularSymbols(Gamma0(64)).cuspidal_subspace()
             sage: M.is_splittable_anemic()
@@ -1589,7 +1589,7 @@ class HeckeModule_free_module(HeckeModule_generic):
         r"""
         Number of generators of self (equal to the rank).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularForms(1, 12).ngens()
             2
@@ -1787,7 +1787,7 @@ def _dict_set(v, n, key, val):
     r"""
     Rough-and-ready implementation of a two-layer-deep dictionary.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.modular.hecke.module import _dict_set
         sage: v = {}
