@@ -37,7 +37,7 @@ def example_type_space(example_no = 0):
     Quickly return an example of a type space. Used mainly to speed up
     doctesting.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.modular.local_comp.type_space import example_type_space
         sage: example_type_space()  # takes a while but caches stuff (21s on sage.math, 2012)
@@ -157,7 +157,7 @@ class TypeSpace(SageObject):
 
     def __init__(self, f, p, base_extend=True):
         r"""
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space() # indirect doctest
@@ -184,7 +184,7 @@ class TypeSpace(SageObject):
         r"""
         String representation of self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space()._repr_()
@@ -196,7 +196,7 @@ class TypeSpace(SageObject):
         r"""
         Return the prime `p`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().prime()
@@ -208,7 +208,7 @@ class TypeSpace(SageObject):
         r"""
         The newform of which this is the type space.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().form()
@@ -220,7 +220,7 @@ class TypeSpace(SageObject):
         r"""
         Exponent of `p` dividing the level of the form.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().conductor()
@@ -232,7 +232,7 @@ class TypeSpace(SageObject):
         r"""
         Exponent of `p` dividing the conductor of the character of the form.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().character_conductor()
@@ -245,7 +245,7 @@ class TypeSpace(SageObject):
         Largest integer `u` such that level of `f_\chi` = level of `f` for all
         Dirichlet characters `\chi` modulo `p^u`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().u()
@@ -261,7 +261,7 @@ class TypeSpace(SageObject):
         r"""
         Return the underlying vector space of this type space.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().free_module()
@@ -275,7 +275,7 @@ class TypeSpace(SageObject):
         `f` and its Galois conjugates (as a subspace of the vector space
         returned by :meth:`~free_module`).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: T = example_type_space(); T.eigensymbol_subspace()
@@ -293,7 +293,7 @@ class TypeSpace(SageObject):
         r"""
         The level away from `p`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().tame_level()
@@ -306,7 +306,7 @@ class TypeSpace(SageObject):
         Return a `\Gamma_H` group which is the level of all of the relevant
         twists of `f`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().group()
@@ -335,7 +335,7 @@ class TypeSpace(SageObject):
 
         The result is cached.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space().is_minimal()
@@ -353,7 +353,7 @@ class TypeSpace(SageObject):
 
         An error will be raised if `f` is already minimal.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import TypeSpace, example_type_space
             sage: T = example_type_space(1)
@@ -439,7 +439,7 @@ class TypeSpace(SageObject):
         Calculate the action of the matrix [0, -1; 1, 0] on the type space,
         in the unramified (even level) case.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: T = example_type_space(2)
@@ -472,7 +472,7 @@ class TypeSpace(SageObject):
           converted into an element of the matrix group `{\rm SL}_2(\ZZ / p^u
           \ZZ)`).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: T = example_type_space(2)
@@ -509,7 +509,7 @@ class TypeSpace(SageObject):
 
          For internal use (called by :meth:`~rho`).
 
-         EXAMPLE::
+         EXAMPLES::
 
              sage: from sage.modular.local_comp.type_space import example_type_space
              sage: T = example_type_space(3)
@@ -604,7 +604,7 @@ class TypeSpace(SageObject):
         Calculate and store the data necessary to extend the action of `S(K_0)`
         to `K_0`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: example_type_space(2).rho([2,0,0,1]) # indirect doctest
@@ -629,7 +629,7 @@ class TypeSpace(SageObject):
         r"""
         Calculate the action of the group element `g` on the type space.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: T = example_type_space(2)
@@ -708,7 +708,7 @@ class TypeSpace(SageObject):
         Return the action of [0,-1,p,0], in the ramified (odd p-power level)
         case.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.local_comp.type_space import example_type_space
             sage: T = example_type_space(3)
