@@ -133,7 +133,7 @@ def find_generators(*args):
     replaced by the :meth:`~ModularFormsRing.generators` method of
     ModularFormsRing objects.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.modular.modform.find_generators import find_generators
         sage: find_generators()
@@ -149,7 +149,7 @@ def basis_for_modform_space(*args):
     replaced by the :meth:`~ModularFormsRing.q_expansion_basis` method of
     ModularFormsRing objects.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.modular.modform.find_generators import basis_for_modform_space
         sage: basis_for_modform_space()
@@ -234,7 +234,7 @@ class ModularFormsRing(SageObject):
         r"""
         Return the congruence subgroup for which this is the ring of modular forms.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: R = ModularFormsRing(Gamma1(13))
             sage: R.group() is Gamma1(13)
@@ -246,7 +246,7 @@ class ModularFormsRing(SageObject):
         r"""
         Return the coefficient ring of this modular forms ring.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularFormsRing(Gamma1(13)).base_ring()
             Rational Field
@@ -260,7 +260,7 @@ class ModularFormsRing(SageObject):
         Compare self to other. Rings are equal if and only if their groups and
         base rings are.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularFormsRing(3) == 3
             False
@@ -337,7 +337,7 @@ class ModularFormsRing(SageObject):
         a list of pairs (k, f), where f is the q-expansion to precision
         ``prec`` of a modular form of weight k.
 
-        .. seealso::
+        .. SEEALSO::
 
             :meth:`gen_forms`, which does exactly the same thing, but returns
             Sage modular form objects rather than bare power series, and keeps
@@ -473,7 +473,7 @@ class ModularFormsRing(SageObject):
             :meth:`generators`). If called with non-default values for these
             parameters, caching will be disabled.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: A = ModularFormsRing(Gamma0(11), Zmod(5)).gen_forms(); A
             [1 + 12*q^2 + 12*q^3 + 12*q^4 + 12*q^5 + O(q^6), q - 2*q^2 - q^3 + 2*q^4 + q^5 + O(q^6), q - 9*q^4 - 10*q^5 + O(q^6)]
@@ -504,7 +504,7 @@ class ModularFormsRing(SageObject):
 
         a list of tuples, formatted as with ``start_gens``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: R = ModularFormsRing(Gamma1(4))
             sage: R._find_generators(8, (), 2)
@@ -675,7 +675,7 @@ class ModularFormsRing(SageObject):
         Calculate generators for the ideal of cuspidal forms in this ring, as a
         module over the whole ring.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularFormsRing(Gamma0(3)).cuspidal_ideal_generators(maxweight=12)
             [(6, q - 6*q^2 + 9*q^3 + 4*q^4 + O(q^5), q - 6*q^2 + 9*q^3 + 4*q^4 + 6*q^5 + O(q^6))]
