@@ -931,7 +931,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
         further details. Note that this will not work if ``algorithm=eigen``
         and the sign is 0.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(11, 2, base_ring=GF(4,'a')).cuspidal_submodule()._q_expansion_module(prec=4, algorithm="hecke")
             Vector space of degree 4 and dimension 1 over Finite Field in a of size 2^2
@@ -962,7 +962,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
         def q_eigen_gens(f):
             r""" Temporary function for internal use.
 
-            EXAMPLE::
+            EXAMPLES::
 
                 sage: ModularSymbols(11, 4, base_ring=QuadraticField(-7,'b'),sign=1).cuspidal_submodule()._q_expansion_module(prec=5, algorithm="eigen") # indirect doctest
                 Vector space of degree 5 and dimension 2 over Number Field in b with defining polynomial x^2 + 7
@@ -1001,7 +1001,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
 
         - ``prec`` (integer) - number of q-expansion terms to calculate.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(11, 4).cuspidal_submodule()._q_expansion_module_rational(5)
             Vector space of degree 5 and dimension 2 over Rational Field
@@ -1026,7 +1026,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
             r"""
             Temporary function for internal use.
 
-            EXAMPLE::
+            EXAMPLES::
 
                 sage: ModularSymbols(13, 6).cuspidal_submodule()._q_expansion_module_rational(4) # indirect doctest
                 Vector space of degree 4 and dimension 3 over Rational Field
@@ -1244,7 +1244,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
         Return a basis of eigenforms corresponding to this space, which must be
         new, cuspidal and simple.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(17, 2,sign=1).cuspidal_submodule()._q_expansion_basis_eigen(2, "a")
             [q + O(q^2)]
@@ -1396,7 +1396,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
         r"""
         Alias for ``self.modular_symbols_of_level(level)``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(11, 2).hecke_module_of_level(22)
             Modular Symbols space of dimension 7 for Gamma_0(22) of weight 2 with sign 0 over Rational Field
@@ -1514,7 +1514,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
         Decompose self into subspaces which are eigenspaces for the star
         involution.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(Gamma1(19), 2).cuspidal_submodule().star_decomposition()
             [
@@ -1664,7 +1664,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
         is often (but not always) different from the matrix returned by
         ``self.hecke_matrix``, even if the latter has integral entries.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(6,4)
             sage: M.hecke_matrix(3)
@@ -1785,7 +1785,7 @@ class ModularSymbolsSpace(hecke.HeckeModule_free_module):
 
         OUTPUT: a submodule of self
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(Gamma1(11), 3)._compute_sign_submodule(-1)
             Modular Symbols subspace of dimension 10 of Modular Symbols space of dimension 20 for Gamma_1(11) of weight 3 with sign 0 and over Rational Field
@@ -2379,7 +2379,7 @@ class PeriodMapping(SageObject):
 
         - ``A`` - matrix of the associated period map
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(2, 8).cuspidal_submodule().integral_period_mapping() # indirect doctest
             Integral period mapping associated to Modular Symbols subspace of dimension 2 of Modular Symbols space of dimension 4 for Gamma_0(2) of weight 8 with sign 0 over Rational Field
@@ -2405,7 +2405,7 @@ class PeriodMapping(SageObject):
         r"""
         Evaluate this mapping at an element of the domain.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: M = ModularSymbols(17, 2).cuspidal_submodule().integral_period_mapping()
             sage: M(vector([1,0,2]))
@@ -2421,7 +2421,7 @@ class PeriodMapping(SageObject):
         r"""
         Return the matrix of this period mapping.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(11, 2).cuspidal_submodule().integral_period_mapping().matrix()
             [  0 1/5]
@@ -2435,7 +2435,7 @@ class PeriodMapping(SageObject):
         Return the domain of this mapping (which is the ambient space of the
         corresponding modular symbols space).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: ModularSymbols(17, 2).cuspidal_submodule().integral_period_mapping().domain()
             Modular Symbols space of dimension 3 for Gamma_0(17) of weight 2 with sign 0 over Rational Field
@@ -2446,7 +2446,7 @@ class PeriodMapping(SageObject):
         r"""
         Return the codomain of this mapping.
 
-        EXAMPLE:
+        EXAMPLES:
 
         Note that this presently returns the wrong answer, as a consequence of
         various bugs in the free module routines::
