@@ -51,6 +51,7 @@ from sage.matrix.matrix_space import MatrixSpace
 from sage.misc.abstract_method import abstract_method
 from sage.structure.factory import UniqueFactory
 from sage.structure.element import MonoidElement
+from sage.structure.sage_object import richcmp
 from sage.categories.monoids import Monoids
 from sage.categories.morphism import Morphism
 from sage.structure.parent import Parent
@@ -69,7 +70,7 @@ class Sigma0ActionAdjuster(UniqueRepresentation):
         This is used to allow for other conventions for the action of Sigma0
         on the space of distributions.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import _default_adjuster
             sage: A = _default_adjuster()
@@ -150,7 +151,7 @@ class Sigma0_factory(UniqueFactory):
       a 4-tuple of integers. This is supplied in order to support differing
       conventions for the action of `2 \times 2` matrices on distributions.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
         sage: Sigma0(3)
@@ -159,7 +160,7 @@ class Sigma0_factory(UniqueFactory):
 
     def create_key(self, N, base_ring=ZZ, adjuster=None):
         r"""
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: Sigma0.create_key(3)
@@ -182,7 +183,7 @@ class Sigma0_factory(UniqueFactory):
 
     def create_object(self, version, key):
         r"""
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: Sigma0(3) # indirect doctest
@@ -218,7 +219,7 @@ class Sigma0Element(MonoidElement):
     """
     def __init__(self, parent, mat):
         r"""
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3]) # indirect doctest
@@ -229,7 +230,7 @@ class Sigma0Element(MonoidElement):
 
     def __hash__(self):
         r"""
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3])
@@ -244,7 +245,7 @@ class Sigma0Element(MonoidElement):
         r"""
         Return the determinant of this matrix, which is (by assumption) non-zero.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3])
@@ -257,7 +258,7 @@ class Sigma0Element(MonoidElement):
         r"""
         Return the product of two Sigma0 elements.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3])
@@ -272,11 +273,11 @@ class Sigma0Element(MonoidElement):
         """
         return self.parent()(self._mat * other._mat, check=False)
 
-    def __cmp__(self, other):
+    def _richcmp_(self, other, op):
         r"""
         Compare two elements (of a common Sigma0 object).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3])
@@ -286,18 +287,18 @@ class Sigma0Element(MonoidElement):
             sage: s == Sigma0(1)([1,4,3,3])
             True
 
-        This uses the coercion model to find a common parent, with occasionally surprising results:
+        This uses the coercion model to find a common parent, with occasionally surprising results::
 
             sage: t == Sigma0(5)([4, 0, 0, 1])
             False
         """
-        return cmp(self._mat, other._mat)
+        return richcmp(self._mat, other._mat, op)
 
     def _repr_(self):
         r"""
         String representation of self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3])
@@ -310,7 +311,7 @@ class Sigma0Element(MonoidElement):
         r"""
         Return self as a matrix (forgetting the additional data that it is in Sigma0(N)).
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,3])
@@ -328,7 +329,7 @@ class Sigma0Element(MonoidElement):
         r"""
         Return the inverse of self. This will raise an error if the result is not in the monoid.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: s = Sigma0(3)([1,4,3,13])
@@ -384,11 +385,11 @@ class _Sigma0Embedding(Morphism):
         """
         return x.matrix()
 
-    def _cmp_(self, other):
+    def _richcmp_(self, other, op):
         r"""
         Required for pickling.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0, _Sigma0Embedding
             sage: S = Sigma0(3)
@@ -396,14 +397,14 @@ class _Sigma0Embedding(Morphism):
             sage: x == loads(dumps(x))
             True
         """
-        return cmp(type(self), type(other)) or cmp(self.domain(), other.domain())
+        return richcmp(self.domain(), other.domain(), op)
 
 
 class Sigma0_class(Parent):
     r"""
     The class representing the monoid `\Sigma_0(N)`.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
         sage: S = Sigma0(5); S
@@ -423,7 +424,7 @@ class Sigma0_class(Parent):
         Standard init function. For args documentation see the factory
         function.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: S = Sigma0(3) # indirect doctest
@@ -441,7 +442,7 @@ class Sigma0_class(Parent):
         r"""
         Return an element of self. This is implemented in a rather dumb way.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: S = Sigma0(3)
@@ -455,7 +456,7 @@ class Sigma0_class(Parent):
         r"""
         If this monoid is `\Sigma_0(N)`, return `N`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: S = Sigma0(3)
@@ -468,7 +469,7 @@ class Sigma0_class(Parent):
         r"""
         Return the base ring.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: S = Sigma0(3)
@@ -514,7 +515,7 @@ class Sigma0_class(Parent):
         - ``check`` (boolean, default True) -- if True, then check that this
           matrix actually satisfies the conditions.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: S = Sigma0(3)
@@ -548,7 +549,7 @@ class Sigma0_class(Parent):
         r"""
         String representation of ``self``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.modular.pollack_stevens.sigma0 import Sigma0
             sage: S = Sigma0(3)
