@@ -291,9 +291,9 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
 
             sage: M = ZZ^4
             sage: p = matrix(ZZ, [[ 0, -1,  1, -2],
-            ...                   [ 1, -3,  2, -3],
-            ...                   [ 0,  4, -3,  4],
-            ...                   [-2,  8, -4,  3]])
+            ....:                 [ 1, -3,  2, -3],
+            ....:                 [ 0,  4, -3,  4],
+            ....:                 [-2,  8, -4,  3]])
             sage: phi = M.hom(p, M)
             sage: x = vector(ZZ, [1, -3, 5, -2])
             sage: y = phi(x); y
@@ -1028,24 +1028,24 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         Two are equal, the third is different from both of the others.  ::
 
             sage: B = matrix(QQ, [[-3,  5, -4,  2],
-            ...                   [-1,  2, -1,  4],
-            ...                   [ 4, -6,  5, -1],
-            ...                   [-5,  7, -6,  1]])
+            ....:                 [-1,  2, -1,  4],
+            ....:                 [ 4, -6,  5, -1],
+            ....:                 [-5,  7, -6,  1]])
             sage: U = (QQ^4).subspace_with_basis(B.rows())
             sage: C = matrix(QQ, [[-1, -6, -4],
-            ...                   [ 3, -5,  6],
-            ...                   [ 1,  2,  3]])
+            ....:                 [ 3, -5,  6],
+            ....:                 [ 1,  2,  3]])
             sage: V = (QQ^3).subspace_with_basis(C.rows())
             sage: H = Hom(U, V)
 
             sage: D = matrix(QQ, [[-7, -2, -5,  2],
-            ...                   [-5,  1, -4, -8],
-            ...                   [ 1, -1,  1,  4],
-            ...                   [-4, -1, -3,   1]])
+            ....:                 [-5,  1, -4, -8],
+            ....:                 [ 1, -1,  1,  4],
+            ....:                 [-4, -1, -3,   1]])
             sage: X = (QQ^4).subspace_with_basis(D.rows())
             sage: E = matrix(QQ, [[ 4, -1,  4],
-            ...                   [ 5, -4, -5],
-            ...                   [-1,  0, -2]])
+            ....:                 [ 5, -4, -5],
+            ....:                 [-1,  0, -2]])
             sage: Y = (QQ^3).subspace_with_basis(E.rows())
             sage: K = Hom(X, Y)
 
@@ -1354,7 +1354,7 @@ class MatrixMorphism(MatrixMorphism_abstract):
         """
         Tell whether ``self`` is injective.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: V1 = QQ^2
             sage: V2 = QQ^3
