@@ -21,7 +21,7 @@ from sage.structure.unique_representation import UniqueRepresentation
 from sage.structure.element import MonoidElement
 from sage.structure.indexed_generators import IndexedGenerators
 from sage.structure.sage_object import op_EQ, op_NE, richcmp, rich_to_bool
-from sage.combinat.dict_addition import dict_addition
+import sage.data_structures.blas_dict as blas
 
 from sage.categories.monoids import Monoids
 from sage.categories.poor_man_map import PoorManMap
@@ -31,6 +31,7 @@ from sage.rings.infinity import infinity
 from sage.rings.all import ZZ
 from sage.sets.finite_enumerated_set import FiniteEnumeratedSet
 from sage.sets.family import Family
+from six import iteritems
 
 class IndexedMonoidElement(MonoidElement):
     """
@@ -529,7 +530,7 @@ class IndexedFreeAbelianMonoidElement(IndexedMonoidElement):
             F[0]*F[1]^2*F[3]*F[4]
         """
         return self.__class__(self.parent(),
-                              dict_addition([self._monomial, other._monomial]))
+                              blas.add(self._monomial, other._monomial))
 
     def __pow__(self, n):
         """
@@ -554,7 +555,7 @@ class IndexedFreeAbelianMonoidElement(IndexedMonoidElement):
             return self
         if n == 0:
             return self.parent().one()
-        return self.__class__(self.parent(), {k:v*n for k,v in self._monomial.iteritems()})
+        return self.__class__(self.parent(), {k:v*n for k,v in iteritems(self._monomial)})
 
     def __floordiv__(self, elt):
         """
@@ -578,7 +579,7 @@ class IndexedFreeAbelianMonoidElement(IndexedMonoidElement):
             ValueError: invalid cancellation
         """
         d = copy(self._monomial)
-        for k,v in elt._monomial.iteritems():
+        for k,v in iteritems(elt._monomial):
             d[k] -= v
         for k,v in d.items():
             if v < 0:
@@ -938,9 +939,27 @@ class IndexedFreeAbelianMonoid(IndexedMonoid):
             F[-2]^12*F[1]^3
             sage: F({1:3, -2: 12})
             F[-2]^12*F[1]^3
+
+        TESTS::
+
+            sage: F([(1, 3), (1, 2)])
+            F[1]^5
+
+            sage: F([(42, 0)])
+            1
+            sage: F({42: 0})
+            1
         """
         if isinstance(x, (list, tuple)):
-            x = dict(x)
+            d = dict()
+            for k, v in x:
+                if k in d:
+                    d[k] += v
+                else:
+                    d[k] = v
+            x = d
+        if isinstance(x, dict):
+            x = {k: v for k, v in iteritems(x) if v != 0}
         return IndexedMonoid._element_constructor_(self, x)
 
     Element = IndexedFreeAbelianMonoidElement
