@@ -4,8 +4,7 @@ Plotting Functions
 EXAMPLES::
 
     sage: def f(x,y):
-    ...       return math.sin(y*y+x*x)/math.sqrt(x*x+y*y+.0001)
-    ...
+    ....:     return math.sin(y*y+x*x)/math.sqrt(x*x+y*y+.0001)
     sage: P = plot3d(f,(-3,3),(-3,3), adaptive=True, color=rainbow(60, 'rgbtuple'), max_bend=.1, max_depth=15)
     sage: P.show()
 
@@ -18,7 +17,7 @@ EXAMPLES::
 ::
 
     sage: def f(x,y):
-    ...       return math.exp(x/5)*math.sin(y)
+    ....:     return math.exp(x/5)*math.sin(y)
     ...
     sage: P = plot3d(f,(-5,5),(-5,5), adaptive=True, color=['red','yellow'])
     sage: from sage.plot.plot3d.plot3d import axes
@@ -75,6 +74,10 @@ Or, we plot a very simple function indeed::
     
     sphinx_plot(plot3d(pi, (-1,1), (-1,1)))
     
+.. TODO::
+
+    Add support for smooth triangles.
+
 AUTHORS:
 
 - Tom Boothby: adaptive refinement triangles
@@ -88,10 +91,7 @@ AUTHORS:
 - Oscar Lazo, William Cauchois, Jason Grout (2009-2010): Adding coordinate transformations
 """
 from __future__ import absolute_import
-
-
-#TODO:
-#    -- smooth triangles
+from six import iteritems
 
 #*****************************************************************************
 #      Copyright (C) 2007 Robert Bradshaw <robertwb@math.washington.edu>
@@ -120,6 +120,7 @@ from sage.ext.fast_eval import fast_float_arg
 
 from sage.functions.trig import cos, sin
 
+
 class _Coordinates(object):
     """
     This abstract class encapsulates a new coordinate system for plotting.
@@ -200,7 +201,7 @@ class _Coordinates(object):
          - ``params`` - The parameters of func. Corresponds to the dependent
            variables.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.plot.plot3d.plot3d import _ArbitraryCoordinates
             sage: x, y, z = var('x y z')
@@ -415,7 +416,7 @@ class _ArbitraryCoordinates(_Coordinates):
 
     def transform(self, **kwds):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.plot.plot3d.plot3d import _ArbitraryCoordinates
             sage: x, y, z = var('x y z')
@@ -487,7 +488,7 @@ class Spherical(_Coordinates):
         """
         A spherical coordinates transform.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = Spherical('radius', ['azimuth', 'inclination'])
             sage: T.transform(radius=var('r'), azimuth=var('theta'), inclination=var('phi'))
@@ -600,7 +601,7 @@ class SphericalElevation(_Coordinates):
         """
         A spherical elevation coordinates transform.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = SphericalElevation('radius', ['azimuth', 'elevation'])
             sage: T.transform(radius=var('r'), azimuth=var('theta'), elevation=var('phi'))
@@ -670,7 +671,7 @@ class Cylindrical(_Coordinates):
         """
         A cylindrical coordinates transform.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = Cylindrical('height', ['azimuth', 'radius'])
             sage: T.transform(radius=var('r'), azimuth=var('theta'), height=var('z'))
@@ -965,7 +966,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         sage: E = plot3d(2,(u,-pi,pi),(v,-pi,pi),transformation=parabolic_cylindrical,plot_points=[100,100])
         sage: @interact
         ... def _(which_plot=[A,B,C,D,E]):
-        ...       show(which_plot)
+        ....:     show(which_plot)
         <html>...
 
     Now plot a function::
@@ -978,7 +979,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
         sage: J = plot3d(g,(u,-pi,pi),(v,0,pi),transformation=parabolic_cylindrical,plot_points=[100,100])
         sage: @interact
         ... def _(which_plot=[F, G, H, I, J]):
-        ...       show(which_plot)
+        ....:     show(which_plot)
         <html>...
 
     TESTS:
@@ -1134,19 +1135,20 @@ def plot3d_adaptive(f, x_range, y_range, color="automatic",
                 span = 0
             else:
                 span = (len(texture)-1) / (max_z - min_z)    # max to avoid dividing by 0
-            parts = P.partition(lambda x,y,z: int((z-min_z)*span))
+            parts = P.partition(lambda x, y, z: int((z-min_z)*span))
         all = []
-        for k, G in parts.iteritems():
+        for k, G in iteritems(parts):
             G.set_texture(texture[k], opacity=opacity)
             all.append(G)
         P = Graphics3dGroup(all)
     else:
         P.set_texture(texture)
 
-    P.frame_aspect_ratio([1.0,1.0,0.5])
+    P.frame_aspect_ratio([1.0, 1.0, 0.5])
     P._set_extra_kwds(kwds)
     return P
 
+
 def spherical_plot3d(f, urange, vrange, **kwds):
     """
     Plots a function in spherical coordinates.  This function is
