@@ -140,7 +140,7 @@ class DiscreteRandomVariable(RandomVariable_generic):
         with probability function `p`, and `E(X)` be the
         expectation of `X`. Then the variance of `X` is:
 
-        .. math::
+        .. MATH::
 
            \mathrm{var}(X) = E((X-E(x))^2) = \sum_{x \in S} p(x) (X(x) - E(x))^2
         """
@@ -160,7 +160,7 @@ class DiscreteRandomVariable(RandomVariable_generic):
         with probability function `p`, and `E(X)` be the
         expectation of `X`. Then the variance of `X` is:
 
-        .. math::
+        .. MATH::
 
            \mathrm{var}(X) = E((X-E(x))^2) = \sum_{x \in S} p(x) (X(x) - E(x))^2
         """
@@ -180,9 +180,9 @@ class DiscreteRandomVariable(RandomVariable_generic):
         with probability function `p`, and `E(X)` be the
         expectation of `X`. Then the variance of `X` is:
 
-        .. math::
+        .. MATH::
 
-                     \text{cov}(X,Y) = E((X-E(X)*(Y-E(Y)) = \sum_{x \in S} p(x) (X(x) - E(X))(Y(x) - E(Y))
+                     \text{cov}(X,Y) = E((X-E(X)\cdot (Y-E(Y)) = \sum_{x \in S} p(x) (X(x) - E(X))(Y(x) - E(Y))
         """
         Omega = self.probability_space()
         if Omega != other.probability_space():
@@ -203,9 +203,9 @@ class DiscreteRandomVariable(RandomVariable_generic):
         with probability function `p`, and `E(X)` be the
         expectation of `X`. Then the variance of `X` is:
 
-        .. math::
+        .. MATH::
 
-                     \text{cov}(X,Y) = E((X-E(X)*(Y-E(Y)) = \sum_{x \in S} p(x) (X(x) - E(X))(Y(x) - E(Y))
+                     \text{cov}(X,Y) = E((X-E(X)\cdot (Y-E(Y)) = \sum_{x \in S} p(x) (X(x) - E(X))(Y(x) - E(Y))
         """
         Omega = self.probability_space()
         if Omega != other.probability_space():
@@ -226,9 +226,9 @@ class DiscreteRandomVariable(RandomVariable_generic):
         expectation of `X`. Then the standard deviation of
         `X` is defined to be
 
-        .. math::
+        .. MATH::
 
-                     \sigma(X) = \sqrt{ \sum_{x \in S} p(x) (X(x) - E(x))**2}
+                     \sigma(X) = \sqrt{ \sum_{x \in S} p(x) (X(x) - E(x))^2}
         """
         return sqrt(self.variance())
 
@@ -243,9 +243,9 @@ class DiscreteRandomVariable(RandomVariable_generic):
         expectation of `X`. Then the standard deviation of
         `X` is defined to be
 
-        .. math::
+        .. MATH::
 
-                     \sigma(X) = \sqrt{ \sum_{x \in S} p(x) (X(x) - E(x))**2}
+                     \sigma(X) = \sqrt{ \sum_{x \in S} p(x) (X(x) - E(x))^2}
         """
         return sqrt(self.translation_variance(map))
 
@@ -315,8 +315,8 @@ class DiscreteProbabilitySpace(ProbabilitySpace_generic,DiscreteRandomVariable):
             (0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15)
             sage: X.set()
             {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15}
-            sage: X.entropy()
-            1.999725341796875
+            sage: X.entropy().n()
+            1.99972534179688
 
         A probability space can be defined on any list of elements::
 
@@ -326,8 +326,8 @@ class DiscreteProbabilitySpace(ProbabilitySpace_generic,DiscreteRandomVariable):
             sage: X = DiscreteProbabilitySpace(S,P)
             sage: X
             Discrete probability space defined by {'A': 1/2, 'C': 1/4, 'B': 1/4}
-            sage: X.entropy()
-            1.5
+            sage: X.entropy().n()
+            1.50000000000000
         """
         if codomain is None:
             codomain = RealField()
