@@ -54,6 +54,7 @@ AUTHORS:
 
 """
 from __future__ import print_function
+from six.moves import range
 
 from sage.misc.abstract_method import abstract_method
 from sage.misc.fast_methods import WithEqualityById
@@ -903,7 +904,7 @@ class AlgebraicClosureFiniteField_generic(Field):
             (1, z2, z3)
 
         """
-        return tuple([self.gen(i + 1) for i in xrange(n)])
+        return tuple(self.gen(i + 1) for i in range(n))
 
     def algebraic_closure(self):
         """
@@ -967,7 +968,7 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: ((K.gen(2)*x - K.gen(3))**2).roots(K)
             [(3*t6^5 + 2*t6^4 + 2*t6^2 + 3, 2)]
 
-            sage: for _ in xrange(10):
+            sage: for _ in range(10):
             ....:     p = R.random_element(degree=randint(2,8))
             ....:     for r in p.roots(K, multiplicities=False):
             ....:         assert p(r).is_zero(), "r={} is not a root of p={}".format(r,p)
@@ -1019,7 +1020,7 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: (K.gen(2) * T^2 - 1).factor()
             (z2) * (T + z4^3 + z4^2 + z4) * (T + 2*z4^3 + 2*z4^2 + 2*z4)
 
-            sage: for d in xrange(10):
+            sage: for d in range(10):
             ....:     p = R.random_element(degree=randint(2,8))
             ....:     assert p.factor().prod() == p, "error in the factorization of p={}".format(p)
 
