@@ -97,10 +97,10 @@ Classes and Methods
 from __future__ import print_function
 from __future__ import absolute_import
 
-import sage
+from sage.structure.factory import UniqueFactory
 
 
-class CartesianProductFactory(sage.structure.factory.UniqueFactory):
+class CartesianProductFactory(UniqueFactory):
     r"""
     Create various types of Cartesian products depending on its input.
 
@@ -457,6 +457,9 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             sage: G(n).value
             (1, n, 1)
         """
+        from sage.sets.cartesian_product import CartesianProduct
+        from sage.symbolic.ring import SR
+
         def convert_factors(data, raw_data):
             try:
                 return self._convert_factors_(data)
@@ -484,7 +487,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             if P is self:
                 return data
 
-            elif P is sage.symbolic.ring.SR:
+            elif P is SR:
                 from sage.symbolic.operators import mul_vararg
                 if data.operator() == mul_vararg:
                     return convert_factors(data.operands(), data)
@@ -495,8 +498,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             return super(GenericProduct, self)._element_constructor_(data)
         except (TypeError, ValueError):
             pass
-        if isinstance(data, (tuple, list,
-                             sage.sets.cartesian_product.CartesianProduct.Element)):
+        if isinstance(data, (tuple, list, CartesianProduct.Element)):
             return convert_factors(tuple(data), data)
 
         return convert_factors((data,), data)
@@ -697,6 +699,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
         from .growth_group import GenericGrowthGroup, AbstractGrowthGroupFunctor
         from .misc import merge_overlapping
         from .misc import underlying_class
+        from sage.structure.element import get_coercion_model
 
         Sfactors = self.cartesian_factors()
         if isinstance(other, GenericProduct):
@@ -717,7 +720,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             except ValueError:
                 pass
 
-            cm = sage.structure.element.get_coercion_model()
+            cm = get_coercion_model()
             try:
                 Z = cm.common_parent(*Sfactors+Ofactors)
                 return (Z,), (Z,)
@@ -1130,7 +1133,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
                 ...
                 ArithmeticError: Cannot construct e^x in
                 Growth Group x^ZZ * log(x)^ZZ * log(log(x))^ZZ
-                > *previous* TypeError: unsupported operand parent(s) for '*':
+                > *previous* TypeError: unsupported operand parent(s) for *:
                 'Growth Group x^ZZ * log(x)^ZZ * log(log(x))^ZZ' and
                 'Growth Group (e^x)^ZZ'
 
