@@ -142,7 +142,7 @@ fractions. For them special methods give access to preperiod and period::
 On the following we can remark how the tail may change even in the same
 quadratic field::
 
-    sage: for i in xrange(20): print(continued_fraction(i*sqrt2))
+    sage: for i in range(20): print(continued_fraction(i*sqrt2))
     [0]
     [1; (2)*]
     [2; (1, 4)*]
@@ -255,9 +255,9 @@ def rat_interval_cf_list(r1, r2):
         sage: from sage.rings.continued_fraction import rat_interval_cf_list
         sage: rat_interval_cf_list(257/113, 5224/2297)
         [2, 3, 1, 1, 1, 4]
-        sage: for prec in xrange(10,54):
+        sage: for prec in range(10,54):
         ....:     R = RealIntervalField(20)
-        ....:     for _ in xrange(100):
+        ....:     for _ in range(100):
         ....:         x = R.random_element() * R.random_element() + R.random_element() / 100
         ....:         l = x.lower().exact_rational()
         ....:         u = x.upper().exact_rational()
@@ -350,44 +350,44 @@ class ContinuedFraction_base(SageObject):
         EXAMPLES::
 
             sage: print(continued_fraction(pi).str())
-                                         1                          
+                                         1
             3 + ----------------------------------------------------
-                                            1                       
+                                            1
                  7 + -----------------------------------------------
-                                               1                    
+                                               1
                       15 + -----------------------------------------
-                                                 1                  
+                                                 1
                             1 + ------------------------------------
-                                                     1              
+                                                     1
                                  292 + -----------------------------
-                                                       1            
+                                                       1
                                         1 + ------------------------
-                                                          1         
+                                                          1
                                              1 + -------------------
-                                                            1       
+                                                            1
                                                   1 + --------------
-                                                               1    
+                                                               1
                                                        2 + ---------
-                                                            1 + ... 
+                                                            1 + ...
             sage: print(continued_fraction(pi).str(nterms=1))
             3 + ...
             sage: print(continued_fraction(pi).str(nterms=2))
-                    1    
+                    1
             3 + ---------
-                 7 + ... 
+                 7 + ...
 
             sage: print(continued_fraction(243/354).str())
-                       1           
+                       1
             -----------------------
-                         1         
+                         1
              1 + ------------------
-                            1      
+                            1
                   2 + -------------
-                              1    
+                              1
                        5 + --------
-                                 1 
+                                 1
                             3 + ---
-                                 2 
+                                 2
             sage: continued_fraction(243/354).str(join=False)
             ['           1           ',
              '-----------------------',
@@ -402,17 +402,17 @@ class ContinuedFraction_base(SageObject):
              '                     2 ']
 
             sage: print(continued_fraction(243/354).str(unicode=True))
-                       1           
+                       1
             ───────────────────────
-                         1         
+                         1
              1 + ──────────────────
-                            1      
+                            1
                   2 + ─────────────
-                              1    
+                              1
                        5 + ────────
-                                 1 
+                                 1
                             3 + ───
-                                 2 
+                                 2
         """
         nterms = int(nterms)
         if nterms < 0:
@@ -462,13 +462,13 @@ class ContinuedFraction_base(SageObject):
         EXAMPLES::
 
             sage: ascii_art(continued_fraction(43/30))
-                      1      
+                      1
             1 + -------------
-                        1    
+                        1
                  2 + --------
-                           1 
+                           1
                       3 + ---
-                           4 
+                           4
         """
         from sage.typeset.ascii_art import AsciiArt
         return AsciiArt(self.str(unicode=False, join=False))
@@ -478,17 +478,51 @@ class ContinuedFraction_base(SageObject):
         EXAMPLES::
 
             sage: unicode_art(continued_fraction(43/30))
-                      1      
+                      1
             1 + ─────────────
-                        1    
+                        1
                  2 + ────────
-                           1 
+                           1
                       3 + ───
-                           4 
+                           4
         """
         from sage.typeset.unicode_art import UnicodeArt
         return UnicodeArt(self.str(unicode=True, join=False))
 
+    def _latex_(self, nterms=10):
+        r"""
+        EXAMPLES::
+
+            sage: cf_pi = continued_fraction(pi)
+            sage: latex(cf_pi)
+            3
+            + \frac{\displaystyle 1}{\displaystyle 7
+            + \frac{\displaystyle 1}{\displaystyle 15
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 292
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 2
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle \dots}}}}}}}}}}
+            sage: print cf_pi._latex_(nterms=3)
+            3
+            + \frac{\displaystyle 1}{\displaystyle 7
+            + \frac{\displaystyle 1}{\displaystyle 15
+            + \frac{\displaystyle 1}{\displaystyle \dots}}}
+        """
+        nterms = int(nterms)
+        if nterms <= 0:
+            raise ValueError("nterms must be positive")
+        v=[self.quotient(i) for i in range(nterms+1)]
+        s = str(v[0])+'\n'
+        for i in range(1,min(len(v)-1,nterms)):
+            s += '+ \\frac{\\displaystyle 1}{\\displaystyle %s\n' % v[i]
+        s += '+ \\frac{\\displaystyle 1}{\\displaystyle \dots'
+        s += '}'*(len(v)-1)
+        return s
+
     def __abs__(self):
         """
         Return absolute value of self.
@@ -817,7 +851,9 @@ class ContinuedFraction_base(SageObject):
             sage: a.convergents()
             [0, 1/6, 1/7, 5/34, 6/41, 23/157]
 
-            sage: #TODO: example with infinite list
+        .. TODO::
+
+            Add an example with infinite list.
         """
         if self.length() == Infinity:
             from sage.misc.lazy_list import lazy_list
@@ -829,9 +865,9 @@ class ContinuedFraction_base(SageObject):
         r"""
         Return the list of partial quotients of ``self``.
 
-        If ``self`` is an infinite continued fraction, the the object returned
-        is a :class:`~sage.misc.lazy_list.lazy_list_generic` which behave like an
-        infinite list.
+        If ``self`` is an infinite continued fraction, then the object returned
+        is a :class:`~sage.misc.lazy_list.lazy_list_generic` which behaves
+        like an infinite list.
 
         EXAMPLES::
 
@@ -840,7 +876,9 @@ class ContinuedFraction_base(SageObject):
             sage: a.quotients()
             [0, 6, 1, 4, 1, 3]
 
-            sage: #TODO: example with infinite list
+        .. TODO::
+
+            Add an example with infinite list.
         """
         if self.length() == Infinity:
             from sage.misc.lazy_list import lazy_list
@@ -900,11 +938,11 @@ class ContinuedFraction_base(SageObject):
 
             sage: cf = continued_fraction(pi)
             sage: i = iter(cf)
-            sage: [next(i) for _ in xrange(10)]
+            sage: [next(i) for _ in range(10)]
             [3, 7, 15, 1, 292, 1, 1, 1, 2, 1]
-            sage: [next(i) for _ in xrange(10)]
+            sage: [next(i) for _ in range(10)]
             [3, 1, 14, 2, 1, 1, 2, 2, 2, 2]
-            sage: [next(i) for _ in xrange(10)]
+            sage: [next(i) for _ in range(10)]
             [1, 84, 2, 1, 1, 15, 3, 13, 1, 4]
         """
         yield self.quotient(0)
@@ -986,7 +1024,7 @@ class ContinuedFraction_base(SageObject):
             return self.quotient(0)
         return self.quotient(0)+1
 
-    def __nonzero__(self):
+    def __bool__(self):
         """
         Return False if self is zero.
 
@@ -1003,6 +1041,8 @@ class ContinuedFraction_base(SageObject):
         """
         return bool(self.quotient(0)) or self.quotient(1) is not Infinity
 
+    __nonzero__ = __bool__
+
     def is_zero(self):
         r"""
         Test whether ``self`` is zero.
@@ -1236,7 +1276,7 @@ class ContinuedFraction_periodic(ContinuedFraction_base):
         EXAMPLES::
 
             sage: cf = continued_fraction([(12,5),(1,3)])
-            sage: [cf.quotient(i) for i in xrange(10)]
+            sage: [cf.quotient(i) for i in range(10)]
             [12, 5, 1, 3, 1, 3, 1, 3, 1, 3]
         """
         n = int(n)
@@ -1469,16 +1509,37 @@ class ContinuedFraction_periodic(ContinuedFraction_base):
 
             sage: a = continued_fraction(-17/389)
             sage: latex(a)
-            -1+ \frac{\displaystyle 1}{\displaystyle 1+ \frac{\displaystyle 1}{\displaystyle 21+ \frac{\displaystyle 1}{\displaystyle 1+ \frac{\displaystyle 1}{\displaystyle 7+ \frac{\displaystyle 1}{\displaystyle 2}}}}}
+            -1
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 21
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 7
+            + \frac{\displaystyle 1}{\displaystyle 2
+            }}}}}
+            sage: K.<a> = QuadraticField(1234)
+            sage: cf=continued_fraction(a); cf
+            [35; (7, 1, 3, 1, 4, 4, 2, 9, 1, 1, 2, 3, 1, 1, 34, 1, 1, 3, 2, 1, 1, 9, 2, 4, 4, 1, 3, 1, 7, 70)*]
+            sage: latex(cf)
+            35
+            + \frac{\displaystyle 1}{\displaystyle 7
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 3
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle 4
+            + \frac{\displaystyle 1}{\displaystyle 4
+            + \frac{\displaystyle 1}{\displaystyle 2
+            + \frac{\displaystyle 1}{\displaystyle 9
+            + \frac{\displaystyle 1}{\displaystyle 1
+            + \frac{\displaystyle 1}{\displaystyle \dots}}}}}}}}}}
         """
         if self._x2[0] is not Infinity:
-            raise NotImplementedError("latex not implemented for non rational continued fractions")
+            return super(ContinuedFraction_periodic,self)._latex_()
         v = self._x1
         if len(v) == 0:
             return '0'
-        s = str(v[0])
+        s = str(v[0])+'\n'
         for i in range(1,len(v)):
-            s += '+ \\frac{\\displaystyle 1}{\\displaystyle %s' % v[i]
+            s += '+ \\frac{\\displaystyle 1}{\\displaystyle %s\n' % v[i]
         s += '}'*(len(v)-1)
         return s
 
@@ -2376,7 +2437,7 @@ def continued_fraction(x, value=None):
     Note the value returned for floating point number is the continued fraction
     associated to the rational number you obtain with a conversion::
 
-        sage: for _ in xrange(10):
+        sage: for _ in range(10):
         ....:     x = RR.random_element()
         ....:     cff = continued_fraction(x)
         ....:     cfe = QQ(x).continued_fraction()
