@@ -88,6 +88,7 @@ finite polynomial rings are merged with infinite polynomial rings::
 #
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
+from six.moves import range
 
 from sage.rings.integer_ring import ZZ
 from sage.rings.integer import Integer
@@ -426,13 +427,10 @@ class InfinitePolynomial_sparse(RingElement):
 
     def is_unit(self):
         r"""
-        Answers whether ``self`` is a unit
+        Answer whether ``self`` is a unit.
 
         EXAMPLES::
 
-            sage: R1.<x,y> = InfinitePolynomialRing(ZZ)
-            sage: R2.<x,y> = InfinitePolynomialRing(QQ)
-            sage: p = 1 + x[2]
             sage: R1.<x,y> = InfinitePolynomialRing(ZZ)
             sage: R2.<a,b> = InfinitePolynomialRing(QQ)
             sage: (1+x[2]).is_unit()
@@ -446,16 +444,49 @@ class InfinitePolynomial_sparse(RingElement):
             sage: (1+a[2]).is_unit()
             False
 
+        Check that :trac:`22454` is fixed::
+
+            sage: _.<x> = InfinitePolynomialRing(Zmod(4))
+            sage: (1 + 2*x[0]).is_unit()
+            True
+            sage: (x[0]*x[1]).is_unit()
+            False
+            sage: _.<x> = InfinitePolynomialRing(Zmod(900))
+            sage: (7+150*x[0] + 30*x[1] + 120*x[1]*x[100]).is_unit()
+            True
+
         TESTS::
 
             sage: R.<x> = InfinitePolynomialRing(ZZ.quotient_ring(8))
             sage: [R(i).is_unit() for i in range(8)]
             [False, True, False, True, False, True, False, True]
         """
-        if len(self.variables()) > 0:
-            return False
-        else:
-            return self.base_ring()(self._p).is_unit()
+        return self._p.is_unit()
+
+    def is_nilpotent(self):
+        r"""
+        Return ``True`` if ``self`` is nilpotent, i.e., some power of ``self``
+        is 0.
+
+        EXAMPLES::
+
+            sage: R.<x> = InfinitePolynomialRing(QQbar)
+            sage: (x[0]+x[1]).is_nilpotent()
+            False
+            sage: R(0).is_nilpotent()
+            True
+            sage: _.<x> = InfinitePolynomialRing(Zmod(4))
+            sage: (2*x[0]).is_nilpotent()
+            True
+            sage: (2+x[4]*x[7]).is_nilpotent()
+            False
+            sage: _.<y> = InfinitePolynomialRing(Zmod(100))
+            sage: (5+2*y[0] + 10*(y[0]^2+y[1]^2)).is_nilpotent()
+            False
+            sage: (10*y[2] + 20*y[5] - 30*y[2]*y[5] + 70*(y[2]^2+y[5]^2)).is_nilpotent()
+            True
+        """
+        return self._p.is_nilpotent()
 
     @cached_method
     def variables(self):
@@ -1021,18 +1052,18 @@ class InfinitePolynomial_sparse(RingElement):
             Fsmall = dict([[k[0], [e for e in k[1]]] for k in other.footprint().items()])
             ltbig = slt
             ltsmall = olt
-        # Case 1: one of the Infintie Polynomials is scalar.
+        # Case 1: one of the Infinite Polynomials is scalar.
         if not Fsmall:
             return (rawcmp, 1, ltbig/ltsmall)
         # "not Fbig" is now impossible, because we only consider *global* monomial orderings.
         # These are the occurring shifts:
         Lsmall = sorted(Fsmall.keys())
         Lbig   = sorted(Fbig.keys())
-        P = range(Lbig[-1]+1)
-        gens = xrange(PARENT.ngens())
-        if Lsmall[0]==0:
+        P = list(range(Lbig[-1] + 1))
+        gens = list(range(PARENT.ngens()))
+        if Lsmall[0] == 0:
             if 0 not in Fbig:
-                return (None,1,1)
+                return (None, 1, 1)
             Lsmall.pop(0)
             Lbig.pop(0)
             ExpoSmall = Fsmall[0]
