@@ -30,6 +30,7 @@ AUTHORS:
 - David Loeffler (2009-07-10): cleaned up docstrings
 """
 from __future__ import absolute_import
+from six import iteritems, iterkeys
 
 #*****************************************************************************
 #       Copyright (C) 2008 David Roe <roed@math.harvard.edu>,
@@ -45,8 +46,9 @@ from __future__ import absolute_import
 
 
 from sage.structure.category_object import normalize_names
-from sage.structure.element import is_Element
+from sage.structure.element import is_Element, parent
 from sage.rings.ring import is_Ring
+from sage.rings.infinity import infinity
 from sage.rings.integer import Integer
 from sage.rings.polynomial.polynomial_ring_constructor import _single_variate as _single_variate_poly
 from sage.rings.polynomial.polynomial_ring_constructor import _multi_variate as _multi_variate_poly
@@ -387,6 +389,146 @@ def _multi_variate(base_ring, names, n, sparse, order):
     _save_in_cache(key, P)
     return P
 
+def _split_dict_(D, indices, group_by=None):
+    r"""
+    Split the dictionary ``D`` by ``indices`` and ``group_by``.
+
+    INPUT:
+
+    - ``D`` -- a dictionary.
+
+    - ``indices`` -- a tuple or list of nonnegative integers.
+
+    - ``group_by`` -- a tuple or list of nonnegative integers.
+      If this is ``None`` (default), then no grouping is done.
+
+    OUTPUT:
+
+    A dictionary.
+
+    TESTS::
+
+        sage: from sage.rings.polynomial.laurent_polynomial_ring import _split_dict_
+        sage: D = {(0,0,0,0): 'a', (1,0,0,0): 'b',
+        ....:      (1,0,0,2): 'c', (1,2,0,3): 'd'}
+        sage: _split_dict_(D, [1,0,3])
+        {(0, 0, 0): 'a', (0, 1, 0): 'b', (0, 1, 2): 'c', (2, 1, 3): 'd'}
+        sage: _split_dict_(D, [2,3], [0,1])
+        {(0, 0): {(0, 0): 'a'},
+         (1, 0): {(0, 0): 'b', (0, 2): 'c'},
+         (1, 2): {(0, 3): 'd'}}
+        sage: _split_dict_(D, [3,1], [0])
+        {(0,): {(0, 0): 'a'}, (1,): {(0, 0): 'b', (2, 0): 'c', (3, 2): 'd'}}
+
+        sage: _split_dict_(D, [0,None,1,3])
+        {(0, 0, 0, 0): 'a', (1, 0, 0, 0): 'b',
+         (1, 0, 0, 2): 'c', (1, 0, 2, 3): 'd'}
+        sage: _split_dict_(D, [0,1], [None,3,None])
+        {(0, 0, 0): {(0, 0): 'a', (1, 0): 'b'},
+         (0, 2, 0): {(1, 0): 'c'},
+         (0, 3, 0): {(1, 2): 'd'}}
+        sage: _split_dict_(D, [None,3,1], [0,None])
+        {(0, 0): {(0, 0, 0): 'a'},
+         (1, 0): {(0, 0, 0): 'b', (0, 2, 0): 'c',
+                     (0, 3, 2): 'd'}}
+
+        sage: _split_dict_(D, [0,1])
+        Traceback (most recent call last):
+        ...
+        SplitDictError: split not possible
+        sage: _split_dict_(D, [0], [1])
+        Traceback (most recent call last):
+        ...
+        SplitDictError: split not possible
+        sage: _split_dict_({}, [])
+        {}
+    """
+    if not D:
+        return {}
+    if group_by is None:
+        group_by = tuple()
+
+    class SplitDictError(ValueError):
+        pass
+    def get(T, i):
+        return T[i] if i is not None else 0
+    def extract(T, indices):
+        return tuple(get(T, i) for i in indices)
+
+    remaining = sorted(set(range(len(next(iterkeys(D)))))
+                       - set(indices) - set(group_by))
+    result = {}
+    for K, V in iteritems(D):
+        if not all(r == 0 for r in extract(K, remaining)):
+            raise SplitDictError('split not possible')
+        G = extract(K, group_by)
+        I = extract(K, indices)
+        result.setdefault(G, dict()).update({I: V})
+    if not group_by:
+        return result.popitem()[1]
+    else:
+        return result
+
+def _split_laurent_polynomial_dict_(P, M, d):
+    r"""
+    Helper function for splitting a multivariate laurent polynomial
+    during conversion.
+
+    INPUT:
+
+    - ``P`` -- the parent to which we want to convert.
+
+    - ``M`` -- the parent from which we want to convert.
+
+    - ``d`` -- a dictionary mapping tuples (representing the exponents)
+      to their coefficients. This is the dictionary corresponding to
+      an element of ``M``.
+
+    OUTPUT:
+
+    A dictionary corresponding to an element of ``P``.
+
+    TESTS::
+
+        sage: L.<a, b, c, d> = LaurentPolynomialRing(ZZ)
+        sage: M = LaurentPolynomialRing(ZZ, 'c, d')
+        sage: N = LaurentPolynomialRing(M, 'a, b')
+        sage: M(c/d + 1/c)  # indirect doctest
+        c*d^-1 + c^-1
+        sage: N(a + b/c/d + 1/b)  # indirect doctest
+        a + (c^-1*d^-1)*b + b^-1
+    """
+    vars_P = P.variable_names()
+    vars_M = M.variable_names()
+    if not set(vars_M) & set(vars_P):
+        raise TypeError('no common variables')
+
+    def index(T, value):
+        try:
+            return T.index(value)
+        except ValueError:
+            return None
+
+    def value(d, R):
+        assert d
+        if len(d) == 1:
+            k, v = next(iteritems(d))
+            if all(i == 0 for i in k):
+                return R(v)
+        return R(M(d))
+
+    group_by = tuple(index(vars_M, var) for var in vars_P)
+    indices = range(len(vars_M))
+    for g in group_by:
+        if g is not None:
+            indices[g] = None
+    D = _split_dict_(d, indices, group_by)
+    try:
+        return {k: value(v, P.base_ring()) for k, v in iteritems(D)}
+    except (ValueError, TypeError):
+        pass
+    return sum(P({k: 1}) * value(v, P) for k, v in iteritems(D)).dict()
+
 class LaurentPolynomialRing_generic(CommutativeRing, ParentWithGens):
     """
     Laurent polynomial ring (base class).
@@ -475,6 +617,41 @@ class LaurentPolynomialRing_generic(CommutativeRing, ParentWithGens):
             return self.__generators[i]
 
 
+    def variable_names_recursive(self, depth=infinity):
+        r"""
+        Return the list of variable names of this ring and its base rings,
+        as if it were a single multi-variate laurent polynomial.
+
+        INPUT:
+
+        - ``depth`` -- an integer or :mod:`Infinity <sage.rings.infinity>`.
+
+        OUTPUT:
+
+        A tuple of strings.
+
+        EXAMPLES::
+
+            sage: T = LaurentPolynomialRing(QQ, 'x')
+            sage: S = LaurentPolynomialRing(T, 'y')
+            sage: R = LaurentPolynomialRing(S, 'z')
+            sage: R.variable_names_recursive()
+            ('x', 'y', 'z')
+            sage: R.variable_names_recursive(2)
+            ('y', 'z')
+        """
+        if depth <= 0:
+            return ()
+        elif depth == 1:
+            return self.variable_names()
+        else:
+            my_vars = self.variable_names()
+            try:
+               return self.base_ring().variable_names_recursive(depth - len(my_vars)) + my_vars
+            except AttributeError:
+                return my_vars
+
+
     def is_integral_domain(self, proof = True):
         """
         Returns True if self is an integral domain.
@@ -829,7 +1006,73 @@ class LaurentPolynomialRing_univariate(LaurentPolynomialRing_generic):
             sage: L = LaurentPolynomialRing(QQ, 'x')
             sage: L(1/2)
             1/2
+
+            sage: L(x + 3/x)
+            3*x^-1 + x
+
+        ::
+
+            sage: L(exp(x))
+            Traceback (most recent call last):
+            ...
+            TypeError: unable to convert e^x to a rational
+
+        ::
+
+            sage: U = LaurentPolynomialRing(QQ, 'a')
+            sage: V = LaurentPolynomialRing(QQ, 'c')
+            sage: L.<a, b, c, d> = LaurentPolynomialRing(QQ)
+            sage: M = LaurentPolynomialRing(QQ, 'c, d')
+            sage: Mc, Md = M.gens()
+            sage: N = LaurentPolynomialRing(M, 'a, b')
+            sage: Na, Nb = N.gens()
+            sage: U(Na)
+            a
+            sage: V(Mc)
+            c
+
+            sage: M(L(0))
+            0
+            sage: N(L(0))
+            0
+            sage: L(M(0))
+            0
+            sage: L(N(0))
+            0
+
+        ::
+
+            sage: A.<a> = LaurentPolynomialRing(QQ)
+            sage: B.<b> = LaurentPolynomialRing(A)
+            sage: B(a)
+            a
+            sage: C.<c> = LaurentPolynomialRing(B)
+            sage: B(C(b))
+            b
+            sage: D.<d, e> = LaurentPolynomialRing(B)
+            sage: B(D(b))
+            b
         """
+        from sage.symbolic.expression import Expression
+        if isinstance(x, Expression):
+            return x.laurent_polynomial(ring=self)
+
+        elif isinstance(x, (LaurentPolynomial_univariate, LaurentPolynomial_mpair)):
+            P = x.parent()
+            if set(self.variable_names()) & set(P.variable_names()):
+                if isinstance(x, LaurentPolynomial_univariate):
+                    d = {(k,): v for k, v in iteritems(x.dict())}
+                else:
+                    d = x.dict()
+                x = _split_laurent_polynomial_dict_(self, P, d)
+                x = {k[0]: v for k, v in iteritems(x)}
+            elif self.base_ring().has_coerce_map_from(P):
+                x = {0: self.base_ring()(x)}
+            elif x.is_constant() and self.has_coerce_map_from(x.parent().base_ring()):
+                return self(x.constant_coefficient())
+            elif len(self.variable_names()) == len(P.variable_names()):
+                x = x.dict()
+
         return LaurentPolynomial_univariate(self, x)
 
     def __reduce__(self):
@@ -862,15 +1105,130 @@ class LaurentPolynomialRing_mpair(LaurentPolynomialRing_generic):
             raise ValueError("base ring must be an integral domain")
         LaurentPolynomialRing_generic.__init__(self, R, prepend_string, names)
 
-    def _element_constructor_(self, x):
+    def _element_constructor_(self, x, mon=None):
         """
         EXAMPLES::
 
             sage: L = LaurentPolynomialRing(QQ,2,'x')
             sage: L(1/2)
             1/2
+
+            sage: M = LaurentPolynomialRing(QQ, 'x, y')
+            sage: var('x, y')
+            (x, y)
+            sage: M(x/y + 3/x)
+            x*y^-1 + 3*x^-1
+
+        ::
+
+            sage: M(exp(x))
+            Traceback (most recent call last):
+            ...
+            TypeError: unable to convert e^x to a rational
+
+        ::
+
+            sage: L.<a, b, c, d> = LaurentPolynomialRing(QQ)
+            sage: M = LaurentPolynomialRing(QQ, 'c, d')
+            sage: Mc, Md = M.gens()
+            sage: N = LaurentPolynomialRing(M, 'a, b')
+            sage: Na, Nb = N.gens()
+            sage: M(c/d)
+            c*d^-1
+            sage: N(a*b/c/d)
+            (c^-1*d^-1)*a*b
+            sage: N(c/d)
+            c*d^-1
+            sage: L(Mc)
+            c
+            sage: L(Nb)
+            b
+
+            sage: M(L(0))
+            0
+            sage: N(L(0))
+            0
+            sage: L(M(0))
+            0
+            sage: L(N(0))
+            0
+
+            sage: U = LaurentPolynomialRing(QQ, 'a')
+            sage: Ua = U.gen()
+            sage: V = LaurentPolynomialRing(QQ, 'c')
+            sage: Vc = V.gen()
+            sage: L(Ua)
+            a
+            sage: L(Vc)
+            c
+            sage: N(Ua)
+            a
+            sage: M(Vc)
+            c
+
+            sage: P = LaurentPolynomialRing(QQ, 'a, b')
+            sage: Q = LaurentPolynomialRing(P, 'c, d')
+            sage: Q(P.0)
+            a
+
+        ::
+
+            sage: A.<a> = LaurentPolynomialRing(QQ)
+            sage: B.<b> = LaurentPolynomialRing(A)
+            sage: C = LaurentPolynomialRing(QQ, 'a, b')
+            sage: C(B({1: a}))
+            a*b
+            sage: D.<d, e> = LaurentPolynomialRing(B)
+            sage: F.<f, g> = LaurentPolynomialRing(D)
+            sage: D(F(d*e))
+            d*e
+
+        ::
+
+            sage: from sage.rings.polynomial.polydict import ETuple
+            sage: R.<x,y,z> = LaurentPolynomialRing(QQ)
+            sage: mon = ETuple({}, int(3))
+            sage: P = R.polynomial_ring()
+            sage: R(sum(P.gens()), mon)
+            x + y + z
+            sage: R(sum(P.gens()), (-1,-1,-1))
+            y^-1*z^-1 + x^-1*z^-1 + x^-1*y^-1
         """
-        return LaurentPolynomial_mpair(self, x)
+        from sage.symbolic.expression import Expression
+        element_class = LaurentPolynomial_mpair
+
+        if mon is not None:
+            return element_class(self, x, mon)
+
+        P = parent(x)
+        if P is self.polynomial_ring():
+            from sage.rings.polynomial.polydict import ETuple
+            return element_class( self, x, mon=ETuple({}, int(self.ngens())) )
+
+        elif isinstance(x, Expression):
+            return x.laurent_polynomial(ring=self)
+
+        elif isinstance(x, (LaurentPolynomial_univariate, LaurentPolynomial_mpair)):
+            if self.variable_names() == P.variable_names():
+                # No special processing needed here;    
+                #   handled by LaurentPolynomial_mpair.__init__
+                pass
+            elif set(self.variable_names()) & set(P.variable_names()):
+                if isinstance(x, LaurentPolynomial_univariate):
+                    d = {(k,): v for k, v in iteritems(x.dict())}
+                else:
+                    d = x.dict()
+                x = _split_laurent_polynomial_dict_(self, P, d)
+            elif self.base_ring().has_coerce_map_from(P):
+                from sage.rings.polynomial.polydict import ETuple
+                mz = ETuple({}, int(self.ngens()))
+                return element_class(self, {mz: self.base_ring()(x)}, mz)
+            elif x.is_constant() and self.has_coerce_map_from(P.base_ring()):
+                return self(x.constant_coefficient())
+            elif len(self.variable_names()) == len(P.variable_names()):
+                x = x.dict()
+
+        return element_class(self, x)
 
     def __reduce__(self):
         """
