@@ -22,6 +22,8 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from __future__ import print_function
+from six.moves import range
+from builtins import zip
 
 from sage.rings.padics.precision_error import PrecisionError
 from sage.rings.polynomial.polynomial_element import Polynomial
@@ -59,7 +61,7 @@ class Polynomial_padic(Polynomial):
         coeffs = self.list()
         if name is None:
             name = self.parent().variable_name()
-        for n in reversed(xrange(len(coeffs))):
+        for n in reversed(range(len(coeffs))):
             x = coeffs[n]
             if x.valuation() != infinity:
                 if s:
@@ -210,7 +212,7 @@ class Polynomial_padic(Polynomial):
             (3^2 + 2*3^3 + 2*3^4 + 3^5 + 2*3^6 + O(3^22)) * ((1 + O(3^19))*T + (2*3^-1 + 3 + 3^2 + 2*3^5 + 2*3^6 + 2*3^7 + 3^8 + 3^9 + 2*3^11 + 3^15 + 3^17 + O(3^19))) * ((1 + O(3^20))*T + (2*3 + 3^2 + 3^3 + 3^5 + 2*3^6 + 2*3^7 + 3^8 + 3^10 + 3^11 + 2*3^12 + 2*3^14 + 2*3^15 + 2*3^17 + 2*3^18 + O(3^20)))
         """
         if self == 0:
-            raise ArithmeticError("factorization of 0 not defined")
+            raise ArithmeticError("factorization of {!r} is not defined".format(self))
         # Scale self such that 0 is the lowest valuation
         # amongst the coefficients
         try:
@@ -261,7 +263,7 @@ def _pari_padic_factorization_to_sage(G, R, leading_coeff):
         # When the base ring is a field, we normalize
         # the irreducible factors so they have leading
         # coefficient 1.
-        for i in xrange(len(pols)):
+        for i in range(len(pols)):
             lc = pols[i].leading_coefficient()
             lc = lc.lift_to_precision()  # Ensure we don't lose precision
             pols[i] *= ~lc
@@ -270,7 +272,7 @@ def _pari_padic_factorization_to_sage(G, R, leading_coeff):
         # the irreducible factors so that the leading term
         # is a power of p.
         c, leading_coeff = leading_coeff.val_unit()
-        for i in xrange(len(pols)):
+        for i in range(len(pols)):
             v, upart = pols[i].leading_coefficient().val_unit()
             upart = upart.lift_to_precision()  # Ensure we don't lose precision
             pols[i] *= ~upart
