@@ -269,7 +269,7 @@ Sage also supports matrix term order. Given a square matrix `A`,
 
 where `<` is the lexicographic term order.
 
-EXAMPLE::
+EXAMPLES::
 
     sage: m = matrix(2,[2,3,0,1]); m
     [2 3]
@@ -300,7 +300,7 @@ The product order (or block order) `<` `:=` `(<_1,<_2)` on `k[x,y]` is defined a
 These block orders are constructed in Sage by giving a comma separated list of monomial orders
 with the length of each block attached to them.
 
-EXAMPLE:
+EXAMPLES:
 
 As an example, consider constructing a block order where the
 first four variables are compared using the degree reverse
@@ -366,6 +366,7 @@ AUTHORS:
 
 import re
 from sage.structure.sage_object import SageObject
+from sage.misc.superseded import deprecation
 
 print_name_mapping = {
     'lex'           : 'Lexicographic',
@@ -549,7 +550,7 @@ class TermOrder(SageObject):
 
         See Trac :trac:`11316`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('lex')
             sage: t2 = loads(dumps(t))
@@ -804,7 +805,7 @@ class TermOrder(SageObject):
         r"""
         A hash function
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: _=hash(TermOrder('lex'))
         """
@@ -814,7 +815,7 @@ class TermOrder(SageObject):
         """
         Copy other term order to self.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('lex')
             sage: s = TermOrder(t)
@@ -825,44 +826,34 @@ class TermOrder(SageObject):
 
     def __getattr__(self,name):
         """
-        Return the correct compare_tuples/greater_tuple function.
+        Return the correct ``compare_tuples/greater_tuple/sortkey function``.
 
-        EXAMPLE::
+        Note that the ``compare_tuples`` methods have been deprecated in
+        :trac:`21766`.
+
+        EXAMPLES::
 
             sage: TermOrder('lex').compare_tuples
             <bound method TermOrder.compare_tuples_lex of Lexicographic term order>
-
-        ::
-
+            sage: TermOrder('lex').sortkey
+            <bound method TermOrder.sortkey_lex of Lexicographic term order>
             sage: TermOrder('deglex').compare_tuples
             <bound method TermOrder.compare_tuples_deglex of Degree lexicographic term order>
         """
         if name == 'compare_tuples':
-            return getattr(self,'compare_tuples_'+self._name)
+            return getattr(self, 'compare_tuples_' + self._name)
         elif name == 'greater_tuple':
-            return getattr(self,'greater_tuple_'+self._name)
+            return getattr(self, 'greater_tuple_' + self._name)
+        elif name == 'sortkey':
+            return getattr(self, 'sortkey_' + self._name)
         else:
             raise AttributeError(name)
 
-    def compare_tuples_matrix(self,f,g):
+    def compare_tuples_matrix(self, f, g):
         """
-        Compares two exponent tuples with respect to the matrix
-        term order.
-
-        INPUT:
-
-        - ``f`` - exponent tuple
-
-        - ``g`` - exponent tuple
-
-        EXAMPLES::
-
-            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='m(1,3,1,0)')
-            sage: y > x^2 # indirect doctest
-            True
-            sage: y > x^3
-            False
+        DEPRECATED in :trac:`21766`
         """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         for row in self._matrix:
             sf = sum(l*r for (l,r) in zip(row,f))
             sg = sum(l*r for (l,r) in zip(row,g))
@@ -873,25 +864,31 @@ class TermOrder(SageObject):
                 return -1
         return 0
 
-    def compare_tuples_lex(self,f,g):
+    def sortkey_matrix(self, f):
         """
-        Compares two exponent tuples with respect to the lexicographical
+        Return the sortkey of an exponent tuple with respect to the matrix
         term order.
 
         INPUT:
 
         - ``f`` - exponent tuple
 
-        - ``g`` - exponent tuple
+        EXAMPLES::
 
-        EXAMPLE::
-
-            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='lex')
-            sage: x > y^2 # indirect doctest
-            True
-            sage: x > 1
+            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='m(1,3,1,0)')
+            sage: y > x^2 # indirect doctest
             True
+            sage: y > x^3
+            False
         """
+        return tuple(sum(l * r for l, r in zip(row, f))
+                     for row in self._matrix)
+
+    def compare_tuples_lex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         if f > g:
             return 1
         elif f < g:
@@ -899,18 +896,42 @@ class TermOrder(SageObject):
         else:
             return 0
 
-    def compare_tuples_invlex(self,f,g):
+    def sortkey_lex(self, f):
         """
-        Compares two exponent tuples with respect to the inversed
+        Return the sortkey of an exponent tuple with respect to the
         lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
+        EXAMPLES::
 
-        EXAMPLE::
+            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='lex')
+            sage: x > y^2 # indirect doctest
+            True
+            sage: x > 1
+            True
+        """
+        return f
+
+    def compare_tuples_invlex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
+        return self.compare_tuples_lex(f.reversed(),g.reversed())
+
+    def sortkey_invlex(self, f):
+        """
+        Return the sortkey of an exponent tuple with respect to the inversed
+        lexicographical term order.
+
+        INPUT:
+
+        - ``f`` -- exponent tuple
+
+        EXAMPLES::
 
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order='invlex')
             sage: x > y^2 # indirect doctest
@@ -918,27 +939,13 @@ class TermOrder(SageObject):
             sage: x > 1
             True
         """
-        return self.compare_tuples_lex(f.reversed(),g.reversed())
+        return f.reversed()
 
     def compare_tuples_deglex(self,f,g):
         """
-        Compares two exponent tuples with respect to the degree
-        lexicographical term order.
-
-        INPUT:
-
-        - ``f`` - exponent tuple
-
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
-
-            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='deglex')
-            sage: x > y^2 # indirect doctest
-            False
-            sage: x > 1
-            True
+        DEPRECATED in :trac:`21766`
         """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(f.nonzero_values(sort=False))
         sg = sum(g.nonzero_values(sort=False))
         if sf > sg:
@@ -948,25 +955,31 @@ class TermOrder(SageObject):
         elif sf == sg:
             return self.compare_tuples_lex(f,g)
 
-    def compare_tuples_degrevlex(self,f,g):
+    def sortkey_deglex(self, f):
         """
-        Compares two exponent tuples with respect to the degree reversed
+        Return the sortkey of an exponent tuple with respect to the degree
         lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
+        EXAMPLES::
 
-        EXAMPLE::
-
-            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='degrevlex')
+            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='deglex')
             sage: x > y^2 # indirect doctest
             False
             sage: x > 1
             True
+
         """
+        return (sum(f.nonzero_values(sort=False)), f)
+
+    def compare_tuples_degrevlex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(f.nonzero_values(sort=False))
         sg = sum(g.nonzero_values(sort=False))
         if sf > sg:
@@ -974,20 +987,46 @@ class TermOrder(SageObject):
         elif sf < sg:
             return -1
         elif sf == sg:
-            return -self.compare_tuples_lex(f.reversed(),g.reversed())
+            return -self.compare_tuples_lex(f.reversed(), g.reversed())
+
+    def sortkey_degrevlex(self, f):
+        """
+        Return the sortkey of an exponent tuple with respect to the
+        degree reversed lexicographical term order.
+
+        INPUT:
+
+        - ``f`` -- exponent tuple
+
+        EXAMPLES::
+
+            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='degrevlex')
+            sage: x > y^2 # indirect doctest
+            False
+            sage: x > 1
+            True
+
+        """
+        return (sum(f.nonzero_values(sort=False)),
+                tuple(-v for v in f.reversed()))
 
     def compare_tuples_neglex(self,f,g):
         """
-        Compares two exponent tuples with respect to the negative
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
+        return -self.compare_tuples_lex(f,g)
+
+    def sortkey_neglex(self, f):
+        """
+        Return the sortkey of an exponent tuple with respect to the negative
         lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order='neglex')
             sage: x > y^2 # indirect doctest
@@ -995,27 +1034,13 @@ class TermOrder(SageObject):
             sage: x > 1
             False
         """
-        return -self.compare_tuples_lex(f,g)
+        return tuple(-v for v in f)
 
     def compare_tuples_negdegrevlex(self,f,g):
         """
-        Compares two exponent tuples with respect to the negative degree
-        reverse lexicographical term order.
-
-        INPUT:
-
-        - ``f`` - exponent tuple
-
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
-
-            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='negdegrevlex')
-            sage: x > y^2 # indirect doctest
-            True
-            sage: x > 1
-            False
+        DEPRECATED in :trac:`21766`
         """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(f.nonzero_values(sort=False))
         sg = sum(g.nonzero_values(sort=False))
         if sf > sg:
@@ -1023,27 +1048,33 @@ class TermOrder(SageObject):
         elif sf < sg:
             return 1
         elif sf == sg:
-            return (-1)*self.compare_tuples_lex(f.reversed(),g.reversed())
+            return -self.compare_tuples_lex(f.reversed(), g.reversed())
 
-    def compare_tuples_negdeglex(self,f,g):
+    def sortkey_negdegrevlex(self, f):
         """
-        Compares two exponent tuples with respect to the negative degree
-        lexicographical term order.
+        Return the sortkey of an exponent tuple with respect to the
+        negative degree reverse lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
+        EXAMPLES::
 
-        EXAMPLE::
-
-            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='negdeglex')
+            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='negdegrevlex')
             sage: x > y^2 # indirect doctest
             True
             sage: x > 1
             False
         """
+        return (-sum(f.nonzero_values(sort=False)),
+                tuple(-v for v in f.reversed()))
+
+    def compare_tuples_negdeglex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(f.nonzero_values(sort=False))
         sg = sum(g.nonzero_values(sort=False))
         if sf > sg:
@@ -1053,25 +1084,30 @@ class TermOrder(SageObject):
         elif sf == sg:
             return self.compare_tuples_lex(f,g)
 
-    def compare_tuples_degneglex(self,f,g):
+    def sortkey_negdeglex(self, f):
         """
-        Compares two exponent tuples with respect to the degree negative
-        lexicographical term order.
+        Return the sortkey of an exponent tuple with respect to the
+        negative degree lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
+        EXAMPLES::
 
-        EXAMPLE::
-
-            sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='degneglex')
-            sage: x*y > y*z # indirect doctest
-            False
-            sage: x*y > x
+            sage: P.<x,y> = PolynomialRing(QQbar, 2, order='negdeglex')
+            sage: x > y^2 # indirect doctest
             True
+            sage: x > 1
+            False
         """
+        return (-sum(f.nonzero_values(sort=False)), f)
+
+    def compare_tuples_degneglex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(f.nonzero_values(sort=False))
         sg = sum(g.nonzero_values(sort=False))
         if sf < sg:
@@ -1081,18 +1117,49 @@ class TermOrder(SageObject):
         elif sf == sg:
             return self.compare_tuples_neglex(f,g)
 
-    def compare_tuples_wdegrevlex(self,f,g):
+    def sortkey_degneglex(self, f):
         """
-        Compares two exponent tuples with respect to the weighted degree reverse
-        lexicographical term order.
+        Return the sortkey of an exponent tuple with respect to the
+        degree negative lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
+        EXAMPLES::
 
-        EXAMPLE::
+            sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='degneglex')
+            sage: x*y > y*z # indirect doctest
+            False
+            sage: x*y > x
+            True
+        """
+        return (sum(f.nonzero_values(sort=False)), tuple(-v for v in f))
+
+    def compare_tuples_wdegrevlex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
+        sf = sum(l*r for (l,r) in zip(f,self._weights))
+        sg = sum(l*r for (l,r) in zip(g,self._weights))
+        if sf > sg:
+            return 1
+        elif sf < sg:
+            return -1
+        elif sf == sg:
+            return -self.compare_tuples_lex(f.reversed(), g.reversed())
+
+    def sortkey_wdegrevlex(self, f):
+        """
+        Return the sortkey of an exponent tuple with respect to the
+        weighted degree reverse lexicographical term order.
+
+        INPUT:
+
+        - ``f`` -- exponent tuple
+
+        EXAMPLES::
 
             sage: t = TermOrder('wdegrevlex',(3,2))
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order=t)
@@ -1101,6 +1168,14 @@ class TermOrder(SageObject):
             sage: x^2 > y^3
             True
         """
+        return (sum(l * r for (l, r) in zip(f, self._weights)),
+                tuple(-v for v in f.reversed()))
+
+    def compare_tuples_wdeglex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(l*r for (l,r) in zip(f,self._weights))
         sg = sum(l*r for (l,r) in zip(g,self._weights))
         if sf > sg:
@@ -1108,20 +1183,18 @@ class TermOrder(SageObject):
         elif sf < sg:
             return -1
         elif sf == sg:
-            return -self.compare_tuples_lex(f.reversed(),g.reversed())
+            return self.compare_tuples_lex(f,g)
 
-    def compare_tuples_wdeglex(self,f,g):
+    def sortkey_wdeglex(self, f):
         """
-        Compares two exponent tuples with respect to the weighted degree
-        lexicographical term order.
+        Return the sortkey of an exponent tuple with respect to the
+        weighted degree lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('wdeglex',(3,2))
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order=t)
@@ -1130,27 +1203,32 @@ class TermOrder(SageObject):
             sage: x > y
             True
         """
-        sf = sum(l*r for (l,r) in zip(f,self._weights))
-        sg = sum(l*r for (l,r) in zip(g,self._weights))
-        if sf > sg:
-            return 1
-        elif sf < sg:
-            return -1
-        elif sf == sg:
-            return self.compare_tuples_lex(f,g)
+        return (sum(l * r for (l, r) in zip(f, self._weights)), f)
 
     def compare_tuples_negwdeglex(self,f,g):
         """
-        Compares two exponent tuples with respect to the negative weighted
-        degree lexicographical term order.
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
+        sf = sum(l*r for (l,r) in zip(f,self._weights))
+        sg = sum(l*r for (l,r) in zip(g,self._weights))
+        if sf > sg:
+            return -1
+        elif sf < sg:
+            return 1
+        elif sf == sg:
+            return self.compare_tuples_lex(f,g)
+
+    def sortkey_negwdeglex(self, f):
+        """
+        Return the sortkey of an exponent tuple with respect to the
+        negative weighted degree lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('negwdeglex',(3,2))
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order=t)
@@ -1159,6 +1237,13 @@ class TermOrder(SageObject):
             sage: x^2 > y^3
             True
         """
+        return (-sum(l * r for (l, r) in zip(f, self._weights)), f)
+
+    def compare_tuples_negwdegrevlex(self,f,g):
+        """
+        DEPRECATED in :trac:`21766`
+        """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         sf = sum(l*r for (l,r) in zip(f,self._weights))
         sg = sum(l*r for (l,r) in zip(g,self._weights))
         if sf > sg:
@@ -1166,20 +1251,18 @@ class TermOrder(SageObject):
         elif sf < sg:
             return 1
         elif sf == sg:
-            return self.compare_tuples_lex(f,g)
+            return -self.compare_tuples_lex(f.reversed(), g.reversed())
 
-    def compare_tuples_negwdegrevlex(self,f,g):
+    def sortkey_negwdegrevlex(self, f):
         """
-        Compares two exponent tuples with respect to the negative weighted
-        degree reverse lexicographical term order.
+        Return the sortkey of an exponent tuple with respect to the
+        negative weighted degree reverse lexicographical term order.
 
         INPUT:
 
-        - ``f`` - exponent tuple
+        - ``f`` -- exponent tuple
 
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('negwdegrevlex',(3,2))
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order=t)
@@ -1188,34 +1271,14 @@ class TermOrder(SageObject):
             sage: x^2 > y^3
             True
         """
-        sf = sum(l*r for (l,r) in zip(f,self._weights))
-        sg = sum(l*r for (l,r) in zip(g,self._weights))
-        if sf > sg:
-            return -1
-        elif sf < sg:
-            return 1
-        elif sf == sg:
-            return (-1)*self.compare_tuples_lex(f.reversed(),g.reversed())
+        return (-sum(l * r for (l, r) in zip(f, self._weights)),
+                tuple(-v for v in f.reversed()))
 
     def compare_tuples_block(self, f,g):
         """
-        Compares two exponent tuples with respect to the block order as
-        specified when constructing this element.
-
-        INPUT:
-
-        - ``f`` - exponent tuple
-
-        - ``g`` - exponent tuple
-
-        EXAMPLE::
-
-            sage: P.<a,b,c,d,e,f>=PolynomialRing(QQbar, 6, order='degrevlex(3),degrevlex(3)')
-            sage: a > c^4 # indirect doctest
-            False
-            sage: a > e^4
-            True
+        DEPRECATED in :trac:`21766`
         """
+        deprecation(21766, 'sorting of polynomials now uses sortkey instead')
         n = 0
         for block in self:
             r = getattr(block,"compare_tuples_" + block.name())(f[n:n+len(block)],g[n:n+len(block)])
@@ -1224,6 +1287,31 @@ class TermOrder(SageObject):
             n += len(block)
         return 0
 
+    def sortkey_block(self, f):
+        """
+        Return the sortkey of an exponent tuple with respect to the
+        block order as specified when constructing this element.
+
+        INPUT:
+
+        - ``f`` -- exponent tuple
+
+        EXAMPLES::
+
+            sage: P.<a,b,c,d,e,f>=PolynomialRing(QQbar, 6, order='degrevlex(3),degrevlex(3)')
+            sage: a > c^4 # indirect doctest
+            False
+            sage: a > e^4
+            True
+        """
+        key = tuple()
+        n = 0
+        for block in self:
+            r = getattr(block, "sortkey_" + block.name())(f[n:n + len(block)])
+            key += r
+            n += len(block)
+        return key
+
     def greater_tuple_matrix(self,f,g):
         """
         Return the greater exponent tuple with respect to the matrix
@@ -1235,7 +1323,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y> = PolynomialRing(QQbar, 2, order='m(1,3,1,0)')
             sage: y > x^2 # indirect doctest
@@ -1286,7 +1374,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='invlex')
             sage: f = x + y; f.lm() # indirect doctest
@@ -1310,7 +1398,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='deglex')
             sage: f = x + y; f.lm() # indirect doctest
@@ -1362,7 +1450,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='negdegrevlex')
             sage: f = x + y; f.lm() # indirect doctest
@@ -1390,7 +1478,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='negdeglex')
             sage: f = x + y; f.lm() # indirect doctest
@@ -1418,7 +1506,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order='degneglex')
             sage: f = x + y; f.lm() # indirect doctest
@@ -1448,7 +1536,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<a,b,c,d,e,f>=PolynomialRing(QQbar, 6, order='degrevlex(3),degrevlex(3)')
             sage: f = a + c^4; f.lm() # indirect doctest
@@ -1469,7 +1557,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('wdeglex',(1,2,3))
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order=t)
@@ -1523,7 +1611,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('negwdeglex',(1,2,3))
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order=t)
@@ -1552,7 +1640,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder('negwdegrevlex',(1,2,3))
             sage: P.<x,y,z> = PolynomialRing(QQbar, 3, order=t)
@@ -1584,7 +1672,7 @@ class TermOrder(SageObject):
 
         - ``g`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P.<a,b,c,d,e,f>=PolynomialRing(QQbar, 6, order='degrevlex(3),degrevlex(3)')
             sage: f = a + c^4; f.lm() # indirect doctest
@@ -1594,9 +1682,11 @@ class TermOrder(SageObject):
         """
         n = 0
         for block in self:
-            r = getattr(block,"compare_tuples_" + block.name())(f[n:n+len(block)],g[n:n+len(block)])
-            if r != 0:
-                if r < 0:
+            keyfn = getattr(block, "sortkey_" + block.name())
+            f_key = keyfn(f[n:n + len(block)])
+            g_key = keyfn(g[n:n + len(block)])
+            if f_key != g_key:
+                if f_key < g_key:
                     return g
                 else:
                     return f
@@ -1611,7 +1701,7 @@ class TermOrder(SageObject):
 
         - ``f`` - exponent tuple
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t=TermOrder('wdeglex',(1,2,3))
             sage: P.<a,b,c>=PolynomialRing(QQbar, order=t)
@@ -1622,7 +1712,7 @@ class TermOrder(SageObject):
 
     def name(self):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: TermOrder('lex').name()
             'lex'
@@ -1631,7 +1721,7 @@ class TermOrder(SageObject):
 
     def _repr_(self):
         """
-        EXAMPLE::
+        EXAMPLES::
 
             sage: TermOrder('lex') # indirect doctest
             Lexicographic term order
@@ -1658,13 +1748,14 @@ class TermOrder(SageObject):
 
         Used to convert polynomial rings to their SINGULAR representation.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P = PolynomialRing(GF(127),10,names='x',order='lex(3),deglex(5),lex(2)')
             sage: T = P.term_order()
             sage: T.singular_str()
             '(lp(3),Dp(5),lp(2))'
             sage: P._singular_()
+            polynomial ring, over a field, global ordering
             //   characteristic : 127
             //   number of vars : 10
             //        block   1 : ordering lp
@@ -1692,6 +1783,7 @@ class TermOrder(SageObject):
             sage: T.singular_str()
             '(a(1:2),ls(2),a(1:2),ls(2))'
             sage: P._singular_()
+            polynomial ring, over a field, global ordering
             //   characteristic : 0
             //   number of vars : 4
             //        block   1 : ordering a
@@ -1713,7 +1805,7 @@ class TermOrder(SageObject):
         Return a the number of additional blocks SINGULAR needs to allocate
         for handling non-native orderings like `degneglex`.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P = PolynomialRing(GF(127),10,names='x',order='lex(3),deglex(5),lex(2)')
             sage: T = P.term_order()
@@ -1753,7 +1845,7 @@ class TermOrder(SageObject):
         Used to convert polynomial rings to their Macaulay2
         representation.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P = PolynomialRing(GF(127), 8,names='x',order='degrevlex(3),lex(5)')
             sage: T = P.term_order()
@@ -1774,7 +1866,7 @@ class TermOrder(SageObject):
 
         Used to convert polynomial rings to their MAGMA representation.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: P = PolynomialRing(GF(127), 10,names='x',order='degrevlex')
             sage: magma(P)                                                        # optional - magma
@@ -1800,7 +1892,7 @@ class TermOrder(SageObject):
         to be an *attribute* of the same name and the same content.
         So, it is a backward incompatible syntax change.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t=TermOrder('deglex',2)+TermOrder('lex',2)
             sage: t.blocks()
@@ -1815,7 +1907,7 @@ class TermOrder(SageObject):
         """
         Return the matrix defining matrix term order.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t = TermOrder("M(1,2,0,1)")
             sage: t.matrix()
@@ -1829,7 +1921,7 @@ class TermOrder(SageObject):
         """
         Return the weights for weighted term orders.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t=TermOrder('wdeglex',(2,3))
             sage: t.weights()
@@ -1841,7 +1933,7 @@ class TermOrder(SageObject):
         """
         Return true if self and other are equal.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: TermOrder('lex') == TermOrder('lex',3)
             True
@@ -1880,7 +1972,7 @@ class TermOrder(SageObject):
         """
         Return true if self and other are not equal.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T1 = TermOrder('lex',2)+TermOrder('lex',3)
             sage: T2 = TermOrder('lex',3)+TermOrder('lex',2)
@@ -1899,7 +1991,7 @@ class TermOrder(SageObject):
 
         OUTPUT: a block order
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: from sage.rings.polynomial.term_order import TermOrder
             sage: TermOrder('deglex',2) + TermOrder('degrevlex(3),neglex(3)')
@@ -1919,7 +2011,7 @@ class TermOrder(SageObject):
         variables it covers. This may be zero for indefinitely many
         variables.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = TermOrder('lex')
             sage: len(T)
@@ -1938,7 +2030,7 @@ class TermOrder(SageObject):
 
         - ``i`` - index
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = TermOrder('lex')
             sage: T[0]
@@ -1967,7 +2059,7 @@ class TermOrder(SageObject):
         r"""
         Iterate over the blocks of this term order.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = TermOrder('lex')
             sage: list(T) # indirect doctest
@@ -1992,7 +2084,7 @@ class TermOrder(SageObject):
         global. Return false otherwise, which includes
         unknown term orders.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = TermOrder('lex')
             sage: T.is_global()
@@ -2020,7 +2112,7 @@ class TermOrder(SageObject):
         local. Return false otherwise, which includes
         unknown term orders.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: T = TermOrder('lex')
             sage: T.is_local()
@@ -2044,7 +2136,7 @@ class TermOrder(SageObject):
         """
         Return true if self is a block term order.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t=TermOrder('deglex',2)+TermOrder('lex',2)
             sage: t.is_block_order()
@@ -2056,7 +2148,7 @@ class TermOrder(SageObject):
         """
         Return true if self is a weighted degree term order.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: t=TermOrder('wdeglex',(2,3))
             sage: t.is_weighted_degree_order()
@@ -2079,7 +2171,7 @@ def termorder_from_singular(S):
     orders for modules. This is not taken into account in
     Sage.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: singular.eval('ring r1 = (9,x),(a,b,c,d,e,f),(M((1,2,3,0)),wp(2,3),lp)')
         ''
