@@ -32,6 +32,7 @@ AUTHORS:
 #
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
+from six import iteritems
 
 from sage.interfaces.all import magma
 from sage.rings.all import (Integer,
@@ -185,7 +186,7 @@ def cm_j_invariants(K, proof=None):
 
     (list) -- A list of CM `j`-invariants in the field `K`.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: cm_j_invariants(QQ)
         [-262537412640768000, -147197952000, -884736000, -12288000, -884736, -32768, -3375, 0, 1728, 8000, 54000, 287496, 16581375]
@@ -227,7 +228,7 @@ def cm_j_invariants_and_orders(K, proof=None):
     `j`-invariant in `K` with quadratic fundamental discriminant `D`
     and conductor `f`.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: cm_j_invariants_and_orders(QQ)
         [(-3, 3, -12288000), (-3, 2, 54000), (-3, 1, 0), (-4, 2, 287496), (-4, 1, 1728), (-7, 2, 16581375), (-7, 1, -3375), (-8, 1, 8000), (-11, 1, -32768), (-19, 1, -884736), (-43, 1, -884736000), (-67, 1, -147197952000), (-163, 1, -262537412640768000)]
@@ -254,10 +255,10 @@ def cm_j_invariants_and_orders(K, proof=None):
     # polynomial F(x) with a root in K.  If F(x) has a root alpha in K,
     # then F is the minimal polynomial of alpha in K, so the degree of
     # F(x) is at most [K:QQ].
-    dlist = sum([v for h,v in discriminants_with_bounded_class_number(K.degree(), proof=proof).iteritems()], [])
+    dlist = sum([v for h, v in iteritems(discriminants_with_bounded_class_number(K.degree(), proof=proof))], [])
 
-    return [(D,f,j) for D, f in dlist
-             for j in hilbert_class_polynomial(D*f*f).roots(K, multiplicities=False)]
+    return [(D, f, j) for D, f in dlist
+            for j in hilbert_class_polynomial(D*f*f).roots(K, multiplicities=False)]
 
 
 @cached_function
