@@ -269,9 +269,9 @@ class EllipticCurveLocalData(SageObject):
         if algorithm=="pari" and K is QQ:
             Eint = E.integral_model()
             data = Eint.pari_curve().elllocalred(p)
-            self._fp = data[0].python()
-            self._KS = KodairaSymbol(data[1].python())
-            self._cp = data[3].python()
+            self._fp = data[0].sage()
+            self._KS = KodairaSymbol(data[1].sage())
+            self._cp = data[3].sage()
             # We use a global minimal model since we can:
             self._Emin_reduced = Eint.minimal_model()
             self._val_disc = self._Emin_reduced.discriminant().valuation(p)
