@@ -103,6 +103,7 @@ from sage.categories.map import FormalCompositeMap, Map
 from sage.misc.constant_function import ConstantFunction
 from sage.categories.morphism import SetMorphism
 from sage.categories.morphism import Morphism
+from sage.schemes.generic.algebraic_scheme import AlgebraicScheme_subscheme
 
 coercion_model = get_coercion_model()
 
@@ -955,7 +956,7 @@ class SchemeMorphism_polynomial(SchemeMorphism):
                 except (TypeError, AttributeError):
                     raise TypeError("polys (=%s) must be elements of %s"%(polys, source_ring))
             polys = Sequence(polys)
-        self._polys = polys
+        self._polys = tuple(polys)
         SchemeMorphism.__init__(self, parent)
 
     def defining_polynomials(self):
@@ -973,7 +974,7 @@ class SchemeMorphism_polynomial(SchemeMorphism):
             sage: A.<x,y> = AffineSpace(R)
             sage: H = A.Hom(A)
             sage: H([x^3+y, 1-x-y]).defining_polynomials()
-            [x^3 + y, -x - y + 1]
+            (x^3 + y, -x - y + 1)
         """
         return self._polys
 
@@ -1453,6 +1454,103 @@ class SchemeMorphism_polynomial(SchemeMorphism):
                 G.append(f.change_ring(R))
         return(H(G, check))
 
+    def specialization(self, D=None, phi=None, homset=None):
+        r"""
+        Specialization of this map.
+
+        Given a family of maps defined over a polynomial ring. A specialization
+        is a particular member of that family. The specialization can be specified either
+        by a dictionary or a :class:`SpecializationMorphism`.
+
+        INPUT:
+
+        - ``D`` -- dictionary (optional)
+
+        - ``phi`` -- SpecializationMorphism (optional)
+
+        - ``homset`` -- homset of specialized map (optional)
+
+        OUTPUT: :class:`SchemeMorphism_polynomial`
+
+        EXAMPLES::
+
+            sage: R.<c> = PolynomialRing(QQ)
+            sage: P.<x,y> = ProjectiveSpace(R, 1)
+            sage: H = End(P)
+            sage: f = H([x^2 + c*y^2,y^2])
+            sage: f.specialization({c:1})
+            Scheme endomorphism of Projective Space of dimension 1 over Rational Field
+                  Defn: Defined on coordinates by sending (x : y) to
+                        (x^2 + y^2 : y^2)
+
+            ::
+
+            sage: R.<a,b> = PolynomialRing(QQ)
+            sage: P.<x,y> = ProjectiveSpace(R, 1)
+            sage: H = End(P)
+            sage: f = H([x^3 + a*x*y^2 + b*y^3, y^3])
+            sage: from sage.rings.polynomial.flatten import SpecializationMorphism
+            sage: phi = SpecializationMorphism(P.coordinate_ring(), dict({a:2,b:-1}))
+            sage: F = f.specialization(phi=phi); F
+            Scheme endomorphism of Projective Space of dimension 1 over Rational Field
+                  Defn: Defined on coordinates by sending (x : y) to
+                        (x^3 + 2*x*y^2 - y^3 : y^3)
+            sage: g = H([x^2 + a*y^2,y^2])
+            sage: G = g.specialization(phi=phi)
+            sage: G.parent() is F.parent()
+            False
+            sage: G = g.specialization(phi=phi, homset=F.parent())
+            sage: G.parent() is F.parent()
+            True
+
+        ::
+
+            sage: R.<c> = PolynomialRing(QQ)
+            sage: P.<x,y> = ProjectiveSpace(R, 1)
+            sage: X = P.subscheme([x - c*y])
+            sage: H = End(X)
+            sage: f = H([x^2, c*y^2])
+            sage: f.specialization({c:2})
+            Scheme endomorphism of Closed subscheme of Projective Space of dimension 1 over Rational Field defined by:
+                  x - 2*y
+                  Defn: Defined on coordinates by sending (x : y) to
+                        (x^2 : 2*y^2)
+
+        ::
+
+            sage: R.<c> = QQ[]
+            sage: P.<x,y> = ProjectiveSpace(R,1)
+            sage: H = End(P)
+            sage: f = H([x^2 + c*y^2, y^2])
+            sage: F = f.dynatomic_polynomial(3)
+            sage: g = F.specialization({c:1}); g
+            x^6 + x^5*y + 4*x^4*y^2 + 3*x^3*y^3 + 7*x^2*y^4 + 4*x*y^5 + 5*y^6
+            sage: g == f.specialization({c:1}).dynatomic_polynomial(3)
+            True
+        """
+        if D is None:
+            if phi is None:
+                raise ValueError("either the dictionary or the specialization must be provided")
+        else:
+            from sage.rings.polynomial.flatten import SpecializationMorphism
+            phi = SpecializationMorphism(self[0].parent(), D)
+        if homset is None:
+            domain = self.domain()
+            if isinstance(domain, AlgebraicScheme_subscheme):
+                domain = domain.specialization(phi=phi)
+            else:
+                domain = domain.change_ring(phi.codomain().base_ring())
+            if self.is_endomorphism():
+                homset = End(domain)
+            else:
+                codomain = self.codomain()
+                if isinstance(codomain, AlgebraicScheme_subscheme):
+                    codomain = codomain.specialization(phi=phi)
+                else:
+                    codomain = codomain.change_ring(phi.codomain().base_ring())
+                homset = Hom(domain, codomain)
+        return homset([phi(g) for g in self])
+
     def _composition_(self, other, homset):
         r"""
         Straightforward implementation of composition for scheme morphisms
@@ -1804,11 +1902,94 @@ class SchemeMorphism_point(SchemeMorphism):
 
         EXAMPLES::
 
-            sage: P.<x,y>=ProjectiveSpace(ZZ,1)
-            sage: Q=P(152,113)
-            sage: copy(Q) is Q
+            sage: P.<x,y> = ProjectiveSpace(ZZ, 1)
+            sage: Q = P(152, 113)
+            sage: Q2 = copy(Q)
+            sage: Q2 is Q
             False
-            sage: copy(Q) == Q
+            sage: Q2 == Q
             True
         """
         return(self._codomain.point(self._coords, check=False))
+
+    def specialization(self, D=None, phi=None, ambient=None):
+        r"""
+        Specialization of this point.
+
+        Given a family of points defined over a polynomial ring. A specialization
+        is a particular member of that family. The specialization can be specified either
+        by a dictionary or a :class:`SpecializationMorphism`.
+
+        INPUT:
+
+        - ``D`` -- dictionary (optional)
+
+        - ``phi`` -- SpecializationMorphism (optional)
+
+        - ``ambient`` -- ambient space of specialized point (optional)
+
+        OUTPUT: :class:`SchemeMorphism_polynomial`
+
+        EXAMPLES::
+
+            sage: R.<c> = PolynomialRing(QQ)
+            sage: P.<x,y> = ProjectiveSpace(R, 1)
+            sage: Q = P([c,1])
+            sage: Q.specialization({c:1})
+            (1 : 1)
+
+            ::
+
+            sage: R.<a,b> = PolynomialRing(QQ)
+            sage: P.<x,y> = ProjectiveSpace(R, 1)
+            sage: Q = P([a^2 + 2*a*b + 34, 1])
+            sage: from sage.rings.polynomial.flatten import SpecializationMorphism
+            sage: phi = SpecializationMorphism(P.coordinate_ring(),dict({a:2,b:-1}))
+            sage: T = Q.specialization(phi=phi); T
+            (34 : 1)
+            sage: Q2 = P([a,1])
+            sage: T2 = Q2.specialization(phi=phi)
+            sage: T2.codomain() is T.codomain()
+            False
+            sage: T3 = Q2.specialization(phi=phi, ambient=T.codomain())
+            sage: T3.codomain() is T.codomain()
+            True
+
+        ::
+
+            sage: R.<c> = PolynomialRing(QQ)
+            sage: P.<x,y> = ProjectiveSpace(R, 1)
+            sage: X = P.subscheme([x - c*y])
+            sage: Q = X([c, 1])
+            sage: Q2 = Q.specialization({c:2}); Q2
+            (2 : 1)
+            sage: Q2.codomain()
+            Closed subscheme of Projective Space of dimension 1 over Rational Field defined by:
+                  x - 2*y
+
+        ::
+
+            sage: R.<l> = PolynomialRing(QQ)
+            sage: S.<k,j> = PolynomialRing(R)
+            sage: K.<a,b,c,d> = S[]
+            sage: P.<x,y> = ProjectiveSpace(K, 1)
+            sage: H = End(P)
+            sage: Q = P([a^2,b^2])
+            sage: Q.specialization({a:2})
+            (4 : b^2)
+        """
+        if D is None:
+            if phi is None:
+                raise ValueError("either the dictionary or the specialization must be provided")
+        else:
+            from sage.rings.polynomial.flatten import SpecializationMorphism
+            phi = SpecializationMorphism(self.codomain().ambient_space().coordinate_ring(), D)
+        if ambient is None:
+            ambient = self.codomain()
+            if isinstance(ambient, AlgebraicScheme_subscheme):
+                ambient = ambient.specialization(phi=phi)
+            else:
+                ambient = ambient.change_ring(phi.codomain().base_ring())
+        psi = ambient.ambient_space().coordinate_ring().hom([0 for i in range(ambient.ambient_space().ngens())], ambient.base_ring())
+        return ambient([psi(phi(t)) for t in self])
+
