@@ -361,7 +361,7 @@ class KlyachkoBundle_class(SageObject):
         Let the cone be spanned by the rays `\sigma=\langle r_1,\dots,
         r_k\rangle`. This method returns the intersection
 
-        .. math::
+        .. MATH::
 
             \bigcap_{r\in \{r_1,\dots,r_k\}}
             E^{r}(i)
@@ -547,7 +547,7 @@ class KlyachkoBundle_class(SageObject):
 
         The restriction map
 
-        .. math::
+        .. MATH::
 
             E_\sigma(m) \to E_\tau(m)
 
@@ -644,10 +644,10 @@ class KlyachkoBundle_class(SageObject):
             codim = fan.dim() - dim
             d_C = C.differential(codim)
             d_V = []
-            for j in range(0, d_C.ncols()):
+            for j in range(d_C.ncols()):
                 tau = fan(dim)[j]
                 d_V_row = []
-                for i in range(0, d_C.nrows()):
+                for i in range(d_C.nrows()):
                     sigma = fan(dim-1)[i]
                     if sigma.is_face_of(tau):
                         pr = self.E_quotient_projection(sigma, tau, m)
@@ -700,7 +700,7 @@ class KlyachkoBundle_class(SageObject):
             Vector space of dimension 2 over Rational Field
             sage: V.cohomology(weight=(0,0), dim=True)
             (2, 0, 0)
-            sage: for i,j in cartesian_product((range(-2,3), range(-2,3))):
+            sage: for i,j in cartesian_product((list(range(-2,3)), list(range(-2,3)))):
             ....:       HH = V.cohomology(weight=(i,j), dim=True)
             ....:       if HH.is_zero(): continue
             ....:       print('H^*i(P^2, TP^2)_M({}, {}) = {}'.format(i,j,HH))
@@ -724,13 +724,13 @@ class KlyachkoBundle_class(SageObject):
         space_dim = self._variety.dimension()
         C_homology = C.homology()
         HH = dict()
-        for d in range(0, space_dim+1):
+        for d in range(space_dim+1):
             try:
                 HH[d] = C_homology[d]
             except KeyError:
                 HH[d] = FreeModule(self.base_ring(), 0)
         if dim:
-            HH = vector(ZZ, [HH[i].rank() for i in range(0, space_dim+1) ])
+            HH = vector(ZZ, [HH[i].rank() for i in range(space_dim+1) ])
         return HH
 
     def __cmp__(self, other):
