@@ -235,8 +235,8 @@ def Family(indices, function=None, hidden_keys=[], hidden_function=None, lazy=Fa
     called::
 
         sage: def compute_value(i):
-        ...       print('computing 2*'+str(i))
-        ...       return 2*i
+        ....:     print('computing 2*'+str(i))
+        ....:     return 2*i
         sage: f = Family([3,4,7], compute_value, hidden_keys=[2])
         computing 2*3
         computing 2*4
@@ -326,7 +326,7 @@ def Family(indices, function=None, hidden_keys=[], hidden_function=None, lazy=Fa
 
     ::
 
-        sage: f = Family(range(1,27), lambda i: chr(i+96))
+        sage: f = Family(list(range(1,27)), lambda i: chr(i+96))
         sage: f
             Finite family {1: 'a', 2: 'b', 3: 'c', 4: 'd', 5: 'e', 6: 'f', 7: 'g', 8: 'h', 9: 'i', 10: 'j', 11: 'k', 12: 'l', 13: 'm', 14: 'n', 15: 'o', 16: 'p', 17: 'q', 18: 'r', 19: 's', 20: 't', 21: 'u', 22: 'v', 23: 'w', 24: 'x', 25: 'y', 26: 'z'}
         sage: f[2]
