@@ -225,15 +225,21 @@ class Set_object(Set_generic):
             '<class 'sage.sets.set.Set_object_enumerated_with_category'>'
             and 'Integer Ring'
         """
+        from six.moves import range
         from sage.rings.integer import is_Integer
-        if isinstance(X, (int,long)) or is_Integer(X):
+        if isinstance(X, (int, long)) or is_Integer(X):
             # The coercion model will try to call Set_object(0)
             raise ValueError('underlying object cannot be an integer')
 
         category = Sets()
-        if X in Sets().Finite() or isinstance(X, (tuple,list,set,frozenset)):
+        if X in Sets().Finite() or isinstance(X, (tuple, list,
+                                                  set, frozenset)):
             category = Sets().Finite()
 
+        elif isinstance(X, range):
+            category = Sets().Finite()
+            X = tuple(X)
+
         Parent.__init__(self, category=category)
         self.__object = X
 
@@ -798,7 +804,7 @@ class Set_object_enumerated(Set_object):
             sage: X.list()
             [0, 1, c, c + 1, c^2, c^2 + 1, c^2 + c, c^2 + c + 1]
             sage: type(X.list())
-            <type 'list'>
+            <... 'list'>
 
         .. TODO::
 
@@ -826,7 +832,7 @@ class Set_object_enumerated(Set_object):
             sage: X.set()
             {0, 1, c, c + 1, c^2, c^2 + 1, c^2 + c, c^2 + c + 1}
             sage: type(X.set())
-            <type 'set'>
+            <... 'set'>
             sage: type(X)
             <class 'sage.sets.set.Set_object_enumerated_with_category'>
         """
@@ -854,7 +860,7 @@ class Set_object_enumerated(Set_object):
             -1390224788            # 32-bit
              561411537695332972    # 64-bit
             sage: type(s)
-            <type 'frozenset'>
+            <... 'frozenset'>
         """
         return frozenset(self.object())
 
