@@ -8,10 +8,10 @@ representative for each isomorphism class of graphs::
 
     sage: from sage.sets.set_from_iterator import EnumeratedSetFromIterator
     sage: E = EnumeratedSetFromIterator(
-    ...     graphs,
-    ...     name = "Graphs",
-    ...     category = InfiniteEnumeratedSets(),
-    ...     cache = True)
+    ....:   graphs,
+    ....:   name = "Graphs",
+    ....:   category = InfiniteEnumeratedSets(),
+    ....:   cache = True)
     sage: E
     Graphs
     sage: E.unrank(0)
@@ -27,7 +27,7 @@ The module also provides decorator for functions and methods::
 
     sage: from sage.sets.set_from_iterator import set_from_function
     sage: @set_from_function
-    ... def f(n): return xsrange(n)
+    ....: def f(n): return xsrange(n)
     sage: f(3)
     {0, 1, 2}
     sage: f(5)
@@ -37,9 +37,9 @@ The module also provides decorator for functions and methods::
 
     sage: from sage.sets.set_from_iterator import set_from_method
     sage: class A:
-    ...    @set_from_method
-    ...    def f(self,n):
-    ...        return xsrange(n)
+    ....:  @set_from_method
+    ....:  def f(self,n):
+    ....:      return xsrange(n)
     sage: a = A()
     sage: a.f(3)
     {0, 1, 2}
@@ -111,11 +111,11 @@ class EnumeratedSetFromIterator(Parent):
     The same example with a cache and a custom name::
 
         sage: E = EnumeratedSetFromIterator(
-        ...      graphs,
-        ...      args = (8,),
-        ...      category = FiniteEnumeratedSets(),
-        ...      name = "Graphs with 8 vertices",
-        ...      cache = True)
+        ....:    graphs,
+        ....:    args = (8,),
+        ....:    category = FiniteEnumeratedSets(),
+        ....:    name = "Graphs with 8 vertices",
+        ....:    cache = True)
         sage: E
         Graphs with 8 vertices
         sage: E.unrank(3)
@@ -210,9 +210,9 @@ class EnumeratedSetFromIterator(Parent):
             sage: from sage.sets.set_from_iterator import EnumeratedSetFromIterator
             sage: from sage.graphs.graph_generators import graphs
             sage: E = EnumeratedSetFromIterator(graphs,
-            ...      args=(3,),
-            ...      category=FiniteEnumeratedSets(),
-            ...      name="Graphs on 3 vertices")
+            ....:    args=(3,),
+            ....:    category=FiniteEnumeratedSets(),
+            ....:    name="Graphs on 3 vertices")
             sage: E
             Graphs on 3 vertices
             sage: F = loads(dumps(E)); F
@@ -404,7 +404,8 @@ class EnumeratedSetFromIterator(Parent):
         TESTS::
 
             sage: from sage.sets.set_from_iterator import EnumeratedSetFromIterator
-            sage: S = EnumeratedSetFromIterator(xrange, args=(1,4))
+            sage: from six.moves import range
+            sage: S = EnumeratedSetFromIterator(range, args=(1,4))
             sage: S(1)  # indirect doctest
             1
             sage: S(0)  # indirect doctest
@@ -572,10 +573,11 @@ class EnumeratedSetFromIterator_function_decorator(Decorator):
     EXAMPLES::
 
         sage: from sage.sets.set_from_iterator import set_from_function
+        sage: from six.moves import range
         sage: @set_from_function
-        ... def f(n):
-        ...    for i in xrange(n):
-        ...        yield i**2 + i + 1
+        ....: def f(n):
+        ....:     for i in range(n):
+        ....:         yield i**2 + i + 1
         sage: f(3)
         {1, 3, 7}
         sage: f(100)
@@ -586,11 +588,11 @@ class EnumeratedSetFromIterator_function_decorator(Decorator):
     :class:`EnumeratedSetFromIterator`::
 
         sage: @set_from_function(category=InfiniteEnumeratedSets())
-        ... def Fibonacci():
-        ...    a = 1; b = 2
-        ...    while True:
-        ...       yield a
-        ...       a,b = b,a+b
+        ....: def Fibonacci():
+        ....:     a = 1; b = 2
+        ....:     while True:
+        ....:         yield a
+        ....:         a, b = b, a + b
         sage: F = Fibonacci()
         sage: F
         {1, 2, 3, 5, 8, ...}
@@ -600,9 +602,9 @@ class EnumeratedSetFromIterator_function_decorator(Decorator):
     A simple example with many options::
 
         sage: @set_from_function(
-        ...        name = "From %(m)d to %(n)d",
-        ...        category = FiniteEnumeratedSets())
-        ... def f(m,n): return xsrange(m,n+1)
+        ....:      name = "From %(m)d to %(n)d",
+        ....:      category = FiniteEnumeratedSets())
+        ....: def f(m, n): return xsrange(m,n+1)
         sage: E = f(3,10); E
         From 3 to 10
         sage: E.list()
@@ -618,11 +620,11 @@ class EnumeratedSetFromIterator_function_decorator(Decorator):
     ``cached_method``::
 
         sage: @cached_function
-        ... @set_from_function(
-        ...    name = "Graphs on %(n)d vertices",
-        ...    category = FiniteEnumeratedSets(),
-        ...    cache = True)
-        ... def Graphs(n): return graphs(n)
+        ....: @set_from_function(
+        ....:  name = "Graphs on %(n)d vertices",
+        ....:  category = FiniteEnumeratedSets(),
+        ....:  cache = True)
+        ....: def Graphs(n): return graphs(n)
         sage: Graphs(10)
         Graphs on 10 vertices
         sage: Graphs(10).unrank(0)
@@ -633,11 +635,11 @@ class EnumeratedSetFromIterator_function_decorator(Decorator):
     The ``cached_function`` must go first::
 
         sage: @set_from_function(
-        ...    name = "Graphs on %(n)d vertices",
-        ...    category = FiniteEnumeratedSets(),
-        ...    cache = True)
-        ... @cached_function
-        ... def Graphs(n): return graphs(n)
+        ....:  name = "Graphs on %(n)d vertices",
+        ....:  category = FiniteEnumeratedSets(),
+        ....:  cache = True)
+        ....: @cached_function
+        ....: def Graphs(n): return graphs(n)
         sage: Graphs(10)
         Graphs on 10 vertices
         sage: Graphs(10).unrank(0)
@@ -753,7 +755,7 @@ class EnumeratedSetFromIterator_method_caller(Decorator):
             sage: loads(dumps(d.f()))
             Traceback (most recent call last):
             ...
-            PicklingError: Can't pickle <type 'function'>: attribute lookup __builtin__.function failed
+            PicklingError: Can't pickle <... 'function'>: attribute lookup __builtin__.function failed
         """
         self.inst = inst
         self.f = f
@@ -776,11 +778,11 @@ class EnumeratedSetFromIterator_method_caller(Decorator):
 
             sage: from sage.sets.set_from_iterator import set_from_method
             sage: class A:
-            ...    @set_from_method(name = lambda self,n: str(self)*n)
-            ...    def f(self,n):
-            ...        return xsrange(n)
-            ...    def __repr__(self):
-            ...        return "A"
+            ....:  @set_from_method(name = lambda self,n: str(self)*n)
+            ....:  def f(self,n):
+            ....:      return xsrange(n)
+            ....:  def __repr__(self):
+            ....:      return "A"
             sage: a = A()
             sage: a.f(3)                         # indirect doctest
             AAA
@@ -856,9 +858,9 @@ class EnumeratedSetFromIterator_method_decorator(object):
 
         sage: from sage.sets.set_from_iterator import set_from_method
         sage: class A():
-        ...    def n(self): return 12
-        ...    @set_from_method
-        ...    def f(self): return xsrange(self.n())
+        ....:  def n(self): return 12
+        ....:  @set_from_method
+        ....:  def f(self): return xsrange(self.n())
         sage: a = A()
         sage: print(a.f.__class__)
         sage.sets.set_from_iterator.EnumeratedSetFromIterator_method_caller
@@ -870,10 +872,10 @@ class EnumeratedSetFromIterator_method_decorator(object):
     A more complicated example with a parametrized name::
 
         sage: class B():
-        ...    @set_from_method(
-        ...        name = "Graphs(%(n)d)",
-        ...        category = FiniteEnumeratedSets())
-        ...    def graphs(self, n): return graphs(n)
+        ....:  @set_from_method(
+        ....:      name = "Graphs(%(n)d)",
+        ....:      category = FiniteEnumeratedSets())
+        ....:  def graphs(self, n): return graphs(n)
         sage: b = B()
         sage: G3 = b.graphs(3)
         sage: G3
@@ -888,13 +890,13 @@ class EnumeratedSetFromIterator_method_decorator(object):
     And a last example with a name parametrized by a function::
 
         sage: class D():
-        ...    def __init__(self, name): self.name = str(name)
-        ...    def __str__(self): return self.name
-        ...    @set_from_method(
-        ...        name = lambda self,n: str(self)*n,
-        ...        category = FiniteEnumeratedSets())
-        ...    def subset(self, n):
-        ...        return xsrange(n)
+        ....:  def __init__(self, name): self.name = str(name)
+        ....:  def __str__(self): return self.name
+        ....:  @set_from_method(
+        ....:      name = lambda self,n: str(self)*n,
+        ....:      category = FiniteEnumeratedSets())
+        ....:  def subset(self, n):
+        ....:      return xsrange(n)
         sage: d = D('a')
         sage: E = d.subset(3); E
         aaa
@@ -956,9 +958,9 @@ class EnumeratedSetFromIterator_method_decorator(object):
 
             sage: from sage.sets.set_from_iterator import set_from_method
             sage: class A:
-            ...    @set_from_method()    # indirect doctest
-            ...    def f(self):
-            ...        return xsrange(3)
+            ....:  @set_from_method()    # indirect doctest
+            ....:  def f(self):
+            ....:      return xsrange(3)
             sage: a = A()
             sage: a.f()
             {0, 1, 2}
@@ -971,9 +973,9 @@ class EnumeratedSetFromIterator_method_decorator(object):
 
             sage: from sage.sets.set_from_iterator import set_from_method
             sage: class A():
-            ...    def n(self): return 12
-            ...    @set_from_method
-            ...    def f(self): return xsrange(self.n())
+            ....:  def n(self): return 12
+            ....:  @set_from_method
+            ....:  def f(self): return xsrange(self.n())
             sage: a = A()
             sage: print(A.f.__class__)
             sage.sets.set_from_iterator.EnumeratedSetFromIterator_method_caller
