@@ -59,7 +59,7 @@ can be coerced into other systems or evaluated.
     sage: a = pi + e*4/5; a
     pi + 4/5*e
     sage: maxima(a)
-    %pi+4*%e/5
+    %pi+(4*%e)/5
     sage: RealField(15)(a)           # 15 *bits* of precision
     5.316
     sage: gp(a)
@@ -228,13 +228,11 @@ constants_name_table[repr(infinity)] = infinity
 constants_name_table[repr(unsigned_infinity)] = unsigned_infinity
 constants_name_table[repr(minus_infinity)] = minus_infinity
 
-import sage.symbolic.pynac
-sage.symbolic.pynac.register_symbol(infinity, {'maxima':'inf'})
-sage.symbolic.pynac.register_symbol(minus_infinity, {'maxima':'minf'})
-sage.symbolic.pynac.register_symbol(unsigned_infinity, {'maxima':'infinity'})
-
-from .pynac import I
-sage.symbolic.pynac.register_symbol(I, {'mathematica':'I'})
+from sage.libs.pynac.pynac import register_symbol, I
+register_symbol(infinity, {'maxima':'inf'})
+register_symbol(minus_infinity, {'maxima':'minf'})
+register_symbol(unsigned_infinity, {'maxima':'infinity'})
+register_symbol(I, {'mathematica':'I'})
 
 
 def unpickle_Constant(class_name, name, conversions, latex, mathml, domain):
@@ -286,13 +284,12 @@ class Constant(object):
             setattr(self, "_%s_"%system, partial(self._generic_interface, value))
             setattr(self, "_%s_init_"%system, partial(self._generic_interface_init, value))
 
-        from sage.symbolic.constants_c import PynacConstant
+        from sage.libs.pynac.constant import PynacConstant
         self._pynac = PynacConstant(self._name, self._latex, self._domain)
         self._serial = self._pynac.serial()
         constants_table[self._serial] = self
         constants_name_table[self._name] = self
 
-        from sage.symbolic.pynac import register_symbol
         register_symbol(self.expression(), self._conversions)
 
     def __eq__(self, other):
@@ -568,7 +565,7 @@ class Pi(Constant):
             <mi>&pi;</mi>
 
         """
-        conversions = dict(axiom='%pi', maxima='%pi', giac='pi', gp='Pi', kash='PI',
+        conversions = dict(axiom='%pi', fricas='%pi', maxima='%pi', giac='pi', gp='Pi', kash='PI',
                            mathematica='Pi', matlab='pi', maple='pi',
                            octave='pi', pari='Pi', pynac='Pi')
         Constant.__init__(self, name, conversions=conversions,
