@@ -18,8 +18,7 @@ from __future__ import print_function
 
 import operator as _operator
 from sage.rings.rational_field import QQ
-from sage.symbolic.ring import SR
-from sage.symbolic.pynac import I
+from sage.symbolic.all import I, SR
 from sage.functions.all import exp
 from sage.symbolic.operators import arithmetic_operators, relation_operators, FDerivativeOperator, add_vararg, mul_vararg
 from sage.functions.piecewise import piecewise
@@ -534,7 +533,7 @@ class InterfaceInit(Converter):
             sage: a = df.subs(x=exp(x)); a
             D[0](f)(e^x)
             sage: b = maxima(a); b
-            %at('diff('f(_SAGE_VAR_t0),_SAGE_VAR_t0,1),[_SAGE_VAR_t0=%e^_SAGE_VAR_x])
+            %at('diff('f(_SAGE_VAR_t0),_SAGE_VAR_t0,1),_SAGE_VAR_t0=%e^_SAGE_VAR_x)
             sage: bool(b.sage() == a)
             True
 
@@ -543,7 +542,7 @@ class InterfaceInit(Converter):
             sage: a = df.subs(x=4); a
             D[0](f)(4)
             sage: b = maxima(a); b
-            %at('diff('f(_SAGE_VAR_t0),_SAGE_VAR_t0,1),[_SAGE_VAR_t0=4])
+            %at('diff('f(_SAGE_VAR_t0),_SAGE_VAR_t0,1),_SAGE_VAR_t0=4)
             sage: bool(b.sage() == a)
             True
 
@@ -563,7 +562,7 @@ class InterfaceInit(Converter):
             sage: a = f_x.subs(x=4); a
             D[0](f)(4, y)
             sage: b = maxima(a); b
-            %at('diff('f(_SAGE_VAR_t0,_SAGE_VAR_t1),_SAGE_VAR_t0,1),[_SAGE_VAR_t0=4,_SAGE_VAR_t1=_SAGE_VAR_y])
+            %at('diff('f(_SAGE_VAR_t0,_SAGE_VAR_y),_SAGE_VAR_t0,1),_SAGE_VAR_t0=4)
             sage: bool(b.sage() == a)
             True
 
@@ -572,7 +571,7 @@ class InterfaceInit(Converter):
             sage: a = f_x.subs(x=4).subs(y=8); a
             D[0](f)(4, 8)
             sage: b = maxima(a); b
-            %at('diff('f(_SAGE_VAR_t0,_SAGE_VAR_t1),_SAGE_VAR_t0,1),[_SAGE_VAR_t0=4,_SAGE_VAR_t1=8])
+            %at('diff('f(_SAGE_VAR_t0,8),_SAGE_VAR_t0,1),_SAGE_VAR_t0=4)
             sage: bool(b.sage() == a)
             True
 
@@ -661,7 +660,7 @@ class SympyConverter(Converter):
     """
     Converts any expression to SymPy.
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: import sympy
         sage: var('x,y')
@@ -870,6 +869,25 @@ class AlgebraicConverter(Converter):
             Traceback (most recent call last):
             ...
             TypeError: unable to convert zeta(7) to Algebraic Field
+
+        Test :trac:`22571`::
+
+            sage: a.composition(exp(0, hold=True), exp)
+            1
+            sage: a.composition(exp(1, hold=True), exp)
+            Traceback (most recent call last):
+            ...
+            ValueError: unable to represent as an algebraic number
+            sage: a.composition(exp(pi*I*RR(1), hold=True), exp)
+            Traceback (most recent call last):
+            ...
+            TypeError: no canonical coercion from Real Field with 53 bits of precision to Rational Field
+            sage: a.composition(exp(pi*CC.gen(), hold=True), exp)
+            Traceback (most recent call last):
+            ...
+            TypeError: no canonical coercion from Real Field with 53 bits of precision to Rational Field
+            sage: bool(sin(pi*RR("0.7000000000000002")) > 0)
+            True
         """
         func = operator
         operand, = ex.operands()
@@ -878,16 +896,12 @@ class AlgebraicConverter(Converter):
         # Note that comparing functions themselves goes via maxima, and is SLOW
         func_name = repr(func)
         if func_name == 'exp':
-            rat_arg = (operand.imag()/(2*ex.parent().pi()))._rational_()
-            if rat_arg == 0:
-                # here we will either try and simplify, or return
-                raise ValueError("Unable to represent as an algebraic number.")
-            real = operand.real()
-            if real:
-                mag = exp(operand.real())._algebraic_(QQbar)
-            else:
-                mag = 1
-            res = mag * QQbar.zeta(rat_arg.denom())**rat_arg.numer()
+            if operand.real():
+                raise ValueError("unable to represent as an algebraic number")
+            # Coerce (not convert, see #22571) arg to a rational
+            arg = operand.imag()/(2*ex.parent().pi())
+            rat_arg = QQ.coerce(arg.pyobject())
+            res = QQbar.zeta(rat_arg.denom())**rat_arg.numer()
         elif func_name in ['sin', 'cos', 'tan']:
             exp_ia = exp(SR(-1).sqrt()*operand)._algebraic_(QQbar)
             if func_name == 'sin':
@@ -964,6 +978,10 @@ def algebraic(ex, field):
 class PolynomialConverter(Converter):
     def __init__(self, ex, base_ring=None, ring=None):
         """
+        A converter from symbolic expressions to polynomials.
+
+        See :func:`polynomial` for details.
+
         EXAMPLES::
 
             sage: from sage.symbolic.expression_conversions import PolynomialConverter
@@ -990,8 +1008,6 @@ class PolynomialConverter(Converter):
             Traceback (most recent call last):
             ...
             TypeError: y is not a variable of Univariate Polynomial Ring in x over Rational Field
-
-
         """
         if not (ring is None or base_ring is None):
             raise TypeError("either base_ring or ring must be specified, but not both")
@@ -1132,10 +1148,21 @@ class PolynomialConverter(Converter):
 
 def polynomial(ex, base_ring=None, ring=None):
     """
-    Returns a polynomial from the symbolic expression *ex*.  Either a
-    base ring *base_ring* or a polynomial ring *ring* can be specified
-    for the parent of result.  If just a base ring is given, then the variables
-    of the base ring will be the variables of the expression *ex*.
+    Return a polynomial from the symbolic expression ``ex``.
+
+    INPUT:
+
+    - ``ex`` -- a symbolic expression
+
+    - ``base_ring``, ``ring`` -- Either a
+      ``base_ring`` or a polynomial ``ring`` can be
+      specified for the parent of result.
+      If just a ``base_ring`` is given, then the variables
+      of the ``base_ring`` will be the variables of the expression ``ex``.
+
+    OUTPUT:
+
+    A polynomial.
 
     EXAMPLES::
 
@@ -1182,6 +1209,75 @@ def polynomial(ex, base_ring=None, ring=None):
     res = converter()
     return converter.ring(res)
 
+
+class LaurentPolynomialConverter(PolynomialConverter):
+    def __init__(self, ex, base_ring=None, ring=None):
+        """
+        A converter from symbolic expressions to Laurent polynomials.
+
+        See :func:`laurent_polynomial` for details.
+
+        TESTS::
+
+            sage: from sage.symbolic.expression_conversions import LaurentPolynomialConverter
+            sage: x, y = var('x,y')
+            sage: p = LaurentPolynomialConverter(x+1/y, base_ring=QQ)
+            sage: p.base_ring
+            Rational Field
+            sage: p.ring
+            Multivariate Laurent Polynomial Ring in x, y over Rational Field
+        """
+        super(LaurentPolynomialConverter, self).__init__(ex, base_ring, ring)
+
+        if ring is None and base_ring is not None:
+            from sage.rings.all import LaurentPolynomialRing
+            self.ring = LaurentPolynomialRing(self.base_ring,
+                                              names=self.varnames)
+
+
+def laurent_polynomial(ex, base_ring=None, ring=None):
+    """
+    Return a Laurent polynomial from the symbolic expression ``ex``.
+
+    INPUT:
+
+    - ``ex`` -- a symbolic expression
+
+    - ``base_ring``, ``ring`` -- Either a
+      ``base_ring`` or a laurent polynomial ``ring`` can be
+      specified for the parent of result.
+      If just a ``base_ring`` is given, then the variables
+      of the ``base_ring`` will be the variables of the expression ``ex``.
+
+    OUTPUT:
+
+    A Laurent polynomial.
+
+    EXAMPLES::
+
+         sage: from sage.symbolic.expression_conversions import laurent_polynomial
+         sage: f = x^2 + 2/x
+         sage: laurent_polynomial(f, base_ring=QQ)
+         2*x^-1 + x^2
+         sage: _.parent()
+         Univariate Laurent Polynomial Ring in x over Rational Field
+
+         sage: laurent_polynomial(f, ring=LaurentPolynomialRing(QQ, 'x, y'))
+         x^2 + 2*x^-1
+         sage: _.parent()
+         Multivariate Laurent Polynomial Ring in x, y over Rational Field
+
+         sage: x, y = var('x, y')
+         sage: laurent_polynomial(x + 1/y^2, ring=LaurentPolynomialRing(QQ, 'x, y'))
+         x + y^-2
+         sage: _.parent()
+         Multivariate Laurent Polynomial Ring in x, y over Rational Field
+    """
+    converter = LaurentPolynomialConverter(ex, base_ring=base_ring, ring=ring)
+    res = converter()
+    return converter.ring(res)
+
+
 ##############
 # Fast Float #
 ##############
@@ -1894,9 +1990,7 @@ class HoldRemover(ExpressionTreeWalker):
             arctan2(0, 0) + 1
             sage: h = HoldRemover(ex, [hypergeometric])
             sage: h()
-            Traceback (most recent call last):
-            ...
-            RuntimeError: arctan2_eval(): arctan2(0,0) encountered
+            NaN + hypergeometric((1, 2), (3, 4), 0)
         """
         self.ex = ex
         if exclude is None:
@@ -1914,8 +2008,12 @@ class HoldRemover(ExpressionTreeWalker):
             sage: h()
             0
         """
+        from sage.functions.other import Function_sum
+        from sage.calculus.calculus import symbolic_sum
         if not operator:
             return self
+        if isinstance(operator, Function_sum):
+            return symbolic_sum(*map(self, ex.operands()))
         if operator in self._exclude:
             return operator(*map(self, ex.operands()), hold=True)
         else:
