@@ -449,6 +449,19 @@ def test_relation_maxima(relation):
         sage: test_relation_maxima(f1 - f2 == 0)
         True
         sage: forget()
+        
+    In case one of the solutions while solving an equation is a real number::
+        
+        sage: var('K, d, R')
+        (K, d, R)
+        sage: assume(K>0)
+        sage: assume(K, 'noninteger')
+        sage: assume(R>0)
+        sage: assume(R<1)
+        sage: assume(d<R)
+        sage: assumptions()
+        [K > 0, K is noninteger, R > 0, R < 1, d < R]
+    
 
     """
     m = relation._maxima_()
@@ -731,7 +744,7 @@ def solve(f, *args, **kwds):
 
        sage: x,y=var('x y'); c1(x,y)=(x-5)^2+y^2-16; c2(x,y)=(y-3)^2+x^2-9
        sage: solve([c1(x,y),c2(x,y)],[x,y])
-       [[x == -9/68*sqrt(55) + 135/68, y == -15/68*sqrt(11)*sqrt(5) + 123/68], [x == 9/68*sqrt(55) + 135/68, y == 15/68*sqrt(11)*sqrt(5) + 123/68]]
+       [[x == -9/68*sqrt(55) + 135/68, y == -15/68*sqrt(55) + 123/68], [x == 9/68*sqrt(55) + 135/68, y == 15/68*sqrt(55) + 123/68]]
 
     TESTS::
 
@@ -743,7 +756,7 @@ def solve(f, *args, **kwds):
         TypeError:  The first argument must be a symbolic expression or a list of symbolic expressions.
 
     Test if the empty list is returned, too, when (a list of)
-    dictionaries (is) are requested (#8553)::
+    dictionaries (is) are requested (:trac:`8553`)::
 
         sage: solve([SR(0)==1],x)
         []
@@ -756,7 +769,7 @@ def solve(f, *args, **kwds):
         sage: solve((x==1,x==-1),x,solution_dict=0)
         []
 
-    Relaxed form, suggested by Mike Hansen (#8553)::
+    Relaxed form, suggested by Mike Hansen (:trac:`8553`)::
 
         sage: solve([x^2-1],x,solution_dict=-1)
         [{x: -1}, {x: 1}]
@@ -778,7 +791,7 @@ def solve(f, *args, **kwds):
         sage: solve([a+b+a*b == 1], a)
         Traceback (most recent call last):
         ...
-        TypeError: The first argument to solve() should be a symbolic expression or a list of symbolic expressions, cannot handle <type 'bool'>
+        TypeError: The first argument to solve() should be a symbolic expression or a list of symbolic expressions, cannot handle <... 'bool'>
         sage: solve([a, b], (1, a))
         Traceback (most recent call last):
         ...
