@@ -38,6 +38,8 @@ module element has then various representations over the various bases.
 AUTHORS:
 
 - Eric Gourgoulhon, Michal Bejger (2014-2015): initial version
+- Travis Scrimshaw (2016): category set to Modules(ring).FiniteDimensional()
+  (:trac:`20770`)
 
 REFERENCES:
 
@@ -517,6 +519,7 @@ The components on the basis are returned by the square bracket operator for
 #******************************************************************************
 #       Copyright (C) 2015 Eric Gourgoulhon <eric.gourgoulhon@obspm.fr>
 #       Copyright (C) 2015 Michal Bejger <bejger@camk.edu.pl>
+#       Copyright (C) 2016 Travis Scrimshaw <tscrimsh@umn.edu>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
@@ -828,7 +831,7 @@ class FiniteRankFreeModule(UniqueRepresentation, Parent):
         r"""
         Construct some (unamed) element of ``self``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: FiniteRankFreeModule._clear_cache_() # for doctests only
             sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
@@ -856,7 +859,7 @@ class FiniteRankFreeModule(UniqueRepresentation, Parent):
         r"""
         Return a string representation of ``self``.
 
-        EXAMPLE::
+        EXAMPLES::
 
             sage: FiniteRankFreeModule(ZZ, 3, name='M')
             Rank-3 free module M over the Integer Ring
@@ -1800,7 +1803,7 @@ class FiniteRankFreeModule(UniqueRepresentation, Parent):
         r"""
         Return the dual module of ``self``.
 
-        EXAMPLE:
+        EXAMPLES:
 
         Dual of a free module over `\ZZ`::
 
