@@ -24,7 +24,7 @@ def avg(X):
     """
     Return the average of the list X.
 
-    EXAMPLE:
+    EXAMPLES:
         sage: from sage.tests.benchmark import avg
         sage: avg([1,2,3])
         2.0
@@ -46,13 +46,13 @@ class Benchmark:
     functions must perform the same task for each function. Calling
     the run command with a list of systems will then show the timings.
 
-    EXAMPLE:
+    EXAMPLES:
         sage: from sage.tests.benchmark import Benchmark
         sage: B = Benchmark()
         sage: def python():
-        ...    t = cputime()
-        ...    n = 2+2
-        ...    return cputime(t)
+        ....:     t = cputime()
+        ....:     n = 2+2
+        ....:     return cputime(t)
         sage: B.python = python
         sage: B.run(systems=['python'])
         sage.tests.benchmark.Benchmark instance
@@ -129,7 +129,7 @@ class Benchmark:
         """
         Print representation of self, simply coming from self.repr_str.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Benchmark
             sage: B = Benchmark()
             sage: B.repr_str = 'spam'
@@ -166,7 +166,7 @@ class Divpoly(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Divpoly
             sage: B = Divpoly(3)
             sage: isinstance(B.sage(), float)
@@ -183,7 +183,7 @@ class Divpoly(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Divpoly
             sage: B = Divpoly(3)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -205,7 +205,7 @@ class PolySquare(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import PolySquare
             sage: B = PolySquare(3, QQ)
             sage: isinstance(B.sage(), float)
@@ -223,7 +223,7 @@ class PolySquare(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import PolySquare
             sage: B = PolySquare(3, QQ)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -240,7 +240,7 @@ class PolySquare(Benchmark):
         """
         Time the computation in Maple.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import PolySquare
             sage: B = PolySquare(3, QQ)
             sage: isinstance(B.maple()[1], float) # optional - maple
@@ -272,7 +272,7 @@ class MPolynomialPower(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialPower
             sage: B = MPolynomialPower()
             sage: isinstance(B.sage()[1], float)
@@ -294,7 +294,7 @@ class MPolynomialPower(Benchmark):
         """
         Time the computation in Macaulay2.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialPower
             sage: B = MPolynomialPower()
             sage: isinstance(B.macaulay2()[1], float) # optional - macaulay2
@@ -311,7 +311,7 @@ class MPolynomialPower(Benchmark):
         """
         Time the computation in Maxima.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialPower
             sage: B = MPolynomialPower()
             sage: isinstance(B.maxima()[1], float)
@@ -328,7 +328,7 @@ class MPolynomialPower(Benchmark):
         """
         Time the computation in Maple.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialPower
             sage: B = MPolynomialPower()
             sage: isinstance(B.maple()[1], float)  # optional - maple
@@ -345,7 +345,7 @@ class MPolynomialPower(Benchmark):
         """
         Time the computation in Mathematica.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialPower
             sage: B = MPolynomialPower()
             sage: isinstance(B.mathematica()[1], float) # optional - mathematica
@@ -372,7 +372,7 @@ class MPolynomialPower(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialPower
             sage: B = MPolynomialPower()
             sage: isinstance(B.magma(), float) # optional - magma
@@ -406,7 +406,7 @@ class MPolynomialMult(Benchmark):
         """
         Time the computation in Maxima.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult
             sage: B = MPolynomialMult()
             sage: isinstance(B.maxima()[1], float)
@@ -425,7 +425,7 @@ class MPolynomialMult(Benchmark):
         """
         Time the computation in Maple.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult
             sage: B = MPolynomialMult()
             sage: isinstance(B.maple()[1], float)  # optional - maple
@@ -444,7 +444,7 @@ class MPolynomialMult(Benchmark):
         """
         Time the computation in Mathematica.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult
             sage: B = MPolynomialMult()
             sage: isinstance(B.mathematica()[1], float) # optional - mathematica
@@ -472,7 +472,7 @@ class MPolynomialMult(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult
             sage: B = MPolynomialMult()
             sage: isinstance(B.sage()[1], float)
@@ -498,7 +498,7 @@ class MPolynomialMult(Benchmark):
         """
         Time the computation in Macaulay2.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult
             sage: B = MPolynomialMult()
             sage: isinstance(B.macaulay2()[1], float) # optional - macaulay2
@@ -517,7 +517,7 @@ class MPolynomialMult(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult
             sage: B = MPolynomialMult()
             sage: isinstance(B.magma(), float) # optional - magma
@@ -570,7 +570,7 @@ class MPolynomialMult2(Benchmark):
         """
         Time the computation in Maxima.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult2
             sage: B = MPolynomialMult2()
             sage: isinstance(B.maxima()[1], float)
@@ -595,7 +595,7 @@ class MPolynomialMult2(Benchmark):
         """
         Time the computation in Macaulay2.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult2
             sage: B = MPolynomialMult2()
             sage: isinstance(B.macaulay2()[1], float) # optional - macaulay2
@@ -620,7 +620,7 @@ class MPolynomialMult2(Benchmark):
         """
         Time the computation in Maple.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult2
             sage: B = MPolynomialMult2()
             sage: isinstance(B.maple()[1], float) # optional - maple
@@ -645,7 +645,7 @@ class MPolynomialMult2(Benchmark):
         """
         Time the computation in Mathematica.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult2
             sage: B = MPolynomialMult2()
             sage: isinstance(B.mathematica()[1], float) # optional - mathematica
@@ -670,7 +670,7 @@ class MPolynomialMult2(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult2
             sage: B = MPolynomialMult2()
             sage: isinstance(B.sage()[1], float)
@@ -700,7 +700,7 @@ class MPolynomialMult2(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MPolynomialMult2
             sage: B = MPolynomialMult2()
             sage: isinstance(B.magma(), float) # optional - magma
@@ -740,7 +740,7 @@ class CharPolyTp(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import CharPolyTp
             sage: B = CharPolyTp()
             sage: isinstance(B.sage(), float)
@@ -756,7 +756,7 @@ class CharPolyTp(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import CharPolyTp
             sage: B = CharPolyTp()
             sage: isinstance(B.gp(), float)
@@ -772,7 +772,7 @@ class CharPolyTp(Benchmark):
         """
         Time the computation in Pari.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import CharPolyTp
             sage: B = CharPolyTp()
             sage: isinstance(B.pari(), float)
@@ -788,7 +788,7 @@ class CharPolyTp(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import CharPolyTp
             sage: B = CharPolyTp()
             sage: isinstance(B.magma(), float) # optional - magma
@@ -813,7 +813,7 @@ class PolyFactor(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import PolyFactor
             sage: B = PolyFactor(3, QQ)
             sage: isinstance(B.sage(), float)
@@ -832,7 +832,7 @@ class PolyFactor(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import PolyFactor
             sage: B = PolyFactor(3, QQ)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -852,7 +852,7 @@ class PolyFactor(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import PolyFactor
             sage: B = PolyFactor(3, QQ)
             sage: isinstance(B.gp(), float)
@@ -880,7 +880,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.sage(), float)
@@ -896,7 +896,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.gp(), float)
@@ -912,7 +912,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in Maxima.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.maxima()[1], float)
@@ -928,7 +928,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.magma(), float) # optional - magma
@@ -944,7 +944,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in Python.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.python(), float)
@@ -960,7 +960,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in Maple.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.maple()[1], float) # optional - maple
@@ -976,7 +976,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in GAP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.gap()[1], float)
@@ -992,7 +992,7 @@ class SquareInts(Benchmark):
         """
         Time the computation in Mathematica.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SquareInts
             sage: B = SquareInts()
             sage: isinstance(B.mathematica()[1], float) # optional - mathematica
@@ -1015,7 +1015,7 @@ class MatrixSquare(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixSquare
             sage: B = MatrixSquare(3, QQ)
             sage: isinstance(B.sage(), float)
@@ -1033,7 +1033,7 @@ class MatrixSquare(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixSquare
             sage: B = MatrixSquare(3, QQ)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1051,7 +1051,7 @@ class MatrixSquare(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixSquare
             sage: B = MatrixSquare(3, QQ)
             sage: isinstance(B.gp(), float)
@@ -1068,7 +1068,7 @@ class MatrixSquare(Benchmark):
         """
         Time the computation in GAP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixSquare
             sage: B = MatrixSquare(3, QQ)
             sage: isinstance(B.gap()[1], float)
@@ -1091,7 +1091,7 @@ class Factorial(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Factorial
             sage: B = Factorial(10)
             sage: isinstance(B.sage(), float)
@@ -1106,7 +1106,7 @@ class Factorial(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Factorial
             sage: B = Factorial(10)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1121,7 +1121,7 @@ class Factorial(Benchmark):
         """
         Time the computation in Maple.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Factorial
             sage: B = Factorial(10)
             sage: isinstance(B.maple()[1], float) # optional - maple
@@ -1137,7 +1137,7 @@ class Factorial(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Factorial
             sage: B = Factorial(10)
             sage: isinstance(B.gp(), float)
@@ -1157,7 +1157,7 @@ class Fibonacci(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Fibonacci
             sage: B = Fibonacci(10)
             sage: isinstance(B.sage(), float)
@@ -1172,7 +1172,7 @@ class Fibonacci(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Fibonacci
             sage: B = Fibonacci(10)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1187,7 +1187,7 @@ class Fibonacci(Benchmark):
         """
         Time the computation in GAP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Fibonacci
             sage: B = Fibonacci(10)
             sage: isinstance(B.gap()[1], float)
@@ -1203,7 +1203,7 @@ class Fibonacci(Benchmark):
         """
         Time the computation in Mathematica.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Fibonacci
             sage: B = Fibonacci(10)
             sage: isinstance(B.mathematica()[1], float) # optional - mathematica
@@ -1219,7 +1219,7 @@ class Fibonacci(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import Fibonacci
             sage: B = Fibonacci(10)
             sage: isinstance(B.gp(), float)
@@ -1241,7 +1241,7 @@ class SEA(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SEA
             sage: B = SEA(5)
             sage: isinstance(B.sage()[1], float)
@@ -1261,7 +1261,7 @@ class SEA(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import SEA
             sage: B = SEA(5)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1283,7 +1283,7 @@ class MatrixKernel(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixKernel
             sage: B = MatrixKernel(3, QQ)
             sage: isinstance(B.sage(), float)
@@ -1301,7 +1301,7 @@ class MatrixKernel(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixKernel
             sage: B = MatrixKernel(3, QQ)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1319,7 +1319,7 @@ class MatrixKernel(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import MatrixKernel
             sage: B = MatrixKernel(3, QQ)
             sage: isinstance(B.gp(), float)
@@ -1342,7 +1342,7 @@ class ComplexMultiply(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ComplexMultiply
             sage: B = ComplexMultiply(28, 2)
             sage: isinstance(B.sage(), float)
@@ -1359,7 +1359,7 @@ class ComplexMultiply(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ComplexMultiply
             sage: B = ComplexMultiply(28, 2)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1381,7 +1381,7 @@ class ComplexMultiply(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ComplexMultiply
             sage: B = ComplexMultiply(28, 2)
             sage: isinstance(B.gp(), float)
@@ -1405,7 +1405,7 @@ class ModularSymbols1(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ModularSymbols1
             sage: B = ModularSymbols1(11)
             sage: isinstance(B.sage(), float)
@@ -1420,7 +1420,7 @@ class ModularSymbols1(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ModularSymbols1
             sage: B = ModularSymbols1(11)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1444,7 +1444,7 @@ class ModularSymbolsDecomp1(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ModularSymbolsDecomp1
             sage: B = ModularSymbolsDecomp1(11)
             sage: isinstance(B.sage(), float)
@@ -1460,7 +1460,7 @@ class ModularSymbolsDecomp1(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import ModularSymbolsDecomp1
             sage: B = ModularSymbolsDecomp1(11)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1482,7 +1482,7 @@ class EllipticCurveTraces(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurveTraces
             sage: B = EllipticCurveTraces(11)
             sage: isinstance(B.sage(), float)
@@ -1500,7 +1500,7 @@ class EllipticCurveTraces(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurveTraces
             sage: B = EllipticCurveTraces(11)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1521,7 +1521,7 @@ class EllipticCurvePointMul(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurvePointMul
             sage: B = EllipticCurvePointMul(11)
             sage: isinstance(B.sage(), float)
@@ -1538,7 +1538,7 @@ class EllipticCurvePointMul(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurvePointMul
             sage: B = EllipticCurvePointMul(11)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1555,7 +1555,7 @@ class EllipticCurvePointMul(Benchmark):
         """
         Time the computation in GP.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurvePointMul
             sage: B = EllipticCurvePointMul(11)
             sage: isinstance(B.gp(), float)
@@ -1572,7 +1572,7 @@ class EllipticCurvePointMul(Benchmark):
         """
         Time the computation in Pari.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurvePointMul
             sage: B = EllipticCurvePointMul(11)
             sage: isinstance(B.pari(), float)
@@ -1594,7 +1594,7 @@ class EllipticCurveMW(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurveMW
             sage: B = EllipticCurveMW([1,2,3,4,5])
             sage: isinstance(B.sage()[1], float)
@@ -1610,7 +1610,7 @@ class EllipticCurveMW(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import EllipticCurveMW
             sage: B = EllipticCurveMW([1,2,3,4,5])
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1634,7 +1634,7 @@ class FiniteExtFieldMult(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldMult
             sage: B = FiniteExtFieldMult(GF(9, 'x'), 2)
             sage: isinstance(B.sage(), float)
@@ -1651,7 +1651,7 @@ class FiniteExtFieldMult(Benchmark):
         """
         Time the computation in Pari.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldMult
             sage: B = FiniteExtFieldMult(GF(9, 'x'), 2)
             sage: isinstance(B.pari(), float)
@@ -1668,7 +1668,7 @@ class FiniteExtFieldMult(Benchmark):
         """
         Time the computation in Givaro.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldMult
             sage: B = FiniteExtFieldMult(GF(9, 'x'), 2)
             sage: isinstance(B.givaro(), float)
@@ -1690,7 +1690,7 @@ class FiniteExtFieldMult(Benchmark):
 
         TODO: nck?
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldMult
             sage: B = FiniteExtFieldMult(GF(9, 'x'), 2)
             sage: isinstance(B.givaro_nck(), float)
@@ -1712,7 +1712,7 @@ class FiniteExtFieldMult(Benchmark):
 
         TODO: raw?
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldMult
             sage: B = FiniteExtFieldMult(GF(9, 'x'), 2)
             sage: isinstance(B.givaro_raw(), float)
@@ -1732,7 +1732,7 @@ class FiniteExtFieldMult(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldMult
             sage: B = FiniteExtFieldMult(GF(9, 'x'), 2)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1758,7 +1758,7 @@ class FiniteExtFieldAdd(Benchmark):
         """
         Time the computation in Sage.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldAdd
             sage: B = FiniteExtFieldAdd(GF(9,'x'), 2)
             sage: isinstance(B.sage(), float)
@@ -1775,7 +1775,7 @@ class FiniteExtFieldAdd(Benchmark):
         """
         Time the computation in Pari.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldAdd
             sage: B = FiniteExtFieldAdd(GF(9,'x'), 2)
             sage: isinstance(B.pari(), float)
@@ -1792,7 +1792,7 @@ class FiniteExtFieldAdd(Benchmark):
         """
         Time the computation in Givaro.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldAdd
             sage: B = FiniteExtFieldAdd(GF(9,'x'), 2)
             sage: isinstance(B.givaro(), float)
@@ -1814,7 +1814,7 @@ class FiniteExtFieldAdd(Benchmark):
 
         TODO: nck?
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldAdd
             sage: B = FiniteExtFieldAdd(GF(9,'x'), 2)
             sage: isinstance(B.givaro_nck(), float)
@@ -1836,7 +1836,7 @@ class FiniteExtFieldAdd(Benchmark):
 
         TODO: raw?
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldAdd
             sage: B = FiniteExtFieldAdd(GF(9, 'x'), 2)
             sage: isinstance(B.givaro_raw(), float)
@@ -1856,7 +1856,7 @@ class FiniteExtFieldAdd(Benchmark):
         """
         Time the computation in Magma.
 
-        EXAMPLE:
+        EXAMPLES:
             sage: from sage.tests.benchmark import FiniteExtFieldAdd
             sage: B = FiniteExtFieldAdd(GF(9,'x'), 2)
             sage: isinstance(B.magma(), float) # optional - magma
@@ -1959,7 +1959,7 @@ def mpoly_all(include_maple=False):
        * mathematica is sometimes amazing.
        * macaulay2 is also quite bad (though not as bad as maple).
 
-    EXAMPLE::
+    EXAMPLES::
 
         sage: from sage.tests.benchmark import mpoly_all
         sage: mpoly_all() # not tested
