@@ -1,8 +1,13 @@
 #!/usr/bin/env python
 from __future__ import print_function
 
-import os, sys, time, errno, platform, subprocess, glob
+import os, sys, time, errno, platform, subprocess
+from distutils import log
 from distutils.core import setup, DistutilsSetupError
+from distutils.command.build_ext import build_ext
+from distutils.command.install import install
+from distutils.dep_util import newer_group
+
 
 def excepthook(*exc):
     """
@@ -24,7 +29,7 @@ def excepthook(*exc):
     try:
         logfile = os.path.join(os.environ['SAGE_LOGS'],
                 "sagelib-%s.log" % os.environ['SAGE_VERSION'])
-    except:
+    except Exception:
         pass
     else:
         print("Please email sage-devel (http://groups.google.com/group/sage-devel)", file=sys.stderr)
@@ -95,15 +100,6 @@ if DEVEL:
 if subprocess.call("""$CC --version | grep -i 'gcc.* 4[.]8' >/dev/null """, shell=True) == 0:
     extra_compile_args.append('-fno-tree-copyrename')
 
-#########################################################
-### Generate some Python/Cython sources
-#########################################################
-
-make = os.environ.get("MAKE", 'make')
-make_cmdline = "{} -f generate_py_source.mk SAGE_SRC={}".format(make, sage.env.SAGE_SRC)
-status = subprocess.call(make_cmdline, shell=True)
-if status != 0:
-    raise DistutilsSetupError("{} failed".format(make_cmdline))
 
 #########################################################
 ### Testing related stuff
@@ -339,12 +335,115 @@ def execute_list_of_commands(command_list):
 ##
 ########################################################################
 
-from distutils.command.build_ext import build_ext
-from distutils.command.install import install
-from distutils.dep_util import newer_group
-from distutils import log
-
 class sage_build_ext(build_ext):
+    def finalize_options(self):
+        build_ext.finalize_options(self)
+        log.warn("Updating Cython code....")
+        t = time.time()
+        self.run_cython()
+        log.warn("Finished Cythonizing, time: %.2f seconds." % (time.time() - t))
+        self.copy_extra_files()
+        self.check_flags()
+
+    def run_cython(self):
+        """
+        Call ``cythonize()`` to replace the ``ext_modules`` with the
+        extensions containing Cython-generated C code.
+        """
+        from Cython.Build import cythonize
+        import Cython.Compiler.Options
+
+        Cython.Compiler.Options.embed_pos_in_docstring = True
+
+        debug = False
+        if os.environ.get('SAGE_DEBUG', None) != 'no':
+            log.info('Enabling Cython debugging support')
+            debug = True
+
+        profile = False
+        if os.environ.get('SAGE_PROFILE', None) == 'yes':
+            log.info('Enabling Cython profiling support')
+            profile = True
+
+        # We check the Cython version and some relevant configuration
+        # options from the earlier build to see if we need to force a
+        # recythonization. If the version or options have changed, we
+        # must recythonize all files.
+        version_file = os.path.join(SAGE_CYTHONIZED, '.cython_version')
+        version_stamp = '\n'.join([
+            'cython version: ' + str(Cython.__version__),
+            'debug: ' + str(debug),
+            'profile: ' + str(profile),
+        ""])
+        try:
+            if open(version_file).read() == version_stamp:
+                force = False
+            else:
+                # version_file exists but its contents are not what we
+                # want => recythonize all Cython code.
+                force = True
+                # In case this cythonization is interrupted, we end up
+                # in an inconsistent state with C code generated by
+                # different Cython versions or with different options.
+                # To ensure that this inconsistent state will be fixed,
+                # we remove the version_file now to force a
+                # recythonization the next time we build Sage.
+                os.unlink(version_file)
+        except IOError:
+            # Most likely, the version_file does not exist
+            # => (re)cythonize all Cython code.
+            force = True
+
+        # We use [:] to change the list in-place because the same list
+        # object is pointed to from different places.
+        self.extensions[:] = cythonize(
+            self.extensions,
+            nthreads=int(os.environ.get('SAGE_NUM_THREADS', 0)),
+            build_dir=SAGE_CYTHONIZED,
+            force=force,
+            aliases=aliases,
+            compiler_directives={
+                'autotestdict': False,
+                'cdivision': True,
+                'embedsignature': True,
+                'fast_getattr': True,
+                'profile': profile,
+            },
+            # Debugging
+            gdb_debug=debug,
+            output_dir=SAGE_CYTHONIZED,
+            # Disable Cython caching, which is currently too broken to
+            # use reliably: http://trac.sagemath.org/ticket/17851
+            cache=False,
+            )
+
+        open(version_file, 'w').write(version_stamp)
+
+    def check_flags(self):
+        """
+        Sanity check the compiler flags used to build the extensions
+        """
+        forbidden = None
+        if os.environ.get("SAGE_FAT_BINARY") == "yes":
+            # When building with SAGE_FAT_BINARY=yes, we should not
+            # enable CPU features which do not exist on every CPU.
+            # Such flags usually come from other libraries adding the
+            # flags to the pkgconfig configuration.  So if you hit these
+            # errors, the problem is most likely with some external
+            # library and not with Sage.
+            import re
+            forbidden = re.compile(r"-march=|-mpcu=|-msse3|-msse4|-mpopcnt|-mavx")
+
+        if forbidden is not None:
+            errors = 0
+            for ext in self.extensions:
+                flags = ext.extra_compile_args
+                for flag in flags:
+                    if forbidden.match(flag):
+                        log.error("%s uses forbidden flag '%s'", ext.name, flag)
+                        errors += 1
+            if errors:
+                raise RuntimeError("forbidden flags used")
 
     def build_extensions(self):
 
@@ -550,76 +649,31 @@ class sage_build_ext(build_ext):
             build_temp=self.build_temp,
             target_lang=language)
 
+    def copy_extra_files(self):
+        """
+        Copy extra Cython files to the build directory. These will then
+        be installed in site-packages/sage.
+        """
+        dist = self.distribution
+        from sage_setup.find import find_extra_files
+        self.cythonized_files = find_extra_files(dist.packages,
+            ".", SAGE_CYTHONIZED, ["ntlwrap.cpp"])
 
+        for (dst_dir, src_files) in self.cythonized_files:
+            dst = os.path.join(self.build_lib, dst_dir)
+            for src in src_files:
+                self.copy_file(src, dst, preserve_mode=False)
 
+#########################################################
+### Generating auto-generated Sources
+### This must be done before discovering and building
+### the python modules. See #22094.
+#########################################################
 
-#############################################
-###### Cythonize
-#############################################
-
-def run_cythonize():
-    from Cython.Build import cythonize
-    import Cython.Compiler.Options
-    import Cython.Compiler.Main
-
-    # Sage uses these directives (mostly for historical reasons).
-    Cython.Compiler.Options.embed_pos_in_docstring = True
-    Cython.Compiler.Options.directive_defaults['autotestdict'] = False
-    Cython.Compiler.Options.directive_defaults['cdivision'] = True
-    Cython.Compiler.Options.directive_defaults['fast_getattr'] = True
-    # The globals() builtin in Cython was fixed to return to the current scope,
-    # but Sage relies on the broken behavior of returning to the nearest
-    # enclosing Python scope (e.g. to perform variable injection).
-    Cython.Compiler.Options.old_style_globals = True
-
-    debug = False
-    if os.environ.get('SAGE_DEBUG', None) != 'no':
-        print('Enabling Cython debugging support')
-        debug = True
-        Cython.Compiler.Main.default_options['gdb_debug'] = True
-        Cython.Compiler.Main.default_options['output_dir'] = build_base
-
-    profile = False
-    if os.environ.get('SAGE_PROFILE', None) == 'yes':
-        print('Enabling Cython profiling support')
-        profile = True
-
-    # Disable Cython caching (the cache is stored in ~/.cycache which is
-    # Cython's default).
-    # Cycache is currently too broken to use reliably:
-    # http://trac.sagemath.org/ticket/17851
-    Cython.Compiler.Main.default_options['cache'] = False
-
-    force = True
-    version_file = os.path.join(SAGE_CYTHONIZED, '.cython_version')
-    version_stamp = '\n'.join([
-        'cython version: ' + str(Cython.__version__),
-        'debug: ' + str(debug),
-        'profile: ' + str(profile),
-    ""])
-    if os.path.exists(version_file) and open(version_file).read() == version_stamp:
-        force = False
-
-    global ext_modules
-    ext_modules = cythonize(
-        ext_modules,
-        nthreads=int(os.environ.get('SAGE_NUM_THREADS', 0)),
-        build_dir=SAGE_CYTHONIZED,
-        force=force,
-        aliases=aliases,
-        compiler_directives={
-            'embedsignature': True,
-            'profile': profile,
-        })
-
-    open(version_file, 'w').write(version_stamp)
-
-
-print("Updating Cython code....")
-t = time.time()
-run_cythonize()
-print("Finished Cythonizing, time: %.2f seconds." % (time.time() - t))
+log.info("Generating auto-generated sources")
+from sage_setup.autogen import autogen_all
 
+autogen_all()
 
 #########################################################
 ### Discovering Sources
@@ -627,49 +681,76 @@ print("Finished Cythonizing, time: %.2f seconds." % (time.time() - t))
 
 print("Discovering Python/Cython source code....")
 t = time.time()
-from sage_setup.find import find_python_sources, find_extra_files
+from sage_setup.find import find_python_sources
 python_packages, python_modules = find_python_sources(
     SAGE_SRC, ['sage', 'sage_setup'])
-python_data_files = find_extra_files(python_packages,
-    ".", SAGE_CYTHONIZED, SAGE_LIB, ["ntlwrap.cpp"])
 
 log.info('python_packages = {0}'.format(python_packages))
-log.info('python_modules = {0}'.format(python_modules))
-log.info('python_data_files = {0}'.format(python_data_files))
 
 print("Discovered Python/Cython sources, time: %.2f seconds." % (time.time() - t))
 
 
 #########################################################
-### Clean
+### Install Jupyter kernel spec and clean stale files
 #########################################################
 
-print('Cleaning up stale installed files....')
-t = time.time()
-from sage_setup.clean import clean_install_dir
-output_dirs = SITE_PACKAGES + glob.glob(os.path.join(build_base, 'lib*'))
-for output_dir in output_dirs:
-    print('- cleaning {0}'.format(output_dir))
-    clean_install_dir(output_dir, python_packages, python_modules,
-            ext_modules, python_data_files)
-print('Finished cleaning, time: %.2f seconds.' % (time.time() - t))
-
-
-#########################################################
-### Install also Jupyter kernel spec
-#########################################################
-
-# We cannot just add the installation of the kernel spec to data_files
-# since the file is generated, not copied.
 class sage_install(install):
     def run(self):
         install.run(self)
         self.install_kernel_spec()
+        log.warn('Cleaning up stale installed files....')
+        t = time.time()
+        self.clean_stale_files()
+        log.warn('Finished cleaning, time: %.2f seconds.' % (time.time() - t))
 
     def install_kernel_spec(self):
+        """
+        Install the Jupyter kernel spec.
+
+        .. NOTE::
+
+            The files are generated, not copied. Therefore, we cannot
+            use ``data_files`` for this.
+        """
         from sage.repl.ipython_kernel.install import SageKernelSpec
         SageKernelSpec.update()
 
+    def clean_stale_files(self):
+        """
+        Remove stale installed files.
+
+        This removes files which are built/installed but which do not
+        exist in the Sage sources (typically because some source file
+        has been deleted). Files are removed from the build directory
+        ``build/lib-*`` and from the install directory ``site-packages``.
+        """
+        dist = self.distribution
+        cmd_build_py = dist.get_command_obj("build_py")
+        cmd_build_py.ensure_finalized()
+        cmd_build_ext = dist.get_command_obj("build_ext")
+        cmd_build_ext.ensure_finalized()
+
+        # Determine all Python modules inside all packages
+        py_modules = []
+        for package in dist.packages:
+            package_dir = cmd_build_py.get_package_dir(package)
+            py_modules += cmd_build_py.find_package_modules(package, package_dir)
+        # modules is a list of triples (package, module, module_file).
+        # Construct the complete module name from this.
+        py_modules = ["{0}.{1}".format(*m) for m in py_modules]
+
+        # Clean install directory (usually, purelib and platlib are the same)
+        # and build directory.
+        output_dirs = [self.install_purelib, self.install_platlib, self.build_lib]
+        from sage_setup.clean import clean_install_dir
+        for output_dir in set(output_dirs):
+            log.warn('- cleaning {0}'.format(output_dir))
+            clean_install_dir(output_dir,
+                    dist.packages,
+                    py_modules,
+                    dist.ext_modules,
+                    cmd_build_ext.cythonized_files)
+
 
 #########################################################
 ### Distutils
@@ -683,7 +764,5 @@ code = setup(name = 'sage',
       author_email= 'http://groups.google.com/group/sage-support',
       url         = 'http://www.sagemath.org',
       packages    = python_packages,
-      data_files  = python_data_files,
-      scripts = [],
       cmdclass = dict(build_ext=sage_build_ext, install=sage_install),
       ext_modules = ext_modules)
